echo script type: R
echo ">>>>>>>>running test 1"
../source/print_tokens2.exe  < ../inputs/newtst148.tst > ../originals/t1
echo ">>>>>>>>running test 2"
../source/print_tokens2.exe  < ../inputs/newtst1.tst > ../originals/t2
echo ">>>>>>>>running test 3"
../source/print_tokens2.exe  < ../inputs/newtst1.tst.tst > ../originals/t3
echo ">>>>>>>>running test 4"
../source/print_tokens2.exe  < ../inputs/newtst10.tst > ../originals/t4
echo ">>>>>>>>running test 5"
../source/print_tokens2.exe  < ../inputs/newtst100.tst > ../originals/t5
echo ">>>>>>>>running test 6"
../source/print_tokens2.exe  < ../inputs/newtst101.tst > ../originals/t6
echo ">>>>>>>>running test 7"
../source/print_tokens2.exe  < ../inputs/newtst102.tst > ../originals/t7
echo ">>>>>>>>running test 8"
../source/print_tokens2.exe  < ../inputs/newtst103.tst > ../originals/t8
echo ">>>>>>>>running test 9"
../source/print_tokens2.exe  < ../inputs/newtst104.tst > ../originals/t9
echo ">>>>>>>>running test 10"
../source/print_tokens2.exe  < ../inputs/newtst105.tst > ../originals/t10
echo ">>>>>>>>running test 11"
../source/print_tokens2.exe  < ../inputs/newtst106.tst > ../originals/t11
echo ">>>>>>>>running test 12"
../source/print_tokens2.exe  < ../inputs/newtst107.tst > ../originals/t12
echo ">>>>>>>>running test 13"
../source/print_tokens2.exe  < ../inputs/newtst108.tst > ../originals/t13
echo ">>>>>>>>running test 14"
../source/print_tokens2.exe  < ../inputs/newtst109.tst > ../originals/t14
echo ">>>>>>>>running test 15"
../source/print_tokens2.exe  < ../inputs/newtst11.tst > ../originals/t15
echo ">>>>>>>>running test 16"
../source/print_tokens2.exe  < ../inputs/newtst110.tst > ../originals/t16
echo ">>>>>>>>running test 17"
../source/print_tokens2.exe  < ../inputs/newtst111.tst > ../originals/t17
echo ">>>>>>>>running test 18"
../source/print_tokens2.exe  < ../inputs/newtst112.tst > ../originals/t18
echo ">>>>>>>>running test 19"
../source/print_tokens2.exe  < ../inputs/newtst113.tst > ../originals/t19
echo ">>>>>>>>running test 20"
../source/print_tokens2.exe  < ../inputs/newtst114.tst > ../originals/t20
echo ">>>>>>>>running test 21"
../source/print_tokens2.exe  < ../inputs/newtst115.tst > ../originals/t21
echo ">>>>>>>>running test 22"
../source/print_tokens2.exe  < ../inputs/newtst116.tst > ../originals/t22
echo ">>>>>>>>running test 23"
../source/print_tokens2.exe  < ../inputs/newtst117.tst > ../originals/t23
echo ">>>>>>>>running test 24"
../source/print_tokens2.exe  < ../inputs/newtst118.tst > ../originals/t24
echo ">>>>>>>>running test 25"
../source/print_tokens2.exe  < ../inputs/newtst119.tst > ../originals/t25
echo ">>>>>>>>running test 26"
../source/print_tokens2.exe  < ../inputs/newtst12.tst > ../originals/t26
echo ">>>>>>>>running test 27"
../source/print_tokens2.exe  < ../inputs/newtst120.tst > ../originals/t27
echo ">>>>>>>>running test 28"
../source/print_tokens2.exe  < ../inputs/newtst121.tst > ../originals/t28
echo ">>>>>>>>running test 29"
../source/print_tokens2.exe  < ../inputs/newtst122.tst > ../originals/t29
echo ">>>>>>>>running test 30"
../source/print_tokens2.exe  < ../inputs/newtst123.tst > ../originals/t30
echo ">>>>>>>>running test 31"
../source/print_tokens2.exe  < ../inputs/newtst124.tst > ../originals/t31
echo ">>>>>>>>running test 32"
../source/print_tokens2.exe  < ../inputs/newtst125.tst > ../originals/t32
echo ">>>>>>>>running test 33"
../source/print_tokens2.exe  < ../inputs/newtst126.tst > ../originals/t33
echo ">>>>>>>>running test 34"
../source/print_tokens2.exe  < ../inputs/newtst127.tst > ../originals/t34
echo ">>>>>>>>running test 35"
../source/print_tokens2.exe  < ../inputs/newtst128.tst > ../originals/t35
echo ">>>>>>>>running test 36"
../source/print_tokens2.exe  < ../inputs/newtst129.tst > ../originals/t36
echo ">>>>>>>>running test 37"
../source/print_tokens2.exe  < ../inputs/newtst13.tst > ../originals/t37
echo ">>>>>>>>running test 38"
../source/print_tokens2.exe  < ../inputs/newtst130.tst > ../originals/t38
echo ">>>>>>>>running test 39"
../source/print_tokens2.exe  < ../inputs/newtst131.tst > ../originals/t39
echo ">>>>>>>>running test 40"
../source/print_tokens2.exe  < ../inputs/newtst132.tst > ../originals/t40
echo ">>>>>>>>running test 41"
../source/print_tokens2.exe  < ../inputs/newtst133.tst > ../originals/t41
echo ">>>>>>>>running test 42"
../source/print_tokens2.exe  < ../inputs/newtst134.tst > ../originals/t42
echo ">>>>>>>>running test 43"
../source/print_tokens2.exe  < ../inputs/newtst135.tst > ../originals/t43
echo ">>>>>>>>running test 44"
../source/print_tokens2.exe  < ../inputs/newtst136.tst > ../originals/t44
echo ">>>>>>>>running test 45"
../source/print_tokens2.exe  < ../inputs/newtst137.tst > ../originals/t45
echo ">>>>>>>>running test 46"
../source/print_tokens2.exe  < ../inputs/newtst138.tst > ../originals/t46
echo ">>>>>>>>running test 47"
../source/print_tokens2.exe  < ../inputs/newtst139.tst > ../originals/t47
echo ">>>>>>>>running test 48"
../source/print_tokens2.exe  < ../inputs/newtst14.tst > ../originals/t48
echo ">>>>>>>>running test 49"
../source/print_tokens2.exe  < ../inputs/newtst140.tst > ../originals/t49
echo ">>>>>>>>running test 50"
../source/print_tokens2.exe  < ../inputs/newtst141.tst > ../originals/t50
echo ">>>>>>>>running test 51"
../source/print_tokens2.exe  < ../inputs/newtst142.tst > ../originals/t51
echo ">>>>>>>>running test 52"
../source/print_tokens2.exe  < ../inputs/newtst143.tst > ../originals/t52
echo ">>>>>>>>running test 53"
../source/print_tokens2.exe  < ../inputs/newtst144.tst > ../originals/t53
echo ">>>>>>>>running test 54"
../source/print_tokens2.exe  < ../inputs/newtst145.tst > ../originals/t54
echo ">>>>>>>>running test 55"
../source/print_tokens2.exe  < ../inputs/newtst146.tst > ../originals/t55
echo ">>>>>>>>running test 56"
../source/print_tokens2.exe  < ../inputs/newtst147.tst > ../originals/t56
echo ">>>>>>>>running test 57"
../source/print_tokens2.exe  < ../inputs/newtst149.tst > ../originals/t57
echo ">>>>>>>>running test 58"
../source/print_tokens2.exe  < ../inputs/newtst15.tst > ../originals/t58
echo ">>>>>>>>running test 59"
../source/print_tokens2.exe  < ../inputs/newtst150.tst > ../originals/t59
echo ">>>>>>>>running test 60"
../source/print_tokens2.exe  < ../inputs/newtst151.tst > ../originals/t60
echo ">>>>>>>>running test 61"
../source/print_tokens2.exe  < ../inputs/newtst152.tst > ../originals/t61
echo ">>>>>>>>running test 62"
../source/print_tokens2.exe  < ../inputs/newtst153.tst > ../originals/t62
echo ">>>>>>>>running test 63"
../source/print_tokens2.exe  < ../inputs/newtst154.tst > ../originals/t63
echo ">>>>>>>>running test 64"
../source/print_tokens2.exe  < ../inputs/newtst155.tst > ../originals/t64
echo ">>>>>>>>running test 65"
../source/print_tokens2.exe  < ../inputs/newtst156.tst > ../originals/t65
echo ">>>>>>>>running test 66"
../source/print_tokens2.exe  < ../inputs/newtst157.tst > ../originals/t66
echo ">>>>>>>>running test 67"
../source/print_tokens2.exe  < ../inputs/newtst158.tst > ../originals/t67
echo ">>>>>>>>running test 68"
../source/print_tokens2.exe  < ../inputs/newtst159.tst > ../originals/t68
echo ">>>>>>>>running test 69"
../source/print_tokens2.exe  < ../inputs/newtst16.tst > ../originals/t69
echo ">>>>>>>>running test 70"
../source/print_tokens2.exe  < ../inputs/newtst160.tst > ../originals/t70
echo ">>>>>>>>running test 71"
../source/print_tokens2.exe  < ../inputs/newtst161.tst > ../originals/t71
echo ">>>>>>>>running test 72"
../source/print_tokens2.exe  < ../inputs/newtst162.tst > ../originals/t72
echo ">>>>>>>>running test 73"
../source/print_tokens2.exe  < ../inputs/newtst163.tst > ../originals/t73
echo ">>>>>>>>running test 74"
../source/print_tokens2.exe  < ../inputs/newtst164.tst > ../originals/t74
echo ">>>>>>>>running test 75"
../source/print_tokens2.exe  < ../inputs/newtst165.tst > ../originals/t75
echo ">>>>>>>>running test 76"
../source/print_tokens2.exe  < ../inputs/newtst166.tst > ../originals/t76
echo ">>>>>>>>running test 77"
../source/print_tokens2.exe  < ../inputs/newtst167.tst > ../originals/t77
echo ">>>>>>>>running test 78"
../source/print_tokens2.exe  < ../inputs/newtst168.tst > ../originals/t78
echo ">>>>>>>>running test 79"
../source/print_tokens2.exe  < ../inputs/newtst169.tst > ../originals/t79
echo ">>>>>>>>running test 80"
../source/print_tokens2.exe  < ../inputs/newtst17.tst > ../originals/t80
echo ">>>>>>>>running test 81"
../source/print_tokens2.exe  < ../inputs/newtst170.tst > ../originals/t81
echo ">>>>>>>>running test 82"
../source/print_tokens2.exe  < ../inputs/newtst171.tst > ../originals/t82
echo ">>>>>>>>running test 83"
../source/print_tokens2.exe  < ../inputs/newtst172.tst > ../originals/t83
echo ">>>>>>>>running test 84"
../source/print_tokens2.exe  < ../inputs/newtst173.tst > ../originals/t84
echo ">>>>>>>>running test 85"
../source/print_tokens2.exe  < ../inputs/newtst174.tst > ../originals/t85
echo ">>>>>>>>running test 86"
../source/print_tokens2.exe  < ../inputs/newtst175.tst > ../originals/t86
echo ">>>>>>>>running test 87"
../source/print_tokens2.exe  < ../inputs/newtst176.tst > ../originals/t87
echo ">>>>>>>>running test 88"
../source/print_tokens2.exe  < ../inputs/newtst177.tst > ../originals/t88
echo ">>>>>>>>running test 89"
../source/print_tokens2.exe  < ../inputs/newtst178.tst > ../originals/t89
echo ">>>>>>>>running test 90"
../source/print_tokens2.exe  < ../inputs/newtst179.tst > ../originals/t90
echo ">>>>>>>>running test 91"
../source/print_tokens2.exe  < ../inputs/newtst18.tst > ../originals/t91
echo ">>>>>>>>running test 92"
../source/print_tokens2.exe  < ../inputs/newtst180.tst > ../originals/t92
echo ">>>>>>>>running test 93"
../source/print_tokens2.exe  < ../inputs/newtst181.tst > ../originals/t93
echo ">>>>>>>>running test 94"
../source/print_tokens2.exe  < ../inputs/newtst182.tst > ../originals/t94
echo ">>>>>>>>running test 95"
../source/print_tokens2.exe  < ../inputs/newtst183.tst > ../originals/t95
echo ">>>>>>>>running test 96"
../source/print_tokens2.exe  < ../inputs/newtst184.tst > ../originals/t96
echo ">>>>>>>>running test 97"
../source/print_tokens2.exe  < ../inputs/newtst185.tst > ../originals/t97
echo ">>>>>>>>running test 98"
../source/print_tokens2.exe  < ../inputs/newtst186.tst > ../originals/t98
echo ">>>>>>>>running test 99"
../source/print_tokens2.exe  < ../inputs/newtst187.tst > ../originals/t99
echo ">>>>>>>>running test 100"
../source/print_tokens2.exe  < ../inputs/newtst188.tst > ../originals/t100
echo ">>>>>>>>running test 101"
../source/print_tokens2.exe  < ../inputs/newtst189.tst > ../originals/t101
echo ">>>>>>>>running test 102"
../source/print_tokens2.exe  < ../inputs/newtst19.tst > ../originals/t102
echo ">>>>>>>>running test 103"
../source/print_tokens2.exe  < ../inputs/newtst190.tst > ../originals/t103
echo ">>>>>>>>running test 104"
../source/print_tokens2.exe  < ../inputs/newtst191.tst > ../originals/t104
echo ">>>>>>>>running test 105"
../source/print_tokens2.exe  < ../inputs/newtst192.tst > ../originals/t105
echo ">>>>>>>>running test 106"
../source/print_tokens2.exe  < ../inputs/newtst193.tst > ../originals/t106
echo ">>>>>>>>running test 107"
../source/print_tokens2.exe  < ../inputs/newtst194.tst > ../originals/t107
echo ">>>>>>>>running test 108"
../source/print_tokens2.exe  < ../inputs/newtst195.tst > ../originals/t108
echo ">>>>>>>>running test 109"
../source/print_tokens2.exe  < ../inputs/newtst196.tst > ../originals/t109
echo ">>>>>>>>running test 110"
../source/print_tokens2.exe  < ../inputs/newtst197.tst > ../originals/t110
echo ">>>>>>>>running test 111"
../source/print_tokens2.exe  < ../inputs/newtst198.tst > ../originals/t111
echo ">>>>>>>>running test 112"
../source/print_tokens2.exe  < ../inputs/newtst199.tst > ../originals/t112
echo ">>>>>>>>running test 113"
../source/print_tokens2.exe  < ../inputs/newtst2.tst > ../originals/t113
echo ">>>>>>>>running test 114"
../source/print_tokens2.exe  < ../inputs/newtst2.tst.tst > ../originals/t114
echo ">>>>>>>>running test 115"
../source/print_tokens2.exe  < ../inputs/newtst20.tst > ../originals/t115
echo ">>>>>>>>running test 116"
../source/print_tokens2.exe  < ../inputs/newtst200.tst > ../originals/t116
echo ">>>>>>>>running test 117"
../source/print_tokens2.exe  < ../inputs/newtst201.tst > ../originals/t117
echo ">>>>>>>>running test 118"
../source/print_tokens2.exe  < ../inputs/newtst203.tst > ../originals/t118
echo ">>>>>>>>running test 119"
../source/print_tokens2.exe  < ../inputs/newtst204.tst > ../originals/t119
echo ">>>>>>>>running test 120"
../source/print_tokens2.exe  < ../inputs/newtst205.tst > ../originals/t120
echo ">>>>>>>>running test 121"
../source/print_tokens2.exe  < ../inputs/newtst206.tst > ../originals/t121
echo ">>>>>>>>running test 122"
../source/print_tokens2.exe  < ../inputs/newtst207.tst > ../originals/t122
echo ">>>>>>>>running test 123"
../source/print_tokens2.exe  < ../inputs/newtst208.tst > ../originals/t123
echo ">>>>>>>>running test 124"
../source/print_tokens2.exe  < ../inputs/newtst209.tst > ../originals/t124
echo ">>>>>>>>running test 125"
../source/print_tokens2.exe  < ../inputs/newtst21.tst > ../originals/t125
echo ">>>>>>>>running test 126"
../source/print_tokens2.exe  < ../inputs/newtst21.tst.tst > ../originals/t126
echo ">>>>>>>>running test 127"
../source/print_tokens2.exe  < ../inputs/newtst210.tst > ../originals/t127
echo ">>>>>>>>running test 128"
../source/print_tokens2.exe  < ../inputs/newtst211.tst > ../originals/t128
echo ">>>>>>>>running test 129"
../source/print_tokens2.exe  < ../inputs/newtst212.tst > ../originals/t129
echo ">>>>>>>>running test 130"
../source/print_tokens2.exe  < ../inputs/newtst213.tst > ../originals/t130
echo ">>>>>>>>running test 131"
../source/print_tokens2.exe  < ../inputs/newtst214.tst > ../originals/t131
echo ">>>>>>>>running test 132"
../source/print_tokens2.exe  < ../inputs/newtst215.tst > ../originals/t132
echo ">>>>>>>>running test 133"
../source/print_tokens2.exe  < ../inputs/newtst216.tst > ../originals/t133
echo ">>>>>>>>running test 134"
../source/print_tokens2.exe  < ../inputs/newtst217.tst > ../originals/t134
echo ">>>>>>>>running test 135"
../source/print_tokens2.exe  < ../inputs/newtst218.tst > ../originals/t135
echo ">>>>>>>>running test 136"
../source/print_tokens2.exe  < ../inputs/newtst219.tst > ../originals/t136
echo ">>>>>>>>running test 137"
../source/print_tokens2.exe  < ../inputs/newtst22.tst > ../originals/t137
echo ">>>>>>>>running test 138"
../source/print_tokens2.exe  < ../inputs/newtst220.tst > ../originals/t138
echo ">>>>>>>>running test 139"
../source/print_tokens2.exe  < ../inputs/newtst221.tst > ../originals/t139
echo ">>>>>>>>running test 140"
../source/print_tokens2.exe  < ../inputs/newtst222.tst > ../originals/t140
echo ">>>>>>>>running test 141"
../source/print_tokens2.exe  < ../inputs/newtst223.tst > ../originals/t141
echo ">>>>>>>>running test 142"
../source/print_tokens2.exe  < ../inputs/newtst224.tst > ../originals/t142
echo ">>>>>>>>running test 143"
../source/print_tokens2.exe  < ../inputs/newtst225.tst > ../originals/t143
echo ">>>>>>>>running test 144"
../source/print_tokens2.exe  < ../inputs/newtst226.tst > ../originals/t144
echo ">>>>>>>>running test 145"
../source/print_tokens2.exe  < ../inputs/newtst227.tst > ../originals/t145
echo ">>>>>>>>running test 146"
../source/print_tokens2.exe  < ../inputs/newtst228.tst > ../originals/t146
echo ">>>>>>>>running test 147"
../source/print_tokens2.exe  < ../inputs/newtst229.tst > ../originals/t147
echo ">>>>>>>>running test 148"
../source/print_tokens2.exe  < ../inputs/newtst23.tst > ../originals/t148
echo ">>>>>>>>running test 149"
../source/print_tokens2.exe  < ../inputs/newtst230.tst > ../originals/t149
echo ">>>>>>>>running test 150"
../source/print_tokens2.exe  < ../inputs/newtst231.tst > ../originals/t150
echo ">>>>>>>>running test 151"
../source/print_tokens2.exe  < ../inputs/newtst232.tst > ../originals/t151
echo ">>>>>>>>running test 152"
../source/print_tokens2.exe  < ../inputs/newtst233.tst > ../originals/t152
echo ">>>>>>>>running test 153"
../source/print_tokens2.exe  < ../inputs/newtst234.tst > ../originals/t153
echo ">>>>>>>>running test 154"
../source/print_tokens2.exe  < ../inputs/newtst234.tst.tst > ../originals/t154
echo ">>>>>>>>running test 155"
../source/print_tokens2.exe  < ../inputs/newtst235.tst > ../originals/t155
echo ">>>>>>>>running test 156"
../source/print_tokens2.exe  < ../inputs/newtst236.tst > ../originals/t156
echo ">>>>>>>>running test 157"
../source/print_tokens2.exe  < ../inputs/newtst237.tst > ../originals/t157
echo ">>>>>>>>running test 158"
../source/print_tokens2.exe  < ../inputs/newtst238.tst > ../originals/t158
echo ">>>>>>>>running test 159"
../source/print_tokens2.exe  < ../inputs/newtst239.tst > ../originals/t159
echo ">>>>>>>>running test 160"
../source/print_tokens2.exe  < ../inputs/newtst24.tst > ../originals/t160
echo ">>>>>>>>running test 161"
../source/print_tokens2.exe  < ../inputs/newtst240.tst > ../originals/t161
echo ">>>>>>>>running test 162"
../source/print_tokens2.exe  < ../inputs/newtst240.tst.tst > ../originals/t162
echo ">>>>>>>>running test 163"
../source/print_tokens2.exe  < ../inputs/newtst241.tst > ../originals/t163
echo ">>>>>>>>running test 164"
../source/print_tokens2.exe  < ../inputs/newtst241.tst.tst > ../originals/t164
echo ">>>>>>>>running test 165"
../source/print_tokens2.exe  < ../inputs/newtst242.tst > ../originals/t165
echo ">>>>>>>>running test 166"
../source/print_tokens2.exe  < ../inputs/newtst242.tst.tst > ../originals/t166
echo ">>>>>>>>running test 167"
../source/print_tokens2.exe  < ../inputs/newtst243.tst > ../originals/t167
echo ">>>>>>>>running test 168"
../source/print_tokens2.exe  < ../inputs/newtst243.tst.tst > ../originals/t168
echo ">>>>>>>>running test 169"
../source/print_tokens2.exe  < ../inputs/newtst244.tst > ../originals/t169
echo ">>>>>>>>running test 170"
../source/print_tokens2.exe  < ../inputs/newtst244.tst.tst > ../originals/t170
echo ">>>>>>>>running test 171"
../source/print_tokens2.exe  < ../inputs/newtst245.tst > ../originals/t171
echo ">>>>>>>>running test 172"
../source/print_tokens2.exe  < ../inputs/newtst245.tst.tst > ../originals/t172
echo ">>>>>>>>running test 173"
../source/print_tokens2.exe  < ../inputs/newtst246.tst > ../originals/t173
echo ">>>>>>>>running test 174"
../source/print_tokens2.exe  < ../inputs/newtst246.tst.tst > ../originals/t174
echo ">>>>>>>>running test 175"
../source/print_tokens2.exe  < ../inputs/newtst247.tst > ../originals/t175
echo ">>>>>>>>running test 176"
../source/print_tokens2.exe  < ../inputs/newtst247.tst.tst > ../originals/t176
echo ">>>>>>>>running test 177"
../source/print_tokens2.exe  < ../inputs/newtst248.tst > ../originals/t177
echo ">>>>>>>>running test 178"
../source/print_tokens2.exe  < ../inputs/newtst248.tst.tst > ../originals/t178
echo ">>>>>>>>running test 179"
../source/print_tokens2.exe  < ../inputs/newtst249.tst > ../originals/t179
echo ">>>>>>>>running test 180"
../source/print_tokens2.exe  < ../inputs/newtst249.tst.tst > ../originals/t180
echo ">>>>>>>>running test 181"
../source/print_tokens2.exe  < ../inputs/newtst25.tst > ../originals/t181
echo ">>>>>>>>running test 182"
../source/print_tokens2.exe  < ../inputs/newtst250.tst > ../originals/t182
echo ">>>>>>>>running test 183"
../source/print_tokens2.exe  < ../inputs/newtst251.tst > ../originals/t183
echo ">>>>>>>>running test 184"
../source/print_tokens2.exe  < ../inputs/newtst252.tst > ../originals/t184
echo ">>>>>>>>running test 185"
../source/print_tokens2.exe  < ../inputs/newtst253.tst > ../originals/t185
echo ">>>>>>>>running test 186"
../source/print_tokens2.exe  < ../inputs/newtst254.tst > ../originals/t186
echo ">>>>>>>>running test 187"
../source/print_tokens2.exe  < ../inputs/newtst254.tst.tst > ../originals/t187
echo ">>>>>>>>running test 188"
../source/print_tokens2.exe  < ../inputs/newtst255.tst > ../originals/t188
echo ">>>>>>>>running test 189"
../source/print_tokens2.exe  < ../inputs/newtst256.tst > ../originals/t189
echo ">>>>>>>>running test 190"
../source/print_tokens2.exe  < ../inputs/newtst257.tst > ../originals/t190
echo ">>>>>>>>running test 191"
../source/print_tokens2.exe  < ../inputs/newtst258.tst > ../originals/t191
echo ">>>>>>>>running test 192"
../source/print_tokens2.exe  < ../inputs/newtst259.tst > ../originals/t192
echo ">>>>>>>>running test 193"
../source/print_tokens2.exe  < ../inputs/newtst26.tst > ../originals/t193
echo ">>>>>>>>running test 194"
../source/print_tokens2.exe  < ../inputs/newtst260.tst > ../originals/t194
echo ">>>>>>>>running test 195"
../source/print_tokens2.exe  < ../inputs/newtst261.tst > ../originals/t195
echo ">>>>>>>>running test 196"
../source/print_tokens2.exe  < ../inputs/newtst262.tst > ../originals/t196
echo ">>>>>>>>running test 197"
../source/print_tokens2.exe  < ../inputs/newtst263.tst > ../originals/t197
echo ">>>>>>>>running test 198"
../source/print_tokens2.exe  < ../inputs/newtst264.tst > ../originals/t198
echo ">>>>>>>>running test 199"
../source/print_tokens2.exe  < ../inputs/newtst265.tst > ../originals/t199
echo ">>>>>>>>running test 200"
../source/print_tokens2.exe  < ../inputs/newtst266.tst > ../originals/t200
echo ">>>>>>>>running test 201"
../source/print_tokens2.exe  < ../inputs/newtst267.tst > ../originals/t201
echo ">>>>>>>>running test 202"
../source/print_tokens2.exe  < ../inputs/newtst268.tst > ../originals/t202
echo ">>>>>>>>running test 203"
../source/print_tokens2.exe  < ../inputs/newtst269.tst > ../originals/t203
echo ">>>>>>>>running test 204"
../source/print_tokens2.exe  < ../inputs/newtst27.tst > ../originals/t204
echo ">>>>>>>>running test 205"
../source/print_tokens2.exe  < ../inputs/newtst270.tst > ../originals/t205
echo ">>>>>>>>running test 206"
../source/print_tokens2.exe  < ../inputs/newtst271.tst > ../originals/t206
echo ">>>>>>>>running test 207"
../source/print_tokens2.exe  < ../inputs/newtst272.tst > ../originals/t207
echo ">>>>>>>>running test 208"
../source/print_tokens2.exe  < ../inputs/newtst273.tst > ../originals/t208
echo ">>>>>>>>running test 209"
../source/print_tokens2.exe  < ../inputs/newtst274.tst > ../originals/t209
echo ">>>>>>>>running test 210"
../source/print_tokens2.exe  < ../inputs/newtst275.tst > ../originals/t210
echo ">>>>>>>>running test 211"
../source/print_tokens2.exe  < ../inputs/newtst276.tst > ../originals/t211
echo ">>>>>>>>running test 212"
../source/print_tokens2.exe  < ../inputs/newtst277.tst > ../originals/t212
echo ">>>>>>>>running test 213"
../source/print_tokens2.exe  < ../inputs/newtst278.tst > ../originals/t213
echo ">>>>>>>>running test 214"
../source/print_tokens2.exe  < ../inputs/newtst279.tst > ../originals/t214
echo ">>>>>>>>running test 215"
../source/print_tokens2.exe  < ../inputs/newtst28.tst > ../originals/t215
echo ">>>>>>>>running test 216"
../source/print_tokens2.exe  < ../inputs/newtst280.tst > ../originals/t216
echo ">>>>>>>>running test 217"
../source/print_tokens2.exe  < ../inputs/newtst281.tst > ../originals/t217
echo ">>>>>>>>running test 218"
../source/print_tokens2.exe  < ../inputs/newtst282.tst > ../originals/t218
echo ">>>>>>>>running test 219"
../source/print_tokens2.exe  < ../inputs/newtst283.tst > ../originals/t219
echo ">>>>>>>>running test 220"
../source/print_tokens2.exe  < ../inputs/newtst284.tst > ../originals/t220
echo ">>>>>>>>running test 221"
../source/print_tokens2.exe  < ../inputs/newtst285.tst > ../originals/t221
echo ">>>>>>>>running test 222"
../source/print_tokens2.exe  < ../inputs/newtst286.tst > ../originals/t222
echo ">>>>>>>>running test 223"
../source/print_tokens2.exe  < ../inputs/newtst287.tst > ../originals/t223
echo ">>>>>>>>running test 224"
../source/print_tokens2.exe  < ../inputs/newtst288.tst > ../originals/t224
echo ">>>>>>>>running test 225"
../source/print_tokens2.exe  < ../inputs/newtst289.tst > ../originals/t225
echo ">>>>>>>>running test 226"
../source/print_tokens2.exe  < ../inputs/newtst29.tst > ../originals/t226
echo ">>>>>>>>running test 227"
../source/print_tokens2.exe  < ../inputs/newtst290.tst > ../originals/t227
echo ">>>>>>>>running test 228"
../source/print_tokens2.exe  < ../inputs/newtst291.tst > ../originals/t228
echo ">>>>>>>>running test 229"
../source/print_tokens2.exe  < ../inputs/newtst292.tst > ../originals/t229
echo ">>>>>>>>running test 230"
../source/print_tokens2.exe  < ../inputs/newtst293.tst > ../originals/t230
echo ">>>>>>>>running test 231"
../source/print_tokens2.exe  < ../inputs/newtst294.tst > ../originals/t231
echo ">>>>>>>>running test 232"
../source/print_tokens2.exe  < ../inputs/newtst295.tst > ../originals/t232
echo ">>>>>>>>running test 233"
../source/print_tokens2.exe  < ../inputs/newtst296.tst > ../originals/t233
echo ">>>>>>>>running test 234"
../source/print_tokens2.exe  < ../inputs/newtst297.tst > ../originals/t234
echo ">>>>>>>>running test 235"
../source/print_tokens2.exe  < ../inputs/newtst298.tst > ../originals/t235
echo ">>>>>>>>running test 236"
../source/print_tokens2.exe  < ../inputs/newtst299.tst > ../originals/t236
echo ">>>>>>>>running test 237"
../source/print_tokens2.exe  < ../inputs/newtst3.tst > ../originals/t237
echo ">>>>>>>>running test 238"
../source/print_tokens2.exe  < ../inputs/newtst3.tst.tst > ../originals/t238
echo ">>>>>>>>running test 239"
../source/print_tokens2.exe  < ../inputs/newtst30.tst > ../originals/t239
echo ">>>>>>>>running test 240"
../source/print_tokens2.exe  < ../inputs/newtst300.tst > ../originals/t240
echo ">>>>>>>>running test 241"
../source/print_tokens2.exe  < ../inputs/newtst301.tst > ../originals/t241
echo ">>>>>>>>running test 242"
../source/print_tokens2.exe  < ../inputs/newtst302.tst > ../originals/t242
echo ">>>>>>>>running test 243"
../source/print_tokens2.exe  < ../inputs/newtst303.tst > ../originals/t243
echo ">>>>>>>>running test 244"
../source/print_tokens2.exe  < ../inputs/newtst304.tst > ../originals/t244
echo ">>>>>>>>running test 245"
../source/print_tokens2.exe  < ../inputs/newtst305.tst > ../originals/t245
echo ">>>>>>>>running test 246"
../source/print_tokens2.exe  < ../inputs/newtst306.tst > ../originals/t246
echo ">>>>>>>>running test 247"
../source/print_tokens2.exe  < ../inputs/newtst307.tst > ../originals/t247
echo ">>>>>>>>running test 248"
../source/print_tokens2.exe  < ../inputs/newtst308.tst > ../originals/t248
echo ">>>>>>>>running test 249"
../source/print_tokens2.exe  < ../inputs/newtst309.tst > ../originals/t249
echo ">>>>>>>>running test 250"
../source/print_tokens2.exe  < ../inputs/newtst31.tst > ../originals/t250
echo ">>>>>>>>running test 251"
../source/print_tokens2.exe  < ../inputs/newtst31.tst.tst > ../originals/t251
echo ">>>>>>>>running test 252"
../source/print_tokens2.exe  < ../inputs/newtst310.tst > ../originals/t252
echo ">>>>>>>>running test 253"
../source/print_tokens2.exe  < ../inputs/newtst311.tst > ../originals/t253
echo ">>>>>>>>running test 254"
../source/print_tokens2.exe  < ../inputs/newtst312.tst > ../originals/t254
echo ">>>>>>>>running test 255"
../source/print_tokens2.exe  < ../inputs/newtst313.tst > ../originals/t255
echo ">>>>>>>>running test 256"
../source/print_tokens2.exe  < ../inputs/newtst314.tst > ../originals/t256
echo ">>>>>>>>running test 257"
../source/print_tokens2.exe  < ../inputs/newtst315.tst > ../originals/t257
echo ">>>>>>>>running test 258"
../source/print_tokens2.exe  < ../inputs/newtst316.tst > ../originals/t258
echo ">>>>>>>>running test 259"
../source/print_tokens2.exe  < ../inputs/newtst317.tst > ../originals/t259
echo ">>>>>>>>running test 260"
../source/print_tokens2.exe  < ../inputs/newtst318.tst > ../originals/t260
echo ">>>>>>>>running test 261"
../source/print_tokens2.exe  < ../inputs/newtst319.tst > ../originals/t261
echo ">>>>>>>>running test 262"
../source/print_tokens2.exe  < ../inputs/newtst32.tst > ../originals/t262
echo ">>>>>>>>running test 263"
../source/print_tokens2.exe  < ../inputs/newtst320.tst > ../originals/t263
echo ">>>>>>>>running test 264"
../source/print_tokens2.exe  < ../inputs/newtst321.tst > ../originals/t264
echo ">>>>>>>>running test 265"
../source/print_tokens2.exe  < ../inputs/newtst322.tst > ../originals/t265
echo ">>>>>>>>running test 266"
../source/print_tokens2.exe  < ../inputs/newtst323.tst > ../originals/t266
echo ">>>>>>>>running test 267"
../source/print_tokens2.exe  < ../inputs/newtst324.tst > ../originals/t267
echo ">>>>>>>>running test 268"
../source/print_tokens2.exe  < ../inputs/newtst325.tst > ../originals/t268
echo ">>>>>>>>running test 269"
../source/print_tokens2.exe  < ../inputs/newtst326.tst > ../originals/t269
echo ">>>>>>>>running test 270"
../source/print_tokens2.exe  < ../inputs/newtst327.tst > ../originals/t270
echo ">>>>>>>>running test 271"
../source/print_tokens2.exe  < ../inputs/newtst328.tst > ../originals/t271
echo ">>>>>>>>running test 272"
../source/print_tokens2.exe  < ../inputs/newtst329.tst > ../originals/t272
echo ">>>>>>>>running test 273"
../source/print_tokens2.exe  < ../inputs/newtst33.tst > ../originals/t273
echo ">>>>>>>>running test 274"
../source/print_tokens2.exe  < ../inputs/newtst330.tst > ../originals/t274
echo ">>>>>>>>running test 275"
../source/print_tokens2.exe  < ../inputs/newtst331.tst > ../originals/t275
echo ">>>>>>>>running test 276"
../source/print_tokens2.exe  < ../inputs/newtst332.tst > ../originals/t276
echo ">>>>>>>>running test 277"
../source/print_tokens2.exe  < ../inputs/newtst333.tst > ../originals/t277
echo ">>>>>>>>running test 278"
../source/print_tokens2.exe  < ../inputs/newtst334.tst > ../originals/t278
echo ">>>>>>>>running test 279"
../source/print_tokens2.exe  < ../inputs/newtst335.tst > ../originals/t279
echo ">>>>>>>>running test 280"
../source/print_tokens2.exe  < ../inputs/newtst336.tst > ../originals/t280
echo ">>>>>>>>running test 281"
../source/print_tokens2.exe  < ../inputs/newtst337.tst > ../originals/t281
echo ">>>>>>>>running test 282"
../source/print_tokens2.exe  < ../inputs/newtst338.tst > ../originals/t282
echo ">>>>>>>>running test 283"
../source/print_tokens2.exe  < ../inputs/newtst339.tst > ../originals/t283
echo ">>>>>>>>running test 284"
../source/print_tokens2.exe  < ../inputs/newtst34.tst > ../originals/t284
echo ">>>>>>>>running test 285"
../source/print_tokens2.exe  < ../inputs/newtst340.tst > ../originals/t285
echo ">>>>>>>>running test 286"
../source/print_tokens2.exe  < ../inputs/newtst341.tst > ../originals/t286
echo ">>>>>>>>running test 287"
../source/print_tokens2.exe  < ../inputs/newtst342.tst > ../originals/t287
echo ">>>>>>>>running test 288"
../source/print_tokens2.exe  < ../inputs/newtst343.tst > ../originals/t288
echo ">>>>>>>>running test 289"
../source/print_tokens2.exe  < ../inputs/newtst344.tst > ../originals/t289
echo ">>>>>>>>running test 290"
../source/print_tokens2.exe  < ../inputs/newtst345.tst > ../originals/t290
echo ">>>>>>>>running test 291"
../source/print_tokens2.exe  < ../inputs/newtst346.tst > ../originals/t291
echo ">>>>>>>>running test 292"
../source/print_tokens2.exe  < ../inputs/newtst347.tst > ../originals/t292
echo ">>>>>>>>running test 293"
../source/print_tokens2.exe  < ../inputs/newtst348.tst > ../originals/t293
echo ">>>>>>>>running test 294"
../source/print_tokens2.exe  < ../inputs/newtst349.tst > ../originals/t294
echo ">>>>>>>>running test 295"
../source/print_tokens2.exe  < ../inputs/newtst35.tst > ../originals/t295
echo ">>>>>>>>running test 296"
../source/print_tokens2.exe  < ../inputs/newtst350.tst > ../originals/t296
echo ">>>>>>>>running test 297"
../source/print_tokens2.exe  < ../inputs/newtst352.tst > ../originals/t297
echo ">>>>>>>>running test 298"
../source/print_tokens2.exe  < ../inputs/newtst353.tst > ../originals/t298
echo ">>>>>>>>running test 299"
../source/print_tokens2.exe  < ../inputs/newtst354.tst > ../originals/t299
echo ">>>>>>>>running test 300"
../source/print_tokens2.exe  < ../inputs/newtst355.tst > ../originals/t300
echo ">>>>>>>>running test 301"
../source/print_tokens2.exe  < ../inputs/newtst356.tst > ../originals/t301
echo ">>>>>>>>running test 302"
../source/print_tokens2.exe  < ../inputs/newtst357.tst > ../originals/t302
echo ">>>>>>>>running test 303"
../source/print_tokens2.exe  < ../inputs/newtst358.tst > ../originals/t303
echo ">>>>>>>>running test 304"
../source/print_tokens2.exe  < ../inputs/newtst359.tst > ../originals/t304
echo ">>>>>>>>running test 305"
../source/print_tokens2.exe  < ../inputs/newtst36.tst > ../originals/t305
echo ">>>>>>>>running test 306"
../source/print_tokens2.exe  < ../inputs/newtst360.tst > ../originals/t306
echo ">>>>>>>>running test 307"
../source/print_tokens2.exe  < ../inputs/newtst361.tst > ../originals/t307
echo ">>>>>>>>running test 308"
../source/print_tokens2.exe  < ../inputs/newtst362.tst > ../originals/t308
echo ">>>>>>>>running test 309"
../source/print_tokens2.exe  < ../inputs/newtst363.tst > ../originals/t309
echo ">>>>>>>>running test 310"
../source/print_tokens2.exe  < ../inputs/newtst364.tst > ../originals/t310
echo ">>>>>>>>running test 311"
../source/print_tokens2.exe  < ../inputs/newtst365.tst > ../originals/t311
echo ">>>>>>>>running test 312"
../source/print_tokens2.exe  < ../inputs/newtst366.tst > ../originals/t312
echo ">>>>>>>>running test 313"
../source/print_tokens2.exe  < ../inputs/newtst367.tst > ../originals/t313
echo ">>>>>>>>running test 314"
../source/print_tokens2.exe  < ../inputs/newtst368.tst > ../originals/t314
echo ">>>>>>>>running test 315"
../source/print_tokens2.exe  < ../inputs/newtst369.tst > ../originals/t315
echo ">>>>>>>>running test 316"
../source/print_tokens2.exe  < ../inputs/newtst37.tst > ../originals/t316
echo ">>>>>>>>running test 317"
../source/print_tokens2.exe  < ../inputs/newtst370.tst > ../originals/t317
echo ">>>>>>>>running test 318"
../source/print_tokens2.exe  < ../inputs/newtst371.tst > ../originals/t318
echo ">>>>>>>>running test 319"
../source/print_tokens2.exe  < ../inputs/newtst372.tst > ../originals/t319
echo ">>>>>>>>running test 320"
../source/print_tokens2.exe  < ../inputs/newtst373.tst > ../originals/t320
echo ">>>>>>>>running test 321"
../source/print_tokens2.exe  < ../inputs/newtst374.tst > ../originals/t321
echo ">>>>>>>>running test 322"
../source/print_tokens2.exe  < ../inputs/newtst375.tst > ../originals/t322
echo ">>>>>>>>running test 323"
../source/print_tokens2.exe  < ../inputs/newtst376.tst > ../originals/t323
echo ">>>>>>>>running test 324"
../source/print_tokens2.exe  < ../inputs/newtst377.tst > ../originals/t324
echo ">>>>>>>>running test 325"
../source/print_tokens2.exe  < ../inputs/newtst378.tst > ../originals/t325
echo ">>>>>>>>running test 326"
../source/print_tokens2.exe  < ../inputs/newtst379.tst > ../originals/t326
echo ">>>>>>>>running test 327"
../source/print_tokens2.exe  < ../inputs/newtst38.tst > ../originals/t327
echo ">>>>>>>>running test 328"
../source/print_tokens2.exe  < ../inputs/newtst380.tst > ../originals/t328
echo ">>>>>>>>running test 329"
../source/print_tokens2.exe  < ../inputs/newtst381.tst > ../originals/t329
echo ">>>>>>>>running test 330"
../source/print_tokens2.exe  < ../inputs/newtst382.tst > ../originals/t330
echo ">>>>>>>>running test 331"
../source/print_tokens2.exe  < ../inputs/newtst383.tst > ../originals/t331
echo ">>>>>>>>running test 332"
../source/print_tokens2.exe  < ../inputs/newtst384.tst > ../originals/t332
echo ">>>>>>>>running test 333"
../source/print_tokens2.exe  < ../inputs/newtst385.tst > ../originals/t333
echo ">>>>>>>>running test 334"
../source/print_tokens2.exe  < ../inputs/newtst386.tst > ../originals/t334
echo ">>>>>>>>running test 335"
../source/print_tokens2.exe  < ../inputs/newtst387.tst > ../originals/t335
echo ">>>>>>>>running test 336"
../source/print_tokens2.exe  < ../inputs/newtst388.tst > ../originals/t336
echo ">>>>>>>>running test 337"
../source/print_tokens2.exe  < ../inputs/newtst389.tst > ../originals/t337
echo ">>>>>>>>running test 338"
../source/print_tokens2.exe  < ../inputs/newtst39.tst > ../originals/t338
echo ">>>>>>>>running test 339"
../source/print_tokens2.exe  < ../inputs/newtst390.tst > ../originals/t339
echo ">>>>>>>>running test 340"
../source/print_tokens2.exe  < ../inputs/newtst391.tst > ../originals/t340
echo ">>>>>>>>running test 341"
../source/print_tokens2.exe  < ../inputs/newtst392.tst > ../originals/t341
echo ">>>>>>>>running test 342"
../source/print_tokens2.exe  < ../inputs/newtst393.tst > ../originals/t342
echo ">>>>>>>>running test 343"
../source/print_tokens2.exe  < ../inputs/newtst394.tst > ../originals/t343
echo ">>>>>>>>running test 344"
../source/print_tokens2.exe  < ../inputs/newtst395.tst > ../originals/t344
echo ">>>>>>>>running test 345"
../source/print_tokens2.exe  < ../inputs/newtst396.tst > ../originals/t345
echo ">>>>>>>>running test 346"
../source/print_tokens2.exe  < ../inputs/newtst397.tst > ../originals/t346
echo ">>>>>>>>running test 347"
../source/print_tokens2.exe  < ../inputs/newtst398.tst > ../originals/t347
echo ">>>>>>>>running test 348"
../source/print_tokens2.exe  < ../inputs/newtst399.tst > ../originals/t348
echo ">>>>>>>>running test 349"
../source/print_tokens2.exe  < ../inputs/newtst4.tst > ../originals/t349
echo ">>>>>>>>running test 350"
../source/print_tokens2.exe  < ../inputs/newtst4.tst.tst > ../originals/t350
echo ">>>>>>>>running test 351"
../source/print_tokens2.exe  < ../inputs/newtst40.tst > ../originals/t351
echo ">>>>>>>>running test 352"
../source/print_tokens2.exe  < ../inputs/newtst400.tst > ../originals/t352
echo ">>>>>>>>running test 353"
../source/print_tokens2.exe  < ../inputs/newtst401.tst > ../originals/t353
echo ">>>>>>>>running test 354"
../source/print_tokens2.exe  < ../inputs/newtst402.tst > ../originals/t354
echo ">>>>>>>>running test 355"
../source/print_tokens2.exe  < ../inputs/newtst403.tst > ../originals/t355
echo ">>>>>>>>running test 356"
../source/print_tokens2.exe  < ../inputs/newtst404.tst > ../originals/t356
echo ">>>>>>>>running test 357"
../source/print_tokens2.exe  < ../inputs/newtst405.tst > ../originals/t357
echo ">>>>>>>>running test 358"
../source/print_tokens2.exe  < ../inputs/newtst406.tst > ../originals/t358
echo ">>>>>>>>running test 359"
../source/print_tokens2.exe  < ../inputs/newtst407.tst > ../originals/t359
echo ">>>>>>>>running test 360"
../source/print_tokens2.exe  < ../inputs/newtst408.tst > ../originals/t360
echo ">>>>>>>>running test 361"
../source/print_tokens2.exe  < ../inputs/newtst409.tst > ../originals/t361
echo ">>>>>>>>running test 362"
../source/print_tokens2.exe  < ../inputs/newtst41.tst > ../originals/t362
echo ">>>>>>>>running test 363"
../source/print_tokens2.exe  < ../inputs/newtst410.tst > ../originals/t363
echo ">>>>>>>>running test 364"
../source/print_tokens2.exe  < ../inputs/newtst411.tst > ../originals/t364
echo ">>>>>>>>running test 365"
../source/print_tokens2.exe  < ../inputs/newtst412.tst > ../originals/t365
echo ">>>>>>>>running test 366"
../source/print_tokens2.exe  < ../inputs/newtst413.tst > ../originals/t366
echo ">>>>>>>>running test 367"
../source/print_tokens2.exe  < ../inputs/newtst414.tst > ../originals/t367
echo ">>>>>>>>running test 368"
../source/print_tokens2.exe  < ../inputs/newtst415.tst > ../originals/t368
echo ">>>>>>>>running test 369"
../source/print_tokens2.exe  < ../inputs/newtst416.tst > ../originals/t369
echo ">>>>>>>>running test 370"
../source/print_tokens2.exe  < ../inputs/newtst417.tst > ../originals/t370
echo ">>>>>>>>running test 371"
../source/print_tokens2.exe  < ../inputs/newtst418.tst > ../originals/t371
echo ">>>>>>>>running test 372"
../source/print_tokens2.exe  < ../inputs/newtst419.tst > ../originals/t372
echo ">>>>>>>>running test 373"
../source/print_tokens2.exe  < ../inputs/newtst42.tst > ../originals/t373
echo ">>>>>>>>running test 374"
../source/print_tokens2.exe  < ../inputs/newtst420.tst > ../originals/t374
echo ">>>>>>>>running test 375"
../source/print_tokens2.exe  < ../inputs/newtst421.tst > ../originals/t375
echo ">>>>>>>>running test 376"
../source/print_tokens2.exe  < ../inputs/newtst422.tst > ../originals/t376
echo ">>>>>>>>running test 377"
../source/print_tokens2.exe  < ../inputs/newtst423.tst > ../originals/t377
echo ">>>>>>>>running test 378"
../source/print_tokens2.exe  < ../inputs/newtst424.tst > ../originals/t378
echo ">>>>>>>>running test 379"
../source/print_tokens2.exe  < ../inputs/newtst425.tst > ../originals/t379
echo ">>>>>>>>running test 380"
../source/print_tokens2.exe  < ../inputs/newtst426.tst > ../originals/t380
echo ">>>>>>>>running test 381"
../source/print_tokens2.exe  < ../inputs/newtst427.tst > ../originals/t381
echo ">>>>>>>>running test 382"
../source/print_tokens2.exe  < ../inputs/newtst428.tst > ../originals/t382
echo ">>>>>>>>running test 383"
../source/print_tokens2.exe  < ../inputs/newtst429.tst > ../originals/t383
echo ">>>>>>>>running test 384"
../source/print_tokens2.exe  < ../inputs/newtst43.tst > ../originals/t384
echo ">>>>>>>>running test 385"
../source/print_tokens2.exe  < ../inputs/newtst430.tst > ../originals/t385
echo ">>>>>>>>running test 386"
../source/print_tokens2.exe  < ../inputs/newtst431.tst > ../originals/t386
echo ">>>>>>>>running test 387"
../source/print_tokens2.exe  < ../inputs/newtst432.tst > ../originals/t387
echo ">>>>>>>>running test 388"
../source/print_tokens2.exe  < ../inputs/newtst433.tst > ../originals/t388
echo ">>>>>>>>running test 389"
../source/print_tokens2.exe  < ../inputs/newtst434.tst > ../originals/t389
echo ">>>>>>>>running test 390"
../source/print_tokens2.exe  < ../inputs/newtst435.tst > ../originals/t390
echo ">>>>>>>>running test 391"
../source/print_tokens2.exe  < ../inputs/newtst436.tst > ../originals/t391
echo ">>>>>>>>running test 392"
../source/print_tokens2.exe  < ../inputs/newtst437.tst > ../originals/t392
echo ">>>>>>>>running test 393"
../source/print_tokens2.exe  < ../inputs/newtst438.tst > ../originals/t393
echo ">>>>>>>>running test 394"
../source/print_tokens2.exe  < ../inputs/newtst439.tst > ../originals/t394
echo ">>>>>>>>running test 395"
../source/print_tokens2.exe  < ../inputs/newtst44.tst > ../originals/t395
echo ">>>>>>>>running test 396"
../source/print_tokens2.exe  < ../inputs/newtst440.tst > ../originals/t396
echo ">>>>>>>>running test 397"
../source/print_tokens2.exe  < ../inputs/newtst441.tst > ../originals/t397
echo ">>>>>>>>running test 398"
../source/print_tokens2.exe  < ../inputs/newtst442.tst > ../originals/t398
echo ">>>>>>>>running test 399"
../source/print_tokens2.exe  < ../inputs/newtst443.tst > ../originals/t399
echo ">>>>>>>>running test 400"
../source/print_tokens2.exe  < ../inputs/newtst444.tst > ../originals/t400
echo ">>>>>>>>running test 401"
../source/print_tokens2.exe  < ../inputs/newtst445.tst > ../originals/t401
echo ">>>>>>>>running test 402"
../source/print_tokens2.exe  < ../inputs/newtst446.tst > ../originals/t402
echo ">>>>>>>>running test 403"
../source/print_tokens2.exe  < ../inputs/newtst447.tst > ../originals/t403
echo ">>>>>>>>running test 404"
../source/print_tokens2.exe  < ../inputs/newtst448.tst > ../originals/t404
echo ">>>>>>>>running test 405"
../source/print_tokens2.exe  < ../inputs/newtst449.tst > ../originals/t405
echo ">>>>>>>>running test 406"
../source/print_tokens2.exe  < ../inputs/newtst45.tst > ../originals/t406
echo ">>>>>>>>running test 407"
../source/print_tokens2.exe  < ../inputs/newtst450.tst > ../originals/t407
echo ">>>>>>>>running test 408"
../source/print_tokens2.exe  < ../inputs/newtst451.tst > ../originals/t408
echo ">>>>>>>>running test 409"
../source/print_tokens2.exe  < ../inputs/newtst452.tst > ../originals/t409
echo ">>>>>>>>running test 410"
../source/print_tokens2.exe  < ../inputs/newtst453.tst > ../originals/t410
echo ">>>>>>>>running test 411"
../source/print_tokens2.exe  < ../inputs/newtst454.tst > ../originals/t411
echo ">>>>>>>>running test 412"
../source/print_tokens2.exe  < ../inputs/newtst455.tst > ../originals/t412
echo ">>>>>>>>running test 413"
../source/print_tokens2.exe  < ../inputs/newtst456.tst > ../originals/t413
echo ">>>>>>>>running test 414"
../source/print_tokens2.exe  < ../inputs/newtst457.tst > ../originals/t414
echo ">>>>>>>>running test 415"
../source/print_tokens2.exe  < ../inputs/newtst458.tst > ../originals/t415
echo ">>>>>>>>running test 416"
../source/print_tokens2.exe  < ../inputs/newtst459.tst > ../originals/t416
echo ">>>>>>>>running test 417"
../source/print_tokens2.exe  < ../inputs/newtst46.tst > ../originals/t417
echo ">>>>>>>>running test 418"
../source/print_tokens2.exe  < ../inputs/newtst460.tst > ../originals/t418
echo ">>>>>>>>running test 419"
../source/print_tokens2.exe  < ../inputs/newtst461.tst > ../originals/t419
echo ">>>>>>>>running test 420"
../source/print_tokens2.exe  < ../inputs/newtst462.tst > ../originals/t420
echo ">>>>>>>>running test 421"
../source/print_tokens2.exe  < ../inputs/newtst463.tst > ../originals/t421
echo ">>>>>>>>running test 422"
../source/print_tokens2.exe  < ../inputs/newtst464.tst > ../originals/t422
echo ">>>>>>>>running test 423"
../source/print_tokens2.exe  < ../inputs/newtst465.tst > ../originals/t423
echo ">>>>>>>>running test 424"
../source/print_tokens2.exe  < ../inputs/newtst466.tst > ../originals/t424
echo ">>>>>>>>running test 425"
../source/print_tokens2.exe  < ../inputs/newtst467.tst > ../originals/t425
echo ">>>>>>>>running test 426"
../source/print_tokens2.exe  < ../inputs/newtst468.tst > ../originals/t426
echo ">>>>>>>>running test 427"
../source/print_tokens2.exe  < ../inputs/newtst469.tst > ../originals/t427
echo ">>>>>>>>running test 428"
../source/print_tokens2.exe  < ../inputs/newtst47.tst > ../originals/t428
echo ">>>>>>>>running test 429"
../source/print_tokens2.exe  < ../inputs/newtst470.tst > ../originals/t429
echo ">>>>>>>>running test 430"
../source/print_tokens2.exe  < ../inputs/newtst471.tst > ../originals/t430
echo ">>>>>>>>running test 431"
../source/print_tokens2.exe  < ../inputs/newtst472.tst > ../originals/t431
echo ">>>>>>>>running test 432"
../source/print_tokens2.exe  < ../inputs/newtst473.tst > ../originals/t432
echo ">>>>>>>>running test 433"
../source/print_tokens2.exe  < ../inputs/newtst474.tst > ../originals/t433
echo ">>>>>>>>running test 434"
../source/print_tokens2.exe  < ../inputs/newtst475.tst > ../originals/t434
echo ">>>>>>>>running test 435"
../source/print_tokens2.exe  < ../inputs/newtst476.tst > ../originals/t435
echo ">>>>>>>>running test 436"
../source/print_tokens2.exe  < ../inputs/newtst477.tst > ../originals/t436
echo ">>>>>>>>running test 437"
../source/print_tokens2.exe  < ../inputs/newtst478.tst > ../originals/t437
echo ">>>>>>>>running test 438"
../source/print_tokens2.exe  < ../inputs/newtst479.tst > ../originals/t438
echo ">>>>>>>>running test 439"
../source/print_tokens2.exe  < ../inputs/newtst48.tst > ../originals/t439
echo ">>>>>>>>running test 440"
../source/print_tokens2.exe  < ../inputs/newtst480.tst > ../originals/t440
echo ">>>>>>>>running test 441"
../source/print_tokens2.exe  < ../inputs/newtst481.tst > ../originals/t441
echo ">>>>>>>>running test 442"
../source/print_tokens2.exe  < ../inputs/newtst482.tst > ../originals/t442
echo ">>>>>>>>running test 443"
../source/print_tokens2.exe  < ../inputs/newtst483.tst > ../originals/t443
echo ">>>>>>>>running test 444"
../source/print_tokens2.exe  < ../inputs/newtst484.tst > ../originals/t444
echo ">>>>>>>>running test 445"
../source/print_tokens2.exe  < ../inputs/newtst485.tst > ../originals/t445
echo ">>>>>>>>running test 446"
../source/print_tokens2.exe  < ../inputs/newtst486.tst > ../originals/t446
echo ">>>>>>>>running test 447"
../source/print_tokens2.exe  < ../inputs/newtst487.tst > ../originals/t447
echo ">>>>>>>>running test 448"
../source/print_tokens2.exe  < ../inputs/newtst488.tst > ../originals/t448
echo ">>>>>>>>running test 449"
../source/print_tokens2.exe  < ../inputs/newtst489.tst > ../originals/t449
echo ">>>>>>>>running test 450"
../source/print_tokens2.exe  < ../inputs/newtst49.tst > ../originals/t450
echo ">>>>>>>>running test 451"
../source/print_tokens2.exe  < ../inputs/newtst490.tst > ../originals/t451
echo ">>>>>>>>running test 452"
../source/print_tokens2.exe  < ../inputs/newtst491.tst > ../originals/t452
echo ">>>>>>>>running test 453"
../source/print_tokens2.exe  < ../inputs/newtst492.tst > ../originals/t453
echo ">>>>>>>>running test 454"
../source/print_tokens2.exe  < ../inputs/newtst493.tst > ../originals/t454
echo ">>>>>>>>running test 455"
../source/print_tokens2.exe  < ../inputs/newtst494.tst > ../originals/t455
echo ">>>>>>>>running test 456"
../source/print_tokens2.exe  < ../inputs/newtst495.tst > ../originals/t456
echo ">>>>>>>>running test 457"
../source/print_tokens2.exe  < ../inputs/newtst496.tst > ../originals/t457
echo ">>>>>>>>running test 458"
../source/print_tokens2.exe  < ../inputs/newtst497.tst > ../originals/t458
echo ">>>>>>>>running test 459"
../source/print_tokens2.exe  < ../inputs/newtst498.tst > ../originals/t459
echo ">>>>>>>>running test 460"
../source/print_tokens2.exe  < ../inputs/newtst499.tst > ../originals/t460
echo ">>>>>>>>running test 461"
../source/print_tokens2.exe  < ../inputs/newtst5.tst > ../originals/t461
echo ">>>>>>>>running test 462"
../source/print_tokens2.exe  < ../inputs/newtst5.tst.tst > ../originals/t462
echo ">>>>>>>>running test 463"
../source/print_tokens2.exe  < ../inputs/newtst50.tst > ../originals/t463
echo ">>>>>>>>running test 464"
../source/print_tokens2.exe  < ../inputs/newtst500.tst > ../originals/t464
echo ">>>>>>>>running test 465"
../source/print_tokens2.exe  < ../inputs/newtst501.tst > ../originals/t465
echo ">>>>>>>>running test 466"
../source/print_tokens2.exe  < ../inputs/newtst502.tst > ../originals/t466
echo ">>>>>>>>running test 467"
../source/print_tokens2.exe  < ../inputs/newtst503.tst > ../originals/t467
echo ">>>>>>>>running test 468"
../source/print_tokens2.exe  < ../inputs/newtst504.tst > ../originals/t468
echo ">>>>>>>>running test 469"
../source/print_tokens2.exe  < ../inputs/newtst505.tst > ../originals/t469
echo ">>>>>>>>running test 470"
../source/print_tokens2.exe  < ../inputs/newtst506.tst > ../originals/t470
echo ">>>>>>>>running test 471"
../source/print_tokens2.exe  < ../inputs/newtst507.tst > ../originals/t471
echo ">>>>>>>>running test 472"
../source/print_tokens2.exe  < ../inputs/newtst508.tst > ../originals/t472
echo ">>>>>>>>running test 473"
../source/print_tokens2.exe  < ../inputs/newtst509.tst > ../originals/t473
echo ">>>>>>>>running test 474"
../source/print_tokens2.exe  < ../inputs/newtst51.tst > ../originals/t474
echo ">>>>>>>>running test 475"
../source/print_tokens2.exe  < ../inputs/newtst510.tst > ../originals/t475
echo ">>>>>>>>running test 476"
../source/print_tokens2.exe  < ../inputs/newtst511.tst > ../originals/t476
echo ">>>>>>>>running test 477"
../source/print_tokens2.exe  < ../inputs/newtst512.tst > ../originals/t477
echo ">>>>>>>>running test 478"
../source/print_tokens2.exe  < ../inputs/newtst513.tst > ../originals/t478
echo ">>>>>>>>running test 479"
../source/print_tokens2.exe  < ../inputs/newtst514.tst > ../originals/t479
echo ">>>>>>>>running test 480"
../source/print_tokens2.exe  < ../inputs/newtst515.tst > ../originals/t480
echo ">>>>>>>>running test 481"
../source/print_tokens2.exe  < ../inputs/newtst516.tst > ../originals/t481
echo ">>>>>>>>running test 482"
../source/print_tokens2.exe  < ../inputs/newtst517.tst > ../originals/t482
echo ">>>>>>>>running test 483"
../source/print_tokens2.exe  < ../inputs/newtst518.tst > ../originals/t483
echo ">>>>>>>>running test 484"
../source/print_tokens2.exe  < ../inputs/newtst519.tst > ../originals/t484
echo ">>>>>>>>running test 485"
../source/print_tokens2.exe  < ../inputs/newtst52.tst > ../originals/t485
echo ">>>>>>>>running test 486"
../source/print_tokens2.exe  < ../inputs/newtst520.tst > ../originals/t486
echo ">>>>>>>>running test 487"
../source/print_tokens2.exe  < ../inputs/newtst521.tst > ../originals/t487
echo ">>>>>>>>running test 488"
../source/print_tokens2.exe  < ../inputs/newtst522.tst > ../originals/t488
echo ">>>>>>>>running test 489"
../source/print_tokens2.exe  < ../inputs/newtst523.tst > ../originals/t489
echo ">>>>>>>>running test 490"
../source/print_tokens2.exe  < ../inputs/newtst524.tst > ../originals/t490
echo ">>>>>>>>running test 491"
../source/print_tokens2.exe  < ../inputs/newtst525.tst > ../originals/t491
echo ">>>>>>>>running test 492"
../source/print_tokens2.exe  < ../inputs/newtst526.tst > ../originals/t492
echo ">>>>>>>>running test 493"
../source/print_tokens2.exe  < ../inputs/newtst527.tst > ../originals/t493
echo ">>>>>>>>running test 494"
../source/print_tokens2.exe  < ../inputs/newtst528.tst > ../originals/t494
echo ">>>>>>>>running test 495"
../source/print_tokens2.exe  < ../inputs/newtst529.tst > ../originals/t495
echo ">>>>>>>>running test 496"
../source/print_tokens2.exe  < ../inputs/newtst53.tst > ../originals/t496
echo ">>>>>>>>running test 497"
../source/print_tokens2.exe  < ../inputs/newtst530.tst > ../originals/t497
echo ">>>>>>>>running test 498"
../source/print_tokens2.exe  < ../inputs/newtst531.tst > ../originals/t498
echo ">>>>>>>>running test 499"
../source/print_tokens2.exe  < ../inputs/newtst532.tst > ../originals/t499
echo ">>>>>>>>running test 500"
../source/print_tokens2.exe  < ../inputs/newtst533.tst > ../originals/t500
echo ">>>>>>>>running test 501"
../source/print_tokens2.exe  < ../inputs/newtst534.tst > ../originals/t501
echo ">>>>>>>>running test 502"
../source/print_tokens2.exe  < ../inputs/newtst535.tst > ../originals/t502
echo ">>>>>>>>running test 503"
../source/print_tokens2.exe  < ../inputs/newtst536.tst > ../originals/t503
echo ">>>>>>>>running test 504"
../source/print_tokens2.exe  < ../inputs/newtst537.tst > ../originals/t504
echo ">>>>>>>>running test 505"
../source/print_tokens2.exe  < ../inputs/newtst538.tst > ../originals/t505
echo ">>>>>>>>running test 506"
../source/print_tokens2.exe  < ../inputs/newtst539.tst > ../originals/t506
echo ">>>>>>>>running test 507"
../source/print_tokens2.exe  < ../inputs/newtst54.tst > ../originals/t507
echo ">>>>>>>>running test 508"
../source/print_tokens2.exe  < ../inputs/newtst540.tst > ../originals/t508
echo ">>>>>>>>running test 509"
../source/print_tokens2.exe  < ../inputs/newtst541.tst > ../originals/t509
echo ">>>>>>>>running test 510"
../source/print_tokens2.exe  < ../inputs/newtst542.tst > ../originals/t510
echo ">>>>>>>>running test 511"
../source/print_tokens2.exe  < ../inputs/newtst543.tst > ../originals/t511
echo ">>>>>>>>running test 512"
../source/print_tokens2.exe  < ../inputs/newtst544.tst > ../originals/t512
echo ">>>>>>>>running test 513"
../source/print_tokens2.exe  < ../inputs/newtst545.tst > ../originals/t513
echo ">>>>>>>>running test 514"
../source/print_tokens2.exe  < ../inputs/newtst546.tst > ../originals/t514
echo ">>>>>>>>running test 515"
../source/print_tokens2.exe  < ../inputs/newtst547.tst > ../originals/t515
echo ">>>>>>>>running test 516"
../source/print_tokens2.exe  < ../inputs/newtst548.tst > ../originals/t516
echo ">>>>>>>>running test 517"
../source/print_tokens2.exe  < ../inputs/newtst549.tst > ../originals/t517
echo ">>>>>>>>running test 518"
../source/print_tokens2.exe  < ../inputs/newtst55.tst > ../originals/t518
echo ">>>>>>>>running test 519"
../source/print_tokens2.exe  < ../inputs/newtst550.tst > ../originals/t519
echo ">>>>>>>>running test 520"
../source/print_tokens2.exe  < ../inputs/newtst551.tst > ../originals/t520
echo ">>>>>>>>running test 521"
../source/print_tokens2.exe  < ../inputs/newtst552.tst > ../originals/t521
echo ">>>>>>>>running test 522"
../source/print_tokens2.exe  < ../inputs/newtst553.tst > ../originals/t522
echo ">>>>>>>>running test 523"
../source/print_tokens2.exe  < ../inputs/newtst554.tst > ../originals/t523
echo ">>>>>>>>running test 524"
../source/print_tokens2.exe  < ../inputs/newtst555.tst > ../originals/t524
echo ">>>>>>>>running test 525"
../source/print_tokens2.exe  < ../inputs/newtst556.tst > ../originals/t525
echo ">>>>>>>>running test 526"
../source/print_tokens2.exe  < ../inputs/newtst557.tst > ../originals/t526
echo ">>>>>>>>running test 527"
../source/print_tokens2.exe  < ../inputs/newtst558.tst > ../originals/t527
echo ">>>>>>>>running test 528"
../source/print_tokens2.exe  < ../inputs/newtst559.tst > ../originals/t528
echo ">>>>>>>>running test 529"
../source/print_tokens2.exe  < ../inputs/newtst56.tst > ../originals/t529
echo ">>>>>>>>running test 530"
../source/print_tokens2.exe  < ../inputs/newtst560.tst > ../originals/t530
echo ">>>>>>>>running test 531"
../source/print_tokens2.exe  < ../inputs/newtst561.tst > ../originals/t531
echo ">>>>>>>>running test 532"
../source/print_tokens2.exe  < ../inputs/newtst562.tst > ../originals/t532
echo ">>>>>>>>running test 533"
../source/print_tokens2.exe  < ../inputs/newtst563.tst > ../originals/t533
echo ">>>>>>>>running test 534"
../source/print_tokens2.exe  < ../inputs/newtst564.tst > ../originals/t534
echo ">>>>>>>>running test 535"
../source/print_tokens2.exe  < ../inputs/newtst565.tst > ../originals/t535
echo ">>>>>>>>running test 536"
../source/print_tokens2.exe  < ../inputs/newtst566.tst > ../originals/t536
echo ">>>>>>>>running test 537"
../source/print_tokens2.exe  < ../inputs/newtst567.tst > ../originals/t537
echo ">>>>>>>>running test 538"
../source/print_tokens2.exe  < ../inputs/newtst568.tst > ../originals/t538
echo ">>>>>>>>running test 539"
../source/print_tokens2.exe  < ../inputs/newtst569.tst > ../originals/t539
echo ">>>>>>>>running test 540"
../source/print_tokens2.exe  < ../inputs/newtst57.tst > ../originals/t540
echo ">>>>>>>>running test 541"
../source/print_tokens2.exe  < ../inputs/newtst570.tst > ../originals/t541
echo ">>>>>>>>running test 542"
../source/print_tokens2.exe  < ../inputs/newtst571.tst > ../originals/t542
echo ">>>>>>>>running test 543"
../source/print_tokens2.exe  < ../inputs/newtst572.tst > ../originals/t543
echo ">>>>>>>>running test 544"
../source/print_tokens2.exe  < ../inputs/newtst573.tst > ../originals/t544
echo ">>>>>>>>running test 545"
../source/print_tokens2.exe  < ../inputs/newtst574.tst > ../originals/t545
echo ">>>>>>>>running test 546"
../source/print_tokens2.exe  < ../inputs/newtst575.tst > ../originals/t546
echo ">>>>>>>>running test 547"
../source/print_tokens2.exe  < ../inputs/newtst576.tst > ../originals/t547
echo ">>>>>>>>running test 548"
../source/print_tokens2.exe  < ../inputs/newtst577.tst > ../originals/t548
echo ">>>>>>>>running test 549"
../source/print_tokens2.exe  < ../inputs/newtst578.tst > ../originals/t549
echo ">>>>>>>>running test 550"
../source/print_tokens2.exe  < ../inputs/newtst579.tst > ../originals/t550
echo ">>>>>>>>running test 551"
../source/print_tokens2.exe  < ../inputs/newtst58.tst > ../originals/t551
echo ">>>>>>>>running test 552"
../source/print_tokens2.exe  < ../inputs/newtst580.tst > ../originals/t552
echo ">>>>>>>>running test 553"
../source/print_tokens2.exe  < ../inputs/newtst581.tst > ../originals/t553
echo ">>>>>>>>running test 554"
../source/print_tokens2.exe  < ../inputs/newtst582.tst > ../originals/t554
echo ">>>>>>>>running test 555"
../source/print_tokens2.exe  < ../inputs/newtst583.tst > ../originals/t555
echo ">>>>>>>>running test 556"
../source/print_tokens2.exe  < ../inputs/newtst584.tst > ../originals/t556
echo ">>>>>>>>running test 557"
../source/print_tokens2.exe  < ../inputs/newtst585.tst > ../originals/t557
echo ">>>>>>>>running test 558"
../source/print_tokens2.exe  < ../inputs/newtst586.tst > ../originals/t558
echo ">>>>>>>>running test 559"
../source/print_tokens2.exe  < ../inputs/newtst587.tst > ../originals/t559
echo ">>>>>>>>running test 560"
../source/print_tokens2.exe  < ../inputs/newtst588.tst > ../originals/t560
echo ">>>>>>>>running test 561"
../source/print_tokens2.exe  < ../inputs/newtst589.tst > ../originals/t561
echo ">>>>>>>>running test 562"
../source/print_tokens2.exe  < ../inputs/newtst59.tst > ../originals/t562
echo ">>>>>>>>running test 563"
../source/print_tokens2.exe  < ../inputs/newtst590.tst > ../originals/t563
echo ">>>>>>>>running test 564"
../source/print_tokens2.exe  < ../inputs/newtst591.tst > ../originals/t564
echo ">>>>>>>>running test 565"
../source/print_tokens2.exe  < ../inputs/newtst592.tst > ../originals/t565
echo ">>>>>>>>running test 566"
../source/print_tokens2.exe  < ../inputs/newtst593.tst > ../originals/t566
echo ">>>>>>>>running test 567"
../source/print_tokens2.exe  < ../inputs/newtst594.tst > ../originals/t567
echo ">>>>>>>>running test 568"
../source/print_tokens2.exe  < ../inputs/newtst595.tst > ../originals/t568
echo ">>>>>>>>running test 569"
../source/print_tokens2.exe  < ../inputs/newtst596.tst > ../originals/t569
echo ">>>>>>>>running test 570"
../source/print_tokens2.exe  < ../inputs/newtst597.tst > ../originals/t570
echo ">>>>>>>>running test 571"
../source/print_tokens2.exe  < ../inputs/newtst598.tst > ../originals/t571
echo ">>>>>>>>running test 572"
../source/print_tokens2.exe  < ../inputs/newtst599.tst > ../originals/t572
echo ">>>>>>>>running test 573"
../source/print_tokens2.exe  < ../inputs/newtst6.tst > ../originals/t573
echo ">>>>>>>>running test 574"
../source/print_tokens2.exe  < ../inputs/newtst6.tst.tst > ../originals/t574
echo ">>>>>>>>running test 575"
../source/print_tokens2.exe  < ../inputs/newtst60.tst > ../originals/t575
echo ">>>>>>>>running test 576"
../source/print_tokens2.exe  < ../inputs/newtst600.tst > ../originals/t576
echo ">>>>>>>>running test 577"
../source/print_tokens2.exe  < ../inputs/newtst61.tst > ../originals/t577
echo ">>>>>>>>running test 578"
../source/print_tokens2.exe  < ../inputs/newtst62.tst > ../originals/t578
echo ">>>>>>>>running test 579"
../source/print_tokens2.exe  < ../inputs/newtst63.tst > ../originals/t579
echo ">>>>>>>>running test 580"
../source/print_tokens2.exe  < ../inputs/newtst64.tst > ../originals/t580
echo ">>>>>>>>running test 581"
../source/print_tokens2.exe  < ../inputs/newtst65.tst > ../originals/t581
echo ">>>>>>>>running test 582"
../source/print_tokens2.exe  < ../inputs/newtst66.tst > ../originals/t582
echo ">>>>>>>>running test 583"
../source/print_tokens2.exe  < ../inputs/newtst67.tst > ../originals/t583
echo ">>>>>>>>running test 584"
../source/print_tokens2.exe  < ../inputs/newtst68.tst > ../originals/t584
echo ">>>>>>>>running test 585"
../source/print_tokens2.exe  < ../inputs/newtst69.tst > ../originals/t585
echo ">>>>>>>>running test 586"
../source/print_tokens2.exe  < ../inputs/newtst7.tst > ../originals/t586
echo ">>>>>>>>running test 587"
../source/print_tokens2.exe  < ../inputs/newtst7.tst.tst > ../originals/t587
echo ">>>>>>>>running test 588"
../source/print_tokens2.exe  < ../inputs/newtst70.tst > ../originals/t588
echo ">>>>>>>>running test 589"
../source/print_tokens2.exe  < ../inputs/newtst71.tst > ../originals/t589
echo ">>>>>>>>running test 590"
../source/print_tokens2.exe  < ../inputs/newtst72.tst > ../originals/t590
echo ">>>>>>>>running test 591"
../source/print_tokens2.exe  < ../inputs/newtst73.tst > ../originals/t591
echo ">>>>>>>>running test 592"
../source/print_tokens2.exe  < ../inputs/newtst74.tst > ../originals/t592
echo ">>>>>>>>running test 593"
../source/print_tokens2.exe  < ../inputs/newtst75.tst > ../originals/t593
echo ">>>>>>>>running test 594"
../source/print_tokens2.exe  < ../inputs/newtst76.tst > ../originals/t594
echo ">>>>>>>>running test 595"
../source/print_tokens2.exe  < ../inputs/newtst77.tst > ../originals/t595
echo ">>>>>>>>running test 596"
../source/print_tokens2.exe  < ../inputs/newtst78.tst > ../originals/t596
echo ">>>>>>>>running test 597"
../source/print_tokens2.exe  < ../inputs/newtst79.tst > ../originals/t597
echo ">>>>>>>>running test 598"
../source/print_tokens2.exe  < ../inputs/newtst8.tst > ../originals/t598
echo ">>>>>>>>running test 599"
../source/print_tokens2.exe  < ../inputs/newtst8.tst.tst > ../originals/t599
echo ">>>>>>>>running test 600"
../source/print_tokens2.exe  < ../inputs/newtst80.tst > ../originals/t600
echo ">>>>>>>>running test 601"
../source/print_tokens2.exe  < ../inputs/newtst81.tst > ../originals/t601
echo ">>>>>>>>running test 602"
../source/print_tokens2.exe  < ../inputs/newtst82.tst > ../originals/t602
echo ">>>>>>>>running test 603"
../source/print_tokens2.exe  < ../inputs/newtst83.tst > ../originals/t603
echo ">>>>>>>>running test 604"
../source/print_tokens2.exe  < ../inputs/newtst84.tst > ../originals/t604
echo ">>>>>>>>running test 605"
../source/print_tokens2.exe  < ../inputs/newtst85.tst > ../originals/t605
echo ">>>>>>>>running test 606"
../source/print_tokens2.exe  < ../inputs/newtst86.tst > ../originals/t606
echo ">>>>>>>>running test 607"
../source/print_tokens2.exe  < ../inputs/newtst87.tst > ../originals/t607
echo ">>>>>>>>running test 608"
../source/print_tokens2.exe  < ../inputs/newtst88.tst > ../originals/t608
echo ">>>>>>>>running test 609"
../source/print_tokens2.exe  < ../inputs/newtst89.tst > ../originals/t609
echo ">>>>>>>>running test 610"
../source/print_tokens2.exe  < ../inputs/newtst9.tst > ../originals/t610
echo ">>>>>>>>running test 611"
../source/print_tokens2.exe  < ../inputs/newtst9.tst.tst > ../originals/t611
echo ">>>>>>>>running test 612"
../source/print_tokens2.exe  < ../inputs/newtst90.tst > ../originals/t612
echo ">>>>>>>>running test 613"
../source/print_tokens2.exe  < ../inputs/newtst91.tst > ../originals/t613
echo ">>>>>>>>running test 614"
../source/print_tokens2.exe  < ../inputs/newtst92.tst > ../originals/t614
echo ">>>>>>>>running test 615"
../source/print_tokens2.exe  < ../inputs/newtst93.tst > ../originals/t615
echo ">>>>>>>>running test 616"
../source/print_tokens2.exe  < ../inputs/newtst94.tst > ../originals/t616
echo ">>>>>>>>running test 617"
../source/print_tokens2.exe  < ../inputs/newtst95.tst > ../originals/t617
echo ">>>>>>>>running test 618"
../source/print_tokens2.exe  < ../inputs/newtst96.tst > ../originals/t618
echo ">>>>>>>>running test 619"
../source/print_tokens2.exe  < ../inputs/newtst97.tst > ../originals/t619
echo ">>>>>>>>running test 620"
../source/print_tokens2.exe  < ../inputs/newtst98.tst > ../originals/t620
echo ">>>>>>>>running test 621"
../source/print_tokens2.exe  < ../inputs/newtst99.tst > ../originals/t621
echo ">>>>>>>>running test 622"
../source/print_tokens2.exe  < ../inputs/tc1 > ../originals/t622
echo ">>>>>>>>running test 623"
../source/print_tokens2.exe  < ../inputs/tc10 > ../originals/t623
echo ">>>>>>>>running test 624"
../source/print_tokens2.exe  < ../inputs/tc100 > ../originals/t624
echo ">>>>>>>>running test 625"
../source/print_tokens2.exe  < ../inputs/tc101 > ../originals/t625
echo ">>>>>>>>running test 626"
../source/print_tokens2.exe  < ../inputs/tc102 > ../originals/t626
echo ">>>>>>>>running test 627"
../source/print_tokens2.exe  < ../inputs/tc103 > ../originals/t627
echo ">>>>>>>>running test 628"
../source/print_tokens2.exe  < ../inputs/tc104 > ../originals/t628
echo ">>>>>>>>running test 629"
../source/print_tokens2.exe  < ../inputs/tc105 > ../originals/t629
echo ">>>>>>>>running test 630"
../source/print_tokens2.exe  < ../inputs/tc106 > ../originals/t630
echo ">>>>>>>>running test 631"
../source/print_tokens2.exe  < ../inputs/tc107 > ../originals/t631
echo ">>>>>>>>running test 632"
../source/print_tokens2.exe  < ../inputs/tc108 > ../originals/t632
echo ">>>>>>>>running test 633"
../source/print_tokens2.exe  < ../inputs/tc109 > ../originals/t633
echo ">>>>>>>>running test 634"
../source/print_tokens2.exe  < ../inputs/tc11 > ../originals/t634
echo ">>>>>>>>running test 635"
../source/print_tokens2.exe  < ../inputs/tc110 > ../originals/t635
echo ">>>>>>>>running test 636"
../source/print_tokens2.exe  < ../inputs/tc111 > ../originals/t636
echo ">>>>>>>>running test 637"
../source/print_tokens2.exe  < ../inputs/tc112 > ../originals/t637
echo ">>>>>>>>running test 638"
../source/print_tokens2.exe  < ../inputs/tc113 > ../originals/t638
echo ">>>>>>>>running test 639"
../source/print_tokens2.exe  < ../inputs/tc114 > ../originals/t639
echo ">>>>>>>>running test 640"
../source/print_tokens2.exe  < ../inputs/tc115 > ../originals/t640
echo ">>>>>>>>running test 641"
../source/print_tokens2.exe  < ../inputs/tc116 > ../originals/t641
echo ">>>>>>>>running test 642"
../source/print_tokens2.exe  < ../inputs/tc117 > ../originals/t642
echo ">>>>>>>>running test 643"
../source/print_tokens2.exe  < ../inputs/tc118 > ../originals/t643
echo ">>>>>>>>running test 644"
../source/print_tokens2.exe  < ../inputs/tc119 > ../originals/t644
echo ">>>>>>>>running test 645"
../source/print_tokens2.exe  < ../inputs/tc12 > ../originals/t645
echo ">>>>>>>>running test 646"
../source/print_tokens2.exe  < ../inputs/tc120 > ../originals/t646
echo ">>>>>>>>running test 647"
../source/print_tokens2.exe  < ../inputs/tc121 > ../originals/t647
echo ">>>>>>>>running test 648"
../source/print_tokens2.exe  < ../inputs/tc122 > ../originals/t648
echo ">>>>>>>>running test 649"
../source/print_tokens2.exe  < ../inputs/tc123 > ../originals/t649
echo ">>>>>>>>running test 650"
../source/print_tokens2.exe  < ../inputs/tc124 > ../originals/t650
echo ">>>>>>>>running test 651"
../source/print_tokens2.exe  < ../inputs/tc125 > ../originals/t651
echo ">>>>>>>>running test 652"
../source/print_tokens2.exe  < ../inputs/tc126 > ../originals/t652
echo ">>>>>>>>running test 653"
../source/print_tokens2.exe  < ../inputs/tc127 > ../originals/t653
echo ">>>>>>>>running test 654"
../source/print_tokens2.exe  < ../inputs/tc128 > ../originals/t654
echo ">>>>>>>>running test 655"
../source/print_tokens2.exe  < ../inputs/tc129 > ../originals/t655
echo ">>>>>>>>running test 656"
../source/print_tokens2.exe  < ../inputs/tc13 > ../originals/t656
echo ">>>>>>>>running test 657"
../source/print_tokens2.exe  < ../inputs/tc130 > ../originals/t657
echo ">>>>>>>>running test 658"
../source/print_tokens2.exe  < ../inputs/tc131 > ../originals/t658
echo ">>>>>>>>running test 659"
../source/print_tokens2.exe  < ../inputs/tc132 > ../originals/t659
echo ">>>>>>>>running test 660"
../source/print_tokens2.exe  < ../inputs/tc133 > ../originals/t660
echo ">>>>>>>>running test 661"
../source/print_tokens2.exe  < ../inputs/tc134 > ../originals/t661
echo ">>>>>>>>running test 662"
../source/print_tokens2.exe  < ../inputs/tc135 > ../originals/t662
echo ">>>>>>>>running test 663"
../source/print_tokens2.exe  < ../inputs/tc136 > ../originals/t663
echo ">>>>>>>>running test 664"
../source/print_tokens2.exe  < ../inputs/tc137 > ../originals/t664
echo ">>>>>>>>running test 665"
../source/print_tokens2.exe  < ../inputs/tc138 > ../originals/t665
echo ">>>>>>>>running test 666"
../source/print_tokens2.exe  < ../inputs/tc139 > ../originals/t666
echo ">>>>>>>>running test 667"
../source/print_tokens2.exe  < ../inputs/tc14 > ../originals/t667
echo ">>>>>>>>running test 668"
../source/print_tokens2.exe  < ../inputs/tc140 > ../originals/t668
echo ">>>>>>>>running test 669"
../source/print_tokens2.exe  < ../inputs/tc141 > ../originals/t669
echo ">>>>>>>>running test 670"
../source/print_tokens2.exe  < ../inputs/tc142 > ../originals/t670
echo ">>>>>>>>running test 671"
../source/print_tokens2.exe  < ../inputs/tc143 > ../originals/t671
echo ">>>>>>>>running test 672"
../source/print_tokens2.exe  < ../inputs/tc144 > ../originals/t672
echo ">>>>>>>>running test 673"
../source/print_tokens2.exe  < ../inputs/tc145 > ../originals/t673
echo ">>>>>>>>running test 674"
../source/print_tokens2.exe  < ../inputs/tc146 > ../originals/t674
echo ">>>>>>>>running test 675"
../source/print_tokens2.exe  < ../inputs/tc147 > ../originals/t675
echo ">>>>>>>>running test 676"
../source/print_tokens2.exe  < ../inputs/tc148 > ../originals/t676
echo ">>>>>>>>running test 677"
../source/print_tokens2.exe  < ../inputs/tc149 > ../originals/t677
echo ">>>>>>>>running test 678"
../source/print_tokens2.exe  < ../inputs/tc15 > ../originals/t678
echo ">>>>>>>>running test 679"
../source/print_tokens2.exe  < ../inputs/tc150 > ../originals/t679
echo ">>>>>>>>running test 680"
../source/print_tokens2.exe  < ../inputs/tc151 > ../originals/t680
echo ">>>>>>>>running test 681"
../source/print_tokens2.exe  < ../inputs/tc152 > ../originals/t681
echo ">>>>>>>>running test 682"
../source/print_tokens2.exe  < ../inputs/tc153 > ../originals/t682
echo ">>>>>>>>running test 683"
../source/print_tokens2.exe  < ../inputs/tc154 > ../originals/t683
echo ">>>>>>>>running test 684"
../source/print_tokens2.exe  < ../inputs/tc155 > ../originals/t684
echo ">>>>>>>>running test 685"
../source/print_tokens2.exe  < ../inputs/tc156 > ../originals/t685
echo ">>>>>>>>running test 686"
../source/print_tokens2.exe  < ../inputs/tc157 > ../originals/t686
echo ">>>>>>>>running test 687"
../source/print_tokens2.exe  < ../inputs/tc158 > ../originals/t687
echo ">>>>>>>>running test 688"
../source/print_tokens2.exe  < ../inputs/tc159 > ../originals/t688
echo ">>>>>>>>running test 689"
../source/print_tokens2.exe  < ../inputs/tc16 > ../originals/t689
echo ">>>>>>>>running test 690"
../source/print_tokens2.exe  < ../inputs/tc160 > ../originals/t690
echo ">>>>>>>>running test 691"
../source/print_tokens2.exe  < ../inputs/tc161 > ../originals/t691
echo ">>>>>>>>running test 692"
../source/print_tokens2.exe  < ../inputs/tc162 > ../originals/t692
echo ">>>>>>>>running test 693"
../source/print_tokens2.exe  < ../inputs/tc163 > ../originals/t693
echo ">>>>>>>>running test 694"
../source/print_tokens2.exe  < ../inputs/tc164 > ../originals/t694
echo ">>>>>>>>running test 695"
../source/print_tokens2.exe  < ../inputs/tc165 > ../originals/t695
echo ">>>>>>>>running test 696"
../source/print_tokens2.exe  < ../inputs/tc166 > ../originals/t696
echo ">>>>>>>>running test 697"
../source/print_tokens2.exe  < ../inputs/tc167 > ../originals/t697
echo ">>>>>>>>running test 698"
../source/print_tokens2.exe  < ../inputs/tc168 > ../originals/t698
echo ">>>>>>>>running test 699"
../source/print_tokens2.exe  < ../inputs/tc169 > ../originals/t699
echo ">>>>>>>>running test 700"
../source/print_tokens2.exe  < ../inputs/tc17 > ../originals/t700
echo ">>>>>>>>running test 701"
../source/print_tokens2.exe  < ../inputs/tc170 > ../originals/t701
echo ">>>>>>>>running test 702"
../source/print_tokens2.exe  < ../inputs/tc171 > ../originals/t702
echo ">>>>>>>>running test 703"
../source/print_tokens2.exe  < ../inputs/tc172 > ../originals/t703
echo ">>>>>>>>running test 704"
../source/print_tokens2.exe  < ../inputs/tc173 > ../originals/t704
echo ">>>>>>>>running test 705"
../source/print_tokens2.exe  < ../inputs/tc174 > ../originals/t705
echo ">>>>>>>>running test 706"
../source/print_tokens2.exe  < ../inputs/tc175 > ../originals/t706
echo ">>>>>>>>running test 707"
../source/print_tokens2.exe  < ../inputs/tc176 > ../originals/t707
echo ">>>>>>>>running test 708"
../source/print_tokens2.exe  < ../inputs/tc177 > ../originals/t708
echo ">>>>>>>>running test 709"
../source/print_tokens2.exe  < ../inputs/tc178 > ../originals/t709
echo ">>>>>>>>running test 710"
../source/print_tokens2.exe  < ../inputs/tc179 > ../originals/t710
echo ">>>>>>>>running test 711"
../source/print_tokens2.exe  < ../inputs/tc18 > ../originals/t711
echo ">>>>>>>>running test 712"
../source/print_tokens2.exe  < ../inputs/tc180 > ../originals/t712
echo ">>>>>>>>running test 713"
../source/print_tokens2.exe  < ../inputs/tc181 > ../originals/t713
echo ">>>>>>>>running test 714"
../source/print_tokens2.exe  < ../inputs/tc182 > ../originals/t714
echo ">>>>>>>>running test 715"
../source/print_tokens2.exe  < ../inputs/tc183 > ../originals/t715
echo ">>>>>>>>running test 716"
../source/print_tokens2.exe  < ../inputs/tc184 > ../originals/t716
echo ">>>>>>>>running test 717"
../source/print_tokens2.exe  < ../inputs/tc185 > ../originals/t717
echo ">>>>>>>>running test 718"
../source/print_tokens2.exe  < ../inputs/tc186 > ../originals/t718
echo ">>>>>>>>running test 719"
../source/print_tokens2.exe  < ../inputs/tc187 > ../originals/t719
echo ">>>>>>>>running test 720"
../source/print_tokens2.exe  < ../inputs/tc188 > ../originals/t720
echo ">>>>>>>>running test 721"
../source/print_tokens2.exe  < ../inputs/tc189 > ../originals/t721
echo ">>>>>>>>running test 722"
../source/print_tokens2.exe  < ../inputs/tc19 > ../originals/t722
echo ">>>>>>>>running test 723"
../source/print_tokens2.exe  < ../inputs/tc190 > ../originals/t723
echo ">>>>>>>>running test 724"
../source/print_tokens2.exe  < ../inputs/tc191 > ../originals/t724
echo ">>>>>>>>running test 725"
../source/print_tokens2.exe  < ../inputs/tc192 > ../originals/t725
echo ">>>>>>>>running test 726"
../source/print_tokens2.exe  < ../inputs/tc193 > ../originals/t726
echo ">>>>>>>>running test 727"
../source/print_tokens2.exe  < ../inputs/tc194 > ../originals/t727
echo ">>>>>>>>running test 728"
../source/print_tokens2.exe  < ../inputs/tc195 > ../originals/t728
echo ">>>>>>>>running test 729"
../source/print_tokens2.exe  < ../inputs/tc196 > ../originals/t729
echo ">>>>>>>>running test 730"
../source/print_tokens2.exe  < ../inputs/tc197 > ../originals/t730
echo ">>>>>>>>running test 731"
../source/print_tokens2.exe  < ../inputs/tc198 > ../originals/t731
echo ">>>>>>>>running test 732"
../source/print_tokens2.exe  < ../inputs/tc199 > ../originals/t732
echo ">>>>>>>>running test 733"
../source/print_tokens2.exe  < ../inputs/tc2 > ../originals/t733
echo ">>>>>>>>running test 734"
../source/print_tokens2.exe  < ../inputs/tc20 > ../originals/t734
echo ">>>>>>>>running test 735"
../source/print_tokens2.exe  < ../inputs/tc200 > ../originals/t735
echo ">>>>>>>>running test 736"
../source/print_tokens2.exe  < ../inputs/tc201 > ../originals/t736
echo ">>>>>>>>running test 737"
../source/print_tokens2.exe  < ../inputs/tc202 > ../originals/t737
echo ">>>>>>>>running test 738"
../source/print_tokens2.exe  < ../inputs/tc203 > ../originals/t738
echo ">>>>>>>>running test 739"
../source/print_tokens2.exe  < ../inputs/tc204 > ../originals/t739
echo ">>>>>>>>running test 740"
../source/print_tokens2.exe  < ../inputs/tc205 > ../originals/t740
echo ">>>>>>>>running test 741"
../source/print_tokens2.exe  < ../inputs/tc206 > ../originals/t741
echo ">>>>>>>>running test 742"
../source/print_tokens2.exe  < ../inputs/tc207 > ../originals/t742
echo ">>>>>>>>running test 743"
../source/print_tokens2.exe  < ../inputs/tc208 > ../originals/t743
echo ">>>>>>>>running test 744"
../source/print_tokens2.exe  < ../inputs/tc209 > ../originals/t744
echo ">>>>>>>>running test 745"
../source/print_tokens2.exe  < ../inputs/tc21 > ../originals/t745
echo ">>>>>>>>running test 746"
../source/print_tokens2.exe  < ../inputs/tc210 > ../originals/t746
echo ">>>>>>>>running test 747"
../source/print_tokens2.exe  < ../inputs/tc211 > ../originals/t747
echo ">>>>>>>>running test 748"
../source/print_tokens2.exe  < ../inputs/tc212 > ../originals/t748
echo ">>>>>>>>running test 749"
../source/print_tokens2.exe  < ../inputs/tc213 > ../originals/t749
echo ">>>>>>>>running test 750"
../source/print_tokens2.exe  < ../inputs/tc214 > ../originals/t750
echo ">>>>>>>>running test 751"
../source/print_tokens2.exe  < ../inputs/tc215 > ../originals/t751
echo ">>>>>>>>running test 752"
../source/print_tokens2.exe  < ../inputs/tc216 > ../originals/t752
echo ">>>>>>>>running test 753"
../source/print_tokens2.exe  < ../inputs/tc217 > ../originals/t753
echo ">>>>>>>>running test 754"
../source/print_tokens2.exe  < ../inputs/tc218 > ../originals/t754
echo ">>>>>>>>running test 755"
../source/print_tokens2.exe  < ../inputs/tc219 > ../originals/t755
echo ">>>>>>>>running test 756"
../source/print_tokens2.exe  < ../inputs/tc22 > ../originals/t756
echo ">>>>>>>>running test 757"
../source/print_tokens2.exe  < ../inputs/tc220 > ../originals/t757
echo ">>>>>>>>running test 758"
../source/print_tokens2.exe  < ../inputs/tc221 > ../originals/t758
echo ">>>>>>>>running test 759"
../source/print_tokens2.exe  < ../inputs/tc222 > ../originals/t759
echo ">>>>>>>>running test 760"
../source/print_tokens2.exe  < ../inputs/tc223 > ../originals/t760
echo ">>>>>>>>running test 761"
../source/print_tokens2.exe  < ../inputs/tc224 > ../originals/t761
echo ">>>>>>>>running test 762"
../source/print_tokens2.exe  < ../inputs/tc225 > ../originals/t762
echo ">>>>>>>>running test 763"
../source/print_tokens2.exe  < ../inputs/tc226 > ../originals/t763
echo ">>>>>>>>running test 764"
../source/print_tokens2.exe  < ../inputs/tc227 > ../originals/t764
echo ">>>>>>>>running test 765"
../source/print_tokens2.exe  < ../inputs/tc228 > ../originals/t765
echo ">>>>>>>>running test 766"
../source/print_tokens2.exe  < ../inputs/tc229 > ../originals/t766
echo ">>>>>>>>running test 767"
../source/print_tokens2.exe  < ../inputs/tc23 > ../originals/t767
echo ">>>>>>>>running test 768"
../source/print_tokens2.exe  < ../inputs/tc230 > ../originals/t768
echo ">>>>>>>>running test 769"
../source/print_tokens2.exe  < ../inputs/tc231 > ../originals/t769
echo ">>>>>>>>running test 770"
../source/print_tokens2.exe  < ../inputs/tc232 > ../originals/t770
echo ">>>>>>>>running test 771"
../source/print_tokens2.exe  < ../inputs/tc233 > ../originals/t771
echo ">>>>>>>>running test 772"
../source/print_tokens2.exe  < ../inputs/tc234 > ../originals/t772
echo ">>>>>>>>running test 773"
../source/print_tokens2.exe  < ../inputs/tc235 > ../originals/t773
echo ">>>>>>>>running test 774"
../source/print_tokens2.exe  < ../inputs/tc236 > ../originals/t774
echo ">>>>>>>>running test 775"
../source/print_tokens2.exe  < ../inputs/tc237 > ../originals/t775
echo ">>>>>>>>running test 776"
../source/print_tokens2.exe  < ../inputs/tc238 > ../originals/t776
echo ">>>>>>>>running test 777"
../source/print_tokens2.exe  < ../inputs/tc239 > ../originals/t777
echo ">>>>>>>>running test 778"
../source/print_tokens2.exe  < ../inputs/tc24 > ../originals/t778
echo ">>>>>>>>running test 779"
../source/print_tokens2.exe  < ../inputs/tc240 > ../originals/t779
echo ">>>>>>>>running test 780"
../source/print_tokens2.exe  < ../inputs/tc241 > ../originals/t780
echo ">>>>>>>>running test 781"
../source/print_tokens2.exe  < ../inputs/tc242 > ../originals/t781
echo ">>>>>>>>running test 782"
../source/print_tokens2.exe  < ../inputs/tc243 > ../originals/t782
echo ">>>>>>>>running test 783"
../source/print_tokens2.exe  < ../inputs/tc244 > ../originals/t783
echo ">>>>>>>>running test 784"
../source/print_tokens2.exe  < ../inputs/tc245 > ../originals/t784
echo ">>>>>>>>running test 785"
../source/print_tokens2.exe  < ../inputs/tc246 > ../originals/t785
echo ">>>>>>>>running test 786"
../source/print_tokens2.exe  < ../inputs/tc247 > ../originals/t786
echo ">>>>>>>>running test 787"
../source/print_tokens2.exe  < ../inputs/tc248 > ../originals/t787
echo ">>>>>>>>running test 788"
../source/print_tokens2.exe  < ../inputs/tc249 > ../originals/t788
echo ">>>>>>>>running test 789"
../source/print_tokens2.exe  < ../inputs/tc25 > ../originals/t789
echo ">>>>>>>>running test 790"
../source/print_tokens2.exe  < ../inputs/tc250 > ../originals/t790
echo ">>>>>>>>running test 791"
../source/print_tokens2.exe  < ../inputs/tc251 > ../originals/t791
echo ">>>>>>>>running test 792"
../source/print_tokens2.exe  < ../inputs/tc252 > ../originals/t792
echo ">>>>>>>>running test 793"
../source/print_tokens2.exe  < ../inputs/tc253 > ../originals/t793
echo ">>>>>>>>running test 794"
../source/print_tokens2.exe  < ../inputs/tc254 > ../originals/t794
echo ">>>>>>>>running test 795"
../source/print_tokens2.exe  < ../inputs/tc255 > ../originals/t795
echo ">>>>>>>>running test 796"
../source/print_tokens2.exe  < ../inputs/tc256 > ../originals/t796
echo ">>>>>>>>running test 797"
../source/print_tokens2.exe  < ../inputs/tc257 > ../originals/t797
echo ">>>>>>>>running test 798"
../source/print_tokens2.exe  < ../inputs/tc258 > ../originals/t798
echo ">>>>>>>>running test 799"
../source/print_tokens2.exe  < ../inputs/tc259 > ../originals/t799
echo ">>>>>>>>running test 800"
../source/print_tokens2.exe  < ../inputs/tc26 > ../originals/t800
echo ">>>>>>>>running test 801"
../source/print_tokens2.exe  < ../inputs/tc260 > ../originals/t801
echo ">>>>>>>>running test 802"
../source/print_tokens2.exe  < ../inputs/tc261 > ../originals/t802
echo ">>>>>>>>running test 803"
../source/print_tokens2.exe  < ../inputs/tc262 > ../originals/t803
echo ">>>>>>>>running test 804"
../source/print_tokens2.exe  < ../inputs/tc263 > ../originals/t804
echo ">>>>>>>>running test 805"
../source/print_tokens2.exe  < ../inputs/tc264 > ../originals/t805
echo ">>>>>>>>running test 806"
../source/print_tokens2.exe  < ../inputs/tc265 > ../originals/t806
echo ">>>>>>>>running test 807"
../source/print_tokens2.exe  < ../inputs/tc266 > ../originals/t807
echo ">>>>>>>>running test 808"
../source/print_tokens2.exe  < ../inputs/tc267 > ../originals/t808
echo ">>>>>>>>running test 809"
../source/print_tokens2.exe  < ../inputs/tc268 > ../originals/t809
echo ">>>>>>>>running test 810"
../source/print_tokens2.exe  < ../inputs/tc269 > ../originals/t810
echo ">>>>>>>>running test 811"
../source/print_tokens2.exe  < ../inputs/tc27 > ../originals/t811
echo ">>>>>>>>running test 812"
../source/print_tokens2.exe  < ../inputs/tc270 > ../originals/t812
echo ">>>>>>>>running test 813"
../source/print_tokens2.exe  < ../inputs/tc271 > ../originals/t813
echo ">>>>>>>>running test 814"
../source/print_tokens2.exe  < ../inputs/tc272 > ../originals/t814
echo ">>>>>>>>running test 815"
../source/print_tokens2.exe  < ../inputs/tc273 > ../originals/t815
echo ">>>>>>>>running test 816"
../source/print_tokens2.exe  < ../inputs/tc274 > ../originals/t816
echo ">>>>>>>>running test 817"
../source/print_tokens2.exe  < ../inputs/tc275 > ../originals/t817
echo ">>>>>>>>running test 818"
../source/print_tokens2.exe  < ../inputs/tc276 > ../originals/t818
echo ">>>>>>>>running test 819"
../source/print_tokens2.exe  < ../inputs/tc277 > ../originals/t819
echo ">>>>>>>>running test 820"
../source/print_tokens2.exe  < ../inputs/tc278 > ../originals/t820
echo ">>>>>>>>running test 821"
../source/print_tokens2.exe  < ../inputs/tc279 > ../originals/t821
echo ">>>>>>>>running test 822"
../source/print_tokens2.exe  < ../inputs/tc28 > ../originals/t822
echo ">>>>>>>>running test 823"
../source/print_tokens2.exe  < ../inputs/tc280 > ../originals/t823
echo ">>>>>>>>running test 824"
../source/print_tokens2.exe  < ../inputs/tc281 > ../originals/t824
echo ">>>>>>>>running test 825"
../source/print_tokens2.exe  < ../inputs/tc282 > ../originals/t825
echo ">>>>>>>>running test 826"
../source/print_tokens2.exe  < ../inputs/tc283 > ../originals/t826
echo ">>>>>>>>running test 827"
../source/print_tokens2.exe  < ../inputs/tc284 > ../originals/t827
echo ">>>>>>>>running test 828"
../source/print_tokens2.exe  < ../inputs/tc285 > ../originals/t828
echo ">>>>>>>>running test 829"
../source/print_tokens2.exe  < ../inputs/tc286 > ../originals/t829
echo ">>>>>>>>running test 830"
../source/print_tokens2.exe  < ../inputs/tc287 > ../originals/t830
echo ">>>>>>>>running test 831"
../source/print_tokens2.exe  < ../inputs/tc288 > ../originals/t831
echo ">>>>>>>>running test 832"
../source/print_tokens2.exe  < ../inputs/tc289 > ../originals/t832
echo ">>>>>>>>running test 833"
../source/print_tokens2.exe  < ../inputs/tc29 > ../originals/t833
echo ">>>>>>>>running test 834"
../source/print_tokens2.exe  < ../inputs/tc290 > ../originals/t834
echo ">>>>>>>>running test 835"
../source/print_tokens2.exe  < ../inputs/tc291 > ../originals/t835
echo ">>>>>>>>running test 836"
../source/print_tokens2.exe  < ../inputs/tc292 > ../originals/t836
echo ">>>>>>>>running test 837"
../source/print_tokens2.exe  < ../inputs/tc293 > ../originals/t837
echo ">>>>>>>>running test 838"
../source/print_tokens2.exe  < ../inputs/tc294 > ../originals/t838
echo ">>>>>>>>running test 839"
../source/print_tokens2.exe  < ../inputs/tc295 > ../originals/t839
echo ">>>>>>>>running test 840"
../source/print_tokens2.exe  < ../inputs/tc296 > ../originals/t840
echo ">>>>>>>>running test 841"
../source/print_tokens2.exe  < ../inputs/tc297 > ../originals/t841
echo ">>>>>>>>running test 842"
../source/print_tokens2.exe  < ../inputs/tc298 > ../originals/t842
echo ">>>>>>>>running test 843"
../source/print_tokens2.exe  < ../inputs/tc299 > ../originals/t843
echo ">>>>>>>>running test 844"
../source/print_tokens2.exe  < ../inputs/tc3 > ../originals/t844
echo ">>>>>>>>running test 845"
../source/print_tokens2.exe  < ../inputs/tc30 > ../originals/t845
echo ">>>>>>>>running test 846"
../source/print_tokens2.exe  < ../inputs/tc300 > ../originals/t846
echo ">>>>>>>>running test 847"
../source/print_tokens2.exe  < ../inputs/tc301 > ../originals/t847
echo ">>>>>>>>running test 848"
../source/print_tokens2.exe  < ../inputs/tc302 > ../originals/t848
echo ">>>>>>>>running test 849"
../source/print_tokens2.exe  < ../inputs/tc303 > ../originals/t849
echo ">>>>>>>>running test 850"
../source/print_tokens2.exe  < ../inputs/tc304 > ../originals/t850
echo ">>>>>>>>running test 851"
../source/print_tokens2.exe  < ../inputs/tc305 > ../originals/t851
echo ">>>>>>>>running test 852"
../source/print_tokens2.exe  < ../inputs/tc306 > ../originals/t852
echo ">>>>>>>>running test 853"
../source/print_tokens2.exe  < ../inputs/tc307 > ../originals/t853
echo ">>>>>>>>running test 854"
../source/print_tokens2.exe  < ../inputs/tc308 > ../originals/t854
echo ">>>>>>>>running test 855"
../source/print_tokens2.exe  < ../inputs/tc309 > ../originals/t855
echo ">>>>>>>>running test 856"
../source/print_tokens2.exe  < ../inputs/tc31 > ../originals/t856
echo ">>>>>>>>running test 857"
../source/print_tokens2.exe  < ../inputs/tc310 > ../originals/t857
echo ">>>>>>>>running test 858"
../source/print_tokens2.exe  < ../inputs/tc311 > ../originals/t858
echo ">>>>>>>>running test 859"
../source/print_tokens2.exe  < ../inputs/tc312 > ../originals/t859
echo ">>>>>>>>running test 860"
../source/print_tokens2.exe  < ../inputs/tc313 > ../originals/t860
echo ">>>>>>>>running test 861"
../source/print_tokens2.exe  < ../inputs/tc314 > ../originals/t861
echo ">>>>>>>>running test 862"
../source/print_tokens2.exe  < ../inputs/tc315 > ../originals/t862
echo ">>>>>>>>running test 863"
../source/print_tokens2.exe  < ../inputs/tc316 > ../originals/t863
echo ">>>>>>>>running test 864"
../source/print_tokens2.exe  < ../inputs/tc317 > ../originals/t864
echo ">>>>>>>>running test 865"
../source/print_tokens2.exe  < ../inputs/tc318 > ../originals/t865
echo ">>>>>>>>running test 866"
../source/print_tokens2.exe  < ../inputs/tc319 > ../originals/t866
echo ">>>>>>>>running test 867"
../source/print_tokens2.exe  < ../inputs/tc32 > ../originals/t867
echo ">>>>>>>>running test 868"
../source/print_tokens2.exe  < ../inputs/tc320 > ../originals/t868
echo ">>>>>>>>running test 869"
../source/print_tokens2.exe  < ../inputs/tc321 > ../originals/t869
echo ">>>>>>>>running test 870"
../source/print_tokens2.exe  < ../inputs/tc322 > ../originals/t870
echo ">>>>>>>>running test 871"
../source/print_tokens2.exe  < ../inputs/tc323 > ../originals/t871
echo ">>>>>>>>running test 872"
../source/print_tokens2.exe  < ../inputs/tc324 > ../originals/t872
echo ">>>>>>>>running test 873"
../source/print_tokens2.exe  < ../inputs/tc325 > ../originals/t873
echo ">>>>>>>>running test 874"
../source/print_tokens2.exe  < ../inputs/tc326 > ../originals/t874
echo ">>>>>>>>running test 875"
../source/print_tokens2.exe  < ../inputs/tc327 > ../originals/t875
echo ">>>>>>>>running test 876"
../source/print_tokens2.exe  < ../inputs/tc328 > ../originals/t876
echo ">>>>>>>>running test 877"
../source/print_tokens2.exe  < ../inputs/tc329 > ../originals/t877
echo ">>>>>>>>running test 878"
../source/print_tokens2.exe  < ../inputs/tc33 > ../originals/t878
echo ">>>>>>>>running test 879"
../source/print_tokens2.exe  < ../inputs/tc330 > ../originals/t879
echo ">>>>>>>>running test 880"
../source/print_tokens2.exe  < ../inputs/tc331 > ../originals/t880
echo ">>>>>>>>running test 881"
../source/print_tokens2.exe  < ../inputs/tc332 > ../originals/t881
echo ">>>>>>>>running test 882"
../source/print_tokens2.exe  < ../inputs/tc333 > ../originals/t882
echo ">>>>>>>>running test 883"
../source/print_tokens2.exe  < ../inputs/tc334 > ../originals/t883
echo ">>>>>>>>running test 884"
../source/print_tokens2.exe  < ../inputs/tc335 > ../originals/t884
echo ">>>>>>>>running test 885"
../source/print_tokens2.exe  < ../inputs/tc336 > ../originals/t885
echo ">>>>>>>>running test 886"
../source/print_tokens2.exe  < ../inputs/tc337 > ../originals/t886
echo ">>>>>>>>running test 887"
../source/print_tokens2.exe  < ../inputs/tc338 > ../originals/t887
echo ">>>>>>>>running test 888"
../source/print_tokens2.exe  < ../inputs/tc339 > ../originals/t888
echo ">>>>>>>>running test 889"
../source/print_tokens2.exe  < ../inputs/tc34 > ../originals/t889
echo ">>>>>>>>running test 890"
../source/print_tokens2.exe  < ../inputs/tc340 > ../originals/t890
echo ">>>>>>>>running test 891"
../source/print_tokens2.exe  < ../inputs/tc341 > ../originals/t891
echo ">>>>>>>>running test 892"
../source/print_tokens2.exe  < ../inputs/tc342 > ../originals/t892
echo ">>>>>>>>running test 893"
../source/print_tokens2.exe  < ../inputs/tc343 > ../originals/t893
echo ">>>>>>>>running test 894"
../source/print_tokens2.exe  < ../inputs/tc344 > ../originals/t894
echo ">>>>>>>>running test 895"
../source/print_tokens2.exe  < ../inputs/tc345 > ../originals/t895
echo ">>>>>>>>running test 896"
../source/print_tokens2.exe  < ../inputs/tc346 > ../originals/t896
echo ">>>>>>>>running test 897"
../source/print_tokens2.exe  < ../inputs/tc347 > ../originals/t897
echo ">>>>>>>>running test 898"
../source/print_tokens2.exe  < ../inputs/tc348 > ../originals/t898
echo ">>>>>>>>running test 899"
../source/print_tokens2.exe  < ../inputs/tc349 > ../originals/t899
echo ">>>>>>>>running test 900"
../source/print_tokens2.exe  < ../inputs/tc35 > ../originals/t900
echo ">>>>>>>>running test 901"
../source/print_tokens2.exe  < ../inputs/tc350 > ../originals/t901
echo ">>>>>>>>running test 902"
../source/print_tokens2.exe  < ../inputs/tc351 > ../originals/t902
echo ">>>>>>>>running test 903"
../source/print_tokens2.exe  < ../inputs/tc352 > ../originals/t903
echo ">>>>>>>>running test 904"
../source/print_tokens2.exe  < ../inputs/tc353 > ../originals/t904
echo ">>>>>>>>running test 905"
../source/print_tokens2.exe  < ../inputs/tc354 > ../originals/t905
echo ">>>>>>>>running test 906"
../source/print_tokens2.exe  < ../inputs/tc355 > ../originals/t906
echo ">>>>>>>>running test 907"
../source/print_tokens2.exe  < ../inputs/tc356 > ../originals/t907
echo ">>>>>>>>running test 908"
../source/print_tokens2.exe  < ../inputs/tc357 > ../originals/t908
echo ">>>>>>>>running test 909"
../source/print_tokens2.exe  < ../inputs/tc358 > ../originals/t909
echo ">>>>>>>>running test 910"
../source/print_tokens2.exe  < ../inputs/tc359 > ../originals/t910
echo ">>>>>>>>running test 911"
../source/print_tokens2.exe  < ../inputs/tc36 > ../originals/t911
echo ">>>>>>>>running test 912"
../source/print_tokens2.exe  < ../inputs/tc360 > ../originals/t912
echo ">>>>>>>>running test 913"
../source/print_tokens2.exe  < ../inputs/tc361 > ../originals/t913
echo ">>>>>>>>running test 914"
../source/print_tokens2.exe  < ../inputs/tc362 > ../originals/t914
echo ">>>>>>>>running test 915"
../source/print_tokens2.exe  < ../inputs/tc363 > ../originals/t915
echo ">>>>>>>>running test 916"
../source/print_tokens2.exe  < ../inputs/tc364 > ../originals/t916
echo ">>>>>>>>running test 917"
../source/print_tokens2.exe  < ../inputs/tc365 > ../originals/t917
echo ">>>>>>>>running test 918"
../source/print_tokens2.exe  < ../inputs/tc366 > ../originals/t918
echo ">>>>>>>>running test 919"
../source/print_tokens2.exe  < ../inputs/tc367 > ../originals/t919
echo ">>>>>>>>running test 920"
../source/print_tokens2.exe  < ../inputs/tc368 > ../originals/t920
echo ">>>>>>>>running test 921"
../source/print_tokens2.exe  < ../inputs/tc369 > ../originals/t921
echo ">>>>>>>>running test 922"
../source/print_tokens2.exe  < ../inputs/tc37 > ../originals/t922
echo ">>>>>>>>running test 923"
../source/print_tokens2.exe  < ../inputs/tc370 > ../originals/t923
echo ">>>>>>>>running test 924"
../source/print_tokens2.exe  < ../inputs/tc371 > ../originals/t924
echo ">>>>>>>>running test 925"
../source/print_tokens2.exe  < ../inputs/tc372 > ../originals/t925
echo ">>>>>>>>running test 926"
../source/print_tokens2.exe  < ../inputs/tc373 > ../originals/t926
echo ">>>>>>>>running test 927"
../source/print_tokens2.exe  < ../inputs/tc374 > ../originals/t927
echo ">>>>>>>>running test 928"
../source/print_tokens2.exe  < ../inputs/tc375 > ../originals/t928
echo ">>>>>>>>running test 929"
../source/print_tokens2.exe  < ../inputs/tc376 > ../originals/t929
echo ">>>>>>>>running test 930"
../source/print_tokens2.exe  < ../inputs/tc377 > ../originals/t930
echo ">>>>>>>>running test 931"
../source/print_tokens2.exe  < ../inputs/tc378 > ../originals/t931
echo ">>>>>>>>running test 932"
../source/print_tokens2.exe  < ../inputs/tc379 > ../originals/t932
echo ">>>>>>>>running test 933"
../source/print_tokens2.exe  < ../inputs/tc38 > ../originals/t933
echo ">>>>>>>>running test 934"
../source/print_tokens2.exe  < ../inputs/tc380 > ../originals/t934
echo ">>>>>>>>running test 935"
../source/print_tokens2.exe  < ../inputs/tc381 > ../originals/t935
echo ">>>>>>>>running test 936"
../source/print_tokens2.exe  < ../inputs/tc382 > ../originals/t936
echo ">>>>>>>>running test 937"
../source/print_tokens2.exe  < ../inputs/tc383 > ../originals/t937
echo ">>>>>>>>running test 938"
../source/print_tokens2.exe  < ../inputs/tc384 > ../originals/t938
echo ">>>>>>>>running test 939"
../source/print_tokens2.exe  < ../inputs/tc385 > ../originals/t939
echo ">>>>>>>>running test 940"
../source/print_tokens2.exe  < ../inputs/tc386 > ../originals/t940
echo ">>>>>>>>running test 941"
../source/print_tokens2.exe  < ../inputs/tc387 > ../originals/t941
echo ">>>>>>>>running test 942"
../source/print_tokens2.exe  < ../inputs/tc388 > ../originals/t942
echo ">>>>>>>>running test 943"
../source/print_tokens2.exe  < ../inputs/tc389 > ../originals/t943
echo ">>>>>>>>running test 944"
../source/print_tokens2.exe  < ../inputs/tc39 > ../originals/t944
echo ">>>>>>>>running test 945"
../source/print_tokens2.exe  < ../inputs/tc390 > ../originals/t945
echo ">>>>>>>>running test 946"
../source/print_tokens2.exe  < ../inputs/tc391 > ../originals/t946
echo ">>>>>>>>running test 947"
../source/print_tokens2.exe  < ../inputs/tc392 > ../originals/t947
echo ">>>>>>>>running test 948"
../source/print_tokens2.exe  < ../inputs/tc393 > ../originals/t948
echo ">>>>>>>>running test 949"
../source/print_tokens2.exe  < ../inputs/tc394 > ../originals/t949
echo ">>>>>>>>running test 950"
../source/print_tokens2.exe  < ../inputs/tc395 > ../originals/t950
echo ">>>>>>>>running test 951"
../source/print_tokens2.exe  < ../inputs/tc396 > ../originals/t951
echo ">>>>>>>>running test 952"
../source/print_tokens2.exe  < ../inputs/tc397 > ../originals/t952
echo ">>>>>>>>running test 953"
../source/print_tokens2.exe  < ../inputs/tc398 > ../originals/t953
echo ">>>>>>>>running test 954"
../source/print_tokens2.exe  < ../inputs/tc399 > ../originals/t954
echo ">>>>>>>>running test 955"
../source/print_tokens2.exe  < ../inputs/tc4 > ../originals/t955
echo ">>>>>>>>running test 956"
../source/print_tokens2.exe  < ../inputs/tc40 > ../originals/t956
echo ">>>>>>>>running test 957"
../source/print_tokens2.exe  < ../inputs/tc400 > ../originals/t957
echo ">>>>>>>>running test 958"
../source/print_tokens2.exe  < ../inputs/tc41 > ../originals/t958
echo ">>>>>>>>running test 959"
../source/print_tokens2.exe  < ../inputs/tc42 > ../originals/t959
echo ">>>>>>>>running test 960"
../source/print_tokens2.exe  < ../inputs/tc43 > ../originals/t960
echo ">>>>>>>>running test 961"
../source/print_tokens2.exe  < ../inputs/tc44 > ../originals/t961
echo ">>>>>>>>running test 962"
../source/print_tokens2.exe  < ../inputs/tc45 > ../originals/t962
echo ">>>>>>>>running test 963"
../source/print_tokens2.exe  < ../inputs/tc46 > ../originals/t963
echo ">>>>>>>>running test 964"
../source/print_tokens2.exe  < ../inputs/tc47 > ../originals/t964
echo ">>>>>>>>running test 965"
../source/print_tokens2.exe  < ../inputs/tc48 > ../originals/t965
echo ">>>>>>>>running test 966"
../source/print_tokens2.exe  < ../inputs/tc49 > ../originals/t966
echo ">>>>>>>>running test 967"
../source/print_tokens2.exe  < ../inputs/tc5 > ../originals/t967
echo ">>>>>>>>running test 968"
../source/print_tokens2.exe  < ../inputs/tc50 > ../originals/t968
echo ">>>>>>>>running test 969"
../source/print_tokens2.exe  < ../inputs/tc51 > ../originals/t969
echo ">>>>>>>>running test 970"
../source/print_tokens2.exe  < ../inputs/tc52 > ../originals/t970
echo ">>>>>>>>running test 971"
../source/print_tokens2.exe  < ../inputs/tc53 > ../originals/t971
echo ">>>>>>>>running test 972"
../source/print_tokens2.exe  < ../inputs/tc54 > ../originals/t972
echo ">>>>>>>>running test 973"
../source/print_tokens2.exe  < ../inputs/tc55 > ../originals/t973
echo ">>>>>>>>running test 974"
../source/print_tokens2.exe  < ../inputs/tc56 > ../originals/t974
echo ">>>>>>>>running test 975"
../source/print_tokens2.exe  < ../inputs/tc57 > ../originals/t975
echo ">>>>>>>>running test 976"
../source/print_tokens2.exe  < ../inputs/tc58 > ../originals/t976
echo ">>>>>>>>running test 977"
../source/print_tokens2.exe  < ../inputs/tc59 > ../originals/t977
echo ">>>>>>>>running test 978"
../source/print_tokens2.exe  < ../inputs/tc6 > ../originals/t978
echo ">>>>>>>>running test 979"
../source/print_tokens2.exe  < ../inputs/tc60 > ../originals/t979
echo ">>>>>>>>running test 980"
../source/print_tokens2.exe  < ../inputs/tc61 > ../originals/t980
echo ">>>>>>>>running test 981"
../source/print_tokens2.exe  < ../inputs/tc62 > ../originals/t981
echo ">>>>>>>>running test 982"
../source/print_tokens2.exe  < ../inputs/tc63 > ../originals/t982
echo ">>>>>>>>running test 983"
../source/print_tokens2.exe  < ../inputs/tc64 > ../originals/t983
echo ">>>>>>>>running test 984"
../source/print_tokens2.exe  < ../inputs/tc65 > ../originals/t984
echo ">>>>>>>>running test 985"
../source/print_tokens2.exe  < ../inputs/tc66 > ../originals/t985
echo ">>>>>>>>running test 986"
../source/print_tokens2.exe  < ../inputs/tc67 > ../originals/t986
echo ">>>>>>>>running test 987"
../source/print_tokens2.exe  < ../inputs/tc68 > ../originals/t987
echo ">>>>>>>>running test 988"
../source/print_tokens2.exe  < ../inputs/tc69 > ../originals/t988
echo ">>>>>>>>running test 989"
../source/print_tokens2.exe  < ../inputs/tc7 > ../originals/t989
echo ">>>>>>>>running test 990"
../source/print_tokens2.exe  < ../inputs/tc70 > ../originals/t990
echo ">>>>>>>>running test 991"
../source/print_tokens2.exe  < ../inputs/tc71 > ../originals/t991
echo ">>>>>>>>running test 992"
../source/print_tokens2.exe  < ../inputs/tc72 > ../originals/t992
echo ">>>>>>>>running test 993"
../source/print_tokens2.exe  < ../inputs/tc73 > ../originals/t993
echo ">>>>>>>>running test 994"
../source/print_tokens2.exe  < ../inputs/tc74 > ../originals/t994
echo ">>>>>>>>running test 995"
../source/print_tokens2.exe  < ../inputs/tc75 > ../originals/t995
echo ">>>>>>>>running test 996"
../source/print_tokens2.exe  < ../inputs/tc76 > ../originals/t996
echo ">>>>>>>>running test 997"
../source/print_tokens2.exe  < ../inputs/tc77 > ../originals/t997
echo ">>>>>>>>running test 998"
../source/print_tokens2.exe  < ../inputs/tc78 > ../originals/t998
echo ">>>>>>>>running test 999"
../source/print_tokens2.exe  < ../inputs/tc79 > ../originals/t999
echo ">>>>>>>>running test 1000"
../source/print_tokens2.exe  < ../inputs/tc8 > ../originals/t1000
echo ">>>>>>>>running test 1001"
../source/print_tokens2.exe  < ../inputs/tc80 > ../originals/t1001
echo ">>>>>>>>running test 1002"
../source/print_tokens2.exe  < ../inputs/tc81 > ../originals/t1002
echo ">>>>>>>>running test 1003"
../source/print_tokens2.exe  < ../inputs/tc82 > ../originals/t1003
echo ">>>>>>>>running test 1004"
../source/print_tokens2.exe  < ../inputs/tc83 > ../originals/t1004
echo ">>>>>>>>running test 1005"
../source/print_tokens2.exe  < ../inputs/tc84 > ../originals/t1005
echo ">>>>>>>>running test 1006"
../source/print_tokens2.exe  < ../inputs/tc85 > ../originals/t1006
echo ">>>>>>>>running test 1007"
../source/print_tokens2.exe  < ../inputs/tc86 > ../originals/t1007
echo ">>>>>>>>running test 1008"
../source/print_tokens2.exe  < ../inputs/tc87 > ../originals/t1008
echo ">>>>>>>>running test 1009"
../source/print_tokens2.exe  < ../inputs/tc88 > ../originals/t1009
echo ">>>>>>>>running test 1010"
../source/print_tokens2.exe  < ../inputs/tc89 > ../originals/t1010
echo ">>>>>>>>running test 1011"
../source/print_tokens2.exe  < ../inputs/tc9 > ../originals/t1011
echo ">>>>>>>>running test 1012"
../source/print_tokens2.exe  < ../inputs/tc90 > ../originals/t1012
echo ">>>>>>>>running test 1013"
../source/print_tokens2.exe  < ../inputs/tc91 > ../originals/t1013
echo ">>>>>>>>running test 1014"
../source/print_tokens2.exe  < ../inputs/tc92 > ../originals/t1014
echo ">>>>>>>>running test 1015"
../source/print_tokens2.exe  < ../inputs/tc93 > ../originals/t1015
echo ">>>>>>>>running test 1016"
../source/print_tokens2.exe  < ../inputs/tc94 > ../originals/t1016
echo ">>>>>>>>running test 1017"
../source/print_tokens2.exe  < ../inputs/tc95 > ../originals/t1017
echo ">>>>>>>>running test 1018"
../source/print_tokens2.exe  < ../inputs/tc96 > ../originals/t1018
echo ">>>>>>>>running test 1019"
../source/print_tokens2.exe  < ../inputs/tc97 > ../originals/t1019
echo ">>>>>>>>running test 1020"
../source/print_tokens2.exe  < ../inputs/tc98 > ../originals/t1020
echo ">>>>>>>>running test 1021"
../source/print_tokens2.exe  < ../inputs/tc99 > ../originals/t1021
echo ">>>>>>>>running test 1022"
../source/print_tokens2.exe  < ../inputs/test1 > ../originals/t1022
echo ">>>>>>>>running test 1023"
../source/print_tokens2.exe  < ../inputs/test10 > ../originals/t1023
echo ">>>>>>>>running test 1024"
../source/print_tokens2.exe  < ../inputs/test100 > ../originals/t1024
echo ">>>>>>>>running test 1025"
../source/print_tokens2.exe  < ../inputs/test101 > ../originals/t1025
echo ">>>>>>>>running test 1026"
../source/print_tokens2.exe  < ../inputs/test102 > ../originals/t1026
echo ">>>>>>>>running test 1027"
../source/print_tokens2.exe  < ../inputs/test103 > ../originals/t1027
echo ">>>>>>>>running test 1028"
../source/print_tokens2.exe  < ../inputs/test104 > ../originals/t1028
echo ">>>>>>>>running test 1029"
../source/print_tokens2.exe  < ../inputs/test105 > ../originals/t1029
echo ">>>>>>>>running test 1030"
../source/print_tokens2.exe  < ../inputs/test106 > ../originals/t1030
echo ">>>>>>>>running test 1031"
../source/print_tokens2.exe  < ../inputs/test107 > ../originals/t1031
echo ">>>>>>>>running test 1032"
../source/print_tokens2.exe  < ../inputs/test108 > ../originals/t1032
echo ">>>>>>>>running test 1033"
../source/print_tokens2.exe  < ../inputs/test109 > ../originals/t1033
echo ">>>>>>>>running test 1034"
../source/print_tokens2.exe  < ../inputs/test11 > ../originals/t1034
echo ">>>>>>>>running test 1035"
../source/print_tokens2.exe  < ../inputs/test110 > ../originals/t1035
echo ">>>>>>>>running test 1036"
../source/print_tokens2.exe  < ../inputs/test111 > ../originals/t1036
echo ">>>>>>>>running test 1037"
../source/print_tokens2.exe  < ../inputs/test112 > ../originals/t1037
echo ">>>>>>>>running test 1038"
../source/print_tokens2.exe  < ../inputs/test113 > ../originals/t1038
echo ">>>>>>>>running test 1039"
../source/print_tokens2.exe  < ../inputs/test114 > ../originals/t1039
echo ">>>>>>>>running test 1040"
../source/print_tokens2.exe  < ../inputs/test115 > ../originals/t1040
echo ">>>>>>>>running test 1041"
../source/print_tokens2.exe  < ../inputs/test116 > ../originals/t1041
echo ">>>>>>>>running test 1042"
../source/print_tokens2.exe  < ../inputs/test117 > ../originals/t1042
echo ">>>>>>>>running test 1043"
../source/print_tokens2.exe  < ../inputs/test118 > ../originals/t1043
echo ">>>>>>>>running test 1044"
../source/print_tokens2.exe  < ../inputs/test119 > ../originals/t1044
echo ">>>>>>>>running test 1045"
../source/print_tokens2.exe  < ../inputs/test12 > ../originals/t1045
echo ">>>>>>>>running test 1046"
../source/print_tokens2.exe  < ../inputs/test120 > ../originals/t1046
echo ">>>>>>>>running test 1047"
../source/print_tokens2.exe  < ../inputs/test121 > ../originals/t1047
echo ">>>>>>>>running test 1048"
../source/print_tokens2.exe  < ../inputs/test122 > ../originals/t1048
echo ">>>>>>>>running test 1049"
../source/print_tokens2.exe  < ../inputs/test123 > ../originals/t1049
echo ">>>>>>>>running test 1050"
../source/print_tokens2.exe  < ../inputs/test124 > ../originals/t1050
echo ">>>>>>>>running test 1051"
../source/print_tokens2.exe  < ../inputs/test125 > ../originals/t1051
echo ">>>>>>>>running test 1052"
../source/print_tokens2.exe  < ../inputs/test126 > ../originals/t1052
echo ">>>>>>>>running test 1053"
../source/print_tokens2.exe  < ../inputs/test127 > ../originals/t1053
echo ">>>>>>>>running test 1054"
../source/print_tokens2.exe  < ../inputs/test128 > ../originals/t1054
echo ">>>>>>>>running test 1055"
../source/print_tokens2.exe  < ../inputs/test129 > ../originals/t1055
echo ">>>>>>>>running test 1056"
../source/print_tokens2.exe  < ../inputs/test13 > ../originals/t1056
echo ">>>>>>>>running test 1057"
../source/print_tokens2.exe  < ../inputs/test130 > ../originals/t1057
echo ">>>>>>>>running test 1058"
../source/print_tokens2.exe  < ../inputs/test131 > ../originals/t1058
echo ">>>>>>>>running test 1059"
../source/print_tokens2.exe  < ../inputs/test132 > ../originals/t1059
echo ">>>>>>>>running test 1060"
../source/print_tokens2.exe  < ../inputs/test133 > ../originals/t1060
echo ">>>>>>>>running test 1061"
../source/print_tokens2.exe  < ../inputs/test134 > ../originals/t1061
echo ">>>>>>>>running test 1062"
../source/print_tokens2.exe  < ../inputs/test135 > ../originals/t1062
echo ">>>>>>>>running test 1063"
../source/print_tokens2.exe  < ../inputs/test136 > ../originals/t1063
echo ">>>>>>>>running test 1064"
../source/print_tokens2.exe  < ../inputs/test137 > ../originals/t1064
echo ">>>>>>>>running test 1065"
../source/print_tokens2.exe  < ../inputs/test138 > ../originals/t1065
echo ">>>>>>>>running test 1066"
../source/print_tokens2.exe  < ../inputs/test139 > ../originals/t1066
echo ">>>>>>>>running test 1067"
../source/print_tokens2.exe  < ../inputs/test14 > ../originals/t1067
echo ">>>>>>>>running test 1068"
../source/print_tokens2.exe  < ../inputs/test140 > ../originals/t1068
echo ">>>>>>>>running test 1069"
../source/print_tokens2.exe  < ../inputs/test141 > ../originals/t1069
echo ">>>>>>>>running test 1070"
../source/print_tokens2.exe  < ../inputs/test142 > ../originals/t1070
echo ">>>>>>>>running test 1071"
../source/print_tokens2.exe  < ../inputs/test143 > ../originals/t1071
echo ">>>>>>>>running test 1072"
../source/print_tokens2.exe  < ../inputs/test144 > ../originals/t1072
echo ">>>>>>>>running test 1073"
../source/print_tokens2.exe  < ../inputs/test145 > ../originals/t1073
echo ">>>>>>>>running test 1074"
../source/print_tokens2.exe  < ../inputs/test146 > ../originals/t1074
echo ">>>>>>>>running test 1075"
../source/print_tokens2.exe  < ../inputs/test147 > ../originals/t1075
echo ">>>>>>>>running test 1076"
../source/print_tokens2.exe  < ../inputs/test148 > ../originals/t1076
echo ">>>>>>>>running test 1077"
../source/print_tokens2.exe  < ../inputs/test149 > ../originals/t1077
echo ">>>>>>>>running test 1078"
../source/print_tokens2.exe  < ../inputs/test15 > ../originals/t1078
echo ">>>>>>>>running test 1079"
../source/print_tokens2.exe  < ../inputs/test150 > ../originals/t1079
echo ">>>>>>>>running test 1080"
../source/print_tokens2.exe  < ../inputs/test151 > ../originals/t1080
echo ">>>>>>>>running test 1081"
../source/print_tokens2.exe  < ../inputs/test152 > ../originals/t1081
echo ">>>>>>>>running test 1082"
../source/print_tokens2.exe  < ../inputs/test153 > ../originals/t1082
echo ">>>>>>>>running test 1083"
../source/print_tokens2.exe  < ../inputs/test154 > ../originals/t1083
echo ">>>>>>>>running test 1084"
../source/print_tokens2.exe  < ../inputs/test155 > ../originals/t1084
echo ">>>>>>>>running test 1085"
../source/print_tokens2.exe  < ../inputs/test156 > ../originals/t1085
echo ">>>>>>>>running test 1086"
../source/print_tokens2.exe  < ../inputs/test157 > ../originals/t1086
echo ">>>>>>>>running test 1087"
../source/print_tokens2.exe  < ../inputs/test158 > ../originals/t1087
echo ">>>>>>>>running test 1088"
../source/print_tokens2.exe  < ../inputs/test159 > ../originals/t1088
echo ">>>>>>>>running test 1089"
../source/print_tokens2.exe  < ../inputs/test16 > ../originals/t1089
echo ">>>>>>>>running test 1090"
../source/print_tokens2.exe  < ../inputs/test160 > ../originals/t1090
echo ">>>>>>>>running test 1091"
../source/print_tokens2.exe  < ../inputs/test161 > ../originals/t1091
echo ">>>>>>>>running test 1092"
../source/print_tokens2.exe  < ../inputs/test162 > ../originals/t1092
echo ">>>>>>>>running test 1093"
../source/print_tokens2.exe  < ../inputs/test163 > ../originals/t1093
echo ">>>>>>>>running test 1094"
../source/print_tokens2.exe  < ../inputs/test164 > ../originals/t1094
echo ">>>>>>>>running test 1095"
../source/print_tokens2.exe  < ../inputs/test165 > ../originals/t1095
echo ">>>>>>>>running test 1096"
../source/print_tokens2.exe  < ../inputs/test166 > ../originals/t1096
echo ">>>>>>>>running test 1097"
../source/print_tokens2.exe  < ../inputs/test167 > ../originals/t1097
echo ">>>>>>>>running test 1098"
../source/print_tokens2.exe  < ../inputs/test168 > ../originals/t1098
echo ">>>>>>>>running test 1099"
../source/print_tokens2.exe  < ../inputs/test169 > ../originals/t1099
echo ">>>>>>>>running test 1100"
../source/print_tokens2.exe  < ../inputs/test17 > ../originals/t1100
echo ">>>>>>>>running test 1101"
../source/print_tokens2.exe  < ../inputs/test170 > ../originals/t1101
echo ">>>>>>>>running test 1102"
../source/print_tokens2.exe  < ../inputs/test171 > ../originals/t1102
echo ">>>>>>>>running test 1103"
../source/print_tokens2.exe  < ../inputs/test172 > ../originals/t1103
echo ">>>>>>>>running test 1104"
../source/print_tokens2.exe  < ../inputs/test173 > ../originals/t1104
echo ">>>>>>>>running test 1105"
../source/print_tokens2.exe  < ../inputs/test174 > ../originals/t1105
echo ">>>>>>>>running test 1106"
../source/print_tokens2.exe  < ../inputs/test175 > ../originals/t1106
echo ">>>>>>>>running test 1107"
../source/print_tokens2.exe  < ../inputs/test176 > ../originals/t1107
echo ">>>>>>>>running test 1108"
../source/print_tokens2.exe  < ../inputs/test177 > ../originals/t1108
echo ">>>>>>>>running test 1109"
../source/print_tokens2.exe  < ../inputs/test178 > ../originals/t1109
echo ">>>>>>>>running test 1110"
../source/print_tokens2.exe  < ../inputs/test179 > ../originals/t1110
echo ">>>>>>>>running test 1111"
../source/print_tokens2.exe  < ../inputs/test18 > ../originals/t1111
echo ">>>>>>>>running test 1112"
../source/print_tokens2.exe  < ../inputs/test180 > ../originals/t1112
echo ">>>>>>>>running test 1113"
../source/print_tokens2.exe  < ../inputs/test181 > ../originals/t1113
echo ">>>>>>>>running test 1114"
../source/print_tokens2.exe  < ../inputs/test182 > ../originals/t1114
echo ">>>>>>>>running test 1115"
../source/print_tokens2.exe  < ../inputs/test183 > ../originals/t1115
echo ">>>>>>>>running test 1116"
../source/print_tokens2.exe  < ../inputs/test184 > ../originals/t1116
echo ">>>>>>>>running test 1117"
../source/print_tokens2.exe  < ../inputs/test185 > ../originals/t1117
echo ">>>>>>>>running test 1118"
../source/print_tokens2.exe  < ../inputs/test186 > ../originals/t1118
echo ">>>>>>>>running test 1119"
../source/print_tokens2.exe  < ../inputs/test187 > ../originals/t1119
echo ">>>>>>>>running test 1120"
../source/print_tokens2.exe  < ../inputs/test188 > ../originals/t1120
echo ">>>>>>>>running test 1121"
../source/print_tokens2.exe  < ../inputs/test189 > ../originals/t1121
echo ">>>>>>>>running test 1122"
../source/print_tokens2.exe  < ../inputs/test19 > ../originals/t1122
echo ">>>>>>>>running test 1123"
../source/print_tokens2.exe  < ../inputs/test190 > ../originals/t1123
echo ">>>>>>>>running test 1124"
../source/print_tokens2.exe  < ../inputs/test191 > ../originals/t1124
echo ">>>>>>>>running test 1125"
../source/print_tokens2.exe  < ../inputs/test192 > ../originals/t1125
echo ">>>>>>>>running test 1126"
../source/print_tokens2.exe  < ../inputs/test193 > ../originals/t1126
echo ">>>>>>>>running test 1127"
../source/print_tokens2.exe  < ../inputs/test194 > ../originals/t1127
echo ">>>>>>>>running test 1128"
../source/print_tokens2.exe  < ../inputs/test195 > ../originals/t1128
echo ">>>>>>>>running test 1129"
../source/print_tokens2.exe  < ../inputs/test196 > ../originals/t1129
echo ">>>>>>>>running test 1130"
../source/print_tokens2.exe  < ../inputs/test197 > ../originals/t1130
echo ">>>>>>>>running test 1131"
../source/print_tokens2.exe  < ../inputs/test198 > ../originals/t1131
echo ">>>>>>>>running test 1132"
../source/print_tokens2.exe  < ../inputs/test199 > ../originals/t1132
echo ">>>>>>>>running test 1133"
../source/print_tokens2.exe  < ../inputs/test2 > ../originals/t1133
echo ">>>>>>>>running test 1134"
../source/print_tokens2.exe  < ../inputs/test20 > ../originals/t1134
echo ">>>>>>>>running test 1135"
../source/print_tokens2.exe  < ../inputs/test200 > ../originals/t1135
echo ">>>>>>>>running test 1136"
../source/print_tokens2.exe  < ../inputs/test201 > ../originals/t1136
echo ">>>>>>>>running test 1137"
../source/print_tokens2.exe  < ../inputs/test202 > ../originals/t1137
echo ">>>>>>>>running test 1138"
../source/print_tokens2.exe  < ../inputs/test203 > ../originals/t1138
echo ">>>>>>>>running test 1139"
../source/print_tokens2.exe  < ../inputs/test204 > ../originals/t1139
echo ">>>>>>>>running test 1140"
../source/print_tokens2.exe  < ../inputs/test205 > ../originals/t1140
echo ">>>>>>>>running test 1141"
../source/print_tokens2.exe  < ../inputs/test206 > ../originals/t1141
echo ">>>>>>>>running test 1142"
../source/print_tokens2.exe  < ../inputs/test207 > ../originals/t1142
echo ">>>>>>>>running test 1143"
../source/print_tokens2.exe  < ../inputs/test208 > ../originals/t1143
echo ">>>>>>>>running test 1144"
../source/print_tokens2.exe  < ../inputs/test209 > ../originals/t1144
echo ">>>>>>>>running test 1145"
../source/print_tokens2.exe  < ../inputs/test21 > ../originals/t1145
echo ">>>>>>>>running test 1146"
../source/print_tokens2.exe  < ../inputs/test210 > ../originals/t1146
echo ">>>>>>>>running test 1147"
../source/print_tokens2.exe  < ../inputs/test211 > ../originals/t1147
echo ">>>>>>>>running test 1148"
../source/print_tokens2.exe  < ../inputs/test212 > ../originals/t1148
echo ">>>>>>>>running test 1149"
../source/print_tokens2.exe  < ../inputs/test213 > ../originals/t1149
echo ">>>>>>>>running test 1150"
../source/print_tokens2.exe  < ../inputs/test214 > ../originals/t1150
echo ">>>>>>>>running test 1151"
../source/print_tokens2.exe  < ../inputs/test215 > ../originals/t1151
echo ">>>>>>>>running test 1152"
../source/print_tokens2.exe  < ../inputs/test216 > ../originals/t1152
echo ">>>>>>>>running test 1153"
../source/print_tokens2.exe  < ../inputs/test217 > ../originals/t1153
echo ">>>>>>>>running test 1154"
../source/print_tokens2.exe  < ../inputs/test218 > ../originals/t1154
echo ">>>>>>>>running test 1155"
../source/print_tokens2.exe  < ../inputs/test219 > ../originals/t1155
echo ">>>>>>>>running test 1156"
../source/print_tokens2.exe  < ../inputs/test22 > ../originals/t1156
echo ">>>>>>>>running test 1157"
../source/print_tokens2.exe  < ../inputs/test220 > ../originals/t1157
echo ">>>>>>>>running test 1158"
../source/print_tokens2.exe  < ../inputs/test221 > ../originals/t1158
echo ">>>>>>>>running test 1159"
../source/print_tokens2.exe  < ../inputs/test222 > ../originals/t1159
echo ">>>>>>>>running test 1160"
../source/print_tokens2.exe  < ../inputs/test223 > ../originals/t1160
echo ">>>>>>>>running test 1161"
../source/print_tokens2.exe  < ../inputs/test224 > ../originals/t1161
echo ">>>>>>>>running test 1162"
../source/print_tokens2.exe  < ../inputs/test225 > ../originals/t1162
echo ">>>>>>>>running test 1163"
../source/print_tokens2.exe  < ../inputs/test226 > ../originals/t1163
echo ">>>>>>>>running test 1164"
../source/print_tokens2.exe  < ../inputs/test227 > ../originals/t1164
echo ">>>>>>>>running test 1165"
../source/print_tokens2.exe  < ../inputs/test228 > ../originals/t1165
echo ">>>>>>>>running test 1166"
../source/print_tokens2.exe  < ../inputs/test229 > ../originals/t1166
echo ">>>>>>>>running test 1167"
../source/print_tokens2.exe  < ../inputs/test23 > ../originals/t1167
echo ">>>>>>>>running test 1168"
../source/print_tokens2.exe  < ../inputs/test230 > ../originals/t1168
echo ">>>>>>>>running test 1169"
../source/print_tokens2.exe  < ../inputs/test231 > ../originals/t1169
echo ">>>>>>>>running test 1170"
../source/print_tokens2.exe  < ../inputs/test232 > ../originals/t1170
echo ">>>>>>>>running test 1171"
../source/print_tokens2.exe  < ../inputs/test233 > ../originals/t1171
echo ">>>>>>>>running test 1172"
../source/print_tokens2.exe  < ../inputs/test234 > ../originals/t1172
echo ">>>>>>>>running test 1173"
../source/print_tokens2.exe  < ../inputs/test235 > ../originals/t1173
echo ">>>>>>>>running test 1174"
../source/print_tokens2.exe  < ../inputs/test236 > ../originals/t1174
echo ">>>>>>>>running test 1175"
../source/print_tokens2.exe  < ../inputs/test237 > ../originals/t1175
echo ">>>>>>>>running test 1176"
../source/print_tokens2.exe  < ../inputs/test238 > ../originals/t1176
echo ">>>>>>>>running test 1177"
../source/print_tokens2.exe  < ../inputs/test239 > ../originals/t1177
echo ">>>>>>>>running test 1178"
../source/print_tokens2.exe  < ../inputs/test24 > ../originals/t1178
echo ">>>>>>>>running test 1179"
../source/print_tokens2.exe  < ../inputs/test240 > ../originals/t1179
echo ">>>>>>>>running test 1180"
../source/print_tokens2.exe  < ../inputs/test241 > ../originals/t1180
echo ">>>>>>>>running test 1181"
../source/print_tokens2.exe  < ../inputs/test242 > ../originals/t1181
echo ">>>>>>>>running test 1182"
../source/print_tokens2.exe  < ../inputs/test243 > ../originals/t1182
echo ">>>>>>>>running test 1183"
../source/print_tokens2.exe  < ../inputs/test244 > ../originals/t1183
echo ">>>>>>>>running test 1184"
../source/print_tokens2.exe  < ../inputs/test245 > ../originals/t1184
echo ">>>>>>>>running test 1185"
../source/print_tokens2.exe  < ../inputs/test246 > ../originals/t1185
echo ">>>>>>>>running test 1186"
../source/print_tokens2.exe  < ../inputs/test247 > ../originals/t1186
echo ">>>>>>>>running test 1187"
../source/print_tokens2.exe  < ../inputs/test248 > ../originals/t1187
echo ">>>>>>>>running test 1188"
../source/print_tokens2.exe  < ../inputs/test249 > ../originals/t1188
echo ">>>>>>>>running test 1189"
../source/print_tokens2.exe  < ../inputs/test25 > ../originals/t1189
echo ">>>>>>>>running test 1190"
../source/print_tokens2.exe  < ../inputs/test250 > ../originals/t1190
echo ">>>>>>>>running test 1191"
../source/print_tokens2.exe  < ../inputs/test251 > ../originals/t1191
echo ">>>>>>>>running test 1192"
../source/print_tokens2.exe  < ../inputs/test252 > ../originals/t1192
echo ">>>>>>>>running test 1193"
../source/print_tokens2.exe  < ../inputs/test253 > ../originals/t1193
echo ">>>>>>>>running test 1194"
../source/print_tokens2.exe  < ../inputs/test254 > ../originals/t1194
echo ">>>>>>>>running test 1195"
../source/print_tokens2.exe  < ../inputs/test255 > ../originals/t1195
echo ">>>>>>>>running test 1196"
../source/print_tokens2.exe  < ../inputs/test256 > ../originals/t1196
echo ">>>>>>>>running test 1197"
../source/print_tokens2.exe  < ../inputs/test257 > ../originals/t1197
echo ">>>>>>>>running test 1198"
../source/print_tokens2.exe  < ../inputs/test258 > ../originals/t1198
echo ">>>>>>>>running test 1199"
../source/print_tokens2.exe  < ../inputs/test259 > ../originals/t1199
echo ">>>>>>>>running test 1200"
../source/print_tokens2.exe  < ../inputs/test26 > ../originals/t1200
echo ">>>>>>>>running test 1201"
../source/print_tokens2.exe  < ../inputs/test260 > ../originals/t1201
echo ">>>>>>>>running test 1202"
../source/print_tokens2.exe  < ../inputs/test261 > ../originals/t1202
echo ">>>>>>>>running test 1203"
../source/print_tokens2.exe  < ../inputs/test262 > ../originals/t1203
echo ">>>>>>>>running test 1204"
../source/print_tokens2.exe  < ../inputs/test263 > ../originals/t1204
echo ">>>>>>>>running test 1205"
../source/print_tokens2.exe  < ../inputs/test264 > ../originals/t1205
echo ">>>>>>>>running test 1206"
../source/print_tokens2.exe  < ../inputs/test265 > ../originals/t1206
echo ">>>>>>>>running test 1207"
../source/print_tokens2.exe  < ../inputs/test266 > ../originals/t1207
echo ">>>>>>>>running test 1208"
../source/print_tokens2.exe  < ../inputs/test267 > ../originals/t1208
echo ">>>>>>>>running test 1209"
../source/print_tokens2.exe  < ../inputs/test268 > ../originals/t1209
echo ">>>>>>>>running test 1210"
../source/print_tokens2.exe  < ../inputs/test269 > ../originals/t1210
echo ">>>>>>>>running test 1211"
../source/print_tokens2.exe  < ../inputs/test27 > ../originals/t1211
echo ">>>>>>>>running test 1212"
../source/print_tokens2.exe  < ../inputs/test270 > ../originals/t1212
echo ">>>>>>>>running test 1213"
../source/print_tokens2.exe  < ../inputs/test271 > ../originals/t1213
echo ">>>>>>>>running test 1214"
../source/print_tokens2.exe  < ../inputs/test272 > ../originals/t1214
echo ">>>>>>>>running test 1215"
../source/print_tokens2.exe  < ../inputs/test273 > ../originals/t1215
echo ">>>>>>>>running test 1216"
../source/print_tokens2.exe  < ../inputs/test274 > ../originals/t1216
echo ">>>>>>>>running test 1217"
../source/print_tokens2.exe  < ../inputs/test275 > ../originals/t1217
echo ">>>>>>>>running test 1218"
../source/print_tokens2.exe  < ../inputs/test276 > ../originals/t1218
echo ">>>>>>>>running test 1219"
../source/print_tokens2.exe  < ../inputs/test277 > ../originals/t1219
echo ">>>>>>>>running test 1220"
../source/print_tokens2.exe  < ../inputs/test278 > ../originals/t1220
echo ">>>>>>>>running test 1221"
../source/print_tokens2.exe  < ../inputs/test279 > ../originals/t1221
echo ">>>>>>>>running test 1222"
../source/print_tokens2.exe  < ../inputs/test28 > ../originals/t1222
echo ">>>>>>>>running test 1223"
../source/print_tokens2.exe  < ../inputs/test280 > ../originals/t1223
echo ">>>>>>>>running test 1224"
../source/print_tokens2.exe  < ../inputs/test281 > ../originals/t1224
echo ">>>>>>>>running test 1225"
../source/print_tokens2.exe  < ../inputs/test282 > ../originals/t1225
echo ">>>>>>>>running test 1226"
../source/print_tokens2.exe  < ../inputs/test283 > ../originals/t1226
echo ">>>>>>>>running test 1227"
../source/print_tokens2.exe  < ../inputs/test284 > ../originals/t1227
echo ">>>>>>>>running test 1228"
../source/print_tokens2.exe  < ../inputs/test285 > ../originals/t1228
echo ">>>>>>>>running test 1229"
../source/print_tokens2.exe  < ../inputs/test286 > ../originals/t1229
echo ">>>>>>>>running test 1230"
../source/print_tokens2.exe  < ../inputs/test287 > ../originals/t1230
echo ">>>>>>>>running test 1231"
../source/print_tokens2.exe  < ../inputs/test288 > ../originals/t1231
echo ">>>>>>>>running test 1232"
../source/print_tokens2.exe  < ../inputs/test289 > ../originals/t1232
echo ">>>>>>>>running test 1233"
../source/print_tokens2.exe  < ../inputs/test29 > ../originals/t1233
echo ">>>>>>>>running test 1234"
../source/print_tokens2.exe  < ../inputs/test290 > ../originals/t1234
echo ">>>>>>>>running test 1235"
../source/print_tokens2.exe  < ../inputs/test291 > ../originals/t1235
echo ">>>>>>>>running test 1236"
../source/print_tokens2.exe  < ../inputs/test292 > ../originals/t1236
echo ">>>>>>>>running test 1237"
../source/print_tokens2.exe  < ../inputs/test293 > ../originals/t1237
echo ">>>>>>>>running test 1238"
../source/print_tokens2.exe  < ../inputs/test294 > ../originals/t1238
echo ">>>>>>>>running test 1239"
../source/print_tokens2.exe  < ../inputs/test295 > ../originals/t1239
echo ">>>>>>>>running test 1240"
../source/print_tokens2.exe  < ../inputs/test296 > ../originals/t1240
echo ">>>>>>>>running test 1241"
../source/print_tokens2.exe  < ../inputs/test297 > ../originals/t1241
echo ">>>>>>>>running test 1242"
../source/print_tokens2.exe  < ../inputs/test298 > ../originals/t1242
echo ">>>>>>>>running test 1243"
../source/print_tokens2.exe  < ../inputs/test299 > ../originals/t1243
echo ">>>>>>>>running test 1244"
../source/print_tokens2.exe  < ../inputs/test3 > ../originals/t1244
echo ">>>>>>>>running test 1245"
../source/print_tokens2.exe  < ../inputs/test30 > ../originals/t1245
echo ">>>>>>>>running test 1246"
../source/print_tokens2.exe  < ../inputs/test300 > ../originals/t1246
echo ">>>>>>>>running test 1247"
../source/print_tokens2.exe  < ../inputs/test301 > ../originals/t1247
echo ">>>>>>>>running test 1248"
../source/print_tokens2.exe  < ../inputs/test302 > ../originals/t1248
echo ">>>>>>>>running test 1249"
../source/print_tokens2.exe  < ../inputs/test303 > ../originals/t1249
echo ">>>>>>>>running test 1250"
../source/print_tokens2.exe  < ../inputs/test304 > ../originals/t1250
echo ">>>>>>>>running test 1251"
../source/print_tokens2.exe  < ../inputs/test305 > ../originals/t1251
echo ">>>>>>>>running test 1252"
../source/print_tokens2.exe  < ../inputs/test306 > ../originals/t1252
echo ">>>>>>>>running test 1253"
../source/print_tokens2.exe  < ../inputs/test307 > ../originals/t1253
echo ">>>>>>>>running test 1254"
../source/print_tokens2.exe  < ../inputs/test308 > ../originals/t1254
echo ">>>>>>>>running test 1255"
../source/print_tokens2.exe  < ../inputs/test309 > ../originals/t1255
echo ">>>>>>>>running test 1256"
../source/print_tokens2.exe  < ../inputs/test31 > ../originals/t1256
echo ">>>>>>>>running test 1257"
../source/print_tokens2.exe  < ../inputs/test310 > ../originals/t1257
echo ">>>>>>>>running test 1258"
../source/print_tokens2.exe  < ../inputs/test311 > ../originals/t1258
echo ">>>>>>>>running test 1259"
../source/print_tokens2.exe  < ../inputs/test312 > ../originals/t1259
echo ">>>>>>>>running test 1260"
../source/print_tokens2.exe  < ../inputs/test313 > ../originals/t1260
echo ">>>>>>>>running test 1261"
../source/print_tokens2.exe  < ../inputs/test314 > ../originals/t1261
echo ">>>>>>>>running test 1262"
../source/print_tokens2.exe  < ../inputs/test315 > ../originals/t1262
echo ">>>>>>>>running test 1263"
../source/print_tokens2.exe  < ../inputs/test316 > ../originals/t1263
echo ">>>>>>>>running test 1264"
../source/print_tokens2.exe  < ../inputs/test317 > ../originals/t1264
echo ">>>>>>>>running test 1265"
../source/print_tokens2.exe  < ../inputs/test318 > ../originals/t1265
echo ">>>>>>>>running test 1266"
../source/print_tokens2.exe  < ../inputs/test319 > ../originals/t1266
echo ">>>>>>>>running test 1267"
../source/print_tokens2.exe  < ../inputs/test32 > ../originals/t1267
echo ">>>>>>>>running test 1268"
../source/print_tokens2.exe  < ../inputs/test320 > ../originals/t1268
echo ">>>>>>>>running test 1269"
../source/print_tokens2.exe  < ../inputs/test321 > ../originals/t1269
echo ">>>>>>>>running test 1270"
../source/print_tokens2.exe  < ../inputs/test322 > ../originals/t1270
echo ">>>>>>>>running test 1271"
../source/print_tokens2.exe  < ../inputs/test323 > ../originals/t1271
echo ">>>>>>>>running test 1272"
../source/print_tokens2.exe  < ../inputs/test324 > ../originals/t1272
echo ">>>>>>>>running test 1273"
../source/print_tokens2.exe  < ../inputs/test325 > ../originals/t1273
echo ">>>>>>>>running test 1274"
../source/print_tokens2.exe  < ../inputs/test326 > ../originals/t1274
echo ">>>>>>>>running test 1275"
../source/print_tokens2.exe  < ../inputs/test327 > ../originals/t1275
echo ">>>>>>>>running test 1276"
../source/print_tokens2.exe  < ../inputs/test328 > ../originals/t1276
echo ">>>>>>>>running test 1277"
../source/print_tokens2.exe  < ../inputs/test329 > ../originals/t1277
echo ">>>>>>>>running test 1278"
../source/print_tokens2.exe  < ../inputs/test33 > ../originals/t1278
echo ">>>>>>>>running test 1279"
../source/print_tokens2.exe  < ../inputs/test330 > ../originals/t1279
echo ">>>>>>>>running test 1280"
../source/print_tokens2.exe  < ../inputs/test331 > ../originals/t1280
echo ">>>>>>>>running test 1281"
../source/print_tokens2.exe  < ../inputs/test332 > ../originals/t1281
echo ">>>>>>>>running test 1282"
../source/print_tokens2.exe  < ../inputs/test333 > ../originals/t1282
echo ">>>>>>>>running test 1283"
../source/print_tokens2.exe  < ../inputs/test334 > ../originals/t1283
echo ">>>>>>>>running test 1284"
../source/print_tokens2.exe  < ../inputs/test335 > ../originals/t1284
echo ">>>>>>>>running test 1285"
../source/print_tokens2.exe  < ../inputs/test336 > ../originals/t1285
echo ">>>>>>>>running test 1286"
../source/print_tokens2.exe  < ../inputs/test337 > ../originals/t1286
echo ">>>>>>>>running test 1287"
../source/print_tokens2.exe  < ../inputs/test338 > ../originals/t1287
echo ">>>>>>>>running test 1288"
../source/print_tokens2.exe  < ../inputs/test339 > ../originals/t1288
echo ">>>>>>>>running test 1289"
../source/print_tokens2.exe  < ../inputs/test34 > ../originals/t1289
echo ">>>>>>>>running test 1290"
../source/print_tokens2.exe  < ../inputs/test340 > ../originals/t1290
echo ">>>>>>>>running test 1291"
../source/print_tokens2.exe  < ../inputs/test341 > ../originals/t1291
echo ">>>>>>>>running test 1292"
../source/print_tokens2.exe  < ../inputs/test342 > ../originals/t1292
echo ">>>>>>>>running test 1293"
../source/print_tokens2.exe  < ../inputs/test343 > ../originals/t1293
echo ">>>>>>>>running test 1294"
../source/print_tokens2.exe  < ../inputs/test344 > ../originals/t1294
echo ">>>>>>>>running test 1295"
../source/print_tokens2.exe  < ../inputs/test345 > ../originals/t1295
echo ">>>>>>>>running test 1296"
../source/print_tokens2.exe  < ../inputs/test346 > ../originals/t1296
echo ">>>>>>>>running test 1297"
../source/print_tokens2.exe  < ../inputs/test347 > ../originals/t1297
echo ">>>>>>>>running test 1298"
../source/print_tokens2.exe  < ../inputs/test348 > ../originals/t1298
echo ">>>>>>>>running test 1299"
../source/print_tokens2.exe  < ../inputs/test349 > ../originals/t1299
echo ">>>>>>>>running test 1300"
../source/print_tokens2.exe  < ../inputs/test35 > ../originals/t1300
echo ">>>>>>>>running test 1301"
../source/print_tokens2.exe  < ../inputs/test350 > ../originals/t1301
echo ">>>>>>>>running test 1302"
../source/print_tokens2.exe  < ../inputs/test351 > ../originals/t1302
echo ">>>>>>>>running test 1303"
../source/print_tokens2.exe  < ../inputs/test352 > ../originals/t1303
echo ">>>>>>>>running test 1304"
../source/print_tokens2.exe  < ../inputs/test353 > ../originals/t1304
echo ">>>>>>>>running test 1305"
../source/print_tokens2.exe  < ../inputs/test354 > ../originals/t1305
echo ">>>>>>>>running test 1306"
../source/print_tokens2.exe  < ../inputs/test355 > ../originals/t1306
echo ">>>>>>>>running test 1307"
../source/print_tokens2.exe  < ../inputs/test356 > ../originals/t1307
echo ">>>>>>>>running test 1308"
../source/print_tokens2.exe  < ../inputs/test357 > ../originals/t1308
echo ">>>>>>>>running test 1309"
../source/print_tokens2.exe  < ../inputs/test358 > ../originals/t1309
echo ">>>>>>>>running test 1310"
../source/print_tokens2.exe  < ../inputs/test359 > ../originals/t1310
echo ">>>>>>>>running test 1311"
../source/print_tokens2.exe  < ../inputs/test36 > ../originals/t1311
echo ">>>>>>>>running test 1312"
../source/print_tokens2.exe  < ../inputs/test360 > ../originals/t1312
echo ">>>>>>>>running test 1313"
../source/print_tokens2.exe  < ../inputs/test361 > ../originals/t1313
echo ">>>>>>>>running test 1314"
../source/print_tokens2.exe  < ../inputs/test362 > ../originals/t1314
echo ">>>>>>>>running test 1315"
../source/print_tokens2.exe  < ../inputs/test363 > ../originals/t1315
echo ">>>>>>>>running test 1316"
../source/print_tokens2.exe  < ../inputs/test364 > ../originals/t1316
echo ">>>>>>>>running test 1317"
../source/print_tokens2.exe  < ../inputs/test365 > ../originals/t1317
echo ">>>>>>>>running test 1318"
../source/print_tokens2.exe  < ../inputs/test366 > ../originals/t1318
echo ">>>>>>>>running test 1319"
../source/print_tokens2.exe  < ../inputs/test367 > ../originals/t1319
echo ">>>>>>>>running test 1320"
../source/print_tokens2.exe  < ../inputs/test368 > ../originals/t1320
echo ">>>>>>>>running test 1321"
../source/print_tokens2.exe  < ../inputs/test369 > ../originals/t1321
echo ">>>>>>>>running test 1322"
../source/print_tokens2.exe  < ../inputs/test37 > ../originals/t1322
echo ">>>>>>>>running test 1323"
../source/print_tokens2.exe  < ../inputs/test370 > ../originals/t1323
echo ">>>>>>>>running test 1324"
../source/print_tokens2.exe  < ../inputs/test371 > ../originals/t1324
echo ">>>>>>>>running test 1325"
../source/print_tokens2.exe  < ../inputs/test372 > ../originals/t1325
echo ">>>>>>>>running test 1326"
../source/print_tokens2.exe  < ../inputs/test373 > ../originals/t1326
echo ">>>>>>>>running test 1327"
../source/print_tokens2.exe  < ../inputs/test374 > ../originals/t1327
echo ">>>>>>>>running test 1328"
../source/print_tokens2.exe  < ../inputs/test375 > ../originals/t1328
echo ">>>>>>>>running test 1329"
../source/print_tokens2.exe  < ../inputs/test376 > ../originals/t1329
echo ">>>>>>>>running test 1330"
../source/print_tokens2.exe  < ../inputs/test377 > ../originals/t1330
echo ">>>>>>>>running test 1331"
../source/print_tokens2.exe  < ../inputs/test378 > ../originals/t1331
echo ">>>>>>>>running test 1332"
../source/print_tokens2.exe  < ../inputs/test379 > ../originals/t1332
echo ">>>>>>>>running test 1333"
../source/print_tokens2.exe  < ../inputs/test38 > ../originals/t1333
echo ">>>>>>>>running test 1334"
../source/print_tokens2.exe  < ../inputs/test380 > ../originals/t1334
echo ">>>>>>>>running test 1335"
../source/print_tokens2.exe  < ../inputs/test381 > ../originals/t1335
echo ">>>>>>>>running test 1336"
../source/print_tokens2.exe  < ../inputs/test382 > ../originals/t1336
echo ">>>>>>>>running test 1337"
../source/print_tokens2.exe  < ../inputs/test383 > ../originals/t1337
echo ">>>>>>>>running test 1338"
../source/print_tokens2.exe  < ../inputs/test384 > ../originals/t1338
echo ">>>>>>>>running test 1339"
../source/print_tokens2.exe  < ../inputs/test385 > ../originals/t1339
echo ">>>>>>>>running test 1340"
../source/print_tokens2.exe  < ../inputs/test386 > ../originals/t1340
echo ">>>>>>>>running test 1341"
../source/print_tokens2.exe  < ../inputs/test387 > ../originals/t1341
echo ">>>>>>>>running test 1342"
../source/print_tokens2.exe  < ../inputs/test388 > ../originals/t1342
echo ">>>>>>>>running test 1343"
../source/print_tokens2.exe  < ../inputs/test389 > ../originals/t1343
echo ">>>>>>>>running test 1344"
../source/print_tokens2.exe  < ../inputs/test39 > ../originals/t1344
echo ">>>>>>>>running test 1345"
../source/print_tokens2.exe  < ../inputs/test390 > ../originals/t1345
echo ">>>>>>>>running test 1346"
../source/print_tokens2.exe  < ../inputs/test391 > ../originals/t1346
echo ">>>>>>>>running test 1347"
../source/print_tokens2.exe  < ../inputs/test392 > ../originals/t1347
echo ">>>>>>>>running test 1348"
../source/print_tokens2.exe  < ../inputs/test393 > ../originals/t1348
echo ">>>>>>>>running test 1349"
../source/print_tokens2.exe  < ../inputs/test394 > ../originals/t1349
echo ">>>>>>>>running test 1350"
../source/print_tokens2.exe  < ../inputs/test395 > ../originals/t1350
echo ">>>>>>>>running test 1351"
../source/print_tokens2.exe  < ../inputs/test396 > ../originals/t1351
echo ">>>>>>>>running test 1352"
../source/print_tokens2.exe  < ../inputs/test397 > ../originals/t1352
echo ">>>>>>>>running test 1353"
../source/print_tokens2.exe  < ../inputs/test398 > ../originals/t1353
echo ">>>>>>>>running test 1354"
../source/print_tokens2.exe  < ../inputs/test399 > ../originals/t1354
echo ">>>>>>>>running test 1355"
../source/print_tokens2.exe  < ../inputs/test4 > ../originals/t1355
echo ">>>>>>>>running test 1356"
../source/print_tokens2.exe  < ../inputs/test40 > ../originals/t1356
echo ">>>>>>>>running test 1357"
../source/print_tokens2.exe  < ../inputs/test400 > ../originals/t1357
echo ">>>>>>>>running test 1358"
../source/print_tokens2.exe  < ../inputs/test41 > ../originals/t1358
echo ">>>>>>>>running test 1359"
../source/print_tokens2.exe  < ../inputs/test42 > ../originals/t1359
echo ">>>>>>>>running test 1360"
../source/print_tokens2.exe  < ../inputs/test43 > ../originals/t1360
echo ">>>>>>>>running test 1361"
../source/print_tokens2.exe  < ../inputs/test44 > ../originals/t1361
echo ">>>>>>>>running test 1362"
../source/print_tokens2.exe  < ../inputs/test45 > ../originals/t1362
echo ">>>>>>>>running test 1363"
../source/print_tokens2.exe  < ../inputs/test46 > ../originals/t1363
echo ">>>>>>>>running test 1364"
../source/print_tokens2.exe  < ../inputs/test47 > ../originals/t1364
echo ">>>>>>>>running test 1365"
../source/print_tokens2.exe  < ../inputs/test48 > ../originals/t1365
echo ">>>>>>>>running test 1366"
../source/print_tokens2.exe  < ../inputs/test49 > ../originals/t1366
echo ">>>>>>>>running test 1367"
../source/print_tokens2.exe  < ../inputs/test5 > ../originals/t1367
echo ">>>>>>>>running test 1368"
../source/print_tokens2.exe  < ../inputs/test50 > ../originals/t1368
echo ">>>>>>>>running test 1369"
../source/print_tokens2.exe  < ../inputs/test51 > ../originals/t1369
echo ">>>>>>>>running test 1370"
../source/print_tokens2.exe  < ../inputs/test52 > ../originals/t1370
echo ">>>>>>>>running test 1371"
../source/print_tokens2.exe  < ../inputs/test53 > ../originals/t1371
echo ">>>>>>>>running test 1372"
../source/print_tokens2.exe  < ../inputs/test54 > ../originals/t1372
echo ">>>>>>>>running test 1373"
../source/print_tokens2.exe  < ../inputs/test55 > ../originals/t1373
echo ">>>>>>>>running test 1374"
../source/print_tokens2.exe  < ../inputs/test56 > ../originals/t1374
echo ">>>>>>>>running test 1375"
../source/print_tokens2.exe  < ../inputs/test57 > ../originals/t1375
echo ">>>>>>>>running test 1376"
../source/print_tokens2.exe  < ../inputs/test58 > ../originals/t1376
echo ">>>>>>>>running test 1377"
../source/print_tokens2.exe  < ../inputs/test59 > ../originals/t1377
echo ">>>>>>>>running test 1378"
../source/print_tokens2.exe  < ../inputs/test6 > ../originals/t1378
echo ">>>>>>>>running test 1379"
../source/print_tokens2.exe  < ../inputs/test60 > ../originals/t1379
echo ">>>>>>>>running test 1380"
../source/print_tokens2.exe  < ../inputs/test61 > ../originals/t1380
echo ">>>>>>>>running test 1381"
../source/print_tokens2.exe  < ../inputs/test62 > ../originals/t1381
echo ">>>>>>>>running test 1382"
../source/print_tokens2.exe  < ../inputs/test63 > ../originals/t1382
echo ">>>>>>>>running test 1383"
../source/print_tokens2.exe  < ../inputs/test64 > ../originals/t1383
echo ">>>>>>>>running test 1384"
../source/print_tokens2.exe  < ../inputs/test65 > ../originals/t1384
echo ">>>>>>>>running test 1385"
../source/print_tokens2.exe  < ../inputs/test66 > ../originals/t1385
echo ">>>>>>>>running test 1386"
../source/print_tokens2.exe  < ../inputs/test67 > ../originals/t1386
echo ">>>>>>>>running test 1387"
../source/print_tokens2.exe  < ../inputs/test68 > ../originals/t1387
echo ">>>>>>>>running test 1388"
../source/print_tokens2.exe  < ../inputs/test69 > ../originals/t1388
echo ">>>>>>>>running test 1389"
../source/print_tokens2.exe  < ../inputs/test7 > ../originals/t1389
echo ">>>>>>>>running test 1390"
../source/print_tokens2.exe  < ../inputs/test70 > ../originals/t1390
echo ">>>>>>>>running test 1391"
../source/print_tokens2.exe  < ../inputs/test71 > ../originals/t1391
echo ">>>>>>>>running test 1392"
../source/print_tokens2.exe  < ../inputs/test72 > ../originals/t1392
echo ">>>>>>>>running test 1393"
../source/print_tokens2.exe  < ../inputs/test73 > ../originals/t1393
echo ">>>>>>>>running test 1394"
../source/print_tokens2.exe  < ../inputs/test74 > ../originals/t1394
echo ">>>>>>>>running test 1395"
../source/print_tokens2.exe  < ../inputs/test75 > ../originals/t1395
echo ">>>>>>>>running test 1396"
../source/print_tokens2.exe  < ../inputs/test76 > ../originals/t1396
echo ">>>>>>>>running test 1397"
../source/print_tokens2.exe  < ../inputs/test77 > ../originals/t1397
echo ">>>>>>>>running test 1398"
../source/print_tokens2.exe  < ../inputs/test78 > ../originals/t1398
echo ">>>>>>>>running test 1399"
../source/print_tokens2.exe  < ../inputs/test79 > ../originals/t1399
echo ">>>>>>>>running test 1400"
../source/print_tokens2.exe  < ../inputs/test8 > ../originals/t1400
echo ">>>>>>>>running test 1401"
../source/print_tokens2.exe  < ../inputs/test80 > ../originals/t1401
echo ">>>>>>>>running test 1402"
../source/print_tokens2.exe  < ../inputs/test81 > ../originals/t1402
echo ">>>>>>>>running test 1403"
../source/print_tokens2.exe  < ../inputs/test82 > ../originals/t1403
echo ">>>>>>>>running test 1404"
../source/print_tokens2.exe  < ../inputs/test83 > ../originals/t1404
echo ">>>>>>>>running test 1405"
../source/print_tokens2.exe  < ../inputs/test84 > ../originals/t1405
echo ">>>>>>>>running test 1406"
../source/print_tokens2.exe  < ../inputs/test85 > ../originals/t1406
echo ">>>>>>>>running test 1407"
../source/print_tokens2.exe  < ../inputs/test86 > ../originals/t1407
echo ">>>>>>>>running test 1408"
../source/print_tokens2.exe  < ../inputs/test87 > ../originals/t1408
echo ">>>>>>>>running test 1409"
../source/print_tokens2.exe  < ../inputs/test88 > ../originals/t1409
echo ">>>>>>>>running test 1410"
../source/print_tokens2.exe  < ../inputs/test89 > ../originals/t1410
echo ">>>>>>>>running test 1411"
../source/print_tokens2.exe  < ../inputs/test9 > ../originals/t1411
echo ">>>>>>>>running test 1412"
../source/print_tokens2.exe  < ../inputs/test90 > ../originals/t1412
echo ">>>>>>>>running test 1413"
../source/print_tokens2.exe  < ../inputs/test91 > ../originals/t1413
echo ">>>>>>>>running test 1414"
../source/print_tokens2.exe  < ../inputs/test92 > ../originals/t1414
echo ">>>>>>>>running test 1415"
../source/print_tokens2.exe  < ../inputs/test93 > ../originals/t1415
echo ">>>>>>>>running test 1416"
../source/print_tokens2.exe  < ../inputs/test94 > ../originals/t1416
echo ">>>>>>>>running test 1417"
../source/print_tokens2.exe  < ../inputs/test95 > ../originals/t1417
echo ">>>>>>>>running test 1418"
../source/print_tokens2.exe  < ../inputs/test96 > ../originals/t1418
echo ">>>>>>>>running test 1419"
../source/print_tokens2.exe  < ../inputs/test97 > ../originals/t1419
echo ">>>>>>>>running test 1420"
../source/print_tokens2.exe  < ../inputs/test98 > ../originals/t1420
echo ">>>>>>>>running test 1421"
../source/print_tokens2.exe  < ../inputs/test99 > ../originals/t1421
echo ">>>>>>>>running test 1422"
../source/print_tokens2.exe  < ../inputs/ts500 > ../originals/t1422
echo ">>>>>>>>running test 1423"
../source/print_tokens2.exe  < ../inputs/ts501 > ../originals/t1423
echo ">>>>>>>>running test 1424"
../source/print_tokens2.exe  < ../inputs/ts502 > ../originals/t1424
echo ">>>>>>>>running test 1425"
../source/print_tokens2.exe  < ../inputs/ts503 > ../originals/t1425
echo ">>>>>>>>running test 1426"
../source/print_tokens2.exe  < ../inputs/ts504 > ../originals/t1426
echo ">>>>>>>>running test 1427"
../source/print_tokens2.exe  < ../inputs/ts505 > ../originals/t1427
echo ">>>>>>>>running test 1428"
../source/print_tokens2.exe  < ../inputs/ts506 > ../originals/t1428
echo ">>>>>>>>running test 1429"
../source/print_tokens2.exe  < ../inputs/ts507 > ../originals/t1429
echo ">>>>>>>>running test 1430"
../source/print_tokens2.exe  < ../inputs/ts508 > ../originals/t1430
echo ">>>>>>>>running test 1431"
../source/print_tokens2.exe  < ../inputs/ts509 > ../originals/t1431
echo ">>>>>>>>running test 1432"
../source/print_tokens2.exe  < ../inputs/ts510 > ../originals/t1432
echo ">>>>>>>>running test 1433"
../source/print_tokens2.exe  < ../inputs/ts511 > ../originals/t1433
echo ">>>>>>>>running test 1434"
../source/print_tokens2.exe  < ../inputs/ts512 > ../originals/t1434
echo ">>>>>>>>running test 1435"
../source/print_tokens2.exe  < ../inputs/ts513 > ../originals/t1435
echo ">>>>>>>>running test 1436"
../source/print_tokens2.exe  < ../inputs/ts514 > ../originals/t1436
echo ">>>>>>>>running test 1437"
../source/print_tokens2.exe  < ../inputs/ts515 > ../originals/t1437
echo ">>>>>>>>running test 1438"
../source/print_tokens2.exe  < ../inputs/ts516 > ../originals/t1438
echo ">>>>>>>>running test 1439"
../source/print_tokens2.exe  < ../inputs/ts517 > ../originals/t1439
echo ">>>>>>>>running test 1440"
../source/print_tokens2.exe  < ../inputs/ts518 > ../originals/t1440
echo ">>>>>>>>running test 1441"
../source/print_tokens2.exe  < ../inputs/ts519 > ../originals/t1441
echo ">>>>>>>>running test 1442"
../source/print_tokens2.exe  < ../inputs/ts520 > ../originals/t1442
echo ">>>>>>>>running test 1443"
../source/print_tokens2.exe  < ../inputs/ts521 > ../originals/t1443
echo ">>>>>>>>running test 1444"
../source/print_tokens2.exe  < ../inputs/ts522 > ../originals/t1444
echo ">>>>>>>>running test 1445"
../source/print_tokens2.exe  < ../inputs/ts523 > ../originals/t1445
echo ">>>>>>>>running test 1446"
../source/print_tokens2.exe  < ../inputs/ts524 > ../originals/t1446
echo ">>>>>>>>running test 1447"
../source/print_tokens2.exe  < ../inputs/ts525 > ../originals/t1447
echo ">>>>>>>>running test 1448"
../source/print_tokens2.exe  < ../inputs/ts526 > ../originals/t1448
echo ">>>>>>>>running test 1449"
../source/print_tokens2.exe  < ../inputs/ts527 > ../originals/t1449
echo ">>>>>>>>running test 1450"
../source/print_tokens2.exe  < ../inputs/ts528 > ../originals/t1450
echo ">>>>>>>>running test 1451"
../source/print_tokens2.exe  < ../inputs/ts529 > ../originals/t1451
echo ">>>>>>>>running test 1452"
../source/print_tokens2.exe  < ../inputs/ts530 > ../originals/t1452
echo ">>>>>>>>running test 1453"
../source/print_tokens2.exe  < ../inputs/ts531 > ../originals/t1453
echo ">>>>>>>>running test 1454"
../source/print_tokens2.exe  < ../inputs/ts532 > ../originals/t1454
echo ">>>>>>>>running test 1455"
../source/print_tokens2.exe  < ../inputs/ts533 > ../originals/t1455
echo ">>>>>>>>running test 1456"
../source/print_tokens2.exe  < ../inputs/ts534 > ../originals/t1456
echo ">>>>>>>>running test 1457"
../source/print_tokens2.exe  < ../inputs/ts535 > ../originals/t1457
echo ">>>>>>>>running test 1458"
../source/print_tokens2.exe  < ../inputs/ts536 > ../originals/t1458
echo ">>>>>>>>running test 1459"
../source/print_tokens2.exe  < ../inputs/ts537 > ../originals/t1459
echo ">>>>>>>>running test 1460"
../source/print_tokens2.exe  < ../inputs/ts538 > ../originals/t1460
echo ">>>>>>>>running test 1461"
../source/print_tokens2.exe  < ../inputs/ts539 > ../originals/t1461
echo ">>>>>>>>running test 1462"
../source/print_tokens2.exe  < ../inputs/ts540 > ../originals/t1462
echo ">>>>>>>>running test 1463"
../source/print_tokens2.exe  < ../inputs/ts541 > ../originals/t1463
echo ">>>>>>>>running test 1464"
../source/print_tokens2.exe  < ../inputs/ts542 > ../originals/t1464
echo ">>>>>>>>running test 1465"
../source/print_tokens2.exe  < ../inputs/ts543 > ../originals/t1465
echo ">>>>>>>>running test 1466"
../source/print_tokens2.exe  < ../inputs/ts544 > ../originals/t1466
echo ">>>>>>>>running test 1467"
../source/print_tokens2.exe  < ../inputs/ts545 > ../originals/t1467
echo ">>>>>>>>running test 1468"
../source/print_tokens2.exe  < ../inputs/ts546 > ../originals/t1468
echo ">>>>>>>>running test 1469"
../source/print_tokens2.exe  < ../inputs/ts547 > ../originals/t1469
echo ">>>>>>>>running test 1470"
../source/print_tokens2.exe  < ../inputs/ts548 > ../originals/t1470
echo ">>>>>>>>running test 1471"
../source/print_tokens2.exe  < ../inputs/ts549 > ../originals/t1471
echo ">>>>>>>>running test 1472"
../source/print_tokens2.exe  < ../inputs/ts550 > ../originals/t1472
echo ">>>>>>>>running test 1473"
../source/print_tokens2.exe  < ../inputs/ts551 > ../originals/t1473
echo ">>>>>>>>running test 1474"
../source/print_tokens2.exe  < ../inputs/ts552 > ../originals/t1474
echo ">>>>>>>>running test 1475"
../source/print_tokens2.exe  < ../inputs/ts553 > ../originals/t1475
echo ">>>>>>>>running test 1476"
../source/print_tokens2.exe  < ../inputs/ts554 > ../originals/t1476
echo ">>>>>>>>running test 1477"
../source/print_tokens2.exe  < ../inputs/ts555 > ../originals/t1477
echo ">>>>>>>>running test 1478"
../source/print_tokens2.exe  < ../inputs/ts556 > ../originals/t1478
echo ">>>>>>>>running test 1479"
../source/print_tokens2.exe  < ../inputs/ts557 > ../originals/t1479
echo ">>>>>>>>running test 1480"
../source/print_tokens2.exe  < ../inputs/ts558 > ../originals/t1480
echo ">>>>>>>>running test 1481"
../source/print_tokens2.exe  < ../inputs/ts559 > ../originals/t1481
echo ">>>>>>>>running test 1482"
../source/print_tokens2.exe  < ../inputs/ts560 > ../originals/t1482
echo ">>>>>>>>running test 1483"
../source/print_tokens2.exe  < ../inputs/ts561 > ../originals/t1483
echo ">>>>>>>>running test 1484"
../source/print_tokens2.exe  < ../inputs/ts562 > ../originals/t1484
echo ">>>>>>>>running test 1485"
../source/print_tokens2.exe  < ../inputs/ts563 > ../originals/t1485
echo ">>>>>>>>running test 1486"
../source/print_tokens2.exe  < ../inputs/ts564 > ../originals/t1486
echo ">>>>>>>>running test 1487"
../source/print_tokens2.exe  < ../inputs/ts565 > ../originals/t1487
echo ">>>>>>>>running test 1488"
../source/print_tokens2.exe  < ../inputs/ts566 > ../originals/t1488
echo ">>>>>>>>running test 1489"
../source/print_tokens2.exe  < ../inputs/ts567 > ../originals/t1489
echo ">>>>>>>>running test 1490"
../source/print_tokens2.exe  < ../inputs/ts568 > ../originals/t1490
echo ">>>>>>>>running test 1491"
../source/print_tokens2.exe  < ../inputs/ts569 > ../originals/t1491
echo ">>>>>>>>running test 1492"
../source/print_tokens2.exe  < ../inputs/ts570 > ../originals/t1492
echo ">>>>>>>>running test 1493"
../source/print_tokens2.exe  < ../inputs/ts571 > ../originals/t1493
echo ">>>>>>>>running test 1494"
../source/print_tokens2.exe  < ../inputs/ts572 > ../originals/t1494
echo ">>>>>>>>running test 1495"
../source/print_tokens2.exe  < ../inputs/ts573 > ../originals/t1495
echo ">>>>>>>>running test 1496"
../source/print_tokens2.exe  < ../inputs/ts574 > ../originals/t1496
echo ">>>>>>>>running test 1497"
../source/print_tokens2.exe  < ../inputs/ts575 > ../originals/t1497
echo ">>>>>>>>running test 1498"
../source/print_tokens2.exe  < ../inputs/ts576 > ../originals/t1498
echo ">>>>>>>>running test 1499"
../source/print_tokens2.exe  < ../inputs/ts577 > ../originals/t1499
echo ">>>>>>>>running test 1500"
../source/print_tokens2.exe  < ../inputs/ts578 > ../originals/t1500
echo ">>>>>>>>running test 1501"
../source/print_tokens2.exe  < ../inputs/ts579 > ../originals/t1501
echo ">>>>>>>>running test 1502"
../source/print_tokens2.exe  < ../inputs/ts580 > ../originals/t1502
echo ">>>>>>>>running test 1503"
../source/print_tokens2.exe  < ../inputs/ts581 > ../originals/t1503
echo ">>>>>>>>running test 1504"
../source/print_tokens2.exe  < ../inputs/ts582 > ../originals/t1504
echo ">>>>>>>>running test 1505"
../source/print_tokens2.exe  < ../inputs/ts583 > ../originals/t1505
echo ">>>>>>>>running test 1506"
../source/print_tokens2.exe  < ../inputs/ts584 > ../originals/t1506
echo ">>>>>>>>running test 1507"
../source/print_tokens2.exe  < ../inputs/ts585 > ../originals/t1507
echo ">>>>>>>>running test 1508"
../source/print_tokens2.exe  < ../inputs/ts586 > ../originals/t1508
echo ">>>>>>>>running test 1509"
../source/print_tokens2.exe  < ../inputs/ts587 > ../originals/t1509
echo ">>>>>>>>running test 1510"
../source/print_tokens2.exe  < ../inputs/ts588 > ../originals/t1510
echo ">>>>>>>>running test 1511"
../source/print_tokens2.exe  < ../inputs/ts589 > ../originals/t1511
echo ">>>>>>>>running test 1512"
../source/print_tokens2.exe  < ../inputs/ts590 > ../originals/t1512
echo ">>>>>>>>running test 1513"
../source/print_tokens2.exe  < ../inputs/ts591 > ../originals/t1513
echo ">>>>>>>>running test 1514"
../source/print_tokens2.exe  < ../inputs/ts592 > ../originals/t1514
echo ">>>>>>>>running test 1515"
../source/print_tokens2.exe  < ../inputs/ts593 > ../originals/t1515
echo ">>>>>>>>running test 1516"
../source/print_tokens2.exe  < ../inputs/ts594 > ../originals/t1516
echo ">>>>>>>>running test 1517"
../source/print_tokens2.exe  < ../inputs/ts595 > ../originals/t1517
echo ">>>>>>>>running test 1518"
../source/print_tokens2.exe  < ../inputs/ts596 > ../originals/t1518
echo ">>>>>>>>running test 1519"
../source/print_tokens2.exe  < ../inputs/ts597 > ../originals/t1519
echo ">>>>>>>>running test 1520"
../source/print_tokens2.exe  < ../inputs/ts598 > ../originals/t1520
echo ">>>>>>>>running test 1521"
../source/print_tokens2.exe  < ../inputs/ts599 > ../originals/t1521
echo ">>>>>>>>running test 1522"
../source/print_tokens2.exe  < ../inputs/ts600 > ../originals/t1522
echo ">>>>>>>>running test 1523"
../source/print_tokens2.exe  < ../inputs/ts601 > ../originals/t1523
echo ">>>>>>>>running test 1524"
../source/print_tokens2.exe  < ../inputs/ts603 > ../originals/t1524
echo ">>>>>>>>running test 1525"
../source/print_tokens2.exe  < ../inputs/ts604 > ../originals/t1525
echo ">>>>>>>>running test 1526"
../source/print_tokens2.exe  < ../inputs/ts605 > ../originals/t1526
echo ">>>>>>>>running test 1527"
../source/print_tokens2.exe  < ../inputs/ts606 > ../originals/t1527
echo ">>>>>>>>running test 1528"
../source/print_tokens2.exe  < ../inputs/ts607 > ../originals/t1528
echo ">>>>>>>>running test 1529"
../source/print_tokens2.exe  < ../inputs/ts608 > ../originals/t1529
echo ">>>>>>>>running test 1530"
../source/print_tokens2.exe  < ../inputs/ts609 > ../originals/t1530
echo ">>>>>>>>running test 1531"
../source/print_tokens2.exe  < ../inputs/ts610 > ../originals/t1531
echo ">>>>>>>>running test 1532"
../source/print_tokens2.exe  < ../inputs/ts611 > ../originals/t1532
echo ">>>>>>>>running test 1533"
../source/print_tokens2.exe  < ../inputs/ts612 > ../originals/t1533
echo ">>>>>>>>running test 1534"
../source/print_tokens2.exe  < ../inputs/ts613 > ../originals/t1534
echo ">>>>>>>>running test 1535"
../source/print_tokens2.exe  < ../inputs/ts614 > ../originals/t1535
echo ">>>>>>>>running test 1536"
../source/print_tokens2.exe  < ../inputs/ts615 > ../originals/t1536
echo ">>>>>>>>running test 1537"
../source/print_tokens2.exe  < ../inputs/ts616 > ../originals/t1537
echo ">>>>>>>>running test 1538"
../source/print_tokens2.exe  < ../inputs/ts617 > ../originals/t1538
echo ">>>>>>>>running test 1539"
../source/print_tokens2.exe  < ../inputs/ts618 > ../originals/t1539
echo ">>>>>>>>running test 1540"
../source/print_tokens2.exe  < ../inputs/ts619 > ../originals/t1540
echo ">>>>>>>>running test 1541"
../source/print_tokens2.exe  < ../inputs/ts620 > ../originals/t1541
echo ">>>>>>>>running test 1542"
../source/print_tokens2.exe  < ../inputs/ts621 > ../originals/t1542
echo ">>>>>>>>running test 1543"
../source/print_tokens2.exe  < ../inputs/ts622 > ../originals/t1543
echo ">>>>>>>>running test 1544"
../source/print_tokens2.exe  < ../inputs/ts623 > ../originals/t1544
echo ">>>>>>>>running test 1545"
../source/print_tokens2.exe  < ../inputs/ts624 > ../originals/t1545
echo ">>>>>>>>running test 1546"
../source/print_tokens2.exe  < ../inputs/ts625 > ../originals/t1546
echo ">>>>>>>>running test 1547"
../source/print_tokens2.exe  < ../inputs/ts626 > ../originals/t1547
echo ">>>>>>>>running test 1548"
../source/print_tokens2.exe  < ../inputs/ts627 > ../originals/t1548
echo ">>>>>>>>running test 1549"
../source/print_tokens2.exe  < ../inputs/ts628 > ../originals/t1549
echo ">>>>>>>>running test 1550"
../source/print_tokens2.exe  < ../inputs/ts629 > ../originals/t1550
echo ">>>>>>>>running test 1551"
../source/print_tokens2.exe  < ../inputs/ts630 > ../originals/t1551
echo ">>>>>>>>running test 1552"
../source/print_tokens2.exe  < ../inputs/ts631 > ../originals/t1552
echo ">>>>>>>>running test 1553"
../source/print_tokens2.exe  < ../inputs/ts632 > ../originals/t1553
echo ">>>>>>>>running test 1554"
../source/print_tokens2.exe  < ../inputs/ts633 > ../originals/t1554
echo ">>>>>>>>running test 1555"
../source/print_tokens2.exe  < ../inputs/ts634 > ../originals/t1555
echo ">>>>>>>>running test 1556"
../source/print_tokens2.exe  < ../inputs/ts635 > ../originals/t1556
echo ">>>>>>>>running test 1557"
../source/print_tokens2.exe  < ../inputs/ts636 > ../originals/t1557
echo ">>>>>>>>running test 1558"
../source/print_tokens2.exe  < ../inputs/ts637 > ../originals/t1558
echo ">>>>>>>>running test 1559"
../source/print_tokens2.exe  < ../inputs/ts638 > ../originals/t1559
echo ">>>>>>>>running test 1560"
../source/print_tokens2.exe  < ../inputs/ts639 > ../originals/t1560
echo ">>>>>>>>running test 1561"
../source/print_tokens2.exe  < ../inputs/ts640 > ../originals/t1561
echo ">>>>>>>>running test 1562"
../source/print_tokens2.exe  < ../inputs/ts641 > ../originals/t1562
echo ">>>>>>>>running test 1563"
../source/print_tokens2.exe  < ../inputs/ts642 > ../originals/t1563
echo ">>>>>>>>running test 1564"
../source/print_tokens2.exe  < ../inputs/ts643 > ../originals/t1564
echo ">>>>>>>>running test 1565"
../source/print_tokens2.exe  < ../inputs/ts644 > ../originals/t1565
echo ">>>>>>>>running test 1566"
../source/print_tokens2.exe  < ../inputs/ts645 > ../originals/t1566
echo ">>>>>>>>running test 1567"
../source/print_tokens2.exe  < ../inputs/ts646 > ../originals/t1567
echo ">>>>>>>>running test 1568"
../source/print_tokens2.exe  < ../inputs/ts647 > ../originals/t1568
echo ">>>>>>>>running test 1569"
../source/print_tokens2.exe  < ../inputs/ts648 > ../originals/t1569
echo ">>>>>>>>running test 1570"
../source/print_tokens2.exe  < ../inputs/ts649 > ../originals/t1570
echo ">>>>>>>>running test 1571"
../source/print_tokens2.exe  < ../inputs/ts650 > ../originals/t1571
echo ">>>>>>>>running test 1572"
../source/print_tokens2.exe  < ../inputs/ts651 > ../originals/t1572
echo ">>>>>>>>running test 1573"
../source/print_tokens2.exe  < ../inputs/ts652 > ../originals/t1573
echo ">>>>>>>>running test 1574"
../source/print_tokens2.exe  < ../inputs/ts653 > ../originals/t1574
echo ">>>>>>>>running test 1575"
../source/print_tokens2.exe  < ../inputs/ts654 > ../originals/t1575
echo ">>>>>>>>running test 1576"
../source/print_tokens2.exe  < ../inputs/ts655 > ../originals/t1576
echo ">>>>>>>>running test 1577"
../source/print_tokens2.exe  < ../inputs/ts656 > ../originals/t1577
echo ">>>>>>>>running test 1578"
../source/print_tokens2.exe  < ../inputs/ts657 > ../originals/t1578
echo ">>>>>>>>running test 1579"
../source/print_tokens2.exe  < ../inputs/ts658 > ../originals/t1579
echo ">>>>>>>>running test 1580"
../source/print_tokens2.exe  < ../inputs/ts659 > ../originals/t1580
echo ">>>>>>>>running test 1581"
../source/print_tokens2.exe  < ../inputs/ts660 > ../originals/t1581
echo ">>>>>>>>running test 1582"
../source/print_tokens2.exe  < ../inputs/ts661 > ../originals/t1582
echo ">>>>>>>>running test 1583"
../source/print_tokens2.exe  < ../inputs/ts662 > ../originals/t1583
echo ">>>>>>>>running test 1584"
../source/print_tokens2.exe  < ../inputs/ts663 > ../originals/t1584
echo ">>>>>>>>running test 1585"
../source/print_tokens2.exe  < ../inputs/ts664 > ../originals/t1585
echo ">>>>>>>>running test 1586"
../source/print_tokens2.exe  < ../inputs/ts665 > ../originals/t1586
echo ">>>>>>>>running test 1587"
../source/print_tokens2.exe  < ../inputs/ts666 > ../originals/t1587
echo ">>>>>>>>running test 1588"
../source/print_tokens2.exe  < ../inputs/ts667 > ../originals/t1588
echo ">>>>>>>>running test 1589"
../source/print_tokens2.exe  < ../inputs/ts668 > ../originals/t1589
echo ">>>>>>>>running test 1590"
../source/print_tokens2.exe  < ../inputs/ts669 > ../originals/t1590
echo ">>>>>>>>running test 1591"
../source/print_tokens2.exe  < ../inputs/ts670 > ../originals/t1591
echo ">>>>>>>>running test 1592"
../source/print_tokens2.exe  < ../inputs/ts671 > ../originals/t1592
echo ">>>>>>>>running test 1593"
../source/print_tokens2.exe  < ../inputs/ts672 > ../originals/t1593
echo ">>>>>>>>running test 1594"
../source/print_tokens2.exe  < ../inputs/ts673 > ../originals/t1594
echo ">>>>>>>>running test 1595"
../source/print_tokens2.exe  < ../inputs/ts674 > ../originals/t1595
echo ">>>>>>>>running test 1596"
../source/print_tokens2.exe  < ../inputs/ts675 > ../originals/t1596
echo ">>>>>>>>running test 1597"
../source/print_tokens2.exe  < ../inputs/ts676 > ../originals/t1597
echo ">>>>>>>>running test 1598"
../source/print_tokens2.exe  < ../inputs/ts677 > ../originals/t1598
echo ">>>>>>>>running test 1599"
../source/print_tokens2.exe  < ../inputs/ts678 > ../originals/t1599
echo ">>>>>>>>running test 1600"
../source/print_tokens2.exe  < ../inputs/ts679 > ../originals/t1600
echo ">>>>>>>>running test 1601"
../source/print_tokens2.exe  < ../inputs/ts680 > ../originals/t1601
echo ">>>>>>>>running test 1602"
../source/print_tokens2.exe  < ../inputs/ts681 > ../originals/t1602
echo ">>>>>>>>running test 1603"
../source/print_tokens2.exe  < ../inputs/ts682 > ../originals/t1603
echo ">>>>>>>>running test 1604"
../source/print_tokens2.exe  < ../inputs/ts683 > ../originals/t1604
echo ">>>>>>>>running test 1605"
../source/print_tokens2.exe  < ../inputs/ts684 > ../originals/t1605
echo ">>>>>>>>running test 1606"
../source/print_tokens2.exe  < ../inputs/ts685 > ../originals/t1606
echo ">>>>>>>>running test 1607"
../source/print_tokens2.exe  < ../inputs/ts686 > ../originals/t1607
echo ">>>>>>>>running test 1608"
../source/print_tokens2.exe  < ../inputs/ts687 > ../originals/t1608
echo ">>>>>>>>running test 1609"
../source/print_tokens2.exe  < ../inputs/ts688 > ../originals/t1609
echo ">>>>>>>>running test 1610"
../source/print_tokens2.exe  < ../inputs/ts689 > ../originals/t1610
echo ">>>>>>>>running test 1611"
../source/print_tokens2.exe  < ../inputs/ts690 > ../originals/t1611
echo ">>>>>>>>running test 1612"
../source/print_tokens2.exe  < ../inputs/ts691 > ../originals/t1612
echo ">>>>>>>>running test 1613"
../source/print_tokens2.exe  < ../inputs/ts692 > ../originals/t1613
echo ">>>>>>>>running test 1614"
../source/print_tokens2.exe  < ../inputs/ts693 > ../originals/t1614
echo ">>>>>>>>running test 1615"
../source/print_tokens2.exe  < ../inputs/ts694 > ../originals/t1615
echo ">>>>>>>>running test 1616"
../source/print_tokens2.exe  < ../inputs/ts695 > ../originals/t1616
echo ">>>>>>>>running test 1617"
../source/print_tokens2.exe  < ../inputs/ts696 > ../originals/t1617
echo ">>>>>>>>running test 1618"
../source/print_tokens2.exe  < ../inputs/ts697 > ../originals/t1618
echo ">>>>>>>>running test 1619"
../source/print_tokens2.exe  < ../inputs/ts698 > ../originals/t1619
echo ">>>>>>>>running test 1620"
../source/print_tokens2.exe  < ../inputs/ts699 > ../originals/t1620
echo ">>>>>>>>running test 1621"
../source/print_tokens2.exe  < ../inputs/ts701 > ../originals/t1621
echo ">>>>>>>>running test 1622"
../source/print_tokens2.exe  < ../inputs/ts702 > ../originals/t1622
echo ">>>>>>>>running test 1623"
../source/print_tokens2.exe  < ../inputs/ts703 > ../originals/t1623
echo ">>>>>>>>running test 1624"
../source/print_tokens2.exe  < ../inputs/ts704 > ../originals/t1624
echo ">>>>>>>>running test 1625"
../source/print_tokens2.exe  < ../inputs/ts705 > ../originals/t1625
echo ">>>>>>>>running test 1626"
../source/print_tokens2.exe  < ../inputs/ts706 > ../originals/t1626
echo ">>>>>>>>running test 1627"
../source/print_tokens2.exe  < ../inputs/ts707 > ../originals/t1627
echo ">>>>>>>>running test 1628"
../source/print_tokens2.exe  < ../inputs/ts708 > ../originals/t1628
echo ">>>>>>>>running test 1629"
../source/print_tokens2.exe  < ../inputs/ts709 > ../originals/t1629
echo ">>>>>>>>running test 1630"
../source/print_tokens2.exe  < ../inputs/ts710 > ../originals/t1630
echo ">>>>>>>>running test 1631"
../source/print_tokens2.exe  < ../inputs/ts711 > ../originals/t1631
echo ">>>>>>>>running test 1632"
../source/print_tokens2.exe  < ../inputs/ts712 > ../originals/t1632
echo ">>>>>>>>running test 1633"
../source/print_tokens2.exe  < ../inputs/ts713 > ../originals/t1633
echo ">>>>>>>>running test 1634"
../source/print_tokens2.exe  < ../inputs/ts714 > ../originals/t1634
echo ">>>>>>>>running test 1635"
../source/print_tokens2.exe  < ../inputs/ts715 > ../originals/t1635
echo ">>>>>>>>running test 1636"
../source/print_tokens2.exe  < ../inputs/ts716 > ../originals/t1636
echo ">>>>>>>>running test 1637"
../source/print_tokens2.exe  < ../inputs/ts717 > ../originals/t1637
echo ">>>>>>>>running test 1638"
../source/print_tokens2.exe  < ../inputs/ts718 > ../originals/t1638
echo ">>>>>>>>running test 1639"
../source/print_tokens2.exe  < ../inputs/ts719 > ../originals/t1639
echo ">>>>>>>>running test 1640"
../source/print_tokens2.exe  < ../inputs/ts720 > ../originals/t1640
echo ">>>>>>>>running test 1641"
../source/print_tokens2.exe  < ../inputs/ts721 > ../originals/t1641
echo ">>>>>>>>running test 1642"
../source/print_tokens2.exe  < ../inputs/ts722 > ../originals/t1642
echo ">>>>>>>>running test 1643"
../source/print_tokens2.exe  < ../inputs/ts723 > ../originals/t1643
echo ">>>>>>>>running test 1644"
../source/print_tokens2.exe  < ../inputs/ts724 > ../originals/t1644
echo ">>>>>>>>running test 1645"
../source/print_tokens2.exe  < ../inputs/ts725 > ../originals/t1645
echo ">>>>>>>>running test 1646"
../source/print_tokens2.exe  < ../inputs/ts726 > ../originals/t1646
echo ">>>>>>>>running test 1647"
../source/print_tokens2.exe  < ../inputs/ts727 > ../originals/t1647
echo ">>>>>>>>running test 1648"
../source/print_tokens2.exe  < ../inputs/ts728 > ../originals/t1648
echo ">>>>>>>>running test 1649"
../source/print_tokens2.exe  < ../inputs/ts729 > ../originals/t1649
echo ">>>>>>>>running test 1650"
../source/print_tokens2.exe  < ../inputs/ts730 > ../originals/t1650
echo ">>>>>>>>running test 1651"
../source/print_tokens2.exe  < ../inputs/ts731 > ../originals/t1651
echo ">>>>>>>>running test 1652"
../source/print_tokens2.exe  < ../inputs/ts732 > ../originals/t1652
echo ">>>>>>>>running test 1653"
../source/print_tokens2.exe  < ../inputs/ts733 > ../originals/t1653
echo ">>>>>>>>running test 1654"
../source/print_tokens2.exe  < ../inputs/ts734 > ../originals/t1654
echo ">>>>>>>>running test 1655"
../source/print_tokens2.exe  < ../inputs/ts735 > ../originals/t1655
echo ">>>>>>>>running test 1656"
../source/print_tokens2.exe  < ../inputs/ts736 > ../originals/t1656
echo ">>>>>>>>running test 1657"
../source/print_tokens2.exe  < ../inputs/ts737 > ../originals/t1657
echo ">>>>>>>>running test 1658"
../source/print_tokens2.exe  < ../inputs/ts738 > ../originals/t1658
echo ">>>>>>>>running test 1659"
../source/print_tokens2.exe  < ../inputs/ts739 > ../originals/t1659
echo ">>>>>>>>running test 1660"
../source/print_tokens2.exe  < ../inputs/ts740 > ../originals/t1660
echo ">>>>>>>>running test 1661"
../source/print_tokens2.exe  < ../inputs/ts741 > ../originals/t1661
echo ">>>>>>>>running test 1662"
../source/print_tokens2.exe  < ../inputs/ts742 > ../originals/t1662
echo ">>>>>>>>running test 1663"
../source/print_tokens2.exe  < ../inputs/ts743 > ../originals/t1663
echo ">>>>>>>>running test 1664"
../source/print_tokens2.exe  < ../inputs/ts744 > ../originals/t1664
echo ">>>>>>>>running test 1665"
../source/print_tokens2.exe  < ../inputs/ts745 > ../originals/t1665
echo ">>>>>>>>running test 1666"
../source/print_tokens2.exe  < ../inputs/ts746 > ../originals/t1666
echo ">>>>>>>>running test 1667"
../source/print_tokens2.exe  < ../inputs/ts747 > ../originals/t1667
echo ">>>>>>>>running test 1668"
../source/print_tokens2.exe  < ../inputs/ts748 > ../originals/t1668
echo ">>>>>>>>running test 1669"
../source/print_tokens2.exe  < ../inputs/ts749 > ../originals/t1669
echo ">>>>>>>>running test 1670"
../source/print_tokens2.exe  < ../inputs/ts750 > ../originals/t1670
echo ">>>>>>>>running test 1671"
../source/print_tokens2.exe  < ../inputs/ts751 > ../originals/t1671
echo ">>>>>>>>running test 1672"
../source/print_tokens2.exe  < ../inputs/ts752 > ../originals/t1672
echo ">>>>>>>>running test 1673"
../source/print_tokens2.exe  < ../inputs/ts753 > ../originals/t1673
echo ">>>>>>>>running test 1674"
../source/print_tokens2.exe  < ../inputs/ts754 > ../originals/t1674
echo ">>>>>>>>running test 1675"
../source/print_tokens2.exe  < ../inputs/ts755 > ../originals/t1675
echo ">>>>>>>>running test 1676"
../source/print_tokens2.exe  < ../inputs/ts756 > ../originals/t1676
echo ">>>>>>>>running test 1677"
../source/print_tokens2.exe  < ../inputs/ts757 > ../originals/t1677
echo ">>>>>>>>running test 1678"
../source/print_tokens2.exe  < ../inputs/ts758 > ../originals/t1678
echo ">>>>>>>>running test 1679"
../source/print_tokens2.exe  < ../inputs/ts759 > ../originals/t1679
echo ">>>>>>>>running test 1680"
../source/print_tokens2.exe  < ../inputs/ts760 > ../originals/t1680
echo ">>>>>>>>running test 1681"
../source/print_tokens2.exe  < ../inputs/ts761 > ../originals/t1681
echo ">>>>>>>>running test 1682"
../source/print_tokens2.exe  < ../inputs/ts762 > ../originals/t1682
echo ">>>>>>>>running test 1683"
../source/print_tokens2.exe  < ../inputs/ts763 > ../originals/t1683
echo ">>>>>>>>running test 1684"
../source/print_tokens2.exe  < ../inputs/ts764 > ../originals/t1684
echo ">>>>>>>>running test 1685"
../source/print_tokens2.exe  < ../inputs/ts765 > ../originals/t1685
echo ">>>>>>>>running test 1686"
../source/print_tokens2.exe  < ../inputs/ts766 > ../originals/t1686
echo ">>>>>>>>running test 1687"
../source/print_tokens2.exe  < ../inputs/ts767 > ../originals/t1687
echo ">>>>>>>>running test 1688"
../source/print_tokens2.exe  < ../inputs/ts768 > ../originals/t1688
echo ">>>>>>>>running test 1689"
../source/print_tokens2.exe  < ../inputs/ts769 > ../originals/t1689
echo ">>>>>>>>running test 1690"
../source/print_tokens2.exe  < ../inputs/ts770 > ../originals/t1690
echo ">>>>>>>>running test 1691"
../source/print_tokens2.exe  < ../inputs/ts771 > ../originals/t1691
echo ">>>>>>>>running test 1692"
../source/print_tokens2.exe  < ../inputs/ts772 > ../originals/t1692
echo ">>>>>>>>running test 1693"
../source/print_tokens2.exe  < ../inputs/ts773 > ../originals/t1693
echo ">>>>>>>>running test 1694"
../source/print_tokens2.exe  < ../inputs/ts774 > ../originals/t1694
echo ">>>>>>>>running test 1695"
../source/print_tokens2.exe  < ../inputs/ts775 > ../originals/t1695
echo ">>>>>>>>running test 1696"
../source/print_tokens2.exe  < ../inputs/ts776 > ../originals/t1696
echo ">>>>>>>>running test 1697"
../source/print_tokens2.exe  < ../inputs/ts777 > ../originals/t1697
echo ">>>>>>>>running test 1698"
../source/print_tokens2.exe  < ../inputs/ts778 > ../originals/t1698
echo ">>>>>>>>running test 1699"
../source/print_tokens2.exe  < ../inputs/ts779 > ../originals/t1699
echo ">>>>>>>>running test 1700"
../source/print_tokens2.exe  < ../inputs/ts780 > ../originals/t1700
echo ">>>>>>>>running test 1701"
../source/print_tokens2.exe  < ../inputs/ts781 > ../originals/t1701
echo ">>>>>>>>running test 1702"
../source/print_tokens2.exe  < ../inputs/ts782 > ../originals/t1702
echo ">>>>>>>>running test 1703"
../source/print_tokens2.exe  < ../inputs/ts783 > ../originals/t1703
echo ">>>>>>>>running test 1704"
../source/print_tokens2.exe  < ../inputs/ts784 > ../originals/t1704
echo ">>>>>>>>running test 1705"
../source/print_tokens2.exe  < ../inputs/ts785 > ../originals/t1705
echo ">>>>>>>>running test 1706"
../source/print_tokens2.exe  < ../inputs/ts786 > ../originals/t1706
echo ">>>>>>>>running test 1707"
../source/print_tokens2.exe  < ../inputs/ts787 > ../originals/t1707
echo ">>>>>>>>running test 1708"
../source/print_tokens2.exe  < ../inputs/ts788 > ../originals/t1708
echo ">>>>>>>>running test 1709"
../source/print_tokens2.exe  < ../inputs/ts789 > ../originals/t1709
echo ">>>>>>>>running test 1710"
../source/print_tokens2.exe  < ../inputs/ts790 > ../originals/t1710
echo ">>>>>>>>running test 1711"
../source/print_tokens2.exe  < ../inputs/ts791 > ../originals/t1711
echo ">>>>>>>>running test 1712"
../source/print_tokens2.exe  < ../inputs/ts792 > ../originals/t1712
echo ">>>>>>>>running test 1713"
../source/print_tokens2.exe  < ../inputs/ts793 > ../originals/t1713
echo ">>>>>>>>running test 1714"
../source/print_tokens2.exe  < ../inputs/ts794 > ../originals/t1714
echo ">>>>>>>>running test 1715"
../source/print_tokens2.exe  < ../inputs/ts795 > ../originals/t1715
echo ">>>>>>>>running test 1716"
../source/print_tokens2.exe  < ../inputs/ts796 > ../originals/t1716
echo ">>>>>>>>running test 1717"
../source/print_tokens2.exe  < ../inputs/ts797 > ../originals/t1717
echo ">>>>>>>>running test 1718"
../source/print_tokens2.exe  < ../inputs/ts798 > ../originals/t1718
echo ">>>>>>>>running test 1719"
../source/print_tokens2.exe  < ../inputs/ts799 > ../originals/t1719
echo ">>>>>>>>running test 1720"
../source/print_tokens2.exe  < ../inputs/ts800 > ../originals/t1720
echo ">>>>>>>>running test 1721"
../source/print_tokens2.exe  < ../inputs/tst1 > ../originals/t1721
echo ">>>>>>>>running test 1722"
../source/print_tokens2.exe  < ../inputs/tst10 > ../originals/t1722
echo ">>>>>>>>running test 1723"
../source/print_tokens2.exe  < ../inputs/tst100 > ../originals/t1723
echo ">>>>>>>>running test 1724"
../source/print_tokens2.exe  < ../inputs/tst101 > ../originals/t1724
echo ">>>>>>>>running test 1725"
../source/print_tokens2.exe  < ../inputs/tst102 > ../originals/t1725
echo ">>>>>>>>running test 1726"
../source/print_tokens2.exe  < ../inputs/tst103 > ../originals/t1726
echo ">>>>>>>>running test 1727"
../source/print_tokens2.exe  < ../inputs/tst104 > ../originals/t1727
echo ">>>>>>>>running test 1728"
../source/print_tokens2.exe  < ../inputs/tst105 > ../originals/t1728
echo ">>>>>>>>running test 1729"
../source/print_tokens2.exe  < ../inputs/tst106 > ../originals/t1729
echo ">>>>>>>>running test 1730"
../source/print_tokens2.exe  < ../inputs/tst107 > ../originals/t1730
echo ">>>>>>>>running test 1731"
../source/print_tokens2.exe  < ../inputs/tst108 > ../originals/t1731
echo ">>>>>>>>running test 1732"
../source/print_tokens2.exe  < ../inputs/tst109 > ../originals/t1732
echo ">>>>>>>>running test 1733"
../source/print_tokens2.exe  < ../inputs/tst11 > ../originals/t1733
echo ">>>>>>>>running test 1734"
../source/print_tokens2.exe  < ../inputs/tst110 > ../originals/t1734
echo ">>>>>>>>running test 1735"
../source/print_tokens2.exe  < ../inputs/tst111 > ../originals/t1735
echo ">>>>>>>>running test 1736"
../source/print_tokens2.exe  < ../inputs/tst112 > ../originals/t1736
echo ">>>>>>>>running test 1737"
../source/print_tokens2.exe  < ../inputs/tst113 > ../originals/t1737
echo ">>>>>>>>running test 1738"
../source/print_tokens2.exe  < ../inputs/tst114 > ../originals/t1738
echo ">>>>>>>>running test 1739"
../source/print_tokens2.exe  < ../inputs/tst115 > ../originals/t1739
echo ">>>>>>>>running test 1740"
../source/print_tokens2.exe  < ../inputs/tst116 > ../originals/t1740
echo ">>>>>>>>running test 1741"
../source/print_tokens2.exe  < ../inputs/tst117 > ../originals/t1741
echo ">>>>>>>>running test 1742"
../source/print_tokens2.exe  < ../inputs/tst118 > ../originals/t1742
echo ">>>>>>>>running test 1743"
../source/print_tokens2.exe  < ../inputs/tst119 > ../originals/t1743
echo ">>>>>>>>running test 1744"
../source/print_tokens2.exe  < ../inputs/tst12 > ../originals/t1744
echo ">>>>>>>>running test 1745"
../source/print_tokens2.exe  < ../inputs/tst120 > ../originals/t1745
echo ">>>>>>>>running test 1746"
../source/print_tokens2.exe  < ../inputs/tst121 > ../originals/t1746
echo ">>>>>>>>running test 1747"
../source/print_tokens2.exe  < ../inputs/tst122 > ../originals/t1747
echo ">>>>>>>>running test 1748"
../source/print_tokens2.exe  < ../inputs/tst123 > ../originals/t1748
echo ">>>>>>>>running test 1749"
../source/print_tokens2.exe  < ../inputs/tst124 > ../originals/t1749
echo ">>>>>>>>running test 1750"
../source/print_tokens2.exe  < ../inputs/tst125 > ../originals/t1750
echo ">>>>>>>>running test 1751"
../source/print_tokens2.exe  < ../inputs/tst126 > ../originals/t1751
echo ">>>>>>>>running test 1752"
../source/print_tokens2.exe  < ../inputs/tst127 > ../originals/t1752
echo ">>>>>>>>running test 1753"
../source/print_tokens2.exe  < ../inputs/tst128 > ../originals/t1753
echo ">>>>>>>>running test 1754"
../source/print_tokens2.exe  < ../inputs/tst129 > ../originals/t1754
echo ">>>>>>>>running test 1755"
../source/print_tokens2.exe  < ../inputs/tst13 > ../originals/t1755
echo ">>>>>>>>running test 1756"
../source/print_tokens2.exe  < ../inputs/tst130 > ../originals/t1756
echo ">>>>>>>>running test 1757"
../source/print_tokens2.exe  < ../inputs/tst131 > ../originals/t1757
echo ">>>>>>>>running test 1758"
../source/print_tokens2.exe  < ../inputs/tst132 > ../originals/t1758
echo ">>>>>>>>running test 1759"
../source/print_tokens2.exe  < ../inputs/tst133 > ../originals/t1759
echo ">>>>>>>>running test 1760"
../source/print_tokens2.exe  < ../inputs/tst134 > ../originals/t1760
echo ">>>>>>>>running test 1761"
../source/print_tokens2.exe  < ../inputs/tst135 > ../originals/t1761
echo ">>>>>>>>running test 1762"
../source/print_tokens2.exe  < ../inputs/tst136 > ../originals/t1762
echo ">>>>>>>>running test 1763"
../source/print_tokens2.exe  < ../inputs/tst137 > ../originals/t1763
echo ">>>>>>>>running test 1764"
../source/print_tokens2.exe  < ../inputs/tst138 > ../originals/t1764
echo ">>>>>>>>running test 1765"
../source/print_tokens2.exe  < ../inputs/tst139 > ../originals/t1765
echo ">>>>>>>>running test 1766"
../source/print_tokens2.exe  < ../inputs/tst14 > ../originals/t1766
echo ">>>>>>>>running test 1767"
../source/print_tokens2.exe  < ../inputs/tst140 > ../originals/t1767
echo ">>>>>>>>running test 1768"
../source/print_tokens2.exe  < ../inputs/tst141 > ../originals/t1768
echo ">>>>>>>>running test 1769"
../source/print_tokens2.exe  < ../inputs/tst142 > ../originals/t1769
echo ">>>>>>>>running test 1770"
../source/print_tokens2.exe  < ../inputs/tst143 > ../originals/t1770
echo ">>>>>>>>running test 1771"
../source/print_tokens2.exe  < ../inputs/tst144 > ../originals/t1771
echo ">>>>>>>>running test 1772"
../source/print_tokens2.exe  < ../inputs/tst145 > ../originals/t1772
echo ">>>>>>>>running test 1773"
../source/print_tokens2.exe  < ../inputs/tst146 > ../originals/t1773
echo ">>>>>>>>running test 1774"
../source/print_tokens2.exe  < ../inputs/tst147 > ../originals/t1774
echo ">>>>>>>>running test 1775"
../source/print_tokens2.exe  < ../inputs/tst148 > ../originals/t1775
echo ">>>>>>>>running test 1776"
../source/print_tokens2.exe  < ../inputs/tst149 > ../originals/t1776
echo ">>>>>>>>running test 1777"
../source/print_tokens2.exe  < ../inputs/tst15 > ../originals/t1777
echo ">>>>>>>>running test 1778"
../source/print_tokens2.exe  < ../inputs/tst150 > ../originals/t1778
echo ">>>>>>>>running test 1779"
../source/print_tokens2.exe  < ../inputs/tst151 > ../originals/t1779
echo ">>>>>>>>running test 1780"
../source/print_tokens2.exe  < ../inputs/tst152 > ../originals/t1780
echo ">>>>>>>>running test 1781"
../source/print_tokens2.exe  < ../inputs/tst153 > ../originals/t1781
echo ">>>>>>>>running test 1782"
../source/print_tokens2.exe  < ../inputs/tst154 > ../originals/t1782
echo ">>>>>>>>running test 1783"
../source/print_tokens2.exe  < ../inputs/tst155 > ../originals/t1783
echo ">>>>>>>>running test 1784"
../source/print_tokens2.exe  < ../inputs/tst156 > ../originals/t1784
echo ">>>>>>>>running test 1785"
../source/print_tokens2.exe  < ../inputs/tst157 > ../originals/t1785
echo ">>>>>>>>running test 1786"
../source/print_tokens2.exe  < ../inputs/tst158 > ../originals/t1786
echo ">>>>>>>>running test 1787"
../source/print_tokens2.exe  < ../inputs/tst159 > ../originals/t1787
echo ">>>>>>>>running test 1788"
../source/print_tokens2.exe  < ../inputs/tst16 > ../originals/t1788
echo ">>>>>>>>running test 1789"
../source/print_tokens2.exe  < ../inputs/tst160 > ../originals/t1789
echo ">>>>>>>>running test 1790"
../source/print_tokens2.exe  < ../inputs/tst161 > ../originals/t1790
echo ">>>>>>>>running test 1791"
../source/print_tokens2.exe  < ../inputs/tst162 > ../originals/t1791
echo ">>>>>>>>running test 1792"
../source/print_tokens2.exe  < ../inputs/tst163 > ../originals/t1792
echo ">>>>>>>>running test 1793"
../source/print_tokens2.exe  < ../inputs/tst164 > ../originals/t1793
echo ">>>>>>>>running test 1794"
../source/print_tokens2.exe  < ../inputs/tst165 > ../originals/t1794
echo ">>>>>>>>running test 1795"
../source/print_tokens2.exe  < ../inputs/tst166 > ../originals/t1795
echo ">>>>>>>>running test 1796"
../source/print_tokens2.exe  < ../inputs/tst167 > ../originals/t1796
echo ">>>>>>>>running test 1797"
../source/print_tokens2.exe  < ../inputs/tst168 > ../originals/t1797
echo ">>>>>>>>running test 1798"
../source/print_tokens2.exe  < ../inputs/tst169 > ../originals/t1798
echo ">>>>>>>>running test 1799"
../source/print_tokens2.exe  < ../inputs/tst17 > ../originals/t1799
echo ">>>>>>>>running test 1800"
../source/print_tokens2.exe  < ../inputs/tst170 > ../originals/t1800
echo ">>>>>>>>running test 1801"
../source/print_tokens2.exe  < ../inputs/tst171 > ../originals/t1801
echo ">>>>>>>>running test 1802"
../source/print_tokens2.exe  < ../inputs/tst172 > ../originals/t1802
echo ">>>>>>>>running test 1803"
../source/print_tokens2.exe  < ../inputs/tst173 > ../originals/t1803
echo ">>>>>>>>running test 1804"
../source/print_tokens2.exe  < ../inputs/tst174 > ../originals/t1804
echo ">>>>>>>>running test 1805"
../source/print_tokens2.exe  < ../inputs/tst175 > ../originals/t1805
echo ">>>>>>>>running test 1806"
../source/print_tokens2.exe  < ../inputs/tst176 > ../originals/t1806
echo ">>>>>>>>running test 1807"
../source/print_tokens2.exe  < ../inputs/tst177 > ../originals/t1807
echo ">>>>>>>>running test 1808"
../source/print_tokens2.exe  < ../inputs/tst178 > ../originals/t1808
echo ">>>>>>>>running test 1809"
../source/print_tokens2.exe  < ../inputs/tst179 > ../originals/t1809
echo ">>>>>>>>running test 1810"
../source/print_tokens2.exe  < ../inputs/tst18 > ../originals/t1810
echo ">>>>>>>>running test 1811"
../source/print_tokens2.exe  < ../inputs/tst180 > ../originals/t1811
echo ">>>>>>>>running test 1812"
../source/print_tokens2.exe  < ../inputs/tst181 > ../originals/t1812
echo ">>>>>>>>running test 1813"
../source/print_tokens2.exe  < ../inputs/tst182 > ../originals/t1813
echo ">>>>>>>>running test 1814"
../source/print_tokens2.exe  < ../inputs/tst183 > ../originals/t1814
echo ">>>>>>>>running test 1815"
../source/print_tokens2.exe  < ../inputs/tst184 > ../originals/t1815
echo ">>>>>>>>running test 1816"
../source/print_tokens2.exe  < ../inputs/tst185 > ../originals/t1816
echo ">>>>>>>>running test 1817"
../source/print_tokens2.exe  < ../inputs/tst186 > ../originals/t1817
echo ">>>>>>>>running test 1818"
../source/print_tokens2.exe  < ../inputs/tst187 > ../originals/t1818
echo ">>>>>>>>running test 1819"
../source/print_tokens2.exe  < ../inputs/tst188 > ../originals/t1819
echo ">>>>>>>>running test 1820"
../source/print_tokens2.exe  < ../inputs/tst189 > ../originals/t1820
echo ">>>>>>>>running test 1821"
../source/print_tokens2.exe  < ../inputs/tst19 > ../originals/t1821
echo ">>>>>>>>running test 1822"
../source/print_tokens2.exe  < ../inputs/tst190 > ../originals/t1822
echo ">>>>>>>>running test 1823"
../source/print_tokens2.exe  < ../inputs/tst191 > ../originals/t1823
echo ">>>>>>>>running test 1824"
../source/print_tokens2.exe  < ../inputs/tst192 > ../originals/t1824
echo ">>>>>>>>running test 1825"
../source/print_tokens2.exe  < ../inputs/tst193 > ../originals/t1825
echo ">>>>>>>>running test 1826"
../source/print_tokens2.exe  < ../inputs/tst194 > ../originals/t1826
echo ">>>>>>>>running test 1827"
../source/print_tokens2.exe  < ../inputs/tst195 > ../originals/t1827
echo ">>>>>>>>running test 1828"
../source/print_tokens2.exe  < ../inputs/tst196 > ../originals/t1828
echo ">>>>>>>>running test 1829"
../source/print_tokens2.exe  < ../inputs/tst197 > ../originals/t1829
echo ">>>>>>>>running test 1830"
../source/print_tokens2.exe  < ../inputs/tst198 > ../originals/t1830
echo ">>>>>>>>running test 1831"
../source/print_tokens2.exe  < ../inputs/tst199 > ../originals/t1831
echo ">>>>>>>>running test 1832"
../source/print_tokens2.exe  < ../inputs/tst2 > ../originals/t1832
echo ">>>>>>>>running test 1833"
../source/print_tokens2.exe  < ../inputs/tst20 > ../originals/t1833
echo ">>>>>>>>running test 1834"
../source/print_tokens2.exe  < ../inputs/tst200 > ../originals/t1834
echo ">>>>>>>>running test 1835"
../source/print_tokens2.exe  < ../inputs/tst201 > ../originals/t1835
echo ">>>>>>>>running test 1836"
../source/print_tokens2.exe  < ../inputs/tst203 > ../originals/t1836
echo ">>>>>>>>running test 1837"
../source/print_tokens2.exe  < ../inputs/tst204 > ../originals/t1837
echo ">>>>>>>>running test 1838"
../source/print_tokens2.exe  < ../inputs/tst205 > ../originals/t1838
echo ">>>>>>>>running test 1839"
../source/print_tokens2.exe  < ../inputs/tst206 > ../originals/t1839
echo ">>>>>>>>running test 1840"
../source/print_tokens2.exe  < ../inputs/tst207 > ../originals/t1840
echo ">>>>>>>>running test 1841"
../source/print_tokens2.exe  < ../inputs/tst208 > ../originals/t1841
echo ">>>>>>>>running test 1842"
../source/print_tokens2.exe  < ../inputs/tst209 > ../originals/t1842
echo ">>>>>>>>running test 1843"
../source/print_tokens2.exe  < ../inputs/tst21 > ../originals/t1843
echo ">>>>>>>>running test 1844"
../source/print_tokens2.exe  < ../inputs/tst210 > ../originals/t1844
echo ">>>>>>>>running test 1845"
../source/print_tokens2.exe  < ../inputs/tst211 > ../originals/t1845
echo ">>>>>>>>running test 1846"
../source/print_tokens2.exe  < ../inputs/tst212 > ../originals/t1846
echo ">>>>>>>>running test 1847"
../source/print_tokens2.exe  < ../inputs/tst213 > ../originals/t1847
echo ">>>>>>>>running test 1848"
../source/print_tokens2.exe  < ../inputs/tst214 > ../originals/t1848
echo ">>>>>>>>running test 1849"
../source/print_tokens2.exe  < ../inputs/tst215 > ../originals/t1849
echo ">>>>>>>>running test 1850"
../source/print_tokens2.exe  < ../inputs/tst216 > ../originals/t1850
echo ">>>>>>>>running test 1851"
../source/print_tokens2.exe  < ../inputs/tst217 > ../originals/t1851
echo ">>>>>>>>running test 1852"
../source/print_tokens2.exe  < ../inputs/tst218 > ../originals/t1852
echo ">>>>>>>>running test 1853"
../source/print_tokens2.exe  < ../inputs/tst219 > ../originals/t1853
echo ">>>>>>>>running test 1854"
../source/print_tokens2.exe  < ../inputs/tst22 > ../originals/t1854
echo ">>>>>>>>running test 1855"
../source/print_tokens2.exe  < ../inputs/tst220 > ../originals/t1855
echo ">>>>>>>>running test 1856"
../source/print_tokens2.exe  < ../inputs/tst221 > ../originals/t1856
echo ">>>>>>>>running test 1857"
../source/print_tokens2.exe  < ../inputs/tst222 > ../originals/t1857
echo ">>>>>>>>running test 1858"
../source/print_tokens2.exe  < ../inputs/tst223 > ../originals/t1858
echo ">>>>>>>>running test 1859"
../source/print_tokens2.exe  < ../inputs/tst224 > ../originals/t1859
echo ">>>>>>>>running test 1860"
../source/print_tokens2.exe  < ../inputs/tst225 > ../originals/t1860
echo ">>>>>>>>running test 1861"
../source/print_tokens2.exe  < ../inputs/tst226 > ../originals/t1861
echo ">>>>>>>>running test 1862"
../source/print_tokens2.exe  < ../inputs/tst227 > ../originals/t1862
echo ">>>>>>>>running test 1863"
../source/print_tokens2.exe  < ../inputs/tst228 > ../originals/t1863
echo ">>>>>>>>running test 1864"
../source/print_tokens2.exe  < ../inputs/tst229 > ../originals/t1864
echo ">>>>>>>>running test 1865"
../source/print_tokens2.exe  < ../inputs/tst23 > ../originals/t1865
echo ">>>>>>>>running test 1866"
../source/print_tokens2.exe  < ../inputs/tst230 > ../originals/t1866
echo ">>>>>>>>running test 1867"
../source/print_tokens2.exe  < ../inputs/tst231 > ../originals/t1867
echo ">>>>>>>>running test 1868"
../source/print_tokens2.exe  < ../inputs/tst232 > ../originals/t1868
echo ">>>>>>>>running test 1869"
../source/print_tokens2.exe  < ../inputs/tst233 > ../originals/t1869
echo ">>>>>>>>running test 1870"
../source/print_tokens2.exe  < ../inputs/tst234 > ../originals/t1870
echo ">>>>>>>>running test 1871"
../source/print_tokens2.exe  < ../inputs/tst235 > ../originals/t1871
echo ">>>>>>>>running test 1872"
../source/print_tokens2.exe  < ../inputs/tst236 > ../originals/t1872
echo ">>>>>>>>running test 1873"
../source/print_tokens2.exe  < ../inputs/tst237 > ../originals/t1873
echo ">>>>>>>>running test 1874"
../source/print_tokens2.exe  < ../inputs/tst238 > ../originals/t1874
echo ">>>>>>>>running test 1875"
../source/print_tokens2.exe  < ../inputs/tst239 > ../originals/t1875
echo ">>>>>>>>running test 1876"
../source/print_tokens2.exe  < ../inputs/tst24 > ../originals/t1876
echo ">>>>>>>>running test 1877"
../source/print_tokens2.exe  < ../inputs/tst240 > ../originals/t1877
echo ">>>>>>>>running test 1878"
../source/print_tokens2.exe  < ../inputs/tst241 > ../originals/t1878
echo ">>>>>>>>running test 1879"
../source/print_tokens2.exe  < ../inputs/tst242 > ../originals/t1879
echo ">>>>>>>>running test 1880"
../source/print_tokens2.exe  < ../inputs/tst243 > ../originals/t1880
echo ">>>>>>>>running test 1881"
../source/print_tokens2.exe  < ../inputs/tst244 > ../originals/t1881
echo ">>>>>>>>running test 1882"
../source/print_tokens2.exe  < ../inputs/tst245 > ../originals/t1882
echo ">>>>>>>>running test 1883"
../source/print_tokens2.exe  < ../inputs/tst246 > ../originals/t1883
echo ">>>>>>>>running test 1884"
../source/print_tokens2.exe  < ../inputs/tst247 > ../originals/t1884
echo ">>>>>>>>running test 1885"
../source/print_tokens2.exe  < ../inputs/tst248 > ../originals/t1885
echo ">>>>>>>>running test 1886"
../source/print_tokens2.exe  < ../inputs/tst249 > ../originals/t1886
echo ">>>>>>>>running test 1887"
../source/print_tokens2.exe  < ../inputs/tst25 > ../originals/t1887
echo ">>>>>>>>running test 1888"
../source/print_tokens2.exe  < ../inputs/tst250 > ../originals/t1888
echo ">>>>>>>>running test 1889"
../source/print_tokens2.exe  < ../inputs/tst251 > ../originals/t1889
echo ">>>>>>>>running test 1890"
../source/print_tokens2.exe  < ../inputs/tst252 > ../originals/t1890
echo ">>>>>>>>running test 1891"
../source/print_tokens2.exe  < ../inputs/tst253 > ../originals/t1891
echo ">>>>>>>>running test 1892"
../source/print_tokens2.exe  < ../inputs/tst254 > ../originals/t1892
echo ">>>>>>>>running test 1893"
../source/print_tokens2.exe  < ../inputs/tst255 > ../originals/t1893
echo ">>>>>>>>running test 1894"
../source/print_tokens2.exe  < ../inputs/tst256 > ../originals/t1894
echo ">>>>>>>>running test 1895"
../source/print_tokens2.exe  < ../inputs/tst257 > ../originals/t1895
echo ">>>>>>>>running test 1896"
../source/print_tokens2.exe  < ../inputs/tst258 > ../originals/t1896
echo ">>>>>>>>running test 1897"
../source/print_tokens2.exe  < ../inputs/tst259 > ../originals/t1897
echo ">>>>>>>>running test 1898"
../source/print_tokens2.exe  < ../inputs/tst26 > ../originals/t1898
echo ">>>>>>>>running test 1899"
../source/print_tokens2.exe  < ../inputs/tst260 > ../originals/t1899
echo ">>>>>>>>running test 1900"
../source/print_tokens2.exe  < ../inputs/tst261 > ../originals/t1900
echo ">>>>>>>>running test 1901"
../source/print_tokens2.exe  < ../inputs/tst262 > ../originals/t1901
echo ">>>>>>>>running test 1902"
../source/print_tokens2.exe  < ../inputs/tst263 > ../originals/t1902
echo ">>>>>>>>running test 1903"
../source/print_tokens2.exe  < ../inputs/tst264 > ../originals/t1903
echo ">>>>>>>>running test 1904"
../source/print_tokens2.exe  < ../inputs/tst265 > ../originals/t1904
echo ">>>>>>>>running test 1905"
../source/print_tokens2.exe  < ../inputs/tst266 > ../originals/t1905
echo ">>>>>>>>running test 1906"
../source/print_tokens2.exe  < ../inputs/tst267 > ../originals/t1906
echo ">>>>>>>>running test 1907"
../source/print_tokens2.exe  < ../inputs/tst268 > ../originals/t1907
echo ">>>>>>>>running test 1908"
../source/print_tokens2.exe  < ../inputs/tst269 > ../originals/t1908
echo ">>>>>>>>running test 1909"
../source/print_tokens2.exe  < ../inputs/tst27 > ../originals/t1909
echo ">>>>>>>>running test 1910"
../source/print_tokens2.exe  < ../inputs/tst270 > ../originals/t1910
echo ">>>>>>>>running test 1911"
../source/print_tokens2.exe  < ../inputs/tst271 > ../originals/t1911
echo ">>>>>>>>running test 1912"
../source/print_tokens2.exe  < ../inputs/tst272 > ../originals/t1912
echo ">>>>>>>>running test 1913"
../source/print_tokens2.exe  < ../inputs/tst273 > ../originals/t1913
echo ">>>>>>>>running test 1914"
../source/print_tokens2.exe  < ../inputs/tst274 > ../originals/t1914
echo ">>>>>>>>running test 1915"
../source/print_tokens2.exe  < ../inputs/tst275 > ../originals/t1915
echo ">>>>>>>>running test 1916"
../source/print_tokens2.exe  < ../inputs/tst276 > ../originals/t1916
echo ">>>>>>>>running test 1917"
../source/print_tokens2.exe  < ../inputs/tst277 > ../originals/t1917
echo ">>>>>>>>running test 1918"
../source/print_tokens2.exe  < ../inputs/tst278 > ../originals/t1918
echo ">>>>>>>>running test 1919"
../source/print_tokens2.exe  < ../inputs/tst279 > ../originals/t1919
echo ">>>>>>>>running test 1920"
../source/print_tokens2.exe  < ../inputs/tst28 > ../originals/t1920
echo ">>>>>>>>running test 1921"
../source/print_tokens2.exe  < ../inputs/tst280 > ../originals/t1921
echo ">>>>>>>>running test 1922"
../source/print_tokens2.exe  < ../inputs/tst281 > ../originals/t1922
echo ">>>>>>>>running test 1923"
../source/print_tokens2.exe  < ../inputs/tst282 > ../originals/t1923
echo ">>>>>>>>running test 1924"
../source/print_tokens2.exe  < ../inputs/tst283 > ../originals/t1924
echo ">>>>>>>>running test 1925"
../source/print_tokens2.exe  < ../inputs/tst284 > ../originals/t1925
echo ">>>>>>>>running test 1926"
../source/print_tokens2.exe  < ../inputs/tst285 > ../originals/t1926
echo ">>>>>>>>running test 1927"
../source/print_tokens2.exe  < ../inputs/tst286 > ../originals/t1927
echo ">>>>>>>>running test 1928"
../source/print_tokens2.exe  < ../inputs/tst287 > ../originals/t1928
echo ">>>>>>>>running test 1929"
../source/print_tokens2.exe  < ../inputs/tst288 > ../originals/t1929
echo ">>>>>>>>running test 1930"
../source/print_tokens2.exe  < ../inputs/tst289 > ../originals/t1930
echo ">>>>>>>>running test 1931"
../source/print_tokens2.exe  < ../inputs/tst29 > ../originals/t1931
echo ">>>>>>>>running test 1932"
../source/print_tokens2.exe  < ../inputs/tst290 > ../originals/t1932
echo ">>>>>>>>running test 1933"
../source/print_tokens2.exe  < ../inputs/tst291 > ../originals/t1933
echo ">>>>>>>>running test 1934"
../source/print_tokens2.exe  < ../inputs/tst292 > ../originals/t1934
echo ">>>>>>>>running test 1935"
../source/print_tokens2.exe  < ../inputs/tst293 > ../originals/t1935
echo ">>>>>>>>running test 1936"
../source/print_tokens2.exe  < ../inputs/tst294 > ../originals/t1936
echo ">>>>>>>>running test 1937"
../source/print_tokens2.exe  < ../inputs/tst295 > ../originals/t1937
echo ">>>>>>>>running test 1938"
../source/print_tokens2.exe  < ../inputs/tst296 > ../originals/t1938
echo ">>>>>>>>running test 1939"
../source/print_tokens2.exe  < ../inputs/tst297 > ../originals/t1939
echo ">>>>>>>>running test 1940"
../source/print_tokens2.exe  < ../inputs/tst298 > ../originals/t1940
echo ">>>>>>>>running test 1941"
../source/print_tokens2.exe  < ../inputs/tst299 > ../originals/t1941
echo ">>>>>>>>running test 1942"
../source/print_tokens2.exe  < ../inputs/tst3 > ../originals/t1942
echo ">>>>>>>>running test 1943"
../source/print_tokens2.exe  < ../inputs/tst30 > ../originals/t1943
echo ">>>>>>>>running test 1944"
../source/print_tokens2.exe  < ../inputs/tst300 > ../originals/t1944
echo ">>>>>>>>running test 1945"
../source/print_tokens2.exe  < ../inputs/tst31 > ../originals/t1945
echo ">>>>>>>>running test 1946"
../source/print_tokens2.exe  < ../inputs/tst32 > ../originals/t1946
echo ">>>>>>>>running test 1947"
../source/print_tokens2.exe  < ../inputs/tst33 > ../originals/t1947
echo ">>>>>>>>running test 1948"
../source/print_tokens2.exe  < ../inputs/tst34 > ../originals/t1948
echo ">>>>>>>>running test 1949"
../source/print_tokens2.exe  < ../inputs/tst35 > ../originals/t1949
echo ">>>>>>>>running test 1950"
../source/print_tokens2.exe  < ../inputs/tst36 > ../originals/t1950
echo ">>>>>>>>running test 1951"
../source/print_tokens2.exe  < ../inputs/tst37 > ../originals/t1951
echo ">>>>>>>>running test 1952"
../source/print_tokens2.exe  < ../inputs/tst38 > ../originals/t1952
echo ">>>>>>>>running test 1953"
../source/print_tokens2.exe  < ../inputs/tst39 > ../originals/t1953
echo ">>>>>>>>running test 1954"
../source/print_tokens2.exe  < ../inputs/tst4 > ../originals/t1954
echo ">>>>>>>>running test 1955"
../source/print_tokens2.exe  < ../inputs/tst40 > ../originals/t1955
echo ">>>>>>>>running test 1956"
../source/print_tokens2.exe  < ../inputs/tst41 > ../originals/t1956
echo ">>>>>>>>running test 1957"
../source/print_tokens2.exe  < ../inputs/tst42 > ../originals/t1957
echo ">>>>>>>>running test 1958"
../source/print_tokens2.exe  < ../inputs/tst43 > ../originals/t1958
echo ">>>>>>>>running test 1959"
../source/print_tokens2.exe  < ../inputs/tst44 > ../originals/t1959
echo ">>>>>>>>running test 1960"
../source/print_tokens2.exe  < ../inputs/tst45 > ../originals/t1960
echo ">>>>>>>>running test 1961"
../source/print_tokens2.exe  < ../inputs/tst46 > ../originals/t1961
echo ">>>>>>>>running test 1962"
../source/print_tokens2.exe  < ../inputs/tst47 > ../originals/t1962
echo ">>>>>>>>running test 1963"
../source/print_tokens2.exe  < ../inputs/tst48 > ../originals/t1963
echo ">>>>>>>>running test 1964"
../source/print_tokens2.exe  < ../inputs/tst49 > ../originals/t1964
echo ">>>>>>>>running test 1965"
../source/print_tokens2.exe  < ../inputs/tst5 > ../originals/t1965
echo ">>>>>>>>running test 1966"
../source/print_tokens2.exe  < ../inputs/tst50 > ../originals/t1966
echo ">>>>>>>>running test 1967"
../source/print_tokens2.exe  < ../inputs/tst51 > ../originals/t1967
echo ">>>>>>>>running test 1968"
../source/print_tokens2.exe  < ../inputs/tst52 > ../originals/t1968
echo ">>>>>>>>running test 1969"
../source/print_tokens2.exe  < ../inputs/tst53 > ../originals/t1969
echo ">>>>>>>>running test 1970"
../source/print_tokens2.exe  < ../inputs/tst54 > ../originals/t1970
echo ">>>>>>>>running test 1971"
../source/print_tokens2.exe  < ../inputs/tst55 > ../originals/t1971
echo ">>>>>>>>running test 1972"
../source/print_tokens2.exe  < ../inputs/tst56 > ../originals/t1972
echo ">>>>>>>>running test 1973"
../source/print_tokens2.exe  < ../inputs/tst57 > ../originals/t1973
echo ">>>>>>>>running test 1974"
../source/print_tokens2.exe  < ../inputs/tst58 > ../originals/t1974
echo ">>>>>>>>running test 1975"
../source/print_tokens2.exe  < ../inputs/tst59 > ../originals/t1975
echo ">>>>>>>>running test 1976"
../source/print_tokens2.exe  < ../inputs/tst6 > ../originals/t1976
echo ">>>>>>>>running test 1977"
../source/print_tokens2.exe  < ../inputs/tst60 > ../originals/t1977
echo ">>>>>>>>running test 1978"
../source/print_tokens2.exe  < ../inputs/tst61 > ../originals/t1978
echo ">>>>>>>>running test 1979"
../source/print_tokens2.exe  < ../inputs/tst62 > ../originals/t1979
echo ">>>>>>>>running test 1980"
../source/print_tokens2.exe  < ../inputs/tst63 > ../originals/t1980
echo ">>>>>>>>running test 1981"
../source/print_tokens2.exe  < ../inputs/tst64 > ../originals/t1981
echo ">>>>>>>>running test 1982"
../source/print_tokens2.exe  < ../inputs/tst65 > ../originals/t1982
echo ">>>>>>>>running test 1983"
../source/print_tokens2.exe  < ../inputs/tst66 > ../originals/t1983
echo ">>>>>>>>running test 1984"
../source/print_tokens2.exe  < ../inputs/tst67 > ../originals/t1984
echo ">>>>>>>>running test 1985"
../source/print_tokens2.exe  < ../inputs/tst68 > ../originals/t1985
echo ">>>>>>>>running test 1986"
../source/print_tokens2.exe  < ../inputs/tst69 > ../originals/t1986
echo ">>>>>>>>running test 1987"
../source/print_tokens2.exe  < ../inputs/tst7 > ../originals/t1987
echo ">>>>>>>>running test 1988"
../source/print_tokens2.exe  < ../inputs/tst70 > ../originals/t1988
echo ">>>>>>>>running test 1989"
../source/print_tokens2.exe  < ../inputs/tst71 > ../originals/t1989
echo ">>>>>>>>running test 1990"
../source/print_tokens2.exe  < ../inputs/tst72 > ../originals/t1990
echo ">>>>>>>>running test 1991"
../source/print_tokens2.exe  < ../inputs/tst73 > ../originals/t1991
echo ">>>>>>>>running test 1992"
../source/print_tokens2.exe  < ../inputs/tst74 > ../originals/t1992
echo ">>>>>>>>running test 1993"
../source/print_tokens2.exe  < ../inputs/tst75 > ../originals/t1993
echo ">>>>>>>>running test 1994"
../source/print_tokens2.exe  < ../inputs/tst76 > ../originals/t1994
echo ">>>>>>>>running test 1995"
../source/print_tokens2.exe  < ../inputs/tst77 > ../originals/t1995
echo ">>>>>>>>running test 1996"
../source/print_tokens2.exe  < ../inputs/tst78 > ../originals/t1996
echo ">>>>>>>>running test 1997"
../source/print_tokens2.exe  < ../inputs/tst79 > ../originals/t1997
echo ">>>>>>>>running test 1998"
../source/print_tokens2.exe  < ../inputs/tst8 > ../originals/t1998
echo ">>>>>>>>running test 1999"
../source/print_tokens2.exe  < ../inputs/tst80 > ../originals/t1999
echo ">>>>>>>>running test 2000"
../source/print_tokens2.exe  < ../inputs/tst81 > ../originals/t2000
echo ">>>>>>>>running test 2001"
../source/print_tokens2.exe  < ../inputs/tst82 > ../originals/t2001
echo ">>>>>>>>running test 2002"
../source/print_tokens2.exe  < ../inputs/tst83 > ../originals/t2002
echo ">>>>>>>>running test 2003"
../source/print_tokens2.exe  < ../inputs/tst84 > ../originals/t2003
echo ">>>>>>>>running test 2004"
../source/print_tokens2.exe  < ../inputs/tst85 > ../originals/t2004
echo ">>>>>>>>running test 2005"
../source/print_tokens2.exe  < ../inputs/tst86 > ../originals/t2005
echo ">>>>>>>>running test 2006"
../source/print_tokens2.exe  < ../inputs/tst87 > ../originals/t2006
echo ">>>>>>>>running test 2007"
../source/print_tokens2.exe  < ../inputs/tst88 > ../originals/t2007
echo ">>>>>>>>running test 2008"
../source/print_tokens2.exe  < ../inputs/tst89 > ../originals/t2008
echo ">>>>>>>>running test 2009"
../source/print_tokens2.exe  < ../inputs/tst9 > ../originals/t2009
echo ">>>>>>>>running test 2010"
../source/print_tokens2.exe  < ../inputs/tst90 > ../originals/t2010
echo ">>>>>>>>running test 2011"
../source/print_tokens2.exe  < ../inputs/tst91 > ../originals/t2011
echo ">>>>>>>>running test 2012"
../source/print_tokens2.exe  < ../inputs/tst92 > ../originals/t2012
echo ">>>>>>>>running test 2013"
../source/print_tokens2.exe  < ../inputs/tst93 > ../originals/t2013
echo ">>>>>>>>running test 2014"
../source/print_tokens2.exe  < ../inputs/tst94 > ../originals/t2014
echo ">>>>>>>>running test 2015"
../source/print_tokens2.exe  < ../inputs/tst95 > ../originals/t2015
echo ">>>>>>>>running test 2016"
../source/print_tokens2.exe  < ../inputs/tst96 > ../originals/t2016
echo ">>>>>>>>running test 2017"
../source/print_tokens2.exe  < ../inputs/tst97 > ../originals/t2017
echo ">>>>>>>>running test 2018"
../source/print_tokens2.exe  < ../inputs/tst98 > ../originals/t2018
echo ">>>>>>>>running test 2019"
../source/print_tokens2.exe  < ../inputs/tst99 > ../originals/t2019
echo ">>>>>>>>running test 2020"
../source/print_tokens2.exe  < ../inputs/uslin.100 > ../originals/t2020
echo ">>>>>>>>running test 2021"
../source/print_tokens2.exe  < ../inputs/uslin.1002 > ../originals/t2021
echo ">>>>>>>>running test 2022"
../source/print_tokens2.exe  < ../inputs/uslin.1006 > ../originals/t2022
echo ">>>>>>>>running test 2023"
../source/print_tokens2.exe  < ../inputs/uslin.1007 > ../originals/t2023
echo ">>>>>>>>running test 2024"
../source/print_tokens2.exe  < ../inputs/uslin.101 > ../originals/t2024
echo ">>>>>>>>running test 2025"
../source/print_tokens2.exe  < ../inputs/uslin.1011 > ../originals/t2025
echo ">>>>>>>>running test 2026"
../source/print_tokens2.exe  < ../inputs/uslin.1012 > ../originals/t2026
echo ">>>>>>>>running test 2027"
../source/print_tokens2.exe  < ../inputs/uslin.1013 > ../originals/t2027
echo ">>>>>>>>running test 2028"
../source/print_tokens2.exe  < ../inputs/uslin.1016 > ../originals/t2028
echo ">>>>>>>>running test 2029"
../source/print_tokens2.exe  < ../inputs/uslin.1017 > ../originals/t2029
echo ">>>>>>>>running test 2030"
../source/print_tokens2.exe  < ../inputs/uslin.1019 > ../originals/t2030
echo ">>>>>>>>running test 2031"
../source/print_tokens2.exe  < ../inputs/uslin.102 > ../originals/t2031
echo ">>>>>>>>running test 2032"
../source/print_tokens2.exe  < ../inputs/uslin.1021 > ../originals/t2032
echo ">>>>>>>>running test 2033"
../source/print_tokens2.exe  < ../inputs/uslin.1022 > ../originals/t2033
echo ">>>>>>>>running test 2034"
../source/print_tokens2.exe  < ../inputs/uslin.1023 > ../originals/t2034
echo ">>>>>>>>running test 2035"
../source/print_tokens2.exe  < ../inputs/uslin.1026 > ../originals/t2035
echo ">>>>>>>>running test 2036"
../source/print_tokens2.exe  < ../inputs/uslin.1027 > ../originals/t2036
echo ">>>>>>>>running test 2037"
../source/print_tokens2.exe  < ../inputs/uslin.1028 > ../originals/t2037
echo ">>>>>>>>running test 2038"
../source/print_tokens2.exe  < ../inputs/uslin.1029 > ../originals/t2038
echo ">>>>>>>>running test 2039"
../source/print_tokens2.exe  < ../inputs/uslin.103 > ../originals/t2039
echo ">>>>>>>>running test 2040"
../source/print_tokens2.exe  < ../inputs/uslin.1033 > ../originals/t2040
echo ">>>>>>>>running test 2041"
../source/print_tokens2.exe  < ../inputs/uslin.1037 > ../originals/t2041
echo ">>>>>>>>running test 2042"
../source/print_tokens2.exe  < ../inputs/uslin.104 > ../originals/t2042
echo ">>>>>>>>running test 2043"
../source/print_tokens2.exe  < ../inputs/uslin.1041 > ../originals/t2043
echo ">>>>>>>>running test 2044"
../source/print_tokens2.exe  < ../inputs/uslin.1044 > ../originals/t2044
echo ">>>>>>>>running test 2045"
../source/print_tokens2.exe  < ../inputs/uslin.1051 > ../originals/t2045
echo ">>>>>>>>running test 2046"
../source/print_tokens2.exe  < ../inputs/uslin.1052 > ../originals/t2046
echo ">>>>>>>>running test 2047"
../source/print_tokens2.exe  < ../inputs/uslin.1053 > ../originals/t2047
echo ">>>>>>>>running test 2048"
../source/print_tokens2.exe  < ../inputs/uslin.1056 > ../originals/t2048
echo ">>>>>>>>running test 2049"
../source/print_tokens2.exe  < ../inputs/uslin.1058 > ../originals/t2049
echo ">>>>>>>>running test 2050"
../source/print_tokens2.exe  < ../inputs/uslin.1062 > ../originals/t2050
echo ">>>>>>>>running test 2051"
../source/print_tokens2.exe  < ../inputs/uslin.1063 > ../originals/t2051
echo ">>>>>>>>running test 2052"
../source/print_tokens2.exe  < ../inputs/uslin.1064 > ../originals/t2052
echo ">>>>>>>>running test 2053"
../source/print_tokens2.exe  < ../inputs/uslin.1066 > ../originals/t2053
echo ">>>>>>>>running test 2054"
../source/print_tokens2.exe  < ../inputs/uslin.1070 > ../originals/t2054
echo ">>>>>>>>running test 2055"
../source/print_tokens2.exe  < ../inputs/uslin.1072 > ../originals/t2055
echo ">>>>>>>>running test 2056"
../source/print_tokens2.exe  < ../inputs/uslin.1073 > ../originals/t2056
echo ">>>>>>>>running test 2057"
../source/print_tokens2.exe  < ../inputs/uslin.1079 > ../originals/t2057
echo ">>>>>>>>running test 2058"
../source/print_tokens2.exe  < ../inputs/uslin.108 > ../originals/t2058
echo ">>>>>>>>running test 2059"
../source/print_tokens2.exe  < ../inputs/uslin.1081 > ../originals/t2059
echo ">>>>>>>>running test 2060"
../source/print_tokens2.exe  < ../inputs/uslin.1083 > ../originals/t2060
echo ">>>>>>>>running test 2061"
../source/print_tokens2.exe  < ../inputs/uslin.1086 > ../originals/t2061
echo ">>>>>>>>running test 2062"
../source/print_tokens2.exe  < ../inputs/uslin.1087 > ../originals/t2062
echo ">>>>>>>>running test 2063"
../source/print_tokens2.exe  < ../inputs/uslin.1088 > ../originals/t2063
echo ">>>>>>>>running test 2064"
../source/print_tokens2.exe  < ../inputs/uslin.1089 > ../originals/t2064
echo ">>>>>>>>running test 2065"
../source/print_tokens2.exe  < ../inputs/uslin.1090 > ../originals/t2065
echo ">>>>>>>>running test 2066"
../source/print_tokens2.exe  < ../inputs/uslin.1097 > ../originals/t2066
echo ">>>>>>>>running test 2067"
../source/print_tokens2.exe  < ../inputs/uslin.1098 > ../originals/t2067
echo ">>>>>>>>running test 2068"
../source/print_tokens2.exe  < ../inputs/uslin.1099 > ../originals/t2068
echo ">>>>>>>>running test 2069"
../source/print_tokens2.exe  < ../inputs/uslin.11 > ../originals/t2069
echo ">>>>>>>>running test 2070"
../source/print_tokens2.exe  < ../inputs/uslin.110 > ../originals/t2070
echo ">>>>>>>>running test 2071"
../source/print_tokens2.exe  < ../inputs/uslin.1100 > ../originals/t2071
echo ">>>>>>>>running test 2072"
../source/print_tokens2.exe  < ../inputs/uslin.1102 > ../originals/t2072
echo ">>>>>>>>running test 2073"
../source/print_tokens2.exe  < ../inputs/uslin.1104 > ../originals/t2073
echo ">>>>>>>>running test 2074"
../source/print_tokens2.exe  < ../inputs/uslin.1106 > ../originals/t2074
echo ">>>>>>>>running test 2075"
../source/print_tokens2.exe  < ../inputs/uslin.1107 > ../originals/t2075
echo ">>>>>>>>running test 2076"
../source/print_tokens2.exe  < ../inputs/uslin.1108 > ../originals/t2076
echo ">>>>>>>>running test 2077"
../source/print_tokens2.exe  < ../inputs/uslin.1111 > ../originals/t2077
echo ">>>>>>>>running test 2078"
../source/print_tokens2.exe  < ../inputs/uslin.1116 > ../originals/t2078
echo ">>>>>>>>running test 2079"
../source/print_tokens2.exe  < ../inputs/uslin.1117 > ../originals/t2079
echo ">>>>>>>>running test 2080"
../source/print_tokens2.exe  < ../inputs/uslin.1118 > ../originals/t2080
echo ">>>>>>>>running test 2081"
../source/print_tokens2.exe  < ../inputs/uslin.112 > ../originals/t2081
echo ">>>>>>>>running test 2082"
../source/print_tokens2.exe  < ../inputs/uslin.1122 > ../originals/t2082
echo ">>>>>>>>running test 2083"
../source/print_tokens2.exe  < ../inputs/uslin.1123 > ../originals/t2083
echo ">>>>>>>>running test 2084"
../source/print_tokens2.exe  < ../inputs/uslin.1128 > ../originals/t2084
echo ">>>>>>>>running test 2085"
../source/print_tokens2.exe  < ../inputs/uslin.1129 > ../originals/t2085
echo ">>>>>>>>running test 2086"
../source/print_tokens2.exe  < ../inputs/uslin.113 > ../originals/t2086
echo ">>>>>>>>running test 2087"
../source/print_tokens2.exe  < ../inputs/uslin.1131 > ../originals/t2087
echo ">>>>>>>>running test 2088"
../source/print_tokens2.exe  < ../inputs/uslin.1132 > ../originals/t2088
echo ">>>>>>>>running test 2089"
../source/print_tokens2.exe  < ../inputs/uslin.1133 > ../originals/t2089
echo ">>>>>>>>running test 2090"
../source/print_tokens2.exe  < ../inputs/uslin.1134 > ../originals/t2090
echo ">>>>>>>>running test 2091"
../source/print_tokens2.exe  < ../inputs/uslin.1135 > ../originals/t2091
echo ">>>>>>>>running test 2092"
../source/print_tokens2.exe  < ../inputs/uslin.1136 > ../originals/t2092
echo ">>>>>>>>running test 2093"
../source/print_tokens2.exe  < ../inputs/uslin.1137 > ../originals/t2093
echo ">>>>>>>>running test 2094"
../source/print_tokens2.exe  < ../inputs/uslin.1138 > ../originals/t2094
echo ">>>>>>>>running test 2095"
../source/print_tokens2.exe  < ../inputs/uslin.1143 > ../originals/t2095
echo ">>>>>>>>running test 2096"
../source/print_tokens2.exe  < ../inputs/uslin.1145 > ../originals/t2096
echo ">>>>>>>>running test 2097"
../source/print_tokens2.exe  < ../inputs/uslin.1146 > ../originals/t2097
echo ">>>>>>>>running test 2098"
../source/print_tokens2.exe  < ../inputs/uslin.1147 > ../originals/t2098
echo ">>>>>>>>running test 2099"
../source/print_tokens2.exe  < ../inputs/uslin.1148 > ../originals/t2099
echo ">>>>>>>>running test 2100"
../source/print_tokens2.exe  < ../inputs/uslin.1149 > ../originals/t2100
echo ">>>>>>>>running test 2101"
../source/print_tokens2.exe  < ../inputs/uslin.1150 > ../originals/t2101
echo ">>>>>>>>running test 2102"
../source/print_tokens2.exe  < ../inputs/uslin.1151 > ../originals/t2102
echo ">>>>>>>>running test 2103"
../source/print_tokens2.exe  < ../inputs/uslin.1152 > ../originals/t2103
echo ">>>>>>>>running test 2104"
../source/print_tokens2.exe  < ../inputs/uslin.1153 > ../originals/t2104
echo ">>>>>>>>running test 2105"
../source/print_tokens2.exe  < ../inputs/uslin.1154 > ../originals/t2105
echo ">>>>>>>>running test 2106"
../source/print_tokens2.exe  < ../inputs/uslin.1157 > ../originals/t2106
echo ">>>>>>>>running test 2107"
../source/print_tokens2.exe  < ../inputs/uslin.1158 > ../originals/t2107
echo ">>>>>>>>running test 2108"
../source/print_tokens2.exe  < ../inputs/uslin.116 > ../originals/t2108
echo ">>>>>>>>running test 2109"
../source/print_tokens2.exe  < ../inputs/uslin.1161 > ../originals/t2109
echo ">>>>>>>>running test 2110"
../source/print_tokens2.exe  < ../inputs/uslin.1164 > ../originals/t2110
echo ">>>>>>>>running test 2111"
../source/print_tokens2.exe  < ../inputs/uslin.1168 > ../originals/t2111
echo ">>>>>>>>running test 2112"
../source/print_tokens2.exe  < ../inputs/uslin.1169 > ../originals/t2112
echo ">>>>>>>>running test 2113"
../source/print_tokens2.exe  < ../inputs/uslin.1170 > ../originals/t2113
echo ">>>>>>>>running test 2114"
../source/print_tokens2.exe  < ../inputs/uslin.1171 > ../originals/t2114
echo ">>>>>>>>running test 2115"
../source/print_tokens2.exe  < ../inputs/uslin.1172 > ../originals/t2115
echo ">>>>>>>>running test 2116"
../source/print_tokens2.exe  < ../inputs/uslin.1175 > ../originals/t2116
echo ">>>>>>>>running test 2117"
../source/print_tokens2.exe  < ../inputs/uslin.1176 > ../originals/t2117
echo ">>>>>>>>running test 2118"
../source/print_tokens2.exe  < ../inputs/uslin.1177 > ../originals/t2118
echo ">>>>>>>>running test 2119"
../source/print_tokens2.exe  < ../inputs/uslin.1178 > ../originals/t2119
echo ">>>>>>>>running test 2120"
../source/print_tokens2.exe  < ../inputs/uslin.118 > ../originals/t2120
echo ">>>>>>>>running test 2121"
../source/print_tokens2.exe  < ../inputs/uslin.1181 > ../originals/t2121
echo ">>>>>>>>running test 2122"
../source/print_tokens2.exe  < ../inputs/uslin.1183 > ../originals/t2122
echo ">>>>>>>>running test 2123"
../source/print_tokens2.exe  < ../inputs/uslin.1188 > ../originals/t2123
echo ">>>>>>>>running test 2124"
../source/print_tokens2.exe  < ../inputs/uslin.1190 > ../originals/t2124
echo ">>>>>>>>running test 2125"
../source/print_tokens2.exe  < ../inputs/uslin.1194 > ../originals/t2125
echo ">>>>>>>>running test 2126"
../source/print_tokens2.exe  < ../inputs/uslin.1195 > ../originals/t2126
echo ">>>>>>>>running test 2127"
../source/print_tokens2.exe  < ../inputs/uslin.1197 > ../originals/t2127
echo ">>>>>>>>running test 2128"
../source/print_tokens2.exe  < ../inputs/uslin.1199 > ../originals/t2128
echo ">>>>>>>>running test 2129"
../source/print_tokens2.exe  < ../inputs/uslin.12 > ../originals/t2129
echo ">>>>>>>>running test 2130"
../source/print_tokens2.exe  < ../inputs/uslin.120 > ../originals/t2130
echo ">>>>>>>>running test 2131"
../source/print_tokens2.exe  < ../inputs/uslin.1201 > ../originals/t2131
echo ">>>>>>>>running test 2132"
../source/print_tokens2.exe  < ../inputs/uslin.1203 > ../originals/t2132
echo ">>>>>>>>running test 2133"
../source/print_tokens2.exe  < ../inputs/uslin.1204 > ../originals/t2133
echo ">>>>>>>>running test 2134"
../source/print_tokens2.exe  < ../inputs/uslin.1205 > ../originals/t2134
echo ">>>>>>>>running test 2135"
../source/print_tokens2.exe  < ../inputs/uslin.1208 > ../originals/t2135
echo ">>>>>>>>running test 2136"
../source/print_tokens2.exe  < ../inputs/uslin.1210 > ../originals/t2136
echo ">>>>>>>>running test 2137"
../source/print_tokens2.exe  < ../inputs/uslin.1211 > ../originals/t2137
echo ">>>>>>>>running test 2138"
../source/print_tokens2.exe  < ../inputs/uslin.1213 > ../originals/t2138
echo ">>>>>>>>running test 2139"
../source/print_tokens2.exe  < ../inputs/uslin.1214 > ../originals/t2139
echo ">>>>>>>>running test 2140"
../source/print_tokens2.exe  < ../inputs/uslin.1215 > ../originals/t2140
echo ">>>>>>>>running test 2141"
../source/print_tokens2.exe  < ../inputs/uslin.1216 > ../originals/t2141
echo ">>>>>>>>running test 2142"
../source/print_tokens2.exe  < ../inputs/uslin.1218 > ../originals/t2142
echo ">>>>>>>>running test 2143"
../source/print_tokens2.exe  < ../inputs/uslin.122 > ../originals/t2143
echo ">>>>>>>>running test 2144"
../source/print_tokens2.exe  < ../inputs/uslin.1220 > ../originals/t2144
echo ">>>>>>>>running test 2145"
../source/print_tokens2.exe  < ../inputs/uslin.1221 > ../originals/t2145
echo ">>>>>>>>running test 2146"
../source/print_tokens2.exe  < ../inputs/uslin.1222 > ../originals/t2146
echo ">>>>>>>>running test 2147"
../source/print_tokens2.exe  < ../inputs/uslin.1225 > ../originals/t2147
echo ">>>>>>>>running test 2148"
../source/print_tokens2.exe  < ../inputs/uslin.1227 > ../originals/t2148
echo ">>>>>>>>running test 2149"
../source/print_tokens2.exe  < ../inputs/uslin.1229 > ../originals/t2149
echo ">>>>>>>>running test 2150"
../source/print_tokens2.exe  < ../inputs/uslin.123 > ../originals/t2150
echo ">>>>>>>>running test 2151"
../source/print_tokens2.exe  < ../inputs/uslin.1230 > ../originals/t2151
echo ">>>>>>>>running test 2152"
../source/print_tokens2.exe  < ../inputs/uslin.1231 > ../originals/t2152
echo ">>>>>>>>running test 2153"
../source/print_tokens2.exe  < ../inputs/uslin.1232 > ../originals/t2153
echo ">>>>>>>>running test 2154"
../source/print_tokens2.exe  < ../inputs/uslin.1236 > ../originals/t2154
echo ">>>>>>>>running test 2155"
../source/print_tokens2.exe  < ../inputs/uslin.1238 > ../originals/t2155
echo ">>>>>>>>running test 2156"
../source/print_tokens2.exe  < ../inputs/uslin.124 > ../originals/t2156
echo ">>>>>>>>running test 2157"
../source/print_tokens2.exe  < ../inputs/uslin.1240 > ../originals/t2157
echo ">>>>>>>>running test 2158"
../source/print_tokens2.exe  < ../inputs/uslin.1242 > ../originals/t2158
echo ">>>>>>>>running test 2159"
../source/print_tokens2.exe  < ../inputs/uslin.1244 > ../originals/t2159
echo ">>>>>>>>running test 2160"
../source/print_tokens2.exe  < ../inputs/uslin.1247 > ../originals/t2160
echo ">>>>>>>>running test 2161"
../source/print_tokens2.exe  < ../inputs/uslin.1248 > ../originals/t2161
echo ">>>>>>>>running test 2162"
../source/print_tokens2.exe  < ../inputs/uslin.1251 > ../originals/t2162
echo ">>>>>>>>running test 2163"
../source/print_tokens2.exe  < ../inputs/uslin.1254 > ../originals/t2163
echo ">>>>>>>>running test 2164"
../source/print_tokens2.exe  < ../inputs/uslin.1257 > ../originals/t2164
echo ">>>>>>>>running test 2165"
../source/print_tokens2.exe  < ../inputs/uslin.1259 > ../originals/t2165
echo ">>>>>>>>running test 2166"
../source/print_tokens2.exe  < ../inputs/uslin.1261 > ../originals/t2166
echo ">>>>>>>>running test 2167"
../source/print_tokens2.exe  < ../inputs/uslin.1262 > ../originals/t2167
echo ">>>>>>>>running test 2168"
../source/print_tokens2.exe  < ../inputs/uslin.1263 > ../originals/t2168
echo ">>>>>>>>running test 2169"
../source/print_tokens2.exe  < ../inputs/uslin.1269 > ../originals/t2169
echo ">>>>>>>>running test 2170"
../source/print_tokens2.exe  < ../inputs/uslin.1271 > ../originals/t2170
echo ">>>>>>>>running test 2171"
../source/print_tokens2.exe  < ../inputs/uslin.1273 > ../originals/t2171
echo ">>>>>>>>running test 2172"
../source/print_tokens2.exe  < ../inputs/uslin.1274 > ../originals/t2172
echo ">>>>>>>>running test 2173"
../source/print_tokens2.exe  < ../inputs/uslin.1275 > ../originals/t2173
echo ">>>>>>>>running test 2174"
../source/print_tokens2.exe  < ../inputs/uslin.1277 > ../originals/t2174
echo ">>>>>>>>running test 2175"
../source/print_tokens2.exe  < ../inputs/uslin.1279 > ../originals/t2175
echo ">>>>>>>>running test 2176"
../source/print_tokens2.exe  < ../inputs/uslin.1280 > ../originals/t2176
echo ">>>>>>>>running test 2177"
../source/print_tokens2.exe  < ../inputs/uslin.1282 > ../originals/t2177
echo ">>>>>>>>running test 2178"
../source/print_tokens2.exe  < ../inputs/uslin.1284 > ../originals/t2178
echo ">>>>>>>>running test 2179"
../source/print_tokens2.exe  < ../inputs/uslin.1285 > ../originals/t2179
echo ">>>>>>>>running test 2180"
../source/print_tokens2.exe  < ../inputs/uslin.1286 > ../originals/t2180
echo ">>>>>>>>running test 2181"
../source/print_tokens2.exe  < ../inputs/uslin.1288 > ../originals/t2181
echo ">>>>>>>>running test 2182"
../source/print_tokens2.exe  < ../inputs/uslin.1293 > ../originals/t2182
echo ">>>>>>>>running test 2183"
../source/print_tokens2.exe  < ../inputs/uslin.1295 > ../originals/t2183
echo ">>>>>>>>running test 2184"
../source/print_tokens2.exe  < ../inputs/uslin.1296 > ../originals/t2184
echo ">>>>>>>>running test 2185"
../source/print_tokens2.exe  < ../inputs/uslin.1297 > ../originals/t2185
echo ">>>>>>>>running test 2186"
../source/print_tokens2.exe  < ../inputs/uslin.1299 > ../originals/t2186
echo ">>>>>>>>running test 2187"
../source/print_tokens2.exe  < ../inputs/uslin.13 > ../originals/t2187
echo ">>>>>>>>running test 2188"
../source/print_tokens2.exe  < ../inputs/uslin.130 > ../originals/t2188
echo ">>>>>>>>running test 2189"
../source/print_tokens2.exe  < ../inputs/uslin.1300 > ../originals/t2189
echo ">>>>>>>>running test 2190"
../source/print_tokens2.exe  < ../inputs/uslin.1301 > ../originals/t2190
echo ">>>>>>>>running test 2191"
../source/print_tokens2.exe  < ../inputs/uslin.1304 > ../originals/t2191
echo ">>>>>>>>running test 2192"
../source/print_tokens2.exe  < ../inputs/uslin.1307 > ../originals/t2192
echo ">>>>>>>>running test 2193"
../source/print_tokens2.exe  < ../inputs/uslin.1308 > ../originals/t2193
echo ">>>>>>>>running test 2194"
../source/print_tokens2.exe  < ../inputs/uslin.1309 > ../originals/t2194
echo ">>>>>>>>running test 2195"
../source/print_tokens2.exe  < ../inputs/uslin.1310 > ../originals/t2195
echo ">>>>>>>>running test 2196"
../source/print_tokens2.exe  < ../inputs/uslin.1311 > ../originals/t2196
echo ">>>>>>>>running test 2197"
../source/print_tokens2.exe  < ../inputs/uslin.1312 > ../originals/t2197
echo ">>>>>>>>running test 2198"
../source/print_tokens2.exe  < ../inputs/uslin.1313 > ../originals/t2198
echo ">>>>>>>>running test 2199"
../source/print_tokens2.exe  < ../inputs/uslin.1314 > ../originals/t2199
echo ">>>>>>>>running test 2200"
../source/print_tokens2.exe  < ../inputs/uslin.1315 > ../originals/t2200
echo ">>>>>>>>running test 2201"
../source/print_tokens2.exe  < ../inputs/uslin.1318 > ../originals/t2201
echo ">>>>>>>>running test 2202"
../source/print_tokens2.exe  < ../inputs/uslin.1319 > ../originals/t2202
echo ">>>>>>>>running test 2203"
../source/print_tokens2.exe  < ../inputs/uslin.1320 > ../originals/t2203
echo ">>>>>>>>running test 2204"
../source/print_tokens2.exe  < ../inputs/uslin.1323 > ../originals/t2204
echo ">>>>>>>>running test 2205"
../source/print_tokens2.exe  < ../inputs/uslin.1326 > ../originals/t2205
echo ">>>>>>>>running test 2206"
../source/print_tokens2.exe  < ../inputs/uslin.1329 > ../originals/t2206
echo ">>>>>>>>running test 2207"
../source/print_tokens2.exe  < ../inputs/uslin.133 > ../originals/t2207
echo ">>>>>>>>running test 2208"
../source/print_tokens2.exe  < ../inputs/uslin.1331 > ../originals/t2208
echo ">>>>>>>>running test 2209"
../source/print_tokens2.exe  < ../inputs/uslin.1332 > ../originals/t2209
echo ">>>>>>>>running test 2210"
../source/print_tokens2.exe  < ../inputs/uslin.1336 > ../originals/t2210
echo ">>>>>>>>running test 2211"
../source/print_tokens2.exe  < ../inputs/uslin.1338 > ../originals/t2211
echo ">>>>>>>>running test 2212"
../source/print_tokens2.exe  < ../inputs/uslin.1343 > ../originals/t2212
echo ">>>>>>>>running test 2213"
../source/print_tokens2.exe  < ../inputs/uslin.1344 > ../originals/t2213
echo ">>>>>>>>running test 2214"
../source/print_tokens2.exe  < ../inputs/uslin.1345 > ../originals/t2214
echo ">>>>>>>>running test 2215"
../source/print_tokens2.exe  < ../inputs/uslin.1347 > ../originals/t2215
echo ">>>>>>>>running test 2216"
../source/print_tokens2.exe  < ../inputs/uslin.1349 > ../originals/t2216
echo ">>>>>>>>running test 2217"
../source/print_tokens2.exe  < ../inputs/uslin.135 > ../originals/t2217
echo ">>>>>>>>running test 2218"
../source/print_tokens2.exe  < ../inputs/uslin.1350 > ../originals/t2218
echo ">>>>>>>>running test 2219"
../source/print_tokens2.exe  < ../inputs/uslin.1351 > ../originals/t2219
echo ">>>>>>>>running test 2220"
../source/print_tokens2.exe  < ../inputs/uslin.1356 > ../originals/t2220
echo ">>>>>>>>running test 2221"
../source/print_tokens2.exe  < ../inputs/uslin.1357 > ../originals/t2221
echo ">>>>>>>>running test 2222"
../source/print_tokens2.exe  < ../inputs/uslin.136 > ../originals/t2222
echo ">>>>>>>>running test 2223"
../source/print_tokens2.exe  < ../inputs/uslin.1360 > ../originals/t2223
echo ">>>>>>>>running test 2224"
../source/print_tokens2.exe  < ../inputs/uslin.1361 > ../originals/t2224
echo ">>>>>>>>running test 2225"
../source/print_tokens2.exe  < ../inputs/uslin.1362 > ../originals/t2225
echo ">>>>>>>>running test 2226"
../source/print_tokens2.exe  < ../inputs/uslin.1363 > ../originals/t2226
echo ">>>>>>>>running test 2227"
../source/print_tokens2.exe  < ../inputs/uslin.1366 > ../originals/t2227
echo ">>>>>>>>running test 2228"
../source/print_tokens2.exe  < ../inputs/uslin.1367 > ../originals/t2228
echo ">>>>>>>>running test 2229"
../source/print_tokens2.exe  < ../inputs/uslin.1369 > ../originals/t2229
echo ">>>>>>>>running test 2230"
../source/print_tokens2.exe  < ../inputs/uslin.1372 > ../originals/t2230
echo ">>>>>>>>running test 2231"
../source/print_tokens2.exe  < ../inputs/uslin.1377 > ../originals/t2231
echo ">>>>>>>>running test 2232"
../source/print_tokens2.exe  < ../inputs/uslin.1381 > ../originals/t2232
echo ">>>>>>>>running test 2233"
../source/print_tokens2.exe  < ../inputs/uslin.1382 > ../originals/t2233
echo ">>>>>>>>running test 2234"
../source/print_tokens2.exe  < ../inputs/uslin.1383 > ../originals/t2234
echo ">>>>>>>>running test 2235"
../source/print_tokens2.exe  < ../inputs/uslin.1387 > ../originals/t2235
echo ">>>>>>>>running test 2236"
../source/print_tokens2.exe  < ../inputs/uslin.1388 > ../originals/t2236
echo ">>>>>>>>running test 2237"
../source/print_tokens2.exe  < ../inputs/uslin.1392 > ../originals/t2237
echo ">>>>>>>>running test 2238"
../source/print_tokens2.exe  < ../inputs/uslin.1393 > ../originals/t2238
echo ">>>>>>>>running test 2239"
../source/print_tokens2.exe  < ../inputs/uslin.1396 > ../originals/t2239
echo ">>>>>>>>running test 2240"
../source/print_tokens2.exe  < ../inputs/uslin.1397 > ../originals/t2240
echo ">>>>>>>>running test 2241"
../source/print_tokens2.exe  < ../inputs/uslin.140 > ../originals/t2241
echo ">>>>>>>>running test 2242"
../source/print_tokens2.exe  < ../inputs/uslin.1404 > ../originals/t2242
echo ">>>>>>>>running test 2243"
../source/print_tokens2.exe  < ../inputs/uslin.1405 > ../originals/t2243
echo ">>>>>>>>running test 2244"
../source/print_tokens2.exe  < ../inputs/uslin.1408 > ../originals/t2244
echo ">>>>>>>>running test 2245"
../source/print_tokens2.exe  < ../inputs/uslin.1409 > ../originals/t2245
echo ">>>>>>>>running test 2246"
../source/print_tokens2.exe  < ../inputs/uslin.1410 > ../originals/t2246
echo ">>>>>>>>running test 2247"
../source/print_tokens2.exe  < ../inputs/uslin.1413 > ../originals/t2247
echo ">>>>>>>>running test 2248"
../source/print_tokens2.exe  < ../inputs/uslin.1415 > ../originals/t2248
echo ">>>>>>>>running test 2249"
../source/print_tokens2.exe  < ../inputs/uslin.142 > ../originals/t2249
echo ">>>>>>>>running test 2250"
../source/print_tokens2.exe  < ../inputs/uslin.1420 > ../originals/t2250
echo ">>>>>>>>running test 2251"
../source/print_tokens2.exe  < ../inputs/uslin.1421 > ../originals/t2251
echo ">>>>>>>>running test 2252"
../source/print_tokens2.exe  < ../inputs/uslin.1424 > ../originals/t2252
echo ">>>>>>>>running test 2253"
../source/print_tokens2.exe  < ../inputs/uslin.1425 > ../originals/t2253
echo ">>>>>>>>running test 2254"
../source/print_tokens2.exe  < ../inputs/uslin.1429 > ../originals/t2254
echo ">>>>>>>>running test 2255"
../source/print_tokens2.exe  < ../inputs/uslin.143 > ../originals/t2255
echo ">>>>>>>>running test 2256"
../source/print_tokens2.exe  < ../inputs/uslin.1430 > ../originals/t2256
echo ">>>>>>>>running test 2257"
../source/print_tokens2.exe  < ../inputs/uslin.1437 > ../originals/t2257
echo ">>>>>>>>running test 2258"
../source/print_tokens2.exe  < ../inputs/uslin.1438 > ../originals/t2258
echo ">>>>>>>>running test 2259"
../source/print_tokens2.exe  < ../inputs/uslin.1439 > ../originals/t2259
echo ">>>>>>>>running test 2260"
../source/print_tokens2.exe  < ../inputs/uslin.1441 > ../originals/t2260
echo ">>>>>>>>running test 2261"
../source/print_tokens2.exe  < ../inputs/uslin.1443 > ../originals/t2261
echo ">>>>>>>>running test 2262"
../source/print_tokens2.exe  < ../inputs/uslin.145 > ../originals/t2262
echo ">>>>>>>>running test 2263"
../source/print_tokens2.exe  < ../inputs/uslin.1455 > ../originals/t2263
echo ">>>>>>>>running test 2264"
../source/print_tokens2.exe  < ../inputs/uslin.1457 > ../originals/t2264
echo ">>>>>>>>running test 2265"
../source/print_tokens2.exe  < ../inputs/uslin.1459 > ../originals/t2265
echo ">>>>>>>>running test 2266"
../source/print_tokens2.exe  < ../inputs/uslin.1461 > ../originals/t2266
echo ">>>>>>>>running test 2267"
../source/print_tokens2.exe  < ../inputs/uslin.1468 > ../originals/t2267
echo ">>>>>>>>running test 2268"
../source/print_tokens2.exe  < ../inputs/uslin.1469 > ../originals/t2268
echo ">>>>>>>>running test 2269"
../source/print_tokens2.exe  < ../inputs/uslin.147 > ../originals/t2269
echo ">>>>>>>>running test 2270"
../source/print_tokens2.exe  < ../inputs/uslin.1470 > ../originals/t2270
echo ">>>>>>>>running test 2271"
../source/print_tokens2.exe  < ../inputs/uslin.1475 > ../originals/t2271
echo ">>>>>>>>running test 2272"
../source/print_tokens2.exe  < ../inputs/uslin.1476 > ../originals/t2272
echo ">>>>>>>>running test 2273"
../source/print_tokens2.exe  < ../inputs/uslin.1480 > ../originals/t2273
echo ">>>>>>>>running test 2274"
../source/print_tokens2.exe  < ../inputs/uslin.1483 > ../originals/t2274
echo ">>>>>>>>running test 2275"
../source/print_tokens2.exe  < ../inputs/uslin.1486 > ../originals/t2275
echo ">>>>>>>>running test 2276"
../source/print_tokens2.exe  < ../inputs/uslin.1491 > ../originals/t2276
echo ">>>>>>>>running test 2277"
../source/print_tokens2.exe  < ../inputs/uslin.1492 > ../originals/t2277
echo ">>>>>>>>running test 2278"
../source/print_tokens2.exe  < ../inputs/uslin.1493 > ../originals/t2278
echo ">>>>>>>>running test 2279"
../source/print_tokens2.exe  < ../inputs/uslin.1494 > ../originals/t2279
echo ">>>>>>>>running test 2280"
../source/print_tokens2.exe  < ../inputs/uslin.1496 > ../originals/t2280
echo ">>>>>>>>running test 2281"
../source/print_tokens2.exe  < ../inputs/uslin.1497 > ../originals/t2281
echo ">>>>>>>>running test 2282"
../source/print_tokens2.exe  < ../inputs/uslin.15 > ../originals/t2282
echo ">>>>>>>>running test 2283"
../source/print_tokens2.exe  < ../inputs/uslin.1501 > ../originals/t2283
echo ">>>>>>>>running test 2284"
../source/print_tokens2.exe  < ../inputs/uslin.1502 > ../originals/t2284
echo ">>>>>>>>running test 2285"
../source/print_tokens2.exe  < ../inputs/uslin.1504 > ../originals/t2285
echo ">>>>>>>>running test 2286"
../source/print_tokens2.exe  < ../inputs/uslin.1509 > ../originals/t2286
echo ">>>>>>>>running test 2287"
../source/print_tokens2.exe  < ../inputs/uslin.151 > ../originals/t2287
echo ">>>>>>>>running test 2288"
../source/print_tokens2.exe  < ../inputs/uslin.1510 > ../originals/t2288
echo ">>>>>>>>running test 2289"
../source/print_tokens2.exe  < ../inputs/uslin.1516 > ../originals/t2289
echo ">>>>>>>>running test 2290"
../source/print_tokens2.exe  < ../inputs/uslin.1517 > ../originals/t2290
echo ">>>>>>>>running test 2291"
../source/print_tokens2.exe  < ../inputs/uslin.1518 > ../originals/t2291
echo ">>>>>>>>running test 2292"
../source/print_tokens2.exe  < ../inputs/uslin.1519 > ../originals/t2292
echo ">>>>>>>>running test 2293"
../source/print_tokens2.exe  < ../inputs/uslin.1524 > ../originals/t2293
echo ">>>>>>>>running test 2294"
../source/print_tokens2.exe  < ../inputs/uslin.1525 > ../originals/t2294
echo ">>>>>>>>running test 2295"
../source/print_tokens2.exe  < ../inputs/uslin.1526 > ../originals/t2295
echo ">>>>>>>>running test 2296"
../source/print_tokens2.exe  < ../inputs/uslin.1527 > ../originals/t2296
echo ">>>>>>>>running test 2297"
../source/print_tokens2.exe  < ../inputs/uslin.1529 > ../originals/t2297
echo ">>>>>>>>running test 2298"
../source/print_tokens2.exe  < ../inputs/uslin.153 > ../originals/t2298
echo ">>>>>>>>running test 2299"
../source/print_tokens2.exe  < ../inputs/uslin.1530 > ../originals/t2299
echo ">>>>>>>>running test 2300"
../source/print_tokens2.exe  < ../inputs/uslin.1532 > ../originals/t2300
echo ">>>>>>>>running test 2301"
../source/print_tokens2.exe  < ../inputs/uslin.1534 > ../originals/t2301
echo ">>>>>>>>running test 2302"
../source/print_tokens2.exe  < ../inputs/uslin.1538 > ../originals/t2302
echo ">>>>>>>>running test 2303"
../source/print_tokens2.exe  < ../inputs/uslin.1539 > ../originals/t2303
echo ">>>>>>>>running test 2304"
../source/print_tokens2.exe  < ../inputs/uslin.154 > ../originals/t2304
echo ">>>>>>>>running test 2305"
../source/print_tokens2.exe  < ../inputs/uslin.1541 > ../originals/t2305
echo ">>>>>>>>running test 2306"
../source/print_tokens2.exe  < ../inputs/uslin.1542 > ../originals/t2306
echo ">>>>>>>>running test 2307"
../source/print_tokens2.exe  < ../inputs/uslin.1546 > ../originals/t2307
echo ">>>>>>>>running test 2308"
../source/print_tokens2.exe  < ../inputs/uslin.1549 > ../originals/t2308
echo ">>>>>>>>running test 2309"
../source/print_tokens2.exe  < ../inputs/uslin.155 > ../originals/t2309
echo ">>>>>>>>running test 2310"
../source/print_tokens2.exe  < ../inputs/uslin.1551 > ../originals/t2310
echo ">>>>>>>>running test 2311"
../source/print_tokens2.exe  < ../inputs/uslin.1554 > ../originals/t2311
echo ">>>>>>>>running test 2312"
../source/print_tokens2.exe  < ../inputs/uslin.1556 > ../originals/t2312
echo ">>>>>>>>running test 2313"
../source/print_tokens2.exe  < ../inputs/uslin.1557 > ../originals/t2313
echo ">>>>>>>>running test 2314"
../source/print_tokens2.exe  < ../inputs/uslin.1559 > ../originals/t2314
echo ">>>>>>>>running test 2315"
../source/print_tokens2.exe  < ../inputs/uslin.1562 > ../originals/t2315
echo ">>>>>>>>running test 2316"
../source/print_tokens2.exe  < ../inputs/uslin.1563 > ../originals/t2316
echo ">>>>>>>>running test 2317"
../source/print_tokens2.exe  < ../inputs/uslin.1565 > ../originals/t2317
echo ">>>>>>>>running test 2318"
../source/print_tokens2.exe  < ../inputs/uslin.1566 > ../originals/t2318
echo ">>>>>>>>running test 2319"
../source/print_tokens2.exe  < ../inputs/uslin.1567 > ../originals/t2319
echo ">>>>>>>>running test 2320"
../source/print_tokens2.exe  < ../inputs/uslin.1569 > ../originals/t2320
echo ">>>>>>>>running test 2321"
../source/print_tokens2.exe  < ../inputs/uslin.157 > ../originals/t2321
echo ">>>>>>>>running test 2322"
../source/print_tokens2.exe  < ../inputs/uslin.1570 > ../originals/t2322
echo ">>>>>>>>running test 2323"
../source/print_tokens2.exe  < ../inputs/uslin.1572 > ../originals/t2323
echo ">>>>>>>>running test 2324"
../source/print_tokens2.exe  < ../inputs/uslin.1576 > ../originals/t2324
echo ">>>>>>>>running test 2325"
../source/print_tokens2.exe  < ../inputs/uslin.1578 > ../originals/t2325
echo ">>>>>>>>running test 2326"
../source/print_tokens2.exe  < ../inputs/uslin.1579 > ../originals/t2326
echo ">>>>>>>>running test 2327"
../source/print_tokens2.exe  < ../inputs/uslin.1584 > ../originals/t2327
echo ">>>>>>>>running test 2328"
../source/print_tokens2.exe  < ../inputs/uslin.1587 > ../originals/t2328
echo ">>>>>>>>running test 2329"
../source/print_tokens2.exe  < ../inputs/uslin.1588 > ../originals/t2329
echo ">>>>>>>>running test 2330"
../source/print_tokens2.exe  < ../inputs/uslin.1589 > ../originals/t2330
echo ">>>>>>>>running test 2331"
../source/print_tokens2.exe  < ../inputs/uslin.1593 > ../originals/t2331
echo ">>>>>>>>running test 2332"
../source/print_tokens2.exe  < ../inputs/uslin.1596 > ../originals/t2332
echo ">>>>>>>>running test 2333"
../source/print_tokens2.exe  < ../inputs/uslin.1598 > ../originals/t2333
echo ">>>>>>>>running test 2334"
../source/print_tokens2.exe  < ../inputs/uslin.1599 > ../originals/t2334
echo ">>>>>>>>running test 2335"
../source/print_tokens2.exe  < ../inputs/uslin.16 > ../originals/t2335
echo ">>>>>>>>running test 2336"
../source/print_tokens2.exe  < ../inputs/uslin.160 > ../originals/t2336
echo ">>>>>>>>running test 2337"
../source/print_tokens2.exe  < ../inputs/uslin.1600 > ../originals/t2337
echo ">>>>>>>>running test 2338"
../source/print_tokens2.exe  < ../inputs/uslin.1604 > ../originals/t2338
echo ">>>>>>>>running test 2339"
../source/print_tokens2.exe  < ../inputs/uslin.1605 > ../originals/t2339
echo ">>>>>>>>running test 2340"
../source/print_tokens2.exe  < ../inputs/uslin.1609 > ../originals/t2340
echo ">>>>>>>>running test 2341"
../source/print_tokens2.exe  < ../inputs/uslin.161 > ../originals/t2341
echo ">>>>>>>>running test 2342"
../source/print_tokens2.exe  < ../inputs/uslin.1611 > ../originals/t2342
echo ">>>>>>>>running test 2343"
../source/print_tokens2.exe  < ../inputs/uslin.1612 > ../originals/t2343
echo ">>>>>>>>running test 2344"
../source/print_tokens2.exe  < ../inputs/uslin.1613 > ../originals/t2344
echo ">>>>>>>>running test 2345"
../source/print_tokens2.exe  < ../inputs/uslin.1615 > ../originals/t2345
echo ">>>>>>>>running test 2346"
../source/print_tokens2.exe  < ../inputs/uslin.1616 > ../originals/t2346
echo ">>>>>>>>running test 2347"
../source/print_tokens2.exe  < ../inputs/uslin.162 > ../originals/t2347
echo ">>>>>>>>running test 2348"
../source/print_tokens2.exe  < ../inputs/uslin.1621 > ../originals/t2348
echo ">>>>>>>>running test 2349"
../source/print_tokens2.exe  < ../inputs/uslin.1622 > ../originals/t2349
echo ">>>>>>>>running test 2350"
../source/print_tokens2.exe  < ../inputs/uslin.1627 > ../originals/t2350
echo ">>>>>>>>running test 2351"
../source/print_tokens2.exe  < ../inputs/uslin.1628 > ../originals/t2351
echo ">>>>>>>>running test 2352"
../source/print_tokens2.exe  < ../inputs/uslin.163 > ../originals/t2352
echo ">>>>>>>>running test 2353"
../source/print_tokens2.exe  < ../inputs/uslin.1633 > ../originals/t2353
echo ">>>>>>>>running test 2354"
../source/print_tokens2.exe  < ../inputs/uslin.1636 > ../originals/t2354
echo ">>>>>>>>running test 2355"
../source/print_tokens2.exe  < ../inputs/uslin.1639 > ../originals/t2355
echo ">>>>>>>>running test 2356"
../source/print_tokens2.exe  < ../inputs/uslin.164 > ../originals/t2356
echo ">>>>>>>>running test 2357"
../source/print_tokens2.exe  < ../inputs/uslin.1640 > ../originals/t2357
echo ">>>>>>>>running test 2358"
../source/print_tokens2.exe  < ../inputs/uslin.1642 > ../originals/t2358
echo ">>>>>>>>running test 2359"
../source/print_tokens2.exe  < ../inputs/uslin.1643 > ../originals/t2359
echo ">>>>>>>>running test 2360"
../source/print_tokens2.exe  < ../inputs/uslin.1647 > ../originals/t2360
echo ">>>>>>>>running test 2361"
../source/print_tokens2.exe  < ../inputs/uslin.1648 > ../originals/t2361
echo ">>>>>>>>running test 2362"
../source/print_tokens2.exe  < ../inputs/uslin.1649 > ../originals/t2362
echo ">>>>>>>>running test 2363"
../source/print_tokens2.exe  < ../inputs/uslin.1650 > ../originals/t2363
echo ">>>>>>>>running test 2364"
../source/print_tokens2.exe  < ../inputs/uslin.1658 > ../originals/t2364
echo ">>>>>>>>running test 2365"
../source/print_tokens2.exe  < ../inputs/uslin.1659 > ../originals/t2365
echo ">>>>>>>>running test 2366"
../source/print_tokens2.exe  < ../inputs/uslin.1660 > ../originals/t2366
echo ">>>>>>>>running test 2367"
../source/print_tokens2.exe  < ../inputs/uslin.1666 > ../originals/t2367
echo ">>>>>>>>running test 2368"
../source/print_tokens2.exe  < ../inputs/uslin.1667 > ../originals/t2368
echo ">>>>>>>>running test 2369"
../source/print_tokens2.exe  < ../inputs/uslin.1668 > ../originals/t2369
echo ">>>>>>>>running test 2370"
../source/print_tokens2.exe  < ../inputs/uslin.1669 > ../originals/t2370
echo ">>>>>>>>running test 2371"
../source/print_tokens2.exe  < ../inputs/uslin.1670 > ../originals/t2371
echo ">>>>>>>>running test 2372"
../source/print_tokens2.exe  < ../inputs/uslin.1671 > ../originals/t2372
echo ">>>>>>>>running test 2373"
../source/print_tokens2.exe  < ../inputs/uslin.1672 > ../originals/t2373
echo ">>>>>>>>running test 2374"
../source/print_tokens2.exe  < ../inputs/uslin.1675 > ../originals/t2374
echo ">>>>>>>>running test 2375"
../source/print_tokens2.exe  < ../inputs/uslin.1676 > ../originals/t2375
echo ">>>>>>>>running test 2376"
../source/print_tokens2.exe  < ../inputs/uslin.1679 > ../originals/t2376
echo ">>>>>>>>running test 2377"
../source/print_tokens2.exe  < ../inputs/uslin.1681 > ../originals/t2377
echo ">>>>>>>>running test 2378"
../source/print_tokens2.exe  < ../inputs/uslin.1686 > ../originals/t2378
echo ">>>>>>>>running test 2379"
../source/print_tokens2.exe  < ../inputs/uslin.169 > ../originals/t2379
echo ">>>>>>>>running test 2380"
../source/print_tokens2.exe  < ../inputs/uslin.1691 > ../originals/t2380
echo ">>>>>>>>running test 2381"
../source/print_tokens2.exe  < ../inputs/uslin.1694 > ../originals/t2381
echo ">>>>>>>>running test 2382"
../source/print_tokens2.exe  < ../inputs/uslin.1695 > ../originals/t2382
echo ">>>>>>>>running test 2383"
../source/print_tokens2.exe  < ../inputs/uslin.1698 > ../originals/t2383
echo ">>>>>>>>running test 2384"
../source/print_tokens2.exe  < ../inputs/uslin.17 > ../originals/t2384
echo ">>>>>>>>running test 2385"
../source/print_tokens2.exe  < ../inputs/uslin.170 > ../originals/t2385
echo ">>>>>>>>running test 2386"
../source/print_tokens2.exe  < ../inputs/uslin.1702 > ../originals/t2386
echo ">>>>>>>>running test 2387"
../source/print_tokens2.exe  < ../inputs/uslin.1707 > ../originals/t2387
echo ">>>>>>>>running test 2388"
../source/print_tokens2.exe  < ../inputs/uslin.171 > ../originals/t2388
echo ">>>>>>>>running test 2389"
../source/print_tokens2.exe  < ../inputs/uslin.1710 > ../originals/t2389
echo ">>>>>>>>running test 2390"
../source/print_tokens2.exe  < ../inputs/uslin.1711 > ../originals/t2390
echo ">>>>>>>>running test 2391"
../source/print_tokens2.exe  < ../inputs/uslin.1712 > ../originals/t2391
echo ">>>>>>>>running test 2392"
../source/print_tokens2.exe  < ../inputs/uslin.1716 > ../originals/t2392
echo ">>>>>>>>running test 2393"
../source/print_tokens2.exe  < ../inputs/uslin.1724 > ../originals/t2393
echo ">>>>>>>>running test 2394"
../source/print_tokens2.exe  < ../inputs/uslin.1730 > ../originals/t2394
echo ">>>>>>>>running test 2395"
../source/print_tokens2.exe  < ../inputs/uslin.1735 > ../originals/t2395
echo ">>>>>>>>running test 2396"
../source/print_tokens2.exe  < ../inputs/uslin.1737 > ../originals/t2396
echo ">>>>>>>>running test 2397"
../source/print_tokens2.exe  < ../inputs/uslin.1738 > ../originals/t2397
echo ">>>>>>>>running test 2398"
../source/print_tokens2.exe  < ../inputs/uslin.1740 > ../originals/t2398
echo ">>>>>>>>running test 2399"
../source/print_tokens2.exe  < ../inputs/uslin.1742 > ../originals/t2399
echo ">>>>>>>>running test 2400"
../source/print_tokens2.exe  < ../inputs/uslin.1744 > ../originals/t2400
echo ">>>>>>>>running test 2401"
../source/print_tokens2.exe  < ../inputs/uslin.175 > ../originals/t2401
echo ">>>>>>>>running test 2402"
../source/print_tokens2.exe  < ../inputs/uslin.1753 > ../originals/t2402
echo ">>>>>>>>running test 2403"
../source/print_tokens2.exe  < ../inputs/uslin.1754 > ../originals/t2403
echo ">>>>>>>>running test 2404"
../source/print_tokens2.exe  < ../inputs/uslin.1755 > ../originals/t2404
echo ">>>>>>>>running test 2405"
../source/print_tokens2.exe  < ../inputs/uslin.1756 > ../originals/t2405
echo ">>>>>>>>running test 2406"
../source/print_tokens2.exe  < ../inputs/uslin.176 > ../originals/t2406
echo ">>>>>>>>running test 2407"
../source/print_tokens2.exe  < ../inputs/uslin.1760 > ../originals/t2407
echo ">>>>>>>>running test 2408"
../source/print_tokens2.exe  < ../inputs/uslin.1762 > ../originals/t2408
echo ">>>>>>>>running test 2409"
../source/print_tokens2.exe  < ../inputs/uslin.1764 > ../originals/t2409
echo ">>>>>>>>running test 2410"
../source/print_tokens2.exe  < ../inputs/uslin.177 > ../originals/t2410
echo ">>>>>>>>running test 2411"
../source/print_tokens2.exe  < ../inputs/uslin.1771 > ../originals/t2411
echo ">>>>>>>>running test 2412"
../source/print_tokens2.exe  < ../inputs/uslin.1773 > ../originals/t2412
echo ">>>>>>>>running test 2413"
../source/print_tokens2.exe  < ../inputs/uslin.1774 > ../originals/t2413
echo ">>>>>>>>running test 2414"
../source/print_tokens2.exe  < ../inputs/uslin.1776 > ../originals/t2414
echo ">>>>>>>>running test 2415"
../source/print_tokens2.exe  < ../inputs/uslin.1778 > ../originals/t2415
echo ">>>>>>>>running test 2416"
../source/print_tokens2.exe  < ../inputs/uslin.1782 > ../originals/t2416
echo ">>>>>>>>running test 2417"
../source/print_tokens2.exe  < ../inputs/uslin.1783 > ../originals/t2417
echo ">>>>>>>>running test 2418"
../source/print_tokens2.exe  < ../inputs/uslin.1785 > ../originals/t2418
echo ">>>>>>>>running test 2419"
../source/print_tokens2.exe  < ../inputs/uslin.1787 > ../originals/t2419
echo ">>>>>>>>running test 2420"
../source/print_tokens2.exe  < ../inputs/uslin.1789 > ../originals/t2420
echo ">>>>>>>>running test 2421"
../source/print_tokens2.exe  < ../inputs/uslin.1792 > ../originals/t2421
echo ">>>>>>>>running test 2422"
../source/print_tokens2.exe  < ../inputs/uslin.1793 > ../originals/t2422
echo ">>>>>>>>running test 2423"
../source/print_tokens2.exe  < ../inputs/uslin.1794 > ../originals/t2423
echo ">>>>>>>>running test 2424"
../source/print_tokens2.exe  < ../inputs/uslin.1798 > ../originals/t2424
echo ">>>>>>>>running test 2425"
../source/print_tokens2.exe  < ../inputs/uslin.1800 > ../originals/t2425
echo ">>>>>>>>running test 2426"
../source/print_tokens2.exe  < ../inputs/uslin.1802 > ../originals/t2426
echo ">>>>>>>>running test 2427"
../source/print_tokens2.exe  < ../inputs/uslin.1806 > ../originals/t2427
echo ">>>>>>>>running test 2428"
../source/print_tokens2.exe  < ../inputs/uslin.1809 > ../originals/t2428
echo ">>>>>>>>running test 2429"
../source/print_tokens2.exe  < ../inputs/uslin.1812 > ../originals/t2429
echo ">>>>>>>>running test 2430"
../source/print_tokens2.exe  < ../inputs/uslin.1814 > ../originals/t2430
echo ">>>>>>>>running test 2431"
../source/print_tokens2.exe  < ../inputs/uslin.1816 > ../originals/t2431
echo ">>>>>>>>running test 2432"
../source/print_tokens2.exe  < ../inputs/uslin.1818 > ../originals/t2432
echo ">>>>>>>>running test 2433"
../source/print_tokens2.exe  < ../inputs/uslin.1819 > ../originals/t2433
echo ">>>>>>>>running test 2434"
../source/print_tokens2.exe  < ../inputs/uslin.182 > ../originals/t2434
echo ">>>>>>>>running test 2435"
../source/print_tokens2.exe  < ../inputs/uslin.1821 > ../originals/t2435
echo ">>>>>>>>running test 2436"
../source/print_tokens2.exe  < ../inputs/uslin.1823 > ../originals/t2436
echo ">>>>>>>>running test 2437"
../source/print_tokens2.exe  < ../inputs/uslin.1827 > ../originals/t2437
echo ">>>>>>>>running test 2438"
../source/print_tokens2.exe  < ../inputs/uslin.1829 > ../originals/t2438
echo ">>>>>>>>running test 2439"
../source/print_tokens2.exe  < ../inputs/uslin.1830 > ../originals/t2439
echo ">>>>>>>>running test 2440"
../source/print_tokens2.exe  < ../inputs/uslin.1832 > ../originals/t2440
echo ">>>>>>>>running test 2441"
../source/print_tokens2.exe  < ../inputs/uslin.1835 > ../originals/t2441
echo ">>>>>>>>running test 2442"
../source/print_tokens2.exe  < ../inputs/uslin.1836 > ../originals/t2442
echo ">>>>>>>>running test 2443"
../source/print_tokens2.exe  < ../inputs/uslin.1837 > ../originals/t2443
echo ">>>>>>>>running test 2444"
../source/print_tokens2.exe  < ../inputs/uslin.1838 > ../originals/t2444
echo ">>>>>>>>running test 2445"
../source/print_tokens2.exe  < ../inputs/uslin.1839 > ../originals/t2445
echo ">>>>>>>>running test 2446"
../source/print_tokens2.exe  < ../inputs/uslin.184 > ../originals/t2446
echo ">>>>>>>>running test 2447"
../source/print_tokens2.exe  < ../inputs/uslin.1845 > ../originals/t2447
echo ">>>>>>>>running test 2448"
../source/print_tokens2.exe  < ../inputs/uslin.1847 > ../originals/t2448
echo ">>>>>>>>running test 2449"
../source/print_tokens2.exe  < ../inputs/uslin.1848 > ../originals/t2449
echo ">>>>>>>>running test 2450"
../source/print_tokens2.exe  < ../inputs/uslin.185 > ../originals/t2450
echo ">>>>>>>>running test 2451"
../source/print_tokens2.exe  < ../inputs/uslin.1850 > ../originals/t2451
echo ">>>>>>>>running test 2452"
../source/print_tokens2.exe  < ../inputs/uslin.1855 > ../originals/t2452
echo ">>>>>>>>running test 2453"
../source/print_tokens2.exe  < ../inputs/uslin.1856 > ../originals/t2453
echo ">>>>>>>>running test 2454"
../source/print_tokens2.exe  < ../inputs/uslin.1858 > ../originals/t2454
echo ">>>>>>>>running test 2455"
../source/print_tokens2.exe  < ../inputs/uslin.1862 > ../originals/t2455
echo ">>>>>>>>running test 2456"
../source/print_tokens2.exe  < ../inputs/uslin.1863 > ../originals/t2456
echo ">>>>>>>>running test 2457"
../source/print_tokens2.exe  < ../inputs/uslin.1865 > ../originals/t2457
echo ">>>>>>>>running test 2458"
../source/print_tokens2.exe  < ../inputs/uslin.1871 > ../originals/t2458
echo ">>>>>>>>running test 2459"
../source/print_tokens2.exe  < ../inputs/uslin.1872 > ../originals/t2459
echo ">>>>>>>>running test 2460"
../source/print_tokens2.exe  < ../inputs/uslin.1873 > ../originals/t2460
echo ">>>>>>>>running test 2461"
../source/print_tokens2.exe  < ../inputs/uslin.1874 > ../originals/t2461
echo ">>>>>>>>running test 2462"
../source/print_tokens2.exe  < ../inputs/uslin.1876 > ../originals/t2462
echo ">>>>>>>>running test 2463"
../source/print_tokens2.exe  < ../inputs/uslin.1877 > ../originals/t2463
echo ">>>>>>>>running test 2464"
../source/print_tokens2.exe  < ../inputs/uslin.1878 > ../originals/t2464
echo ">>>>>>>>running test 2465"
../source/print_tokens2.exe  < ../inputs/uslin.188 > ../originals/t2465
echo ">>>>>>>>running test 2466"
../source/print_tokens2.exe  < ../inputs/uslin.1880 > ../originals/t2466
echo ">>>>>>>>running test 2467"
../source/print_tokens2.exe  < ../inputs/uslin.1881 > ../originals/t2467
echo ">>>>>>>>running test 2468"
../source/print_tokens2.exe  < ../inputs/uslin.1882 > ../originals/t2468
echo ">>>>>>>>running test 2469"
../source/print_tokens2.exe  < ../inputs/uslin.1885 > ../originals/t2469
echo ">>>>>>>>running test 2470"
../source/print_tokens2.exe  < ../inputs/uslin.1886 > ../originals/t2470
echo ">>>>>>>>running test 2471"
../source/print_tokens2.exe  < ../inputs/uslin.1887 > ../originals/t2471
echo ">>>>>>>>running test 2472"
../source/print_tokens2.exe  < ../inputs/uslin.189 > ../originals/t2472
echo ">>>>>>>>running test 2473"
../source/print_tokens2.exe  < ../inputs/uslin.1891 > ../originals/t2473
echo ">>>>>>>>running test 2474"
../source/print_tokens2.exe  < ../inputs/uslin.1892 > ../originals/t2474
echo ">>>>>>>>running test 2475"
../source/print_tokens2.exe  < ../inputs/uslin.1893 > ../originals/t2475
echo ">>>>>>>>running test 2476"
../source/print_tokens2.exe  < ../inputs/uslin.1895 > ../originals/t2476
echo ">>>>>>>>running test 2477"
../source/print_tokens2.exe  < ../inputs/uslin.1896 > ../originals/t2477
echo ">>>>>>>>running test 2478"
../source/print_tokens2.exe  < ../inputs/uslin.1897 > ../originals/t2478
echo ">>>>>>>>running test 2479"
../source/print_tokens2.exe  < ../inputs/uslin.1898 > ../originals/t2479
echo ">>>>>>>>running test 2480"
../source/print_tokens2.exe  < ../inputs/uslin.190 > ../originals/t2480
echo ">>>>>>>>running test 2481"
../source/print_tokens2.exe  < ../inputs/uslin.1903 > ../originals/t2481
echo ">>>>>>>>running test 2482"
../source/print_tokens2.exe  < ../inputs/uslin.1905 > ../originals/t2482
echo ">>>>>>>>running test 2483"
../source/print_tokens2.exe  < ../inputs/uslin.1907 > ../originals/t2483
echo ">>>>>>>>running test 2484"
../source/print_tokens2.exe  < ../inputs/uslin.1908 > ../originals/t2484
echo ">>>>>>>>running test 2485"
../source/print_tokens2.exe  < ../inputs/uslin.191 > ../originals/t2485
echo ">>>>>>>>running test 2486"
../source/print_tokens2.exe  < ../inputs/uslin.1912 > ../originals/t2486
echo ">>>>>>>>running test 2487"
../source/print_tokens2.exe  < ../inputs/uslin.1913 > ../originals/t2487
echo ">>>>>>>>running test 2488"
../source/print_tokens2.exe  < ../inputs/uslin.1914 > ../originals/t2488
echo ">>>>>>>>running test 2489"
../source/print_tokens2.exe  < ../inputs/uslin.1916 > ../originals/t2489
echo ">>>>>>>>running test 2490"
../source/print_tokens2.exe  < ../inputs/uslin.1917 > ../originals/t2490
echo ">>>>>>>>running test 2491"
../source/print_tokens2.exe  < ../inputs/uslin.1918 > ../originals/t2491
echo ">>>>>>>>running test 2492"
../source/print_tokens2.exe  < ../inputs/uslin.1920 > ../originals/t2492
echo ">>>>>>>>running test 2493"
../source/print_tokens2.exe  < ../inputs/uslin.1922 > ../originals/t2493
echo ">>>>>>>>running test 2494"
../source/print_tokens2.exe  < ../inputs/uslin.1924 > ../originals/t2494
echo ">>>>>>>>running test 2495"
../source/print_tokens2.exe  < ../inputs/uslin.1925 > ../originals/t2495
echo ">>>>>>>>running test 2496"
../source/print_tokens2.exe  < ../inputs/uslin.1926 > ../originals/t2496
echo ">>>>>>>>running test 2497"
../source/print_tokens2.exe  < ../inputs/uslin.1929 > ../originals/t2497
echo ">>>>>>>>running test 2498"
../source/print_tokens2.exe  < ../inputs/uslin.193 > ../originals/t2498
echo ">>>>>>>>running test 2499"
../source/print_tokens2.exe  < ../inputs/uslin.1931 > ../originals/t2499
echo ">>>>>>>>running test 2500"
../source/print_tokens2.exe  < ../inputs/uslin.1932 > ../originals/t2500
echo ">>>>>>>>running test 2501"
../source/print_tokens2.exe  < ../inputs/uslin.1934 > ../originals/t2501
echo ">>>>>>>>running test 2502"
../source/print_tokens2.exe  < ../inputs/uslin.1935 > ../originals/t2502
echo ">>>>>>>>running test 2503"
../source/print_tokens2.exe  < ../inputs/uslin.1936 > ../originals/t2503
echo ">>>>>>>>running test 2504"
../source/print_tokens2.exe  < ../inputs/uslin.1937 > ../originals/t2504
echo ">>>>>>>>running test 2505"
../source/print_tokens2.exe  < ../inputs/uslin.1938 > ../originals/t2505
echo ">>>>>>>>running test 2506"
../source/print_tokens2.exe  < ../inputs/uslin.1944 > ../originals/t2506
echo ">>>>>>>>running test 2507"
../source/print_tokens2.exe  < ../inputs/uslin.1945 > ../originals/t2507
echo ">>>>>>>>running test 2508"
../source/print_tokens2.exe  < ../inputs/uslin.1946 > ../originals/t2508
echo ">>>>>>>>running test 2509"
../source/print_tokens2.exe  < ../inputs/uslin.1947 > ../originals/t2509
echo ">>>>>>>>running test 2510"
../source/print_tokens2.exe  < ../inputs/uslin.1948 > ../originals/t2510
echo ">>>>>>>>running test 2511"
../source/print_tokens2.exe  < ../inputs/uslin.195 > ../originals/t2511
echo ">>>>>>>>running test 2512"
../source/print_tokens2.exe  < ../inputs/uslin.1950 > ../originals/t2512
echo ">>>>>>>>running test 2513"
../source/print_tokens2.exe  < ../inputs/uslin.1955 > ../originals/t2513
echo ">>>>>>>>running test 2514"
../source/print_tokens2.exe  < ../inputs/uslin.1958 > ../originals/t2514
echo ">>>>>>>>running test 2515"
../source/print_tokens2.exe  < ../inputs/uslin.1959 > ../originals/t2515
echo ">>>>>>>>running test 2516"
../source/print_tokens2.exe  < ../inputs/uslin.1961 > ../originals/t2516
echo ">>>>>>>>running test 2517"
../source/print_tokens2.exe  < ../inputs/uslin.1964 > ../originals/t2517
echo ">>>>>>>>running test 2518"
../source/print_tokens2.exe  < ../inputs/uslin.1970 > ../originals/t2518
echo ">>>>>>>>running test 2519"
../source/print_tokens2.exe  < ../inputs/uslin.1972 > ../originals/t2519
echo ">>>>>>>>running test 2520"
../source/print_tokens2.exe  < ../inputs/uslin.1974 > ../originals/t2520
echo ">>>>>>>>running test 2521"
../source/print_tokens2.exe  < ../inputs/uslin.1975 > ../originals/t2521
echo ">>>>>>>>running test 2522"
../source/print_tokens2.exe  < ../inputs/uslin.1979 > ../originals/t2522
echo ">>>>>>>>running test 2523"
../source/print_tokens2.exe  < ../inputs/uslin.1984 > ../originals/t2523
echo ">>>>>>>>running test 2524"
../source/print_tokens2.exe  < ../inputs/uslin.1985 > ../originals/t2524
echo ">>>>>>>>running test 2525"
../source/print_tokens2.exe  < ../inputs/uslin.1988 > ../originals/t2525
echo ">>>>>>>>running test 2526"
../source/print_tokens2.exe  < ../inputs/uslin.1989 > ../originals/t2526
echo ">>>>>>>>running test 2527"
../source/print_tokens2.exe  < ../inputs/uslin.1990 > ../originals/t2527
echo ">>>>>>>>running test 2528"
../source/print_tokens2.exe  < ../inputs/uslin.1995 > ../originals/t2528
echo ">>>>>>>>running test 2529"
../source/print_tokens2.exe  < ../inputs/uslin.1997 > ../originals/t2529
echo ">>>>>>>>running test 2530"
../source/print_tokens2.exe  < ../inputs/uslin.1999 > ../originals/t2530
echo ">>>>>>>>running test 2531"
../source/print_tokens2.exe  < ../inputs/uslin.20 > ../originals/t2531
echo ">>>>>>>>running test 2532"
../source/print_tokens2.exe  < ../inputs/uslin.2000 > ../originals/t2532
echo ">>>>>>>>running test 2533"
../source/print_tokens2.exe  < ../inputs/uslin.201 > ../originals/t2533
echo ">>>>>>>>running test 2534"
../source/print_tokens2.exe  < ../inputs/uslin.204 > ../originals/t2534
echo ">>>>>>>>running test 2535"
../source/print_tokens2.exe  < ../inputs/uslin.206 > ../originals/t2535
echo ">>>>>>>>running test 2536"
../source/print_tokens2.exe  < ../inputs/uslin.207 > ../originals/t2536
echo ">>>>>>>>running test 2537"
../source/print_tokens2.exe  < ../inputs/uslin.208 > ../originals/t2537
echo ">>>>>>>>running test 2538"
../source/print_tokens2.exe  < ../inputs/uslin.209 > ../originals/t2538
echo ">>>>>>>>running test 2539"
../source/print_tokens2.exe  < ../inputs/uslin.21 > ../originals/t2539
echo ">>>>>>>>running test 2540"
../source/print_tokens2.exe  < ../inputs/uslin.210 > ../originals/t2540
echo ">>>>>>>>running test 2541"
../source/print_tokens2.exe  < ../inputs/uslin.213 > ../originals/t2541
echo ">>>>>>>>running test 2542"
../source/print_tokens2.exe  < ../inputs/uslin.214 > ../originals/t2542
echo ">>>>>>>>running test 2543"
../source/print_tokens2.exe  < ../inputs/uslin.215 > ../originals/t2543
echo ">>>>>>>>running test 2544"
../source/print_tokens2.exe  < ../inputs/uslin.22 > ../originals/t2544
echo ">>>>>>>>running test 2545"
../source/print_tokens2.exe  < ../inputs/uslin.225 > ../originals/t2545
echo ">>>>>>>>running test 2546"
../source/print_tokens2.exe  < ../inputs/uslin.226 > ../originals/t2546
echo ">>>>>>>>running test 2547"
../source/print_tokens2.exe  < ../inputs/uslin.230 > ../originals/t2547
echo ">>>>>>>>running test 2548"
../source/print_tokens2.exe  < ../inputs/uslin.233 > ../originals/t2548
echo ">>>>>>>>running test 2549"
../source/print_tokens2.exe  < ../inputs/uslin.234 > ../originals/t2549
echo ">>>>>>>>running test 2550"
../source/print_tokens2.exe  < ../inputs/uslin.237 > ../originals/t2550
echo ">>>>>>>>running test 2551"
../source/print_tokens2.exe  < ../inputs/uslin.238 > ../originals/t2551
echo ">>>>>>>>running test 2552"
../source/print_tokens2.exe  < ../inputs/uslin.239 > ../originals/t2552
echo ">>>>>>>>running test 2553"
../source/print_tokens2.exe  < ../inputs/uslin.243 > ../originals/t2553
echo ">>>>>>>>running test 2554"
../source/print_tokens2.exe  < ../inputs/uslin.244 > ../originals/t2554
echo ">>>>>>>>running test 2555"
../source/print_tokens2.exe  < ../inputs/uslin.245 > ../originals/t2555
echo ">>>>>>>>running test 2556"
../source/print_tokens2.exe  < ../inputs/uslin.246 > ../originals/t2556
echo ">>>>>>>>running test 2557"
../source/print_tokens2.exe  < ../inputs/uslin.247 > ../originals/t2557
echo ">>>>>>>>running test 2558"
../source/print_tokens2.exe  < ../inputs/uslin.248 > ../originals/t2558
echo ">>>>>>>>running test 2559"
../source/print_tokens2.exe  < ../inputs/uslin.249 > ../originals/t2559
echo ">>>>>>>>running test 2560"
../source/print_tokens2.exe  < ../inputs/uslin.25 > ../originals/t2560
echo ">>>>>>>>running test 2561"
../source/print_tokens2.exe  < ../inputs/uslin.251 > ../originals/t2561
echo ">>>>>>>>running test 2562"
../source/print_tokens2.exe  < ../inputs/uslin.252 > ../originals/t2562
echo ">>>>>>>>running test 2563"
../source/print_tokens2.exe  < ../inputs/uslin.254 > ../originals/t2563
echo ">>>>>>>>running test 2564"
../source/print_tokens2.exe  < ../inputs/uslin.256 > ../originals/t2564
echo ">>>>>>>>running test 2565"
../source/print_tokens2.exe  < ../inputs/uslin.257 > ../originals/t2565
echo ">>>>>>>>running test 2566"
../source/print_tokens2.exe  < ../inputs/uslin.258 > ../originals/t2566
echo ">>>>>>>>running test 2567"
../source/print_tokens2.exe  < ../inputs/uslin.260 > ../originals/t2567
echo ">>>>>>>>running test 2568"
../source/print_tokens2.exe  < ../inputs/uslin.266 > ../originals/t2568
echo ">>>>>>>>running test 2569"
../source/print_tokens2.exe  < ../inputs/uslin.267 > ../originals/t2569
echo ">>>>>>>>running test 2570"
../source/print_tokens2.exe  < ../inputs/uslin.268 > ../originals/t2570
echo ">>>>>>>>running test 2571"
../source/print_tokens2.exe  < ../inputs/uslin.27 > ../originals/t2571
echo ">>>>>>>>running test 2572"
../source/print_tokens2.exe  < ../inputs/uslin.270 > ../originals/t2572
echo ">>>>>>>>running test 2573"
../source/print_tokens2.exe  < ../inputs/uslin.271 > ../originals/t2573
echo ">>>>>>>>running test 2574"
../source/print_tokens2.exe  < ../inputs/uslin.272 > ../originals/t2574
echo ">>>>>>>>running test 2575"
../source/print_tokens2.exe  < ../inputs/uslin.275 > ../originals/t2575
echo ">>>>>>>>running test 2576"
../source/print_tokens2.exe  < ../inputs/uslin.276 > ../originals/t2576
echo ">>>>>>>>running test 2577"
../source/print_tokens2.exe  < ../inputs/uslin.277 > ../originals/t2577
echo ">>>>>>>>running test 2578"
../source/print_tokens2.exe  < ../inputs/uslin.28 > ../originals/t2578
echo ">>>>>>>>running test 2579"
../source/print_tokens2.exe  < ../inputs/uslin.280 > ../originals/t2579
echo ">>>>>>>>running test 2580"
../source/print_tokens2.exe  < ../inputs/uslin.281 > ../originals/t2580
echo ">>>>>>>>running test 2581"
../source/print_tokens2.exe  < ../inputs/uslin.282 > ../originals/t2581
echo ">>>>>>>>running test 2582"
../source/print_tokens2.exe  < ../inputs/uslin.283 > ../originals/t2582
echo ">>>>>>>>running test 2583"
../source/print_tokens2.exe  < ../inputs/uslin.286 > ../originals/t2583
echo ">>>>>>>>running test 2584"
../source/print_tokens2.exe  < ../inputs/uslin.289 > ../originals/t2584
echo ">>>>>>>>running test 2585"
../source/print_tokens2.exe  < ../inputs/uslin.294 > ../originals/t2585
echo ">>>>>>>>running test 2586"
../source/print_tokens2.exe  < ../inputs/uslin.295 > ../originals/t2586
echo ">>>>>>>>running test 2587"
../source/print_tokens2.exe  < ../inputs/uslin.296 > ../originals/t2587
echo ">>>>>>>>running test 2588"
../source/print_tokens2.exe  < ../inputs/uslin.297 > ../originals/t2588
echo ">>>>>>>>running test 2589"
../source/print_tokens2.exe  < ../inputs/uslin.298 > ../originals/t2589
echo ">>>>>>>>running test 2590"
../source/print_tokens2.exe  < ../inputs/uslin.299 > ../originals/t2590
echo ">>>>>>>>running test 2591"
../source/print_tokens2.exe  < ../inputs/uslin.30 > ../originals/t2591
echo ">>>>>>>>running test 2592"
../source/print_tokens2.exe  < ../inputs/uslin.302 > ../originals/t2592
echo ">>>>>>>>running test 2593"
../source/print_tokens2.exe  < ../inputs/uslin.305 > ../originals/t2593
echo ">>>>>>>>running test 2594"
../source/print_tokens2.exe  < ../inputs/uslin.306 > ../originals/t2594
echo ">>>>>>>>running test 2595"
../source/print_tokens2.exe  < ../inputs/uslin.307 > ../originals/t2595
echo ">>>>>>>>running test 2596"
../source/print_tokens2.exe  < ../inputs/uslin.31 > ../originals/t2596
echo ">>>>>>>>running test 2597"
../source/print_tokens2.exe  < ../inputs/uslin.311 > ../originals/t2597
echo ">>>>>>>>running test 2598"
../source/print_tokens2.exe  < ../inputs/uslin.318 > ../originals/t2598
echo ">>>>>>>>running test 2599"
../source/print_tokens2.exe  < ../inputs/uslin.319 > ../originals/t2599
echo ">>>>>>>>running test 2600"
../source/print_tokens2.exe  < ../inputs/uslin.320 > ../originals/t2600
echo ">>>>>>>>running test 2601"
../source/print_tokens2.exe  < ../inputs/uslin.321 > ../originals/t2601
echo ">>>>>>>>running test 2602"
../source/print_tokens2.exe  < ../inputs/uslin.322 > ../originals/t2602
echo ">>>>>>>>running test 2603"
../source/print_tokens2.exe  < ../inputs/uslin.323 > ../originals/t2603
echo ">>>>>>>>running test 2604"
../source/print_tokens2.exe  < ../inputs/uslin.325 > ../originals/t2604
echo ">>>>>>>>running test 2605"
../source/print_tokens2.exe  < ../inputs/uslin.327 > ../originals/t2605
echo ">>>>>>>>running test 2606"
../source/print_tokens2.exe  < ../inputs/uslin.329 > ../originals/t2606
echo ">>>>>>>>running test 2607"
../source/print_tokens2.exe  < ../inputs/uslin.33 > ../originals/t2607
echo ">>>>>>>>running test 2608"
../source/print_tokens2.exe  < ../inputs/uslin.330 > ../originals/t2608
echo ">>>>>>>>running test 2609"
../source/print_tokens2.exe  < ../inputs/uslin.333 > ../originals/t2609
echo ">>>>>>>>running test 2610"
../source/print_tokens2.exe  < ../inputs/uslin.335 > ../originals/t2610
echo ">>>>>>>>running test 2611"
../source/print_tokens2.exe  < ../inputs/uslin.337 > ../originals/t2611
echo ">>>>>>>>running test 2612"
../source/print_tokens2.exe  < ../inputs/uslin.339 > ../originals/t2612
echo ">>>>>>>>running test 2613"
../source/print_tokens2.exe  < ../inputs/uslin.34 > ../originals/t2613
echo ">>>>>>>>running test 2614"
../source/print_tokens2.exe  < ../inputs/uslin.340 > ../originals/t2614
echo ">>>>>>>>running test 2615"
../source/print_tokens2.exe  < ../inputs/uslin.343 > ../originals/t2615
echo ">>>>>>>>running test 2616"
../source/print_tokens2.exe  < ../inputs/uslin.344 > ../originals/t2616
echo ">>>>>>>>running test 2617"
../source/print_tokens2.exe  < ../inputs/uslin.345 > ../originals/t2617
echo ">>>>>>>>running test 2618"
../source/print_tokens2.exe  < ../inputs/uslin.348 > ../originals/t2618
echo ">>>>>>>>running test 2619"
../source/print_tokens2.exe  < ../inputs/uslin.349 > ../originals/t2619
echo ">>>>>>>>running test 2620"
../source/print_tokens2.exe  < ../inputs/uslin.350 > ../originals/t2620
echo ">>>>>>>>running test 2621"
../source/print_tokens2.exe  < ../inputs/uslin.352 > ../originals/t2621
echo ">>>>>>>>running test 2622"
../source/print_tokens2.exe  < ../inputs/uslin.353 > ../originals/t2622
echo ">>>>>>>>running test 2623"
../source/print_tokens2.exe  < ../inputs/uslin.355 > ../originals/t2623
echo ">>>>>>>>running test 2624"
../source/print_tokens2.exe  < ../inputs/uslin.36 > ../originals/t2624
echo ">>>>>>>>running test 2625"
../source/print_tokens2.exe  < ../inputs/uslin.360 > ../originals/t2625
echo ">>>>>>>>running test 2626"
../source/print_tokens2.exe  < ../inputs/uslin.362 > ../originals/t2626
echo ">>>>>>>>running test 2627"
../source/print_tokens2.exe  < ../inputs/uslin.363 > ../originals/t2627
echo ">>>>>>>>running test 2628"
../source/print_tokens2.exe  < ../inputs/uslin.367 > ../originals/t2628
echo ">>>>>>>>running test 2629"
../source/print_tokens2.exe  < ../inputs/uslin.369 > ../originals/t2629
echo ">>>>>>>>running test 2630"
../source/print_tokens2.exe  < ../inputs/uslin.37 > ../originals/t2630
echo ">>>>>>>>running test 2631"
../source/print_tokens2.exe  < ../inputs/uslin.377 > ../originals/t2631
echo ">>>>>>>>running test 2632"
../source/print_tokens2.exe  < ../inputs/uslin.378 > ../originals/t2632
echo ">>>>>>>>running test 2633"
../source/print_tokens2.exe  < ../inputs/uslin.379 > ../originals/t2633
echo ">>>>>>>>running test 2634"
../source/print_tokens2.exe  < ../inputs/uslin.380 > ../originals/t2634
echo ">>>>>>>>running test 2635"
../source/print_tokens2.exe  < ../inputs/uslin.383 > ../originals/t2635
echo ">>>>>>>>running test 2636"
../source/print_tokens2.exe  < ../inputs/uslin.386 > ../originals/t2636
echo ">>>>>>>>running test 2637"
../source/print_tokens2.exe  < ../inputs/uslin.387 > ../originals/t2637
echo ">>>>>>>>running test 2638"
../source/print_tokens2.exe  < ../inputs/uslin.388 > ../originals/t2638
echo ">>>>>>>>running test 2639"
../source/print_tokens2.exe  < ../inputs/uslin.392 > ../originals/t2639
echo ">>>>>>>>running test 2640"
../source/print_tokens2.exe  < ../inputs/uslin.395 > ../originals/t2640
echo ">>>>>>>>running test 2641"
../source/print_tokens2.exe  < ../inputs/uslin.396 > ../originals/t2641
echo ">>>>>>>>running test 2642"
../source/print_tokens2.exe  < ../inputs/uslin.398 > ../originals/t2642
echo ">>>>>>>>running test 2643"
../source/print_tokens2.exe  < ../inputs/uslin.4 > ../originals/t2643
echo ">>>>>>>>running test 2644"
../source/print_tokens2.exe  < ../inputs/uslin.40 > ../originals/t2644
echo ">>>>>>>>running test 2645"
../source/print_tokens2.exe  < ../inputs/uslin.402 > ../originals/t2645
echo ">>>>>>>>running test 2646"
../source/print_tokens2.exe  < ../inputs/uslin.407 > ../originals/t2646
echo ">>>>>>>>running test 2647"
../source/print_tokens2.exe  < ../inputs/uslin.41 > ../originals/t2647
echo ">>>>>>>>running test 2648"
../source/print_tokens2.exe  < ../inputs/uslin.412 > ../originals/t2648
echo ">>>>>>>>running test 2649"
../source/print_tokens2.exe  < ../inputs/uslin.413 > ../originals/t2649
echo ">>>>>>>>running test 2650"
../source/print_tokens2.exe  < ../inputs/uslin.415 > ../originals/t2650
echo ">>>>>>>>running test 2651"
../source/print_tokens2.exe  < ../inputs/uslin.418 > ../originals/t2651
echo ">>>>>>>>running test 2652"
../source/print_tokens2.exe  < ../inputs/uslin.419 > ../originals/t2652
echo ">>>>>>>>running test 2653"
../source/print_tokens2.exe  < ../inputs/uslin.42 > ../originals/t2653
echo ">>>>>>>>running test 2654"
../source/print_tokens2.exe  < ../inputs/uslin.421 > ../originals/t2654
echo ">>>>>>>>running test 2655"
../source/print_tokens2.exe  < ../inputs/uslin.423 > ../originals/t2655
echo ">>>>>>>>running test 2656"
../source/print_tokens2.exe  < ../inputs/uslin.424 > ../originals/t2656
echo ">>>>>>>>running test 2657"
../source/print_tokens2.exe  < ../inputs/uslin.425 > ../originals/t2657
echo ">>>>>>>>running test 2658"
../source/print_tokens2.exe  < ../inputs/uslin.428 > ../originals/t2658
echo ">>>>>>>>running test 2659"
../source/print_tokens2.exe  < ../inputs/uslin.430 > ../originals/t2659
echo ">>>>>>>>running test 2660"
../source/print_tokens2.exe  < ../inputs/uslin.432 > ../originals/t2660
echo ">>>>>>>>running test 2661"
../source/print_tokens2.exe  < ../inputs/uslin.433 > ../originals/t2661
echo ">>>>>>>>running test 2662"
../source/print_tokens2.exe  < ../inputs/uslin.434 > ../originals/t2662
echo ">>>>>>>>running test 2663"
../source/print_tokens2.exe  < ../inputs/uslin.435 > ../originals/t2663
echo ">>>>>>>>running test 2664"
../source/print_tokens2.exe  < ../inputs/uslin.436 > ../originals/t2664
echo ">>>>>>>>running test 2665"
../source/print_tokens2.exe  < ../inputs/uslin.438 > ../originals/t2665
echo ">>>>>>>>running test 2666"
../source/print_tokens2.exe  < ../inputs/uslin.441 > ../originals/t2666
echo ">>>>>>>>running test 2667"
../source/print_tokens2.exe  < ../inputs/uslin.442 > ../originals/t2667
echo ">>>>>>>>running test 2668"
../source/print_tokens2.exe  < ../inputs/uslin.447 > ../originals/t2668
echo ">>>>>>>>running test 2669"
../source/print_tokens2.exe  < ../inputs/uslin.448 > ../originals/t2669
echo ">>>>>>>>running test 2670"
../source/print_tokens2.exe  < ../inputs/uslin.449 > ../originals/t2670
echo ">>>>>>>>running test 2671"
../source/print_tokens2.exe  < ../inputs/uslin.450 > ../originals/t2671
echo ">>>>>>>>running test 2672"
../source/print_tokens2.exe  < ../inputs/uslin.451 > ../originals/t2672
echo ">>>>>>>>running test 2673"
../source/print_tokens2.exe  < ../inputs/uslin.455 > ../originals/t2673
echo ">>>>>>>>running test 2674"
../source/print_tokens2.exe  < ../inputs/uslin.456 > ../originals/t2674
echo ">>>>>>>>running test 2675"
../source/print_tokens2.exe  < ../inputs/uslin.457 > ../originals/t2675
echo ">>>>>>>>running test 2676"
../source/print_tokens2.exe  < ../inputs/uslin.459 > ../originals/t2676
echo ">>>>>>>>running test 2677"
../source/print_tokens2.exe  < ../inputs/uslin.462 > ../originals/t2677
echo ">>>>>>>>running test 2678"
../source/print_tokens2.exe  < ../inputs/uslin.463 > ../originals/t2678
echo ">>>>>>>>running test 2679"
../source/print_tokens2.exe  < ../inputs/uslin.467 > ../originals/t2679
echo ">>>>>>>>running test 2680"
../source/print_tokens2.exe  < ../inputs/uslin.468 > ../originals/t2680
echo ">>>>>>>>running test 2681"
../source/print_tokens2.exe  < ../inputs/uslin.469 > ../originals/t2681
echo ">>>>>>>>running test 2682"
../source/print_tokens2.exe  < ../inputs/uslin.47 > ../originals/t2682
echo ">>>>>>>>running test 2683"
../source/print_tokens2.exe  < ../inputs/uslin.475 > ../originals/t2683
echo ">>>>>>>>running test 2684"
../source/print_tokens2.exe  < ../inputs/uslin.476 > ../originals/t2684
echo ">>>>>>>>running test 2685"
../source/print_tokens2.exe  < ../inputs/uslin.477 > ../originals/t2685
echo ">>>>>>>>running test 2686"
../source/print_tokens2.exe  < ../inputs/uslin.479 > ../originals/t2686
echo ">>>>>>>>running test 2687"
../source/print_tokens2.exe  < ../inputs/uslin.48 > ../originals/t2687
echo ">>>>>>>>running test 2688"
../source/print_tokens2.exe  < ../inputs/uslin.480 > ../originals/t2688
echo ">>>>>>>>running test 2689"
../source/print_tokens2.exe  < ../inputs/uslin.483 > ../originals/t2689
echo ">>>>>>>>running test 2690"
../source/print_tokens2.exe  < ../inputs/uslin.487 > ../originals/t2690
echo ">>>>>>>>running test 2691"
../source/print_tokens2.exe  < ../inputs/uslin.489 > ../originals/t2691
echo ">>>>>>>>running test 2692"
../source/print_tokens2.exe  < ../inputs/uslin.493 > ../originals/t2692
echo ">>>>>>>>running test 2693"
../source/print_tokens2.exe  < ../inputs/uslin.494 > ../originals/t2693
echo ">>>>>>>>running test 2694"
../source/print_tokens2.exe  < ../inputs/uslin.496 > ../originals/t2694
echo ">>>>>>>>running test 2695"
../source/print_tokens2.exe  < ../inputs/uslin.50 > ../originals/t2695
echo ">>>>>>>>running test 2696"
../source/print_tokens2.exe  < ../inputs/uslin.502 > ../originals/t2696
echo ">>>>>>>>running test 2697"
../source/print_tokens2.exe  < ../inputs/uslin.504 > ../originals/t2697
echo ">>>>>>>>running test 2698"
../source/print_tokens2.exe  < ../inputs/uslin.506 > ../originals/t2698
echo ">>>>>>>>running test 2699"
../source/print_tokens2.exe  < ../inputs/uslin.507 > ../originals/t2699
echo ">>>>>>>>running test 2700"
../source/print_tokens2.exe  < ../inputs/uslin.510 > ../originals/t2700
echo ">>>>>>>>running test 2701"
../source/print_tokens2.exe  < ../inputs/uslin.511 > ../originals/t2701
echo ">>>>>>>>running test 2702"
../source/print_tokens2.exe  < ../inputs/uslin.512 > ../originals/t2702
echo ">>>>>>>>running test 2703"
../source/print_tokens2.exe  < ../inputs/uslin.513 > ../originals/t2703
echo ">>>>>>>>running test 2704"
../source/print_tokens2.exe  < ../inputs/uslin.514 > ../originals/t2704
echo ">>>>>>>>running test 2705"
../source/print_tokens2.exe  < ../inputs/uslin.515 > ../originals/t2705
echo ">>>>>>>>running test 2706"
../source/print_tokens2.exe  < ../inputs/uslin.518 > ../originals/t2706
echo ">>>>>>>>running test 2707"
../source/print_tokens2.exe  < ../inputs/uslin.519 > ../originals/t2707
echo ">>>>>>>>running test 2708"
../source/print_tokens2.exe  < ../inputs/uslin.52 > ../originals/t2708
echo ">>>>>>>>running test 2709"
../source/print_tokens2.exe  < ../inputs/uslin.520 > ../originals/t2709
echo ">>>>>>>>running test 2710"
../source/print_tokens2.exe  < ../inputs/uslin.522 > ../originals/t2710
echo ">>>>>>>>running test 2711"
../source/print_tokens2.exe  < ../inputs/uslin.525 > ../originals/t2711
echo ">>>>>>>>running test 2712"
../source/print_tokens2.exe  < ../inputs/uslin.526 > ../originals/t2712
echo ">>>>>>>>running test 2713"
../source/print_tokens2.exe  < ../inputs/uslin.527 > ../originals/t2713
echo ">>>>>>>>running test 2714"
../source/print_tokens2.exe  < ../inputs/uslin.528 > ../originals/t2714
echo ">>>>>>>>running test 2715"
../source/print_tokens2.exe  < ../inputs/uslin.533 > ../originals/t2715
echo ">>>>>>>>running test 2716"
../source/print_tokens2.exe  < ../inputs/uslin.534 > ../originals/t2716
echo ">>>>>>>>running test 2717"
../source/print_tokens2.exe  < ../inputs/uslin.537 > ../originals/t2717
echo ">>>>>>>>running test 2718"
../source/print_tokens2.exe  < ../inputs/uslin.538 > ../originals/t2718
echo ">>>>>>>>running test 2719"
../source/print_tokens2.exe  < ../inputs/uslin.539 > ../originals/t2719
echo ">>>>>>>>running test 2720"
../source/print_tokens2.exe  < ../inputs/uslin.54 > ../originals/t2720
echo ">>>>>>>>running test 2721"
../source/print_tokens2.exe  < ../inputs/uslin.540 > ../originals/t2721
echo ">>>>>>>>running test 2722"
../source/print_tokens2.exe  < ../inputs/uslin.543 > ../originals/t2722
echo ">>>>>>>>running test 2723"
../source/print_tokens2.exe  < ../inputs/uslin.544 > ../originals/t2723
echo ">>>>>>>>running test 2724"
../source/print_tokens2.exe  < ../inputs/uslin.552 > ../originals/t2724
echo ">>>>>>>>running test 2725"
../source/print_tokens2.exe  < ../inputs/uslin.553 > ../originals/t2725
echo ">>>>>>>>running test 2726"
../source/print_tokens2.exe  < ../inputs/uslin.558 > ../originals/t2726
echo ">>>>>>>>running test 2727"
../source/print_tokens2.exe  < ../inputs/uslin.562 > ../originals/t2727
echo ">>>>>>>>running test 2728"
../source/print_tokens2.exe  < ../inputs/uslin.566 > ../originals/t2728
echo ">>>>>>>>running test 2729"
../source/print_tokens2.exe  < ../inputs/uslin.568 > ../originals/t2729
echo ">>>>>>>>running test 2730"
../source/print_tokens2.exe  < ../inputs/uslin.569 > ../originals/t2730
echo ">>>>>>>>running test 2731"
../source/print_tokens2.exe  < ../inputs/uslin.570 > ../originals/t2731
echo ">>>>>>>>running test 2732"
../source/print_tokens2.exe  < ../inputs/uslin.571 > ../originals/t2732
echo ">>>>>>>>running test 2733"
../source/print_tokens2.exe  < ../inputs/uslin.572 > ../originals/t2733
echo ">>>>>>>>running test 2734"
../source/print_tokens2.exe  < ../inputs/uslin.573 > ../originals/t2734
echo ">>>>>>>>running test 2735"
../source/print_tokens2.exe  < ../inputs/uslin.574 > ../originals/t2735
echo ">>>>>>>>running test 2736"
../source/print_tokens2.exe  < ../inputs/uslin.576 > ../originals/t2736
echo ">>>>>>>>running test 2737"
../source/print_tokens2.exe  < ../inputs/uslin.577 > ../originals/t2737
echo ">>>>>>>>running test 2738"
../source/print_tokens2.exe  < ../inputs/uslin.579 > ../originals/t2738
echo ">>>>>>>>running test 2739"
../source/print_tokens2.exe  < ../inputs/uslin.58 > ../originals/t2739
echo ">>>>>>>>running test 2740"
../source/print_tokens2.exe  < ../inputs/uslin.580 > ../originals/t2740
echo ">>>>>>>>running test 2741"
../source/print_tokens2.exe  < ../inputs/uslin.581 > ../originals/t2741
echo ">>>>>>>>running test 2742"
../source/print_tokens2.exe  < ../inputs/uslin.582 > ../originals/t2742
echo ">>>>>>>>running test 2743"
../source/print_tokens2.exe  < ../inputs/uslin.583 > ../originals/t2743
echo ">>>>>>>>running test 2744"
../source/print_tokens2.exe  < ../inputs/uslin.584 > ../originals/t2744
echo ">>>>>>>>running test 2745"
../source/print_tokens2.exe  < ../inputs/uslin.585 > ../originals/t2745
echo ">>>>>>>>running test 2746"
../source/print_tokens2.exe  < ../inputs/uslin.586 > ../originals/t2746
echo ">>>>>>>>running test 2747"
../source/print_tokens2.exe  < ../inputs/uslin.592 > ../originals/t2747
echo ">>>>>>>>running test 2748"
../source/print_tokens2.exe  < ../inputs/uslin.593 > ../originals/t2748
echo ">>>>>>>>running test 2749"
../source/print_tokens2.exe  < ../inputs/uslin.594 > ../originals/t2749
echo ">>>>>>>>running test 2750"
../source/print_tokens2.exe  < ../inputs/uslin.596 > ../originals/t2750
echo ">>>>>>>>running test 2751"
../source/print_tokens2.exe  < ../inputs/uslin.597 > ../originals/t2751
echo ">>>>>>>>running test 2752"
../source/print_tokens2.exe  < ../inputs/uslin.598 > ../originals/t2752
echo ">>>>>>>>running test 2753"
../source/print_tokens2.exe  < ../inputs/uslin.60 > ../originals/t2753
echo ">>>>>>>>running test 2754"
../source/print_tokens2.exe  < ../inputs/uslin.602 > ../originals/t2754
echo ">>>>>>>>running test 2755"
../source/print_tokens2.exe  < ../inputs/uslin.605 > ../originals/t2755
echo ">>>>>>>>running test 2756"
../source/print_tokens2.exe  < ../inputs/uslin.607 > ../originals/t2756
echo ">>>>>>>>running test 2757"
../source/print_tokens2.exe  < ../inputs/uslin.611 > ../originals/t2757
echo ">>>>>>>>running test 2758"
../source/print_tokens2.exe  < ../inputs/uslin.614 > ../originals/t2758
echo ">>>>>>>>running test 2759"
../source/print_tokens2.exe  < ../inputs/uslin.615 > ../originals/t2759
echo ">>>>>>>>running test 2760"
../source/print_tokens2.exe  < ../inputs/uslin.616 > ../originals/t2760
echo ">>>>>>>>running test 2761"
../source/print_tokens2.exe  < ../inputs/uslin.617 > ../originals/t2761
echo ">>>>>>>>running test 2762"
../source/print_tokens2.exe  < ../inputs/uslin.619 > ../originals/t2762
echo ">>>>>>>>running test 2763"
../source/print_tokens2.exe  < ../inputs/uslin.62 > ../originals/t2763
echo ">>>>>>>>running test 2764"
../source/print_tokens2.exe  < ../inputs/uslin.621 > ../originals/t2764
echo ">>>>>>>>running test 2765"
../source/print_tokens2.exe  < ../inputs/uslin.623 > ../originals/t2765
echo ">>>>>>>>running test 2766"
../source/print_tokens2.exe  < ../inputs/uslin.624 > ../originals/t2766
echo ">>>>>>>>running test 2767"
../source/print_tokens2.exe  < ../inputs/uslin.625 > ../originals/t2767
echo ">>>>>>>>running test 2768"
../source/print_tokens2.exe  < ../inputs/uslin.626 > ../originals/t2768
echo ">>>>>>>>running test 2769"
../source/print_tokens2.exe  < ../inputs/uslin.627 > ../originals/t2769
echo ">>>>>>>>running test 2770"
../source/print_tokens2.exe  < ../inputs/uslin.63 > ../originals/t2770
echo ">>>>>>>>running test 2771"
../source/print_tokens2.exe  < ../inputs/uslin.630 > ../originals/t2771
echo ">>>>>>>>running test 2772"
../source/print_tokens2.exe  < ../inputs/uslin.633 > ../originals/t2772
echo ">>>>>>>>running test 2773"
../source/print_tokens2.exe  < ../inputs/uslin.636 > ../originals/t2773
echo ">>>>>>>>running test 2774"
../source/print_tokens2.exe  < ../inputs/uslin.64 > ../originals/t2774
echo ">>>>>>>>running test 2775"
../source/print_tokens2.exe  < ../inputs/uslin.640 > ../originals/t2775
echo ">>>>>>>>running test 2776"
../source/print_tokens2.exe  < ../inputs/uslin.642 > ../originals/t2776
echo ">>>>>>>>running test 2777"
../source/print_tokens2.exe  < ../inputs/uslin.647 > ../originals/t2777
echo ">>>>>>>>running test 2778"
../source/print_tokens2.exe  < ../inputs/uslin.648 > ../originals/t2778
echo ">>>>>>>>running test 2779"
../source/print_tokens2.exe  < ../inputs/uslin.655 > ../originals/t2779
echo ">>>>>>>>running test 2780"
../source/print_tokens2.exe  < ../inputs/uslin.656 > ../originals/t2780
echo ">>>>>>>>running test 2781"
../source/print_tokens2.exe  < ../inputs/uslin.659 > ../originals/t2781
echo ">>>>>>>>running test 2782"
../source/print_tokens2.exe  < ../inputs/uslin.662 > ../originals/t2782
echo ">>>>>>>>running test 2783"
../source/print_tokens2.exe  < ../inputs/uslin.663 > ../originals/t2783
echo ">>>>>>>>running test 2784"
../source/print_tokens2.exe  < ../inputs/uslin.665 > ../originals/t2784
echo ">>>>>>>>running test 2785"
../source/print_tokens2.exe  < ../inputs/uslin.668 > ../originals/t2785
echo ">>>>>>>>running test 2786"
../source/print_tokens2.exe  < ../inputs/uslin.669 > ../originals/t2786
echo ">>>>>>>>running test 2787"
../source/print_tokens2.exe  < ../inputs/uslin.67 > ../originals/t2787
echo ">>>>>>>>running test 2788"
../source/print_tokens2.exe  < ../inputs/uslin.670 > ../originals/t2788
echo ">>>>>>>>running test 2789"
../source/print_tokens2.exe  < ../inputs/uslin.673 > ../originals/t2789
echo ">>>>>>>>running test 2790"
../source/print_tokens2.exe  < ../inputs/uslin.674 > ../originals/t2790
echo ">>>>>>>>running test 2791"
../source/print_tokens2.exe  < ../inputs/uslin.676 > ../originals/t2791
echo ">>>>>>>>running test 2792"
../source/print_tokens2.exe  < ../inputs/uslin.677 > ../originals/t2792
echo ">>>>>>>>running test 2793"
../source/print_tokens2.exe  < ../inputs/uslin.679 > ../originals/t2793
echo ">>>>>>>>running test 2794"
../source/print_tokens2.exe  < ../inputs/uslin.68 > ../originals/t2794
echo ">>>>>>>>running test 2795"
../source/print_tokens2.exe  < ../inputs/uslin.680 > ../originals/t2795
echo ">>>>>>>>running test 2796"
../source/print_tokens2.exe  < ../inputs/uslin.682 > ../originals/t2796
echo ">>>>>>>>running test 2797"
../source/print_tokens2.exe  < ../inputs/uslin.686 > ../originals/t2797
echo ">>>>>>>>running test 2798"
../source/print_tokens2.exe  < ../inputs/uslin.691 > ../originals/t2798
echo ">>>>>>>>running test 2799"
../source/print_tokens2.exe  < ../inputs/uslin.695 > ../originals/t2799
echo ">>>>>>>>running test 2800"
../source/print_tokens2.exe  < ../inputs/uslin.70 > ../originals/t2800
echo ">>>>>>>>running test 2801"
../source/print_tokens2.exe  < ../inputs/uslin.701 > ../originals/t2801
echo ">>>>>>>>running test 2802"
../source/print_tokens2.exe  < ../inputs/uslin.704 > ../originals/t2802
echo ">>>>>>>>running test 2803"
../source/print_tokens2.exe  < ../inputs/uslin.706 > ../originals/t2803
echo ">>>>>>>>running test 2804"
../source/print_tokens2.exe  < ../inputs/uslin.708 > ../originals/t2804
echo ">>>>>>>>running test 2805"
../source/print_tokens2.exe  < ../inputs/uslin.709 > ../originals/t2805
echo ">>>>>>>>running test 2806"
../source/print_tokens2.exe  < ../inputs/uslin.71 > ../originals/t2806
echo ">>>>>>>>running test 2807"
../source/print_tokens2.exe  < ../inputs/uslin.712 > ../originals/t2807
echo ">>>>>>>>running test 2808"
../source/print_tokens2.exe  < ../inputs/uslin.713 > ../originals/t2808
echo ">>>>>>>>running test 2809"
../source/print_tokens2.exe  < ../inputs/uslin.716 > ../originals/t2809
echo ">>>>>>>>running test 2810"
../source/print_tokens2.exe  < ../inputs/uslin.717 > ../originals/t2810
echo ">>>>>>>>running test 2811"
../source/print_tokens2.exe  < ../inputs/uslin.719 > ../originals/t2811
echo ">>>>>>>>running test 2812"
../source/print_tokens2.exe  < ../inputs/uslin.72 > ../originals/t2812
echo ">>>>>>>>running test 2813"
../source/print_tokens2.exe  < ../inputs/uslin.721 > ../originals/t2813
echo ">>>>>>>>running test 2814"
../source/print_tokens2.exe  < ../inputs/uslin.723 > ../originals/t2814
echo ">>>>>>>>running test 2815"
../source/print_tokens2.exe  < ../inputs/uslin.727 > ../originals/t2815
echo ">>>>>>>>running test 2816"
../source/print_tokens2.exe  < ../inputs/uslin.728 > ../originals/t2816
echo ">>>>>>>>running test 2817"
../source/print_tokens2.exe  < ../inputs/uslin.734 > ../originals/t2817
echo ">>>>>>>>running test 2818"
../source/print_tokens2.exe  < ../inputs/uslin.736 > ../originals/t2818
echo ">>>>>>>>running test 2819"
../source/print_tokens2.exe  < ../inputs/uslin.738 > ../originals/t2819
echo ">>>>>>>>running test 2820"
../source/print_tokens2.exe  < ../inputs/uslin.74 > ../originals/t2820
echo ">>>>>>>>running test 2821"
../source/print_tokens2.exe  < ../inputs/uslin.742 > ../originals/t2821
echo ">>>>>>>>running test 2822"
../source/print_tokens2.exe  < ../inputs/uslin.744 > ../originals/t2822
echo ">>>>>>>>running test 2823"
../source/print_tokens2.exe  < ../inputs/uslin.746 > ../originals/t2823
echo ">>>>>>>>running test 2824"
../source/print_tokens2.exe  < ../inputs/uslin.747 > ../originals/t2824
echo ">>>>>>>>running test 2825"
../source/print_tokens2.exe  < ../inputs/uslin.748 > ../originals/t2825
echo ">>>>>>>>running test 2826"
../source/print_tokens2.exe  < ../inputs/uslin.75 > ../originals/t2826
echo ">>>>>>>>running test 2827"
../source/print_tokens2.exe  < ../inputs/uslin.751 > ../originals/t2827
echo ">>>>>>>>running test 2828"
../source/print_tokens2.exe  < ../inputs/uslin.752 > ../originals/t2828
echo ">>>>>>>>running test 2829"
../source/print_tokens2.exe  < ../inputs/uslin.753 > ../originals/t2829
echo ">>>>>>>>running test 2830"
../source/print_tokens2.exe  < ../inputs/uslin.756 > ../originals/t2830
echo ">>>>>>>>running test 2831"
../source/print_tokens2.exe  < ../inputs/uslin.758 > ../originals/t2831
echo ">>>>>>>>running test 2832"
../source/print_tokens2.exe  < ../inputs/uslin.76 > ../originals/t2832
echo ">>>>>>>>running test 2833"
../source/print_tokens2.exe  < ../inputs/uslin.760 > ../originals/t2833
echo ">>>>>>>>running test 2834"
../source/print_tokens2.exe  < ../inputs/uslin.761 > ../originals/t2834
echo ">>>>>>>>running test 2835"
../source/print_tokens2.exe  < ../inputs/uslin.765 > ../originals/t2835
echo ">>>>>>>>running test 2836"
../source/print_tokens2.exe  < ../inputs/uslin.766 > ../originals/t2836
echo ">>>>>>>>running test 2837"
../source/print_tokens2.exe  < ../inputs/uslin.767 > ../originals/t2837
echo ">>>>>>>>running test 2838"
../source/print_tokens2.exe  < ../inputs/uslin.768 > ../originals/t2838
echo ">>>>>>>>running test 2839"
../source/print_tokens2.exe  < ../inputs/uslin.769 > ../originals/t2839
echo ">>>>>>>>running test 2840"
../source/print_tokens2.exe  < ../inputs/uslin.77 > ../originals/t2840
echo ">>>>>>>>running test 2841"
../source/print_tokens2.exe  < ../inputs/uslin.772 > ../originals/t2841
echo ">>>>>>>>running test 2842"
../source/print_tokens2.exe  < ../inputs/uslin.773 > ../originals/t2842
echo ">>>>>>>>running test 2843"
../source/print_tokens2.exe  < ../inputs/uslin.775 > ../originals/t2843
echo ">>>>>>>>running test 2844"
../source/print_tokens2.exe  < ../inputs/uslin.776 > ../originals/t2844
echo ">>>>>>>>running test 2845"
../source/print_tokens2.exe  < ../inputs/uslin.777 > ../originals/t2845
echo ">>>>>>>>running test 2846"
../source/print_tokens2.exe  < ../inputs/uslin.778 > ../originals/t2846
echo ">>>>>>>>running test 2847"
../source/print_tokens2.exe  < ../inputs/uslin.779 > ../originals/t2847
echo ">>>>>>>>running test 2848"
../source/print_tokens2.exe  < ../inputs/uslin.78 > ../originals/t2848
echo ">>>>>>>>running test 2849"
../source/print_tokens2.exe  < ../inputs/uslin.781 > ../originals/t2849
echo ">>>>>>>>running test 2850"
../source/print_tokens2.exe  < ../inputs/uslin.784 > ../originals/t2850
echo ">>>>>>>>running test 2851"
../source/print_tokens2.exe  < ../inputs/uslin.786 > ../originals/t2851
echo ">>>>>>>>running test 2852"
../source/print_tokens2.exe  < ../inputs/uslin.787 > ../originals/t2852
echo ">>>>>>>>running test 2853"
../source/print_tokens2.exe  < ../inputs/uslin.788 > ../originals/t2853
echo ">>>>>>>>running test 2854"
../source/print_tokens2.exe  < ../inputs/uslin.789 > ../originals/t2854
echo ">>>>>>>>running test 2855"
../source/print_tokens2.exe  < ../inputs/uslin.79 > ../originals/t2855
echo ">>>>>>>>running test 2856"
../source/print_tokens2.exe  < ../inputs/uslin.790 > ../originals/t2856
echo ">>>>>>>>running test 2857"
../source/print_tokens2.exe  < ../inputs/uslin.791 > ../originals/t2857
echo ">>>>>>>>running test 2858"
../source/print_tokens2.exe  < ../inputs/uslin.793 > ../originals/t2858
echo ">>>>>>>>running test 2859"
../source/print_tokens2.exe  < ../inputs/uslin.798 > ../originals/t2859
echo ">>>>>>>>running test 2860"
../source/print_tokens2.exe  < ../inputs/uslin.80 > ../originals/t2860
echo ">>>>>>>>running test 2861"
../source/print_tokens2.exe  < ../inputs/uslin.803 > ../originals/t2861
echo ">>>>>>>>running test 2862"
../source/print_tokens2.exe  < ../inputs/uslin.807 > ../originals/t2862
echo ">>>>>>>>running test 2863"
../source/print_tokens2.exe  < ../inputs/uslin.808 > ../originals/t2863
echo ">>>>>>>>running test 2864"
../source/print_tokens2.exe  < ../inputs/uslin.811 > ../originals/t2864
echo ">>>>>>>>running test 2865"
../source/print_tokens2.exe  < ../inputs/uslin.814 > ../originals/t2865
echo ">>>>>>>>running test 2866"
../source/print_tokens2.exe  < ../inputs/uslin.816 > ../originals/t2866
echo ">>>>>>>>running test 2867"
../source/print_tokens2.exe  < ../inputs/uslin.818 > ../originals/t2867
echo ">>>>>>>>running test 2868"
../source/print_tokens2.exe  < ../inputs/uslin.82 > ../originals/t2868
echo ">>>>>>>>running test 2869"
../source/print_tokens2.exe  < ../inputs/uslin.821 > ../originals/t2869
echo ">>>>>>>>running test 2870"
../source/print_tokens2.exe  < ../inputs/uslin.823 > ../originals/t2870
echo ">>>>>>>>running test 2871"
../source/print_tokens2.exe  < ../inputs/uslin.825 > ../originals/t2871
echo ">>>>>>>>running test 2872"
../source/print_tokens2.exe  < ../inputs/uslin.828 > ../originals/t2872
echo ">>>>>>>>running test 2873"
../source/print_tokens2.exe  < ../inputs/uslin.829 > ../originals/t2873
echo ">>>>>>>>running test 2874"
../source/print_tokens2.exe  < ../inputs/uslin.83 > ../originals/t2874
echo ">>>>>>>>running test 2875"
../source/print_tokens2.exe  < ../inputs/uslin.831 > ../originals/t2875
echo ">>>>>>>>running test 2876"
../source/print_tokens2.exe  < ../inputs/uslin.832 > ../originals/t2876
echo ">>>>>>>>running test 2877"
../source/print_tokens2.exe  < ../inputs/uslin.834 > ../originals/t2877
echo ">>>>>>>>running test 2878"
../source/print_tokens2.exe  < ../inputs/uslin.836 > ../originals/t2878
echo ">>>>>>>>running test 2879"
../source/print_tokens2.exe  < ../inputs/uslin.837 > ../originals/t2879
echo ">>>>>>>>running test 2880"
../source/print_tokens2.exe  < ../inputs/uslin.840 > ../originals/t2880
echo ">>>>>>>>running test 2881"
../source/print_tokens2.exe  < ../inputs/uslin.843 > ../originals/t2881
echo ">>>>>>>>running test 2882"
../source/print_tokens2.exe  < ../inputs/uslin.85 > ../originals/t2882
echo ">>>>>>>>running test 2883"
../source/print_tokens2.exe  < ../inputs/uslin.851 > ../originals/t2883
echo ">>>>>>>>running test 2884"
../source/print_tokens2.exe  < ../inputs/uslin.855 > ../originals/t2884
echo ">>>>>>>>running test 2885"
../source/print_tokens2.exe  < ../inputs/uslin.858 > ../originals/t2885
echo ">>>>>>>>running test 2886"
../source/print_tokens2.exe  < ../inputs/uslin.860 > ../originals/t2886
echo ">>>>>>>>running test 2887"
../source/print_tokens2.exe  < ../inputs/uslin.862 > ../originals/t2887
echo ">>>>>>>>running test 2888"
../source/print_tokens2.exe  < ../inputs/uslin.864 > ../originals/t2888
echo ">>>>>>>>running test 2889"
../source/print_tokens2.exe  < ../inputs/uslin.865 > ../originals/t2889
echo ">>>>>>>>running test 2890"
../source/print_tokens2.exe  < ../inputs/uslin.866 > ../originals/t2890
echo ">>>>>>>>running test 2891"
../source/print_tokens2.exe  < ../inputs/uslin.87 > ../originals/t2891
echo ">>>>>>>>running test 2892"
../source/print_tokens2.exe  < ../inputs/uslin.871 > ../originals/t2892
echo ">>>>>>>>running test 2893"
../source/print_tokens2.exe  < ../inputs/uslin.88 > ../originals/t2893
echo ">>>>>>>>running test 2894"
../source/print_tokens2.exe  < ../inputs/uslin.880 > ../originals/t2894
echo ">>>>>>>>running test 2895"
../source/print_tokens2.exe  < ../inputs/uslin.888 > ../originals/t2895
echo ">>>>>>>>running test 2896"
../source/print_tokens2.exe  < ../inputs/uslin.89 > ../originals/t2896
echo ">>>>>>>>running test 2897"
../source/print_tokens2.exe  < ../inputs/uslin.892 > ../originals/t2897
echo ">>>>>>>>running test 2898"
../source/print_tokens2.exe  < ../inputs/uslin.895 > ../originals/t2898
echo ">>>>>>>>running test 2899"
../source/print_tokens2.exe  < ../inputs/uslin.896 > ../originals/t2899
echo ">>>>>>>>running test 2900"
../source/print_tokens2.exe  < ../inputs/uslin.898 > ../originals/t2900
echo ">>>>>>>>running test 2901"
../source/print_tokens2.exe  < ../inputs/uslin.9 > ../originals/t2901
echo ">>>>>>>>running test 2902"
../source/print_tokens2.exe  < ../inputs/uslin.903 > ../originals/t2902
echo ">>>>>>>>running test 2903"
../source/print_tokens2.exe  < ../inputs/uslin.904 > ../originals/t2903
echo ">>>>>>>>running test 2904"
../source/print_tokens2.exe  < ../inputs/uslin.905 > ../originals/t2904
echo ">>>>>>>>running test 2905"
../source/print_tokens2.exe  < ../inputs/uslin.906 > ../originals/t2905
echo ">>>>>>>>running test 2906"
../source/print_tokens2.exe  < ../inputs/uslin.910 > ../originals/t2906
echo ">>>>>>>>running test 2907"
../source/print_tokens2.exe  < ../inputs/uslin.913 > ../originals/t2907
echo ">>>>>>>>running test 2908"
../source/print_tokens2.exe  < ../inputs/uslin.914 > ../originals/t2908
echo ">>>>>>>>running test 2909"
../source/print_tokens2.exe  < ../inputs/uslin.92 > ../originals/t2909
echo ">>>>>>>>running test 2910"
../source/print_tokens2.exe  < ../inputs/uslin.920 > ../originals/t2910
echo ">>>>>>>>running test 2911"
../source/print_tokens2.exe  < ../inputs/uslin.922 > ../originals/t2911
echo ">>>>>>>>running test 2912"
../source/print_tokens2.exe  < ../inputs/uslin.923 > ../originals/t2912
echo ">>>>>>>>running test 2913"
../source/print_tokens2.exe  < ../inputs/uslin.924 > ../originals/t2913
echo ">>>>>>>>running test 2914"
../source/print_tokens2.exe  < ../inputs/uslin.926 > ../originals/t2914
echo ">>>>>>>>running test 2915"
../source/print_tokens2.exe  < ../inputs/uslin.927 > ../originals/t2915
echo ">>>>>>>>running test 2916"
../source/print_tokens2.exe  < ../inputs/uslin.93 > ../originals/t2916
echo ">>>>>>>>running test 2917"
../source/print_tokens2.exe  < ../inputs/uslin.930 > ../originals/t2917
echo ">>>>>>>>running test 2918"
../source/print_tokens2.exe  < ../inputs/uslin.933 > ../originals/t2918
echo ">>>>>>>>running test 2919"
../source/print_tokens2.exe  < ../inputs/uslin.937 > ../originals/t2919
echo ">>>>>>>>running test 2920"
../source/print_tokens2.exe  < ../inputs/uslin.94 > ../originals/t2920
echo ">>>>>>>>running test 2921"
../source/print_tokens2.exe  < ../inputs/uslin.942 > ../originals/t2921
echo ">>>>>>>>running test 2922"
../source/print_tokens2.exe  < ../inputs/uslin.944 > ../originals/t2922
echo ">>>>>>>>running test 2923"
../source/print_tokens2.exe  < ../inputs/uslin.945 > ../originals/t2923
echo ">>>>>>>>running test 2924"
../source/print_tokens2.exe  < ../inputs/uslin.949 > ../originals/t2924
echo ">>>>>>>>running test 2925"
../source/print_tokens2.exe  < ../inputs/uslin.954 > ../originals/t2925
echo ">>>>>>>>running test 2926"
../source/print_tokens2.exe  < ../inputs/uslin.955 > ../originals/t2926
echo ">>>>>>>>running test 2927"
../source/print_tokens2.exe  < ../inputs/uslin.957 > ../originals/t2927
echo ">>>>>>>>running test 2928"
../source/print_tokens2.exe  < ../inputs/uslin.958 > ../originals/t2928
echo ">>>>>>>>running test 2929"
../source/print_tokens2.exe  < ../inputs/uslin.96 > ../originals/t2929
echo ">>>>>>>>running test 2930"
../source/print_tokens2.exe  < ../inputs/uslin.960 > ../originals/t2930
echo ">>>>>>>>running test 2931"
../source/print_tokens2.exe  < ../inputs/uslin.961 > ../originals/t2931
echo ">>>>>>>>running test 2932"
../source/print_tokens2.exe  < ../inputs/uslin.962 > ../originals/t2932
echo ">>>>>>>>running test 2933"
../source/print_tokens2.exe  < ../inputs/uslin.964 > ../originals/t2933
echo ">>>>>>>>running test 2934"
../source/print_tokens2.exe  < ../inputs/uslin.966 > ../originals/t2934
echo ">>>>>>>>running test 2935"
../source/print_tokens2.exe  < ../inputs/uslin.968 > ../originals/t2935
echo ">>>>>>>>running test 2936"
../source/print_tokens2.exe  < ../inputs/uslin.969 > ../originals/t2936
echo ">>>>>>>>running test 2937"
../source/print_tokens2.exe  < ../inputs/uslin.97 > ../originals/t2937
echo ">>>>>>>>running test 2938"
../source/print_tokens2.exe  < ../inputs/uslin.971 > ../originals/t2938
echo ">>>>>>>>running test 2939"
../source/print_tokens2.exe  < ../inputs/uslin.973 > ../originals/t2939
echo ">>>>>>>>running test 2940"
../source/print_tokens2.exe  < ../inputs/uslin.974 > ../originals/t2940
echo ">>>>>>>>running test 2941"
../source/print_tokens2.exe  < ../inputs/uslin.978 > ../originals/t2941
echo ">>>>>>>>running test 2942"
../source/print_tokens2.exe  < ../inputs/uslin.98 > ../originals/t2942
echo ">>>>>>>>running test 2943"
../source/print_tokens2.exe  < ../inputs/uslin.981 > ../originals/t2943
echo ">>>>>>>>running test 2944"
../source/print_tokens2.exe  < ../inputs/uslin.982 > ../originals/t2944
echo ">>>>>>>>running test 2945"
../source/print_tokens2.exe  < ../inputs/uslin.984 > ../originals/t2945
echo ">>>>>>>>running test 2946"
../source/print_tokens2.exe  < ../inputs/uslin.987 > ../originals/t2946
echo ">>>>>>>>running test 2947"
../source/print_tokens2.exe  < ../inputs/uslin.989 > ../originals/t2947
echo ">>>>>>>>running test 2948"
../source/print_tokens2.exe  < ../inputs/uslin.99 > ../originals/t2948
echo ">>>>>>>>running test 2949"
../source/print_tokens2.exe  < ../inputs/uslin.991 > ../originals/t2949
echo ">>>>>>>>running test 2950"
../source/print_tokens2.exe  < ../inputs/uslin.992 > ../originals/t2950
echo ">>>>>>>>running test 2951"
../source/print_tokens2.exe  < ../inputs/uslin.993 > ../originals/t2951
echo ">>>>>>>>running test 2952"
../source/print_tokens2.exe  < ../inputs/uslin.994 > ../originals/t2952
echo ">>>>>>>>running test 2953"
../source/print_tokens2.exe  < ../inputs/uslin.995 > ../originals/t2953
echo ">>>>>>>>running test 2954"
../source/print_tokens2.exe  < ../inputs/uslin.996 > ../originals/t2954
echo ">>>>>>>>running test 2955"
../source/print_tokens2.exe  < ../inputs/uslin.999 > ../originals/t2955
echo ">>>>>>>>running test 2956"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t2956
echo ">>>>>>>>running test 2957"
../source/print_tokens2.exe ../inputs/jk1     > ../originals/t2957
echo ">>>>>>>>running test 2958"
../source/print_tokens2.exe ../inputs/jk10     > ../originals/t2958
echo ">>>>>>>>running test 2959"
../source/print_tokens2.exe ../inputs/jk11     > ../originals/t2959
echo ">>>>>>>>running test 2960"
../source/print_tokens2.exe ../inputs/jk12     > ../originals/t2960
echo ">>>>>>>>running test 2961"
../source/print_tokens2.exe ../inputs/jk13     > ../originals/t2961
echo ">>>>>>>>running test 2962"
../source/print_tokens2.exe ../inputs/jk14     > ../originals/t2962
echo ">>>>>>>>running test 2963"
../source/print_tokens2.exe ../inputs/jk15     > ../originals/t2963
echo ">>>>>>>>running test 2964"
../source/print_tokens2.exe ../inputs/jk16     > ../originals/t2964
echo ">>>>>>>>running test 2965"
../source/print_tokens2.exe ../inputs/jk17     > ../originals/t2965
echo ">>>>>>>>running test 2966"
../source/print_tokens2.exe ../inputs/jk18     > ../originals/t2966
echo ">>>>>>>>running test 2967"
../source/print_tokens2.exe ../inputs/jk19     > ../originals/t2967
echo ">>>>>>>>running test 2968"
../source/print_tokens2.exe ../inputs/jk2     > ../originals/t2968
echo ">>>>>>>>running test 2969"
../source/print_tokens2.exe ../inputs/jk20     > ../originals/t2969
echo ">>>>>>>>running test 2970"
../source/print_tokens2.exe ../inputs/jk21     > ../originals/t2970
echo ">>>>>>>>running test 2971"
../source/print_tokens2.exe ../inputs/jk22     > ../originals/t2971
echo ">>>>>>>>running test 2972"
../source/print_tokens2.exe ../inputs/jk23     > ../originals/t2972
echo ">>>>>>>>running test 2973"
../source/print_tokens2.exe ../inputs/jk24     > ../originals/t2973
echo ">>>>>>>>running test 2974"
../source/print_tokens2.exe ../inputs/jk25     > ../originals/t2974
echo ">>>>>>>>running test 2975"
../source/print_tokens2.exe ../inputs/jk26     > ../originals/t2975
echo ">>>>>>>>running test 2976"
../source/print_tokens2.exe ../inputs/jk27     > ../originals/t2976
echo ">>>>>>>>running test 2977"
../source/print_tokens2.exe ../inputs/jk28     > ../originals/t2977
echo ">>>>>>>>running test 2978"
../source/print_tokens2.exe ../inputs/jk29     > ../originals/t2978
echo ">>>>>>>>running test 2979"
../source/print_tokens2.exe ../inputs/jk3     > ../originals/t2979
echo ">>>>>>>>running test 2980"
../source/print_tokens2.exe ../inputs/jk30     > ../originals/t2980
echo ">>>>>>>>running test 2981"
../source/print_tokens2.exe ../inputs/jk31     > ../originals/t2981
echo ">>>>>>>>running test 2982"
../source/print_tokens2.exe ../inputs/jk32     > ../originals/t2982
echo ">>>>>>>>running test 2983"
../source/print_tokens2.exe ../inputs/jk33     > ../originals/t2983
echo ">>>>>>>>running test 2984"
../source/print_tokens2.exe ../inputs/jk34     > ../originals/t2984
echo ">>>>>>>>running test 2985"
../source/print_tokens2.exe ../inputs/jk35     > ../originals/t2985
echo ">>>>>>>>running test 2986"
../source/print_tokens2.exe ../inputs/jk36     > ../originals/t2986
echo ">>>>>>>>running test 2987"
../source/print_tokens2.exe ../inputs/jk37     > ../originals/t2987
echo ">>>>>>>>running test 2988"
../source/print_tokens2.exe ../inputs/jk38     > ../originals/t2988
echo ">>>>>>>>running test 2989"
../source/print_tokens2.exe ../inputs/jk39     > ../originals/t2989
echo ">>>>>>>>running test 2990"
../source/print_tokens2.exe ../inputs/jk4     > ../originals/t2990
echo ">>>>>>>>running test 2991"
../source/print_tokens2.exe ../inputs/jk40     > ../originals/t2991
echo ">>>>>>>>running test 2992"
../source/print_tokens2.exe ../inputs/jk41     > ../originals/t2992
echo ">>>>>>>>running test 2993"
../source/print_tokens2.exe ../inputs/jk42     > ../originals/t2993
echo ">>>>>>>>running test 2994"
../source/print_tokens2.exe ../inputs/jk43     > ../originals/t2994
echo ">>>>>>>>running test 2995"
../source/print_tokens2.exe ../inputs/jk44     > ../originals/t2995
echo ">>>>>>>>running test 2996"
../source/print_tokens2.exe ../inputs/jk45     > ../originals/t2996
echo ">>>>>>>>running test 2997"
../source/print_tokens2.exe ../inputs/jk46     > ../originals/t2997
echo ">>>>>>>>running test 2998"
../source/print_tokens2.exe ../inputs/jk47     > ../originals/t2998
echo ">>>>>>>>running test 2999"
../source/print_tokens2.exe ../inputs/jk48     > ../originals/t2999
echo ">>>>>>>>running test 3000"
../source/print_tokens2.exe ../inputs/jk49     > ../originals/t3000
echo ">>>>>>>>running test 3001"
../source/print_tokens2.exe ../inputs/jk5     > ../originals/t3001
echo ">>>>>>>>running test 3002"
../source/print_tokens2.exe ../inputs/jk50     > ../originals/t3002
echo ">>>>>>>>running test 3003"
../source/print_tokens2.exe ../inputs/jk6     > ../originals/t3003
echo ">>>>>>>>running test 3004"
../source/print_tokens2.exe ../inputs/jk7     > ../originals/t3004
echo ">>>>>>>>running test 3005"
../source/print_tokens2.exe ../inputs/jk8     > ../originals/t3005
echo ">>>>>>>>running test 3006"
../source/print_tokens2.exe ../inputs/jk9     > ../originals/t3006
echo ">>>>>>>>running test 3007"
../source/print_tokens2.exe ../inputs/newtst522.tst.noeof     > ../originals/t3007
echo ">>>>>>>>running test 3008"
../source/print_tokens2.exe ../inputs/tc240.noeof     > ../originals/t3008
echo ">>>>>>>>running test 3009"
../source/print_tokens2.exe ../inputs/test287.noeof     > ../originals/t3009
echo ">>>>>>>>running test 3010"
../source/print_tokens2.exe ../inputs/test330.noeof     > ../originals/t3010
echo ">>>>>>>>running test 3011"
../source/print_tokens2.exe ../inputs/test373.noeof     > ../originals/t3011
echo ">>>>>>>>running test 3012"
../source/print_tokens2.exe ../inputs/ts516.noeof     > ../originals/t3012
echo ">>>>>>>>running test 3013"
../source/print_tokens2.exe ../inputs/ts583.noeof     > ../originals/t3013
echo ">>>>>>>>running test 3014"
../source/print_tokens2.exe ../inputs/ts609.noeof     > ../originals/t3014
echo ">>>>>>>>running test 3015"
../source/print_tokens2.exe ../inputs/ts789.noeof     > ../originals/t3015
echo ">>>>>>>>running test 3016"
../source/print_tokens2.exe ../inputs/tst110.noeof     > ../originals/t3016
echo ">>>>>>>>running test 3017"
../source/print_tokens2.exe ../inputs/tst52.noeof     > ../originals/t3017
echo ">>>>>>>>running test 3018"
../source/print_tokens2.exe ../inputs/uslin.1     > ../originals/t3018
echo ">>>>>>>>running test 3019"
../source/print_tokens2.exe ../inputs/uslin.10     > ../originals/t3019
echo ">>>>>>>>running test 3020"
../source/print_tokens2.exe ../inputs/uslin.1000     > ../originals/t3020
echo ">>>>>>>>running test 3021"
../source/print_tokens2.exe ../inputs/uslin.1001     > ../originals/t3021
echo ">>>>>>>>running test 3022"
../source/print_tokens2.exe ../inputs/uslin.1003     > ../originals/t3022
echo ">>>>>>>>running test 3023"
../source/print_tokens2.exe ../inputs/uslin.1004     > ../originals/t3023
echo ">>>>>>>>running test 3024"
../source/print_tokens2.exe ../inputs/uslin.1005     > ../originals/t3024
echo ">>>>>>>>running test 3025"
../source/print_tokens2.exe ../inputs/uslin.1008     > ../originals/t3025
echo ">>>>>>>>running test 3026"
../source/print_tokens2.exe ../inputs/uslin.1009     > ../originals/t3026
echo ">>>>>>>>running test 3027"
../source/print_tokens2.exe ../inputs/uslin.1010     > ../originals/t3027
echo ">>>>>>>>running test 3028"
../source/print_tokens2.exe ../inputs/uslin.1014     > ../originals/t3028
echo ">>>>>>>>running test 3029"
../source/print_tokens2.exe ../inputs/uslin.1014.noeof     > ../originals/t3029
echo ">>>>>>>>running test 3030"
../source/print_tokens2.exe ../inputs/uslin.1015     > ../originals/t3030
echo ">>>>>>>>running test 3031"
../source/print_tokens2.exe ../inputs/uslin.1018     > ../originals/t3031
echo ">>>>>>>>running test 3032"
../source/print_tokens2.exe ../inputs/uslin.1020     > ../originals/t3032
echo ">>>>>>>>running test 3033"
../source/print_tokens2.exe ../inputs/uslin.1024     > ../originals/t3033
echo ">>>>>>>>running test 3034"
../source/print_tokens2.exe ../inputs/uslin.1025     > ../originals/t3034
echo ">>>>>>>>running test 3035"
../source/print_tokens2.exe ../inputs/uslin.1030     > ../originals/t3035
echo ">>>>>>>>running test 3036"
../source/print_tokens2.exe ../inputs/uslin.1031     > ../originals/t3036
echo ">>>>>>>>running test 3037"
../source/print_tokens2.exe ../inputs/uslin.1032     > ../originals/t3037
echo ">>>>>>>>running test 3038"
../source/print_tokens2.exe ../inputs/uslin.1034     > ../originals/t3038
echo ">>>>>>>>running test 3039"
../source/print_tokens2.exe ../inputs/uslin.1035     > ../originals/t3039
echo ">>>>>>>>running test 3040"
../source/print_tokens2.exe ../inputs/uslin.1036     > ../originals/t3040
echo ">>>>>>>>running test 3041"
../source/print_tokens2.exe ../inputs/uslin.1038     > ../originals/t3041
echo ">>>>>>>>running test 3042"
../source/print_tokens2.exe ../inputs/uslin.1038.noeof     > ../originals/t3042
echo ">>>>>>>>running test 3043"
../source/print_tokens2.exe ../inputs/uslin.1039     > ../originals/t3043
echo ">>>>>>>>running test 3044"
../source/print_tokens2.exe ../inputs/uslin.1040     > ../originals/t3044
echo ">>>>>>>>running test 3045"
../source/print_tokens2.exe ../inputs/uslin.1042     > ../originals/t3045
echo ">>>>>>>>running test 3046"
../source/print_tokens2.exe ../inputs/uslin.1043     > ../originals/t3046
echo ">>>>>>>>running test 3047"
../source/print_tokens2.exe ../inputs/uslin.1045     > ../originals/t3047
echo ">>>>>>>>running test 3048"
../source/print_tokens2.exe ../inputs/uslin.1046     > ../originals/t3048
echo ">>>>>>>>running test 3049"
../source/print_tokens2.exe ../inputs/uslin.1047     > ../originals/t3049
echo ">>>>>>>>running test 3050"
../source/print_tokens2.exe ../inputs/uslin.1048     > ../originals/t3050
echo ">>>>>>>>running test 3051"
../source/print_tokens2.exe ../inputs/uslin.1049     > ../originals/t3051
echo ">>>>>>>>running test 3052"
../source/print_tokens2.exe ../inputs/uslin.105     > ../originals/t3052
echo ">>>>>>>>running test 3053"
../source/print_tokens2.exe ../inputs/uslin.1050     > ../originals/t3053
echo ">>>>>>>>running test 3054"
../source/print_tokens2.exe ../inputs/uslin.1054     > ../originals/t3054
echo ">>>>>>>>running test 3055"
../source/print_tokens2.exe ../inputs/uslin.1057     > ../originals/t3055
echo ">>>>>>>>running test 3056"
../source/print_tokens2.exe ../inputs/uslin.1059     > ../originals/t3056
echo ">>>>>>>>running test 3057"
../source/print_tokens2.exe ../inputs/uslin.106     > ../originals/t3057
echo ">>>>>>>>running test 3058"
../source/print_tokens2.exe ../inputs/uslin.1061     > ../originals/t3058
echo ">>>>>>>>running test 3059"
../source/print_tokens2.exe ../inputs/uslin.1065     > ../originals/t3059
echo ">>>>>>>>running test 3060"
../source/print_tokens2.exe ../inputs/uslin.1067     > ../originals/t3060
echo ">>>>>>>>running test 3061"
../source/print_tokens2.exe ../inputs/uslin.1068     > ../originals/t3061
echo ">>>>>>>>running test 3062"
../source/print_tokens2.exe ../inputs/uslin.1069     > ../originals/t3062
echo ">>>>>>>>running test 3063"
../source/print_tokens2.exe ../inputs/uslin.107     > ../originals/t3063
echo ">>>>>>>>running test 3064"
../source/print_tokens2.exe ../inputs/uslin.1071     > ../originals/t3064
echo ">>>>>>>>running test 3065"
../source/print_tokens2.exe ../inputs/uslin.1074     > ../originals/t3065
echo ">>>>>>>>running test 3066"
../source/print_tokens2.exe ../inputs/uslin.1075     > ../originals/t3066
echo ">>>>>>>>running test 3067"
../source/print_tokens2.exe ../inputs/uslin.1076     > ../originals/t3067
echo ">>>>>>>>running test 3068"
../source/print_tokens2.exe ../inputs/uslin.1077     > ../originals/t3068
echo ">>>>>>>>running test 3069"
../source/print_tokens2.exe ../inputs/uslin.1078     > ../originals/t3069
echo ">>>>>>>>running test 3070"
../source/print_tokens2.exe ../inputs/uslin.1080     > ../originals/t3070
echo ">>>>>>>>running test 3071"
../source/print_tokens2.exe ../inputs/uslin.1082     > ../originals/t3071
echo ">>>>>>>>running test 3072"
../source/print_tokens2.exe ../inputs/uslin.1084     > ../originals/t3072
echo ">>>>>>>>running test 3073"
../source/print_tokens2.exe ../inputs/uslin.1085     > ../originals/t3073
echo ">>>>>>>>running test 3074"
../source/print_tokens2.exe ../inputs/uslin.109     > ../originals/t3074
echo ">>>>>>>>running test 3075"
../source/print_tokens2.exe ../inputs/uslin.1091     > ../originals/t3075
echo ">>>>>>>>running test 3076"
../source/print_tokens2.exe ../inputs/uslin.1092     > ../originals/t3076
echo ">>>>>>>>running test 3077"
../source/print_tokens2.exe ../inputs/uslin.1093     > ../originals/t3077
echo ">>>>>>>>running test 3078"
../source/print_tokens2.exe ../inputs/uslin.1094     > ../originals/t3078
echo ">>>>>>>>running test 3079"
../source/print_tokens2.exe ../inputs/uslin.1095     > ../originals/t3079
echo ">>>>>>>>running test 3080"
../source/print_tokens2.exe ../inputs/uslin.1096     > ../originals/t3080
echo ">>>>>>>>running test 3081"
../source/print_tokens2.exe ../inputs/uslin.1101     > ../originals/t3081
echo ">>>>>>>>running test 3082"
../source/print_tokens2.exe ../inputs/uslin.1103     > ../originals/t3082
echo ">>>>>>>>running test 3083"
../source/print_tokens2.exe ../inputs/uslin.1105     > ../originals/t3083
echo ">>>>>>>>running test 3084"
../source/print_tokens2.exe ../inputs/uslin.1109      > ../originals/t3084
echo ">>>>>>>>running test 3085"
../source/print_tokens2.exe ../inputs/uslin.111     > ../originals/t3085
echo ">>>>>>>>running test 3086"
../source/print_tokens2.exe ../inputs/uslin.1112     > ../originals/t3086
echo ">>>>>>>>running test 3087"
../source/print_tokens2.exe ../inputs/uslin.1113     > ../originals/t3087
echo ">>>>>>>>running test 3088"
../source/print_tokens2.exe ../inputs/uslin.1114     > ../originals/t3088
echo ">>>>>>>>running test 3089"
../source/print_tokens2.exe ../inputs/uslin.1115     > ../originals/t3089
echo ">>>>>>>>running test 3090"
../source/print_tokens2.exe ../inputs/uslin.1119     > ../originals/t3090
echo ">>>>>>>>running test 3091"
../source/print_tokens2.exe ../inputs/uslin.1120     > ../originals/t3091
echo ">>>>>>>>running test 3092"
../source/print_tokens2.exe ../inputs/uslin.1121     > ../originals/t3092
echo ">>>>>>>>running test 3093"
../source/print_tokens2.exe ../inputs/uslin.1124      > ../originals/t3093
echo ">>>>>>>>running test 3094"
../source/print_tokens2.exe ../inputs/uslin.1125     > ../originals/t3094
echo ">>>>>>>>running test 3095"
../source/print_tokens2.exe ../inputs/uslin.1126     > ../originals/t3095
echo ">>>>>>>>running test 3096"
../source/print_tokens2.exe ../inputs/uslin.1127     > ../originals/t3096
echo ">>>>>>>>running test 3097"
../source/print_tokens2.exe ../inputs/uslin.1130     > ../originals/t3097
echo ">>>>>>>>running test 3098"
../source/print_tokens2.exe ../inputs/uslin.1139     > ../originals/t3098
echo ">>>>>>>>running test 3099"
../source/print_tokens2.exe ../inputs/uslin.114     > ../originals/t3099
echo ">>>>>>>>running test 3100"
../source/print_tokens2.exe ../inputs/uslin.1140     > ../originals/t3100
echo ">>>>>>>>running test 3101"
../source/print_tokens2.exe ../inputs/uslin.1141     > ../originals/t3101
echo ">>>>>>>>running test 3102"
../source/print_tokens2.exe ../inputs/uslin.1142     > ../originals/t3102
echo ">>>>>>>>running test 3103"
../source/print_tokens2.exe ../inputs/uslin.1144     > ../originals/t3103
echo ">>>>>>>>running test 3104"
../source/print_tokens2.exe ../inputs/uslin.115     > ../originals/t3104
echo ">>>>>>>>running test 3105"
../source/print_tokens2.exe ../inputs/uslin.1155     > ../originals/t3105
echo ">>>>>>>>running test 3106"
../source/print_tokens2.exe ../inputs/uslin.1156      > ../originals/t3106
echo ">>>>>>>>running test 3107"
../source/print_tokens2.exe ../inputs/uslin.1159     > ../originals/t3107
echo ">>>>>>>>running test 3108"
../source/print_tokens2.exe ../inputs/uslin.1160     > ../originals/t3108
echo ">>>>>>>>running test 3109"
../source/print_tokens2.exe ../inputs/uslin.1162     > ../originals/t3109
echo ">>>>>>>>running test 3110"
../source/print_tokens2.exe ../inputs/uslin.1163     > ../originals/t3110
echo ">>>>>>>>running test 3111"
../source/print_tokens2.exe ../inputs/uslin.1165     > ../originals/t3111
echo ">>>>>>>>running test 3112"
../source/print_tokens2.exe ../inputs/uslin.1166     > ../originals/t3112
echo ">>>>>>>>running test 3113"
../source/print_tokens2.exe ../inputs/uslin.1167     > ../originals/t3113
echo ">>>>>>>>running test 3114"
../source/print_tokens2.exe ../inputs/uslin.117     > ../originals/t3114
echo ">>>>>>>>running test 3115"
../source/print_tokens2.exe ../inputs/uslin.1173     > ../originals/t3115
echo ">>>>>>>>running test 3116"
../source/print_tokens2.exe ../inputs/uslin.1174     > ../originals/t3116
echo ">>>>>>>>running test 3117"
../source/print_tokens2.exe ../inputs/uslin.1179     > ../originals/t3117
echo ">>>>>>>>running test 3118"
../source/print_tokens2.exe ../inputs/uslin.1180     > ../originals/t3118
echo ">>>>>>>>running test 3119"
../source/print_tokens2.exe ../inputs/uslin.1182     > ../originals/t3119
echo ">>>>>>>>running test 3120"
../source/print_tokens2.exe ../inputs/uslin.1184     > ../originals/t3120
echo ">>>>>>>>running test 3121"
../source/print_tokens2.exe ../inputs/uslin.1185     > ../originals/t3121
echo ">>>>>>>>running test 3122"
../source/print_tokens2.exe ../inputs/uslin.1186     > ../originals/t3122
echo ">>>>>>>>running test 3123"
../source/print_tokens2.exe ../inputs/uslin.1187     > ../originals/t3123
echo ">>>>>>>>running test 3124"
../source/print_tokens2.exe ../inputs/uslin.1189     > ../originals/t3124
echo ">>>>>>>>running test 3125"
../source/print_tokens2.exe ../inputs/uslin.119     > ../originals/t3125
echo ">>>>>>>>running test 3126"
../source/print_tokens2.exe ../inputs/uslin.1191     > ../originals/t3126
echo ">>>>>>>>running test 3127"
../source/print_tokens2.exe ../inputs/uslin.1192     > ../originals/t3127
echo ">>>>>>>>running test 3128"
../source/print_tokens2.exe ../inputs/uslin.1193     > ../originals/t3128
echo ">>>>>>>>running test 3129"
../source/print_tokens2.exe ../inputs/uslin.1196     > ../originals/t3129
echo ">>>>>>>>running test 3130"
../source/print_tokens2.exe ../inputs/uslin.1198     > ../originals/t3130
echo ">>>>>>>>running test 3131"
../source/print_tokens2.exe ../inputs/uslin.1200     > ../originals/t3131
echo ">>>>>>>>running test 3132"
../source/print_tokens2.exe ../inputs/uslin.1202     > ../originals/t3132
echo ">>>>>>>>running test 3133"
../source/print_tokens2.exe ../inputs/uslin.1206     > ../originals/t3133
echo ">>>>>>>>running test 3134"
../source/print_tokens2.exe ../inputs/uslin.1207     > ../originals/t3134
echo ">>>>>>>>running test 3135"
../source/print_tokens2.exe ../inputs/uslin.1209     > ../originals/t3135
echo ">>>>>>>>running test 3136"
../source/print_tokens2.exe ../inputs/uslin.121     > ../originals/t3136
echo ">>>>>>>>running test 3137"
../source/print_tokens2.exe ../inputs/uslin.1212     > ../originals/t3137
echo ">>>>>>>>running test 3138"
../source/print_tokens2.exe ../inputs/uslin.1217     > ../originals/t3138
echo ">>>>>>>>running test 3139"
../source/print_tokens2.exe ../inputs/uslin.1219     > ../originals/t3139
echo ">>>>>>>>running test 3140"
../source/print_tokens2.exe ../inputs/uslin.1224     > ../originals/t3140
echo ">>>>>>>>running test 3141"
../source/print_tokens2.exe ../inputs/uslin.1226     > ../originals/t3141
echo ">>>>>>>>running test 3142"
../source/print_tokens2.exe ../inputs/uslin.1233     > ../originals/t3142
echo ">>>>>>>>running test 3143"
../source/print_tokens2.exe ../inputs/uslin.1234     > ../originals/t3143
echo ">>>>>>>>running test 3144"
../source/print_tokens2.exe ../inputs/uslin.1235     > ../originals/t3144
echo ">>>>>>>>running test 3145"
../source/print_tokens2.exe ../inputs/uslin.1237     > ../originals/t3145
echo ">>>>>>>>running test 3146"
../source/print_tokens2.exe ../inputs/uslin.1239     > ../originals/t3146
echo ">>>>>>>>running test 3147"
../source/print_tokens2.exe ../inputs/uslin.1241     > ../originals/t3147
echo ">>>>>>>>running test 3148"
../source/print_tokens2.exe ../inputs/uslin.1243     > ../originals/t3148
echo ">>>>>>>>running test 3149"
../source/print_tokens2.exe ../inputs/uslin.1245     > ../originals/t3149
echo ">>>>>>>>running test 3150"
../source/print_tokens2.exe ../inputs/uslin.1246     > ../originals/t3150
echo ">>>>>>>>running test 3151"
../source/print_tokens2.exe ../inputs/uslin.125     > ../originals/t3151
echo ">>>>>>>>running test 3152"
../source/print_tokens2.exe ../inputs/uslin.1250     > ../originals/t3152
echo ">>>>>>>>running test 3153"
../source/print_tokens2.exe ../inputs/uslin.1252     > ../originals/t3153
echo ">>>>>>>>running test 3154"
../source/print_tokens2.exe ../inputs/uslin.1253     > ../originals/t3154
echo ">>>>>>>>running test 3155"
../source/print_tokens2.exe ../inputs/uslin.1255      > ../originals/t3155
echo ">>>>>>>>running test 3156"
../source/print_tokens2.exe ../inputs/uslin.1256     > ../originals/t3156
echo ">>>>>>>>running test 3157"
../source/print_tokens2.exe ../inputs/uslin.1258     > ../originals/t3157
echo ">>>>>>>>running test 3158"
../source/print_tokens2.exe ../inputs/uslin.126     > ../originals/t3158
echo ">>>>>>>>running test 3159"
../source/print_tokens2.exe ../inputs/uslin.1260      > ../originals/t3159
echo ">>>>>>>>running test 3160"
../source/print_tokens2.exe ../inputs/uslin.1264     > ../originals/t3160
echo ">>>>>>>>running test 3161"
../source/print_tokens2.exe ../inputs/uslin.1265     > ../originals/t3161
echo ">>>>>>>>running test 3162"
../source/print_tokens2.exe ../inputs/uslin.1266     > ../originals/t3162
echo ">>>>>>>>running test 3163"
../source/print_tokens2.exe ../inputs/uslin.1267     > ../originals/t3163
echo ">>>>>>>>running test 3164"
../source/print_tokens2.exe ../inputs/uslin.1268     > ../originals/t3164
echo ">>>>>>>>running test 3165"
../source/print_tokens2.exe ../inputs/uslin.127     > ../originals/t3165
echo ">>>>>>>>running test 3166"
../source/print_tokens2.exe ../inputs/uslin.1270     > ../originals/t3166
echo ">>>>>>>>running test 3167"
../source/print_tokens2.exe ../inputs/uslin.1272     > ../originals/t3167
echo ">>>>>>>>running test 3168"
../source/print_tokens2.exe ../inputs/uslin.1276     > ../originals/t3168
echo ">>>>>>>>running test 3169"
../source/print_tokens2.exe ../inputs/uslin.1278     > ../originals/t3169
echo ">>>>>>>>running test 3170"
../source/print_tokens2.exe ../inputs/uslin.128     > ../originals/t3170
echo ">>>>>>>>running test 3171"
../source/print_tokens2.exe ../inputs/uslin.1281     > ../originals/t3171
echo ">>>>>>>>running test 3172"
../source/print_tokens2.exe ../inputs/uslin.1283     > ../originals/t3172
echo ">>>>>>>>running test 3173"
../source/print_tokens2.exe ../inputs/uslin.1287     > ../originals/t3173
echo ">>>>>>>>running test 3174"
../source/print_tokens2.exe ../inputs/uslin.1289     > ../originals/t3174
echo ">>>>>>>>running test 3175"
../source/print_tokens2.exe ../inputs/uslin.129     > ../originals/t3175
echo ">>>>>>>>running test 3176"
../source/print_tokens2.exe ../inputs/uslin.1290     > ../originals/t3176
echo ">>>>>>>>running test 3177"
../source/print_tokens2.exe ../inputs/uslin.1291     > ../originals/t3177
echo ">>>>>>>>running test 3178"
../source/print_tokens2.exe ../inputs/uslin.1292     > ../originals/t3178
echo ">>>>>>>>running test 3179"
../source/print_tokens2.exe ../inputs/uslin.1294     > ../originals/t3179
echo ">>>>>>>>running test 3180"
../source/print_tokens2.exe ../inputs/uslin.1298     > ../originals/t3180
echo ">>>>>>>>running test 3181"
../source/print_tokens2.exe ../inputs/uslin.1302     > ../originals/t3181
echo ">>>>>>>>running test 3182"
../source/print_tokens2.exe ../inputs/uslin.1303     > ../originals/t3182
echo ">>>>>>>>running test 3183"
../source/print_tokens2.exe ../inputs/uslin.1305     > ../originals/t3183
echo ">>>>>>>>running test 3184"
../source/print_tokens2.exe ../inputs/uslin.1306     > ../originals/t3184
echo ">>>>>>>>running test 3185"
../source/print_tokens2.exe ../inputs/uslin.131     > ../originals/t3185
echo ">>>>>>>>running test 3186"
../source/print_tokens2.exe ../inputs/uslin.1316     > ../originals/t3186
echo ">>>>>>>>running test 3187"
../source/print_tokens2.exe ../inputs/uslin.1317     > ../originals/t3187
echo ">>>>>>>>running test 3188"
../source/print_tokens2.exe ../inputs/uslin.132     > ../originals/t3188
echo ">>>>>>>>running test 3189"
../source/print_tokens2.exe ../inputs/uslin.1321     > ../originals/t3189
echo ">>>>>>>>running test 3190"
../source/print_tokens2.exe ../inputs/uslin.1322     > ../originals/t3190
echo ">>>>>>>>running test 3191"
../source/print_tokens2.exe ../inputs/uslin.1324     > ../originals/t3191
echo ">>>>>>>>running test 3192"
../source/print_tokens2.exe ../inputs/uslin.1325     > ../originals/t3192
echo ">>>>>>>>running test 3193"
../source/print_tokens2.exe ../inputs/uslin.1327     > ../originals/t3193
echo ">>>>>>>>running test 3194"
../source/print_tokens2.exe ../inputs/uslin.1328     > ../originals/t3194
echo ">>>>>>>>running test 3195"
../source/print_tokens2.exe ../inputs/uslin.1330     > ../originals/t3195
echo ">>>>>>>>running test 3196"
../source/print_tokens2.exe ../inputs/uslin.1333     > ../originals/t3196
echo ">>>>>>>>running test 3197"
../source/print_tokens2.exe ../inputs/uslin.1334     > ../originals/t3197
echo ">>>>>>>>running test 3198"
../source/print_tokens2.exe ../inputs/uslin.1335     > ../originals/t3198
echo ">>>>>>>>running test 3199"
../source/print_tokens2.exe ../inputs/uslin.1337     > ../originals/t3199
echo ">>>>>>>>running test 3200"
../source/print_tokens2.exe ../inputs/uslin.1339     > ../originals/t3200
echo ">>>>>>>>running test 3201"
../source/print_tokens2.exe ../inputs/uslin.134     > ../originals/t3201
echo ">>>>>>>>running test 3202"
../source/print_tokens2.exe ../inputs/uslin.1340     > ../originals/t3202
echo ">>>>>>>>running test 3203"
../source/print_tokens2.exe ../inputs/uslin.1341     > ../originals/t3203
echo ">>>>>>>>running test 3204"
../source/print_tokens2.exe ../inputs/uslin.1342     > ../originals/t3204
echo ">>>>>>>>running test 3205"
../source/print_tokens2.exe ../inputs/uslin.1346     > ../originals/t3205
echo ">>>>>>>>running test 3206"
../source/print_tokens2.exe ../inputs/uslin.1348     > ../originals/t3206
echo ">>>>>>>>running test 3207"
../source/print_tokens2.exe ../inputs/uslin.1352     > ../originals/t3207
echo ">>>>>>>>running test 3208"
../source/print_tokens2.exe ../inputs/uslin.1353     > ../originals/t3208
echo ">>>>>>>>running test 3209"
../source/print_tokens2.exe ../inputs/uslin.1354     > ../originals/t3209
echo ">>>>>>>>running test 3210"
../source/print_tokens2.exe ../inputs/uslin.1358     > ../originals/t3210
echo ">>>>>>>>running test 3211"
../source/print_tokens2.exe ../inputs/uslin.1359     > ../originals/t3211
echo ">>>>>>>>running test 3212"
../source/print_tokens2.exe ../inputs/uslin.1364     > ../originals/t3212
echo ">>>>>>>>running test 3213"
../source/print_tokens2.exe ../inputs/uslin.1368     > ../originals/t3213
echo ">>>>>>>>running test 3214"
../source/print_tokens2.exe ../inputs/uslin.137     > ../originals/t3214
echo ">>>>>>>>running test 3215"
../source/print_tokens2.exe ../inputs/uslin.1370     > ../originals/t3215
echo ">>>>>>>>running test 3216"
../source/print_tokens2.exe ../inputs/uslin.1371     > ../originals/t3216
echo ">>>>>>>>running test 3217"
../source/print_tokens2.exe ../inputs/uslin.1373     > ../originals/t3217
echo ">>>>>>>>running test 3218"
../source/print_tokens2.exe ../inputs/uslin.1374     > ../originals/t3218
echo ">>>>>>>>running test 3219"
../source/print_tokens2.exe ../inputs/uslin.1375     > ../originals/t3219
echo ">>>>>>>>running test 3220"
../source/print_tokens2.exe ../inputs/uslin.1376     > ../originals/t3220
echo ">>>>>>>>running test 3221"
../source/print_tokens2.exe ../inputs/uslin.1378     > ../originals/t3221
echo ">>>>>>>>running test 3222"
../source/print_tokens2.exe ../inputs/uslin.1379     > ../originals/t3222
echo ">>>>>>>>running test 3223"
../source/print_tokens2.exe ../inputs/uslin.138     > ../originals/t3223
echo ">>>>>>>>running test 3224"
../source/print_tokens2.exe ../inputs/uslin.1380     > ../originals/t3224
echo ">>>>>>>>running test 3225"
../source/print_tokens2.exe ../inputs/uslin.1384     > ../originals/t3225
echo ">>>>>>>>running test 3226"
../source/print_tokens2.exe ../inputs/uslin.1385     > ../originals/t3226
echo ">>>>>>>>running test 3227"
../source/print_tokens2.exe ../inputs/uslin.1386     > ../originals/t3227
echo ">>>>>>>>running test 3228"
../source/print_tokens2.exe ../inputs/uslin.1389     > ../originals/t3228
echo ">>>>>>>>running test 3229"
../source/print_tokens2.exe ../inputs/uslin.139     > ../originals/t3229
echo ">>>>>>>>running test 3230"
../source/print_tokens2.exe ../inputs/uslin.1390     > ../originals/t3230
echo ">>>>>>>>running test 3231"
../source/print_tokens2.exe ../inputs/uslin.1391     > ../originals/t3231
echo ">>>>>>>>running test 3232"
../source/print_tokens2.exe ../inputs/uslin.1394     > ../originals/t3232
echo ">>>>>>>>running test 3233"
../source/print_tokens2.exe ../inputs/uslin.1395     > ../originals/t3233
echo ">>>>>>>>running test 3234"
../source/print_tokens2.exe ../inputs/uslin.1398     > ../originals/t3234
echo ">>>>>>>>running test 3235"
../source/print_tokens2.exe ../inputs/uslin.1399     > ../originals/t3235
echo ">>>>>>>>running test 3236"
../source/print_tokens2.exe ../inputs/uslin.14     > ../originals/t3236
echo ">>>>>>>>running test 3237"
../source/print_tokens2.exe ../inputs/uslin.1401     > ../originals/t3237
echo ">>>>>>>>running test 3238"
../source/print_tokens2.exe ../inputs/uslin.1402     > ../originals/t3238
echo ">>>>>>>>running test 3239"
../source/print_tokens2.exe ../inputs/uslin.1406     > ../originals/t3239
echo ">>>>>>>>running test 3240"
../source/print_tokens2.exe ../inputs/uslin.1407     > ../originals/t3240
echo ">>>>>>>>running test 3241"
../source/print_tokens2.exe ../inputs/uslin.141     > ../originals/t3241
echo ">>>>>>>>running test 3242"
../source/print_tokens2.exe ../inputs/uslin.1411     > ../originals/t3242
echo ">>>>>>>>running test 3243"
../source/print_tokens2.exe ../inputs/uslin.1412     > ../originals/t3243
echo ">>>>>>>>running test 3244"
../source/print_tokens2.exe ../inputs/uslin.1414     > ../originals/t3244
echo ">>>>>>>>running test 3245"
../source/print_tokens2.exe ../inputs/uslin.1416     > ../originals/t3245
echo ">>>>>>>>running test 3246"
../source/print_tokens2.exe ../inputs/uslin.1417     > ../originals/t3246
echo ">>>>>>>>running test 3247"
../source/print_tokens2.exe ../inputs/uslin.1418      > ../originals/t3247
echo ">>>>>>>>running test 3248"
../source/print_tokens2.exe ../inputs/uslin.1419     > ../originals/t3248
echo ">>>>>>>>running test 3249"
../source/print_tokens2.exe ../inputs/uslin.1422     > ../originals/t3249
echo ">>>>>>>>running test 3250"
../source/print_tokens2.exe ../inputs/uslin.1423     > ../originals/t3250
echo ">>>>>>>>running test 3251"
../source/print_tokens2.exe ../inputs/uslin.1426     > ../originals/t3251
echo ">>>>>>>>running test 3252"
../source/print_tokens2.exe ../inputs/uslin.1427     > ../originals/t3252
echo ">>>>>>>>running test 3253"
../source/print_tokens2.exe ../inputs/uslin.1428     > ../originals/t3253
echo ">>>>>>>>running test 3254"
../source/print_tokens2.exe ../inputs/uslin.1431     > ../originals/t3254
echo ">>>>>>>>running test 3255"
../source/print_tokens2.exe ../inputs/uslin.1432     > ../originals/t3255
echo ">>>>>>>>running test 3256"
../source/print_tokens2.exe ../inputs/uslin.1433     > ../originals/t3256
echo ">>>>>>>>running test 3257"
../source/print_tokens2.exe ../inputs/uslin.1434     > ../originals/t3257
echo ">>>>>>>>running test 3258"
../source/print_tokens2.exe ../inputs/uslin.1435     > ../originals/t3258
echo ">>>>>>>>running test 3259"
../source/print_tokens2.exe ../inputs/uslin.1436     > ../originals/t3259
echo ">>>>>>>>running test 3260"
../source/print_tokens2.exe ../inputs/uslin.144     > ../originals/t3260
echo ">>>>>>>>running test 3261"
../source/print_tokens2.exe ../inputs/uslin.1440     > ../originals/t3261
echo ">>>>>>>>running test 3262"
../source/print_tokens2.exe ../inputs/uslin.1444     > ../originals/t3262
echo ">>>>>>>>running test 3263"
../source/print_tokens2.exe ../inputs/uslin.1446     > ../originals/t3263
echo ">>>>>>>>running test 3264"
../source/print_tokens2.exe ../inputs/uslin.1447     > ../originals/t3264
echo ">>>>>>>>running test 3265"
../source/print_tokens2.exe ../inputs/uslin.1448     > ../originals/t3265
echo ">>>>>>>>running test 3266"
../source/print_tokens2.exe ../inputs/uslin.1449     > ../originals/t3266
echo ">>>>>>>>running test 3267"
../source/print_tokens2.exe ../inputs/uslin.1450     > ../originals/t3267
echo ">>>>>>>>running test 3268"
../source/print_tokens2.exe ../inputs/uslin.1451     > ../originals/t3268
echo ">>>>>>>>running test 3269"
../source/print_tokens2.exe ../inputs/uslin.1452     > ../originals/t3269
echo ">>>>>>>>running test 3270"
../source/print_tokens2.exe ../inputs/uslin.1453     > ../originals/t3270
echo ">>>>>>>>running test 3271"
../source/print_tokens2.exe ../inputs/uslin.1454     > ../originals/t3271
echo ">>>>>>>>running test 3272"
../source/print_tokens2.exe ../inputs/uslin.1456     > ../originals/t3272
echo ">>>>>>>>running test 3273"
../source/print_tokens2.exe ../inputs/uslin.1458     > ../originals/t3273
echo ">>>>>>>>running test 3274"
../source/print_tokens2.exe ../inputs/uslin.146     > ../originals/t3274
echo ">>>>>>>>running test 3275"
../source/print_tokens2.exe ../inputs/uslin.1460     > ../originals/t3275
echo ">>>>>>>>running test 3276"
../source/print_tokens2.exe ../inputs/uslin.1462     > ../originals/t3276
echo ">>>>>>>>running test 3277"
../source/print_tokens2.exe ../inputs/uslin.1463     > ../originals/t3277
echo ">>>>>>>>running test 3278"
../source/print_tokens2.exe ../inputs/uslin.1464     > ../originals/t3278
echo ">>>>>>>>running test 3279"
../source/print_tokens2.exe ../inputs/uslin.1465     > ../originals/t3279
echo ">>>>>>>>running test 3280"
../source/print_tokens2.exe ../inputs/uslin.1466     > ../originals/t3280
echo ">>>>>>>>running test 3281"
../source/print_tokens2.exe ../inputs/uslin.1467     > ../originals/t3281
echo ">>>>>>>>running test 3282"
../source/print_tokens2.exe ../inputs/uslin.1471     > ../originals/t3282
echo ">>>>>>>>running test 3283"
../source/print_tokens2.exe ../inputs/uslin.1472     > ../originals/t3283
echo ">>>>>>>>running test 3284"
../source/print_tokens2.exe ../inputs/uslin.1473     > ../originals/t3284
echo ">>>>>>>>running test 3285"
../source/print_tokens2.exe ../inputs/uslin.1474     > ../originals/t3285
echo ">>>>>>>>running test 3286"
../source/print_tokens2.exe ../inputs/uslin.1477     > ../originals/t3286
echo ">>>>>>>>running test 3287"
../source/print_tokens2.exe ../inputs/uslin.1478     > ../originals/t3287
echo ">>>>>>>>running test 3288"
../source/print_tokens2.exe ../inputs/uslin.1479     > ../originals/t3288
echo ">>>>>>>>running test 3289"
../source/print_tokens2.exe ../inputs/uslin.148     > ../originals/t3289
echo ">>>>>>>>running test 3290"
../source/print_tokens2.exe ../inputs/uslin.1481     > ../originals/t3290
echo ">>>>>>>>running test 3291"
../source/print_tokens2.exe ../inputs/uslin.1482     > ../originals/t3291
echo ">>>>>>>>running test 3292"
../source/print_tokens2.exe ../inputs/uslin.1484     > ../originals/t3292
echo ">>>>>>>>running test 3293"
../source/print_tokens2.exe ../inputs/uslin.1485     > ../originals/t3293
echo ">>>>>>>>running test 3294"
../source/print_tokens2.exe ../inputs/uslin.1487     > ../originals/t3294
echo ">>>>>>>>running test 3295"
../source/print_tokens2.exe ../inputs/uslin.1488     > ../originals/t3295
echo ">>>>>>>>running test 3296"
../source/print_tokens2.exe ../inputs/uslin.1489     > ../originals/t3296
echo ">>>>>>>>running test 3297"
../source/print_tokens2.exe ../inputs/uslin.149     > ../originals/t3297
echo ">>>>>>>>running test 3298"
../source/print_tokens2.exe ../inputs/uslin.1495     > ../originals/t3298
echo ">>>>>>>>running test 3299"
../source/print_tokens2.exe ../inputs/uslin.1498     > ../originals/t3299
echo ">>>>>>>>running test 3300"
../source/print_tokens2.exe ../inputs/uslin.1499     > ../originals/t3300
echo ">>>>>>>>running test 3301"
../source/print_tokens2.exe ../inputs/uslin.150     > ../originals/t3301
echo ">>>>>>>>running test 3302"
../source/print_tokens2.exe ../inputs/uslin.1500     > ../originals/t3302
echo ">>>>>>>>running test 3303"
../source/print_tokens2.exe ../inputs/uslin.1503     > ../originals/t3303
echo ">>>>>>>>running test 3304"
../source/print_tokens2.exe ../inputs/uslin.1505     > ../originals/t3304
echo ">>>>>>>>running test 3305"
../source/print_tokens2.exe ../inputs/uslin.1506     > ../originals/t3305
echo ">>>>>>>>running test 3306"
../source/print_tokens2.exe ../inputs/uslin.1507     > ../originals/t3306
echo ">>>>>>>>running test 3307"
../source/print_tokens2.exe ../inputs/uslin.1508     > ../originals/t3307
echo ">>>>>>>>running test 3308"
../source/print_tokens2.exe ../inputs/uslin.1511     > ../originals/t3308
echo ">>>>>>>>running test 3309"
../source/print_tokens2.exe ../inputs/uslin.1512     > ../originals/t3309
echo ">>>>>>>>running test 3310"
../source/print_tokens2.exe ../inputs/uslin.1513     > ../originals/t3310
echo ">>>>>>>>running test 3311"
../source/print_tokens2.exe ../inputs/uslin.1514     > ../originals/t3311
echo ">>>>>>>>running test 3312"
../source/print_tokens2.exe ../inputs/uslin.1515     > ../originals/t3312
echo ">>>>>>>>running test 3313"
../source/print_tokens2.exe ../inputs/uslin.152      > ../originals/t3313
echo ">>>>>>>>running test 3314"
../source/print_tokens2.exe ../inputs/uslin.1520     > ../originals/t3314
echo ">>>>>>>>running test 3315"
../source/print_tokens2.exe ../inputs/uslin.1521     > ../originals/t3315
echo ">>>>>>>>running test 3316"
../source/print_tokens2.exe ../inputs/uslin.1522      > ../originals/t3316
echo ">>>>>>>>running test 3317"
../source/print_tokens2.exe ../inputs/uslin.1523     > ../originals/t3317
echo ">>>>>>>>running test 3318"
../source/print_tokens2.exe ../inputs/uslin.1528     > ../originals/t3318
echo ">>>>>>>>running test 3319"
../source/print_tokens2.exe ../inputs/uslin.1531     > ../originals/t3319
echo ">>>>>>>>running test 3320"
../source/print_tokens2.exe ../inputs/uslin.1533     > ../originals/t3320
echo ">>>>>>>>running test 3321"
../source/print_tokens2.exe ../inputs/uslin.1535     > ../originals/t3321
echo ">>>>>>>>running test 3322"
../source/print_tokens2.exe ../inputs/uslin.1536     > ../originals/t3322
echo ">>>>>>>>running test 3323"
../source/print_tokens2.exe ../inputs/uslin.1537     > ../originals/t3323
echo ">>>>>>>>running test 3324"
../source/print_tokens2.exe ../inputs/uslin.1540     > ../originals/t3324
echo ">>>>>>>>running test 3325"
../source/print_tokens2.exe ../inputs/uslin.1543     > ../originals/t3325
echo ">>>>>>>>running test 3326"
../source/print_tokens2.exe ../inputs/uslin.1544     > ../originals/t3326
echo ">>>>>>>>running test 3327"
../source/print_tokens2.exe ../inputs/uslin.1545     > ../originals/t3327
echo ">>>>>>>>running test 3328"
../source/print_tokens2.exe ../inputs/uslin.1547      > ../originals/t3328
echo ">>>>>>>>running test 3329"
../source/print_tokens2.exe ../inputs/uslin.1548     > ../originals/t3329
echo ">>>>>>>>running test 3330"
../source/print_tokens2.exe ../inputs/uslin.1550     > ../originals/t3330
echo ">>>>>>>>running test 3331"
../source/print_tokens2.exe ../inputs/uslin.1552     > ../originals/t3331
echo ">>>>>>>>running test 3332"
../source/print_tokens2.exe ../inputs/uslin.1553     > ../originals/t3332
echo ">>>>>>>>running test 3333"
../source/print_tokens2.exe ../inputs/uslin.1555     > ../originals/t3333
echo ">>>>>>>>running test 3334"
../source/print_tokens2.exe ../inputs/uslin.1558     > ../originals/t3334
echo ">>>>>>>>running test 3335"
../source/print_tokens2.exe ../inputs/uslin.156     > ../originals/t3335
echo ">>>>>>>>running test 3336"
../source/print_tokens2.exe ../inputs/uslin.1560     > ../originals/t3336
echo ">>>>>>>>running test 3337"
../source/print_tokens2.exe ../inputs/uslin.1561     > ../originals/t3337
echo ">>>>>>>>running test 3338"
../source/print_tokens2.exe ../inputs/uslin.1564     > ../originals/t3338
echo ">>>>>>>>running test 3339"
../source/print_tokens2.exe ../inputs/uslin.1568     > ../originals/t3339
echo ">>>>>>>>running test 3340"
../source/print_tokens2.exe ../inputs/uslin.1571     > ../originals/t3340
echo ">>>>>>>>running test 3341"
../source/print_tokens2.exe ../inputs/uslin.1573     > ../originals/t3341
echo ">>>>>>>>running test 3342"
../source/print_tokens2.exe ../inputs/uslin.1574     > ../originals/t3342
echo ">>>>>>>>running test 3343"
../source/print_tokens2.exe ../inputs/uslin.1575      > ../originals/t3343
echo ">>>>>>>>running test 3344"
../source/print_tokens2.exe ../inputs/uslin.1577     > ../originals/t3344
echo ">>>>>>>>running test 3345"
../source/print_tokens2.exe ../inputs/uslin.158     > ../originals/t3345
echo ">>>>>>>>running test 3346"
../source/print_tokens2.exe ../inputs/uslin.1580     > ../originals/t3346
echo ">>>>>>>>running test 3347"
../source/print_tokens2.exe ../inputs/uslin.1581     > ../originals/t3347
echo ">>>>>>>>running test 3348"
../source/print_tokens2.exe ../inputs/uslin.1582     > ../originals/t3348
echo ">>>>>>>>running test 3349"
../source/print_tokens2.exe ../inputs/uslin.1583      > ../originals/t3349
echo ">>>>>>>>running test 3350"
../source/print_tokens2.exe ../inputs/uslin.1585     > ../originals/t3350
echo ">>>>>>>>running test 3351"
../source/print_tokens2.exe ../inputs/uslin.1586      > ../originals/t3351
echo ">>>>>>>>running test 3352"
../source/print_tokens2.exe ../inputs/uslin.159     > ../originals/t3352
echo ">>>>>>>>running test 3353"
../source/print_tokens2.exe ../inputs/uslin.1590     > ../originals/t3353
echo ">>>>>>>>running test 3354"
../source/print_tokens2.exe ../inputs/uslin.1591     > ../originals/t3354
echo ">>>>>>>>running test 3355"
../source/print_tokens2.exe ../inputs/uslin.1592     > ../originals/t3355
echo ">>>>>>>>running test 3356"
../source/print_tokens2.exe ../inputs/uslin.1594     > ../originals/t3356
echo ">>>>>>>>running test 3357"
../source/print_tokens2.exe ../inputs/uslin.1595      > ../originals/t3357
echo ">>>>>>>>running test 3358"
../source/print_tokens2.exe ../inputs/uslin.1597     > ../originals/t3358
echo ">>>>>>>>running test 3359"
../source/print_tokens2.exe ../inputs/uslin.1601     > ../originals/t3359
echo ">>>>>>>>running test 3360"
../source/print_tokens2.exe ../inputs/uslin.1602     > ../originals/t3360
echo ">>>>>>>>running test 3361"
../source/print_tokens2.exe ../inputs/uslin.1603     > ../originals/t3361
echo ">>>>>>>>running test 3362"
../source/print_tokens2.exe ../inputs/uslin.1606     > ../originals/t3362
echo ">>>>>>>>running test 3363"
../source/print_tokens2.exe ../inputs/uslin.1607     > ../originals/t3363
echo ">>>>>>>>running test 3364"
../source/print_tokens2.exe ../inputs/uslin.1608     > ../originals/t3364
echo ">>>>>>>>running test 3365"
../source/print_tokens2.exe ../inputs/uslin.1610      > ../originals/t3365
echo ">>>>>>>>running test 3366"
../source/print_tokens2.exe ../inputs/uslin.1614     > ../originals/t3366
echo ">>>>>>>>running test 3367"
../source/print_tokens2.exe ../inputs/uslin.1617     > ../originals/t3367
echo ">>>>>>>>running test 3368"
../source/print_tokens2.exe ../inputs/uslin.1618     > ../originals/t3368
echo ">>>>>>>>running test 3369"
../source/print_tokens2.exe ../inputs/uslin.1619     > ../originals/t3369
echo ">>>>>>>>running test 3370"
../source/print_tokens2.exe ../inputs/uslin.1620     > ../originals/t3370
echo ">>>>>>>>running test 3371"
../source/print_tokens2.exe ../inputs/uslin.1623     > ../originals/t3371
echo ">>>>>>>>running test 3372"
../source/print_tokens2.exe ../inputs/uslin.1624     > ../originals/t3372
echo ">>>>>>>>running test 3373"
../source/print_tokens2.exe ../inputs/uslin.1625     > ../originals/t3373
echo ">>>>>>>>running test 3374"
../source/print_tokens2.exe ../inputs/uslin.1626      > ../originals/t3374
echo ">>>>>>>>running test 3375"
../source/print_tokens2.exe ../inputs/uslin.1629     > ../originals/t3375
echo ">>>>>>>>running test 3376"
../source/print_tokens2.exe ../inputs/uslin.1630     > ../originals/t3376
echo ">>>>>>>>running test 3377"
../source/print_tokens2.exe ../inputs/uslin.1631     > ../originals/t3377
echo ">>>>>>>>running test 3378"
../source/print_tokens2.exe ../inputs/uslin.1632     > ../originals/t3378
echo ">>>>>>>>running test 3379"
../source/print_tokens2.exe ../inputs/uslin.1634     > ../originals/t3379
echo ">>>>>>>>running test 3380"
../source/print_tokens2.exe ../inputs/uslin.1635     > ../originals/t3380
echo ">>>>>>>>running test 3381"
../source/print_tokens2.exe ../inputs/uslin.1637     > ../originals/t3381
echo ">>>>>>>>running test 3382"
../source/print_tokens2.exe ../inputs/uslin.1638     > ../originals/t3382
echo ">>>>>>>>running test 3383"
../source/print_tokens2.exe ../inputs/uslin.1641     > ../originals/t3383
echo ">>>>>>>>running test 3384"
../source/print_tokens2.exe ../inputs/uslin.1644     > ../originals/t3384
echo ">>>>>>>>running test 3385"
../source/print_tokens2.exe ../inputs/uslin.1645     > ../originals/t3385
echo ">>>>>>>>running test 3386"
../source/print_tokens2.exe ../inputs/uslin.1646     > ../originals/t3386
echo ">>>>>>>>running test 3387"
../source/print_tokens2.exe ../inputs/uslin.165     > ../originals/t3387
echo ">>>>>>>>running test 3388"
../source/print_tokens2.exe ../inputs/uslin.1651     > ../originals/t3388
echo ">>>>>>>>running test 3389"
../source/print_tokens2.exe ../inputs/uslin.1652     > ../originals/t3389
echo ">>>>>>>>running test 3390"
../source/print_tokens2.exe ../inputs/uslin.1653     > ../originals/t3390
echo ">>>>>>>>running test 3391"
../source/print_tokens2.exe ../inputs/uslin.1654     > ../originals/t3391
echo ">>>>>>>>running test 3392"
../source/print_tokens2.exe ../inputs/uslin.1655     > ../originals/t3392
echo ">>>>>>>>running test 3393"
../source/print_tokens2.exe ../inputs/uslin.1656     > ../originals/t3393
echo ">>>>>>>>running test 3394"
../source/print_tokens2.exe ../inputs/uslin.1657     > ../originals/t3394
echo ">>>>>>>>running test 3395"
../source/print_tokens2.exe ../inputs/uslin.166     > ../originals/t3395
echo ">>>>>>>>running test 3396"
../source/print_tokens2.exe ../inputs/uslin.1661     > ../originals/t3396
echo ">>>>>>>>running test 3397"
../source/print_tokens2.exe ../inputs/uslin.1662     > ../originals/t3397
echo ">>>>>>>>running test 3398"
../source/print_tokens2.exe ../inputs/uslin.1663     > ../originals/t3398
echo ">>>>>>>>running test 3399"
../source/print_tokens2.exe ../inputs/uslin.1664     > ../originals/t3399
echo ">>>>>>>>running test 3400"
../source/print_tokens2.exe ../inputs/uslin.1665     > ../originals/t3400
echo ">>>>>>>>running test 3401"
../source/print_tokens2.exe ../inputs/uslin.167     > ../originals/t3401
echo ">>>>>>>>running test 3402"
../source/print_tokens2.exe ../inputs/uslin.1673     > ../originals/t3402
echo ">>>>>>>>running test 3403"
../source/print_tokens2.exe ../inputs/uslin.1674     > ../originals/t3403
echo ">>>>>>>>running test 3404"
../source/print_tokens2.exe ../inputs/uslin.1677      > ../originals/t3404
echo ">>>>>>>>running test 3405"
../source/print_tokens2.exe ../inputs/uslin.1678     > ../originals/t3405
echo ">>>>>>>>running test 3406"
../source/print_tokens2.exe ../inputs/uslin.168     > ../originals/t3406
echo ">>>>>>>>running test 3407"
../source/print_tokens2.exe ../inputs/uslin.1680     > ../originals/t3407
echo ">>>>>>>>running test 3408"
../source/print_tokens2.exe ../inputs/uslin.1682     > ../originals/t3408
echo ">>>>>>>>running test 3409"
../source/print_tokens2.exe ../inputs/uslin.1683     > ../originals/t3409
echo ">>>>>>>>running test 3410"
../source/print_tokens2.exe ../inputs/uslin.1684     > ../originals/t3410
echo ">>>>>>>>running test 3411"
../source/print_tokens2.exe ../inputs/uslin.1685     > ../originals/t3411
echo ">>>>>>>>running test 3412"
../source/print_tokens2.exe ../inputs/uslin.1687     > ../originals/t3412
echo ">>>>>>>>running test 3413"
../source/print_tokens2.exe ../inputs/uslin.1688     > ../originals/t3413
echo ">>>>>>>>running test 3414"
../source/print_tokens2.exe ../inputs/uslin.1689     > ../originals/t3414
echo ">>>>>>>>running test 3415"
../source/print_tokens2.exe ../inputs/uslin.1690     > ../originals/t3415
echo ">>>>>>>>running test 3416"
../source/print_tokens2.exe ../inputs/uslin.1692     > ../originals/t3416
echo ">>>>>>>>running test 3417"
../source/print_tokens2.exe ../inputs/uslin.1693     > ../originals/t3417
echo ">>>>>>>>running test 3418"
../source/print_tokens2.exe ../inputs/uslin.1696     > ../originals/t3418
echo ">>>>>>>>running test 3419"
../source/print_tokens2.exe ../inputs/uslin.1697     > ../originals/t3419
echo ">>>>>>>>running test 3420"
../source/print_tokens2.exe ../inputs/uslin.1699     > ../originals/t3420
echo ">>>>>>>>running test 3421"
../source/print_tokens2.exe ../inputs/uslin.1700     > ../originals/t3421
echo ">>>>>>>>running test 3422"
../source/print_tokens2.exe ../inputs/uslin.1701     > ../originals/t3422
echo ">>>>>>>>running test 3423"
../source/print_tokens2.exe ../inputs/uslin.1703     > ../originals/t3423
echo ">>>>>>>>running test 3424"
../source/print_tokens2.exe ../inputs/uslin.1704     > ../originals/t3424
echo ">>>>>>>>running test 3425"
../source/print_tokens2.exe ../inputs/uslin.1705     > ../originals/t3425
echo ">>>>>>>>running test 3426"
../source/print_tokens2.exe ../inputs/uslin.1706     > ../originals/t3426
echo ">>>>>>>>running test 3427"
../source/print_tokens2.exe ../inputs/uslin.1708     > ../originals/t3427
echo ">>>>>>>>running test 3428"
../source/print_tokens2.exe ../inputs/uslin.1709     > ../originals/t3428
echo ">>>>>>>>running test 3429"
../source/print_tokens2.exe ../inputs/uslin.1713     > ../originals/t3429
echo ">>>>>>>>running test 3430"
../source/print_tokens2.exe ../inputs/uslin.1714     > ../originals/t3430
echo ">>>>>>>>running test 3431"
../source/print_tokens2.exe ../inputs/uslin.1715     > ../originals/t3431
echo ">>>>>>>>running test 3432"
../source/print_tokens2.exe ../inputs/uslin.1717     > ../originals/t3432
echo ">>>>>>>>running test 3433"
../source/print_tokens2.exe ../inputs/uslin.1718     > ../originals/t3433
echo ">>>>>>>>running test 3434"
../source/print_tokens2.exe ../inputs/uslin.1719     > ../originals/t3434
echo ">>>>>>>>running test 3435"
../source/print_tokens2.exe ../inputs/uslin.172     > ../originals/t3435
echo ">>>>>>>>running test 3436"
../source/print_tokens2.exe ../inputs/uslin.1720     > ../originals/t3436
echo ">>>>>>>>running test 3437"
../source/print_tokens2.exe ../inputs/uslin.1721     > ../originals/t3437
echo ">>>>>>>>running test 3438"
../source/print_tokens2.exe ../inputs/uslin.1722     > ../originals/t3438
echo ">>>>>>>>running test 3439"
../source/print_tokens2.exe ../inputs/uslin.1723     > ../originals/t3439
echo ">>>>>>>>running test 3440"
../source/print_tokens2.exe ../inputs/uslin.1725     > ../originals/t3440
echo ">>>>>>>>running test 3441"
../source/print_tokens2.exe ../inputs/uslin.1726     > ../originals/t3441
echo ">>>>>>>>running test 3442"
../source/print_tokens2.exe ../inputs/uslin.1727     > ../originals/t3442
echo ">>>>>>>>running test 3443"
../source/print_tokens2.exe ../inputs/uslin.1729     > ../originals/t3443
echo ">>>>>>>>running test 3444"
../source/print_tokens2.exe ../inputs/uslin.173     > ../originals/t3444
echo ">>>>>>>>running test 3445"
../source/print_tokens2.exe ../inputs/uslin.1731     > ../originals/t3445
echo ">>>>>>>>running test 3446"
../source/print_tokens2.exe ../inputs/uslin.1732     > ../originals/t3446
echo ">>>>>>>>running test 3447"
../source/print_tokens2.exe ../inputs/uslin.1733     > ../originals/t3447
echo ">>>>>>>>running test 3448"
../source/print_tokens2.exe ../inputs/uslin.1734     > ../originals/t3448
echo ">>>>>>>>running test 3449"
../source/print_tokens2.exe ../inputs/uslin.1736     > ../originals/t3449
echo ">>>>>>>>running test 3450"
../source/print_tokens2.exe ../inputs/uslin.1739     > ../originals/t3450
echo ">>>>>>>>running test 3451"
../source/print_tokens2.exe ../inputs/uslin.174     > ../originals/t3451
echo ">>>>>>>>running test 3452"
../source/print_tokens2.exe ../inputs/uslin.1741     > ../originals/t3452
echo ">>>>>>>>running test 3453"
../source/print_tokens2.exe ../inputs/uslin.1743     > ../originals/t3453
echo ">>>>>>>>running test 3454"
../source/print_tokens2.exe ../inputs/uslin.1745     > ../originals/t3454
echo ">>>>>>>>running test 3455"
../source/print_tokens2.exe ../inputs/uslin.1746     > ../originals/t3455
echo ">>>>>>>>running test 3456"
../source/print_tokens2.exe ../inputs/uslin.1747     > ../originals/t3456
echo ">>>>>>>>running test 3457"
../source/print_tokens2.exe ../inputs/uslin.1748     > ../originals/t3457
echo ">>>>>>>>running test 3458"
../source/print_tokens2.exe ../inputs/uslin.1749     > ../originals/t3458
echo ">>>>>>>>running test 3459"
../source/print_tokens2.exe ../inputs/uslin.1750     > ../originals/t3459
echo ">>>>>>>>running test 3460"
../source/print_tokens2.exe ../inputs/uslin.1751     > ../originals/t3460
echo ">>>>>>>>running test 3461"
../source/print_tokens2.exe ../inputs/uslin.1757     > ../originals/t3461
echo ">>>>>>>>running test 3462"
../source/print_tokens2.exe ../inputs/uslin.1758     > ../originals/t3462
echo ">>>>>>>>running test 3463"
../source/print_tokens2.exe ../inputs/uslin.1759     > ../originals/t3463
echo ">>>>>>>>running test 3464"
../source/print_tokens2.exe ../inputs/uslin.1761     > ../originals/t3464
echo ">>>>>>>>running test 3465"
../source/print_tokens2.exe ../inputs/uslin.1763     > ../originals/t3465
echo ">>>>>>>>running test 3466"
../source/print_tokens2.exe ../inputs/uslin.1765     > ../originals/t3466
echo ">>>>>>>>running test 3467"
../source/print_tokens2.exe ../inputs/uslin.1766     > ../originals/t3467
echo ">>>>>>>>running test 3468"
../source/print_tokens2.exe ../inputs/uslin.1767     > ../originals/t3468
echo ">>>>>>>>running test 3469"
../source/print_tokens2.exe ../inputs/uslin.1768     > ../originals/t3469
echo ">>>>>>>>running test 3470"
../source/print_tokens2.exe ../inputs/uslin.1769     > ../originals/t3470
echo ">>>>>>>>running test 3471"
../source/print_tokens2.exe ../inputs/uslin.1770     > ../originals/t3471
echo ">>>>>>>>running test 3472"
../source/print_tokens2.exe ../inputs/uslin.1772     > ../originals/t3472
echo ">>>>>>>>running test 3473"
../source/print_tokens2.exe ../inputs/uslin.1775     > ../originals/t3473
echo ">>>>>>>>running test 3474"
../source/print_tokens2.exe ../inputs/uslin.1777     > ../originals/t3474
echo ">>>>>>>>running test 3475"
../source/print_tokens2.exe ../inputs/uslin.1779     > ../originals/t3475
echo ">>>>>>>>running test 3476"
../source/print_tokens2.exe ../inputs/uslin.178     > ../originals/t3476
echo ">>>>>>>>running test 3477"
../source/print_tokens2.exe ../inputs/uslin.1780     > ../originals/t3477
echo ">>>>>>>>running test 3478"
../source/print_tokens2.exe ../inputs/uslin.1781     > ../originals/t3478
echo ">>>>>>>>running test 3479"
../source/print_tokens2.exe ../inputs/uslin.1784     > ../originals/t3479
echo ">>>>>>>>running test 3480"
../source/print_tokens2.exe ../inputs/uslin.1786     > ../originals/t3480
echo ">>>>>>>>running test 3481"
../source/print_tokens2.exe ../inputs/uslin.1788      > ../originals/t3481
echo ">>>>>>>>running test 3482"
../source/print_tokens2.exe ../inputs/uslin.179     > ../originals/t3482
echo ">>>>>>>>running test 3483"
../source/print_tokens2.exe ../inputs/uslin.1790     > ../originals/t3483
echo ">>>>>>>>running test 3484"
../source/print_tokens2.exe ../inputs/uslin.1791     > ../originals/t3484
echo ">>>>>>>>running test 3485"
../source/print_tokens2.exe ../inputs/uslin.1795      > ../originals/t3485
echo ">>>>>>>>running test 3486"
../source/print_tokens2.exe ../inputs/uslin.1796     > ../originals/t3486
echo ">>>>>>>>running test 3487"
../source/print_tokens2.exe ../inputs/uslin.1797     > ../originals/t3487
echo ">>>>>>>>running test 3488"
../source/print_tokens2.exe ../inputs/uslin.1799     > ../originals/t3488
echo ">>>>>>>>running test 3489"
../source/print_tokens2.exe ../inputs/uslin.18     > ../originals/t3489
echo ">>>>>>>>running test 3490"
../source/print_tokens2.exe ../inputs/uslin.180     > ../originals/t3490
echo ">>>>>>>>running test 3491"
../source/print_tokens2.exe ../inputs/uslin.1801     > ../originals/t3491
echo ">>>>>>>>running test 3492"
../source/print_tokens2.exe ../inputs/uslin.1803     > ../originals/t3492
echo ">>>>>>>>running test 3493"
../source/print_tokens2.exe ../inputs/uslin.1804     > ../originals/t3493
echo ">>>>>>>>running test 3494"
../source/print_tokens2.exe ../inputs/uslin.1805     > ../originals/t3494
echo ">>>>>>>>running test 3495"
../source/print_tokens2.exe ../inputs/uslin.1807     > ../originals/t3495
echo ">>>>>>>>running test 3496"
../source/print_tokens2.exe ../inputs/uslin.1808     > ../originals/t3496
echo ">>>>>>>>running test 3497"
../source/print_tokens2.exe ../inputs/uslin.1810     > ../originals/t3497
echo ">>>>>>>>running test 3498"
../source/print_tokens2.exe ../inputs/uslin.1811     > ../originals/t3498
echo ">>>>>>>>running test 3499"
../source/print_tokens2.exe ../inputs/uslin.1813     > ../originals/t3499
echo ">>>>>>>>running test 3500"
../source/print_tokens2.exe ../inputs/uslin.1815     > ../originals/t3500
echo ">>>>>>>>running test 3501"
../source/print_tokens2.exe ../inputs/uslin.1817     > ../originals/t3501
echo ">>>>>>>>running test 3502"
../source/print_tokens2.exe ../inputs/uslin.1820     > ../originals/t3502
echo ">>>>>>>>running test 3503"
../source/print_tokens2.exe ../inputs/uslin.1822     > ../originals/t3503
echo ">>>>>>>>running test 3504"
../source/print_tokens2.exe ../inputs/uslin.1824     > ../originals/t3504
echo ">>>>>>>>running test 3505"
../source/print_tokens2.exe ../inputs/uslin.1825     > ../originals/t3505
echo ">>>>>>>>running test 3506"
../source/print_tokens2.exe ../inputs/uslin.1826     > ../originals/t3506
echo ">>>>>>>>running test 3507"
../source/print_tokens2.exe ../inputs/uslin.1828     > ../originals/t3507
echo ">>>>>>>>running test 3508"
../source/print_tokens2.exe ../inputs/uslin.183     > ../originals/t3508
echo ">>>>>>>>running test 3509"
../source/print_tokens2.exe ../inputs/uslin.1831     > ../originals/t3509
echo ">>>>>>>>running test 3510"
../source/print_tokens2.exe ../inputs/uslin.1833     > ../originals/t3510
echo ">>>>>>>>running test 3511"
../source/print_tokens2.exe ../inputs/uslin.1834     > ../originals/t3511
echo ">>>>>>>>running test 3512"
../source/print_tokens2.exe ../inputs/uslin.1840     > ../originals/t3512
echo ">>>>>>>>running test 3513"
../source/print_tokens2.exe ../inputs/uslin.1841     > ../originals/t3513
echo ">>>>>>>>running test 3514"
../source/print_tokens2.exe ../inputs/uslin.1842     > ../originals/t3514
echo ">>>>>>>>running test 3515"
../source/print_tokens2.exe ../inputs/uslin.1843     > ../originals/t3515
echo ">>>>>>>>running test 3516"
../source/print_tokens2.exe ../inputs/uslin.1844     > ../originals/t3516
echo ">>>>>>>>running test 3517"
../source/print_tokens2.exe ../inputs/uslin.1846     > ../originals/t3517
echo ">>>>>>>>running test 3518"
../source/print_tokens2.exe ../inputs/uslin.1849     > ../originals/t3518
echo ">>>>>>>>running test 3519"
../source/print_tokens2.exe ../inputs/uslin.1851     > ../originals/t3519
echo ">>>>>>>>running test 3520"
../source/print_tokens2.exe ../inputs/uslin.1852     > ../originals/t3520
echo ">>>>>>>>running test 3521"
../source/print_tokens2.exe ../inputs/uslin.1853      > ../originals/t3521
echo ">>>>>>>>running test 3522"
../source/print_tokens2.exe ../inputs/uslin.1854      > ../originals/t3522
echo ">>>>>>>>running test 3523"
../source/print_tokens2.exe ../inputs/uslin.1857     > ../originals/t3523
echo ">>>>>>>>running test 3524"
../source/print_tokens2.exe ../inputs/uslin.1857.noeof     > ../originals/t3524
echo ">>>>>>>>running test 3525"
../source/print_tokens2.exe ../inputs/uslin.1859     > ../originals/t3525
echo ">>>>>>>>running test 3526"
../source/print_tokens2.exe ../inputs/uslin.186     > ../originals/t3526
echo ">>>>>>>>running test 3527"
../source/print_tokens2.exe ../inputs/uslin.1860     > ../originals/t3527
echo ">>>>>>>>running test 3528"
../source/print_tokens2.exe ../inputs/uslin.1861     > ../originals/t3528
echo ">>>>>>>>running test 3529"
../source/print_tokens2.exe ../inputs/uslin.1864     > ../originals/t3529
echo ">>>>>>>>running test 3530"
../source/print_tokens2.exe ../inputs/uslin.1866     > ../originals/t3530
echo ">>>>>>>>running test 3531"
../source/print_tokens2.exe ../inputs/uslin.1867     > ../originals/t3531
echo ">>>>>>>>running test 3532"
../source/print_tokens2.exe ../inputs/uslin.1868     > ../originals/t3532
echo ">>>>>>>>running test 3533"
../source/print_tokens2.exe ../inputs/uslin.1869     > ../originals/t3533
echo ">>>>>>>>running test 3534"
../source/print_tokens2.exe ../inputs/uslin.187     > ../originals/t3534
echo ">>>>>>>>running test 3535"
../source/print_tokens2.exe ../inputs/uslin.1870     > ../originals/t3535
echo ">>>>>>>>running test 3536"
../source/print_tokens2.exe ../inputs/uslin.1875     > ../originals/t3536
echo ">>>>>>>>running test 3537"
../source/print_tokens2.exe ../inputs/uslin.1879     > ../originals/t3537
echo ">>>>>>>>running test 3538"
../source/print_tokens2.exe ../inputs/uslin.1883     > ../originals/t3538
echo ">>>>>>>>running test 3539"
../source/print_tokens2.exe ../inputs/uslin.1884     > ../originals/t3539
echo ">>>>>>>>running test 3540"
../source/print_tokens2.exe ../inputs/uslin.1888     > ../originals/t3540
echo ">>>>>>>>running test 3541"
../source/print_tokens2.exe ../inputs/uslin.1889     > ../originals/t3541
echo ">>>>>>>>running test 3542"
../source/print_tokens2.exe ../inputs/uslin.1890     > ../originals/t3542
echo ">>>>>>>>running test 3543"
../source/print_tokens2.exe ../inputs/uslin.1894     > ../originals/t3543
echo ">>>>>>>>running test 3544"
../source/print_tokens2.exe ../inputs/uslin.1899     > ../originals/t3544
echo ">>>>>>>>running test 3545"
../source/print_tokens2.exe ../inputs/uslin.19     > ../originals/t3545
echo ">>>>>>>>running test 3546"
../source/print_tokens2.exe ../inputs/uslin.1900     > ../originals/t3546
echo ">>>>>>>>running test 3547"
../source/print_tokens2.exe ../inputs/uslin.1901     > ../originals/t3547
echo ">>>>>>>>running test 3548"
../source/print_tokens2.exe ../inputs/uslin.1902     > ../originals/t3548
echo ">>>>>>>>running test 3549"
../source/print_tokens2.exe ../inputs/uslin.1904     > ../originals/t3549
echo ">>>>>>>>running test 3550"
../source/print_tokens2.exe ../inputs/uslin.1906     > ../originals/t3550
echo ">>>>>>>>running test 3551"
../source/print_tokens2.exe ../inputs/uslin.1909     > ../originals/t3551
echo ">>>>>>>>running test 3552"
../source/print_tokens2.exe ../inputs/uslin.1910     > ../originals/t3552
echo ">>>>>>>>running test 3553"
../source/print_tokens2.exe ../inputs/uslin.1911     > ../originals/t3553
echo ">>>>>>>>running test 3554"
../source/print_tokens2.exe ../inputs/uslin.1915     > ../originals/t3554
echo ">>>>>>>>running test 3555"
../source/print_tokens2.exe ../inputs/uslin.1919     > ../originals/t3555
echo ">>>>>>>>running test 3556"
../source/print_tokens2.exe ../inputs/uslin.192     > ../originals/t3556
echo ">>>>>>>>running test 3557"
../source/print_tokens2.exe ../inputs/uslin.1921     > ../originals/t3557
echo ">>>>>>>>running test 3558"
../source/print_tokens2.exe ../inputs/uslin.1923     > ../originals/t3558
echo ">>>>>>>>running test 3559"
../source/print_tokens2.exe ../inputs/uslin.1927     > ../originals/t3559
echo ">>>>>>>>running test 3560"
../source/print_tokens2.exe ../inputs/uslin.1928      > ../originals/t3560
echo ">>>>>>>>running test 3561"
../source/print_tokens2.exe ../inputs/uslin.1930     > ../originals/t3561
echo ">>>>>>>>running test 3562"
../source/print_tokens2.exe ../inputs/uslin.1939     > ../originals/t3562
echo ">>>>>>>>running test 3563"
../source/print_tokens2.exe ../inputs/uslin.194     > ../originals/t3563
echo ">>>>>>>>running test 3564"
../source/print_tokens2.exe ../inputs/uslin.1940     > ../originals/t3564
echo ">>>>>>>>running test 3565"
../source/print_tokens2.exe ../inputs/uslin.1941     > ../originals/t3565
echo ">>>>>>>>running test 3566"
../source/print_tokens2.exe ../inputs/uslin.1942     > ../originals/t3566
echo ">>>>>>>>running test 3567"
../source/print_tokens2.exe ../inputs/uslin.1943     > ../originals/t3567
echo ">>>>>>>>running test 3568"
../source/print_tokens2.exe ../inputs/uslin.1949     > ../originals/t3568
echo ">>>>>>>>running test 3569"
../source/print_tokens2.exe ../inputs/uslin.1951     > ../originals/t3569
echo ">>>>>>>>running test 3570"
../source/print_tokens2.exe ../inputs/uslin.1952     > ../originals/t3570
echo ">>>>>>>>running test 3571"
../source/print_tokens2.exe ../inputs/uslin.1953     > ../originals/t3571
echo ">>>>>>>>running test 3572"
../source/print_tokens2.exe ../inputs/uslin.1954     > ../originals/t3572
echo ">>>>>>>>running test 3573"
../source/print_tokens2.exe ../inputs/uslin.1956     > ../originals/t3573
echo ">>>>>>>>running test 3574"
../source/print_tokens2.exe ../inputs/uslin.1957     > ../originals/t3574
echo ">>>>>>>>running test 3575"
../source/print_tokens2.exe ../inputs/uslin.196     > ../originals/t3575
echo ">>>>>>>>running test 3576"
../source/print_tokens2.exe ../inputs/uslin.1960     > ../originals/t3576
echo ">>>>>>>>running test 3577"
../source/print_tokens2.exe ../inputs/uslin.1962     > ../originals/t3577
echo ">>>>>>>>running test 3578"
../source/print_tokens2.exe ../inputs/uslin.1963     > ../originals/t3578
echo ">>>>>>>>running test 3579"
../source/print_tokens2.exe ../inputs/uslin.1965     > ../originals/t3579
echo ">>>>>>>>running test 3580"
../source/print_tokens2.exe ../inputs/uslin.1966     > ../originals/t3580
echo ">>>>>>>>running test 3581"
../source/print_tokens2.exe ../inputs/uslin.1967     > ../originals/t3581
echo ">>>>>>>>running test 3582"
../source/print_tokens2.exe ../inputs/uslin.1968     > ../originals/t3582
echo ">>>>>>>>running test 3583"
../source/print_tokens2.exe ../inputs/uslin.1969     > ../originals/t3583
echo ">>>>>>>>running test 3584"
../source/print_tokens2.exe ../inputs/uslin.197      > ../originals/t3584
echo ">>>>>>>>running test 3585"
../source/print_tokens2.exe ../inputs/uslin.1973     > ../originals/t3585
echo ">>>>>>>>running test 3586"
../source/print_tokens2.exe ../inputs/uslin.1976     > ../originals/t3586
echo ">>>>>>>>running test 3587"
../source/print_tokens2.exe ../inputs/uslin.1977     > ../originals/t3587
echo ">>>>>>>>running test 3588"
../source/print_tokens2.exe ../inputs/uslin.1978     > ../originals/t3588
echo ">>>>>>>>running test 3589"
../source/print_tokens2.exe ../inputs/uslin.198     > ../originals/t3589
echo ">>>>>>>>running test 3590"
../source/print_tokens2.exe ../inputs/uslin.1980     > ../originals/t3590
echo ">>>>>>>>running test 3591"
../source/print_tokens2.exe ../inputs/uslin.1981     > ../originals/t3591
echo ">>>>>>>>running test 3592"
../source/print_tokens2.exe ../inputs/uslin.1982     > ../originals/t3592
echo ">>>>>>>>running test 3593"
../source/print_tokens2.exe ../inputs/uslin.1983     > ../originals/t3593
echo ">>>>>>>>running test 3594"
../source/print_tokens2.exe ../inputs/uslin.1984.noeof     > ../originals/t3594
echo ">>>>>>>>running test 3595"
../source/print_tokens2.exe ../inputs/uslin.1986     > ../originals/t3595
echo ">>>>>>>>running test 3596"
../source/print_tokens2.exe ../inputs/uslin.1987     > ../originals/t3596
echo ">>>>>>>>running test 3597"
../source/print_tokens2.exe ../inputs/uslin.199     > ../originals/t3597
echo ">>>>>>>>running test 3598"
../source/print_tokens2.exe ../inputs/uslin.1991     > ../originals/t3598
echo ">>>>>>>>running test 3599"
../source/print_tokens2.exe ../inputs/uslin.1992      > ../originals/t3599
echo ">>>>>>>>running test 3600"
../source/print_tokens2.exe ../inputs/uslin.1993     > ../originals/t3600
echo ">>>>>>>>running test 3601"
../source/print_tokens2.exe ../inputs/uslin.1994     > ../originals/t3601
echo ">>>>>>>>running test 3602"
../source/print_tokens2.exe ../inputs/uslin.1996     > ../originals/t3602
echo ">>>>>>>>running test 3603"
../source/print_tokens2.exe ../inputs/uslin.200     > ../originals/t3603
echo ">>>>>>>>running test 3604"
../source/print_tokens2.exe ../inputs/uslin.202     > ../originals/t3604
echo ">>>>>>>>running test 3605"
../source/print_tokens2.exe ../inputs/uslin.203     > ../originals/t3605
echo ">>>>>>>>running test 3606"
../source/print_tokens2.exe ../inputs/uslin.205     > ../originals/t3606
echo ">>>>>>>>running test 3607"
../source/print_tokens2.exe ../inputs/uslin.211     > ../originals/t3607
echo ">>>>>>>>running test 3608"
../source/print_tokens2.exe ../inputs/uslin.212     > ../originals/t3608
echo ">>>>>>>>running test 3609"
../source/print_tokens2.exe ../inputs/uslin.216     > ../originals/t3609
echo ">>>>>>>>running test 3610"
../source/print_tokens2.exe ../inputs/uslin.217     > ../originals/t3610
echo ">>>>>>>>running test 3611"
../source/print_tokens2.exe ../inputs/uslin.218     > ../originals/t3611
echo ">>>>>>>>running test 3612"
../source/print_tokens2.exe ../inputs/uslin.219     > ../originals/t3612
echo ">>>>>>>>running test 3613"
../source/print_tokens2.exe ../inputs/uslin.220     > ../originals/t3613
echo ">>>>>>>>running test 3614"
../source/print_tokens2.exe ../inputs/uslin.221     > ../originals/t3614
echo ">>>>>>>>running test 3615"
../source/print_tokens2.exe ../inputs/uslin.222     > ../originals/t3615
echo ">>>>>>>>running test 3616"
../source/print_tokens2.exe ../inputs/uslin.223     > ../originals/t3616
echo ">>>>>>>>running test 3617"
../source/print_tokens2.exe ../inputs/uslin.224     > ../originals/t3617
echo ">>>>>>>>running test 3618"
../source/print_tokens2.exe ../inputs/uslin.227     > ../originals/t3618
echo ">>>>>>>>running test 3619"
../source/print_tokens2.exe ../inputs/uslin.228     > ../originals/t3619
echo ">>>>>>>>running test 3620"
../source/print_tokens2.exe ../inputs/uslin.229     > ../originals/t3620
echo ">>>>>>>>running test 3621"
../source/print_tokens2.exe ../inputs/uslin.23     > ../originals/t3621
echo ">>>>>>>>running test 3622"
../source/print_tokens2.exe ../inputs/uslin.231     > ../originals/t3622
echo ">>>>>>>>running test 3623"
../source/print_tokens2.exe ../inputs/uslin.232     > ../originals/t3623
echo ">>>>>>>>running test 3624"
../source/print_tokens2.exe ../inputs/uslin.235     > ../originals/t3624
echo ">>>>>>>>running test 3625"
../source/print_tokens2.exe ../inputs/uslin.236     > ../originals/t3625
echo ">>>>>>>>running test 3626"
../source/print_tokens2.exe ../inputs/uslin.24     > ../originals/t3626
echo ">>>>>>>>running test 3627"
../source/print_tokens2.exe ../inputs/uslin.240     > ../originals/t3627
echo ">>>>>>>>running test 3628"
../source/print_tokens2.exe ../inputs/uslin.241     > ../originals/t3628
echo ">>>>>>>>running test 3629"
../source/print_tokens2.exe ../inputs/uslin.242     > ../originals/t3629
echo ">>>>>>>>running test 3630"
../source/print_tokens2.exe ../inputs/uslin.250     > ../originals/t3630
echo ">>>>>>>>running test 3631"
../source/print_tokens2.exe ../inputs/uslin.253     > ../originals/t3631
echo ">>>>>>>>running test 3632"
../source/print_tokens2.exe ../inputs/uslin.255     > ../originals/t3632
echo ">>>>>>>>running test 3633"
../source/print_tokens2.exe ../inputs/uslin.259     > ../originals/t3633
echo ">>>>>>>>running test 3634"
../source/print_tokens2.exe ../inputs/uslin.26     > ../originals/t3634
echo ">>>>>>>>running test 3635"
../source/print_tokens2.exe ../inputs/uslin.261     > ../originals/t3635
echo ">>>>>>>>running test 3636"
../source/print_tokens2.exe ../inputs/uslin.262     > ../originals/t3636
echo ">>>>>>>>running test 3637"
../source/print_tokens2.exe ../inputs/uslin.263     > ../originals/t3637
echo ">>>>>>>>running test 3638"
../source/print_tokens2.exe ../inputs/uslin.265      > ../originals/t3638
echo ">>>>>>>>running test 3639"
../source/print_tokens2.exe ../inputs/uslin.269     > ../originals/t3639
echo ">>>>>>>>running test 3640"
../source/print_tokens2.exe ../inputs/uslin.273     > ../originals/t3640
echo ">>>>>>>>running test 3641"
../source/print_tokens2.exe ../inputs/uslin.274     > ../originals/t3641
echo ">>>>>>>>running test 3642"
../source/print_tokens2.exe ../inputs/uslin.278     > ../originals/t3642
echo ">>>>>>>>running test 3643"
../source/print_tokens2.exe ../inputs/uslin.279     > ../originals/t3643
echo ">>>>>>>>running test 3644"
../source/print_tokens2.exe ../inputs/uslin.285     > ../originals/t3644
echo ">>>>>>>>running test 3645"
../source/print_tokens2.exe ../inputs/uslin.288     > ../originals/t3645
echo ">>>>>>>>running test 3646"
../source/print_tokens2.exe ../inputs/uslin.29     > ../originals/t3646
echo ">>>>>>>>running test 3647"
../source/print_tokens2.exe ../inputs/uslin.290     > ../originals/t3647
echo ">>>>>>>>running test 3648"
../source/print_tokens2.exe ../inputs/uslin.291     > ../originals/t3648
echo ">>>>>>>>running test 3649"
../source/print_tokens2.exe ../inputs/uslin.292     > ../originals/t3649
echo ">>>>>>>>running test 3650"
../source/print_tokens2.exe ../inputs/uslin.293     > ../originals/t3650
echo ">>>>>>>>running test 3651"
../source/print_tokens2.exe ../inputs/uslin.3      > ../originals/t3651
echo ">>>>>>>>running test 3652"
../source/print_tokens2.exe ../inputs/uslin.300     > ../originals/t3652
echo ">>>>>>>>running test 3653"
../source/print_tokens2.exe ../inputs/uslin.303      > ../originals/t3653
echo ">>>>>>>>running test 3654"
../source/print_tokens2.exe ../inputs/uslin.304     > ../originals/t3654
echo ">>>>>>>>running test 3655"
../source/print_tokens2.exe ../inputs/uslin.308      > ../originals/t3655
echo ">>>>>>>>running test 3656"
../source/print_tokens2.exe ../inputs/uslin.309     > ../originals/t3656
echo ">>>>>>>>running test 3657"
../source/print_tokens2.exe ../inputs/uslin.310     > ../originals/t3657
echo ">>>>>>>>running test 3658"
../source/print_tokens2.exe ../inputs/uslin.312     > ../originals/t3658
echo ">>>>>>>>running test 3659"
../source/print_tokens2.exe ../inputs/uslin.313     > ../originals/t3659
echo ">>>>>>>>running test 3660"
../source/print_tokens2.exe ../inputs/uslin.314     > ../originals/t3660
echo ">>>>>>>>running test 3661"
../source/print_tokens2.exe ../inputs/uslin.315     > ../originals/t3661
echo ">>>>>>>>running test 3662"
../source/print_tokens2.exe ../inputs/uslin.316     > ../originals/t3662
echo ">>>>>>>>running test 3663"
../source/print_tokens2.exe ../inputs/uslin.317     > ../originals/t3663
echo ">>>>>>>>running test 3664"
../source/print_tokens2.exe ../inputs/uslin.32     > ../originals/t3664
echo ">>>>>>>>running test 3665"
../source/print_tokens2.exe ../inputs/uslin.324     > ../originals/t3665
echo ">>>>>>>>running test 3666"
../source/print_tokens2.exe ../inputs/uslin.328     > ../originals/t3666
echo ">>>>>>>>running test 3667"
../source/print_tokens2.exe ../inputs/uslin.331     > ../originals/t3667
echo ">>>>>>>>running test 3668"
../source/print_tokens2.exe ../inputs/uslin.332     > ../originals/t3668
echo ">>>>>>>>running test 3669"
../source/print_tokens2.exe ../inputs/uslin.336     > ../originals/t3669
echo ">>>>>>>>running test 3670"
../source/print_tokens2.exe ../inputs/uslin.341     > ../originals/t3670
echo ">>>>>>>>running test 3671"
../source/print_tokens2.exe ../inputs/uslin.342     > ../originals/t3671
echo ">>>>>>>>running test 3672"
../source/print_tokens2.exe ../inputs/uslin.346     > ../originals/t3672
echo ">>>>>>>>running test 3673"
../source/print_tokens2.exe ../inputs/uslin.347     > ../originals/t3673
echo ">>>>>>>>running test 3674"
../source/print_tokens2.exe ../inputs/uslin.35     > ../originals/t3674
echo ">>>>>>>>running test 3675"
../source/print_tokens2.exe ../inputs/uslin.351     > ../originals/t3675
echo ">>>>>>>>running test 3676"
../source/print_tokens2.exe ../inputs/uslin.354     > ../originals/t3676
echo ">>>>>>>>running test 3677"
../source/print_tokens2.exe ../inputs/uslin.356     > ../originals/t3677
echo ">>>>>>>>running test 3678"
../source/print_tokens2.exe ../inputs/uslin.357     > ../originals/t3678
echo ">>>>>>>>running test 3679"
../source/print_tokens2.exe ../inputs/uslin.358     > ../originals/t3679
echo ">>>>>>>>running test 3680"
../source/print_tokens2.exe ../inputs/uslin.359     > ../originals/t3680
echo ">>>>>>>>running test 3681"
../source/print_tokens2.exe ../inputs/uslin.361     > ../originals/t3681
echo ">>>>>>>>running test 3682"
../source/print_tokens2.exe ../inputs/uslin.364     > ../originals/t3682
echo ">>>>>>>>running test 3683"
../source/print_tokens2.exe ../inputs/uslin.365     > ../originals/t3683
echo ">>>>>>>>running test 3684"
../source/print_tokens2.exe ../inputs/uslin.366     > ../originals/t3684
echo ">>>>>>>>running test 3685"
../source/print_tokens2.exe ../inputs/uslin.368     > ../originals/t3685
echo ">>>>>>>>running test 3686"
../source/print_tokens2.exe ../inputs/uslin.370     > ../originals/t3686
echo ">>>>>>>>running test 3687"
../source/print_tokens2.exe ../inputs/uslin.371     > ../originals/t3687
echo ">>>>>>>>running test 3688"
../source/print_tokens2.exe ../inputs/uslin.373     > ../originals/t3688
echo ">>>>>>>>running test 3689"
../source/print_tokens2.exe ../inputs/uslin.374     > ../originals/t3689
echo ">>>>>>>>running test 3690"
../source/print_tokens2.exe ../inputs/uslin.375     > ../originals/t3690
echo ">>>>>>>>running test 3691"
../source/print_tokens2.exe ../inputs/uslin.376     > ../originals/t3691
echo ">>>>>>>>running test 3692"
../source/print_tokens2.exe ../inputs/uslin.38     > ../originals/t3692
echo ">>>>>>>>running test 3693"
../source/print_tokens2.exe ../inputs/uslin.381     > ../originals/t3693
echo ">>>>>>>>running test 3694"
../source/print_tokens2.exe ../inputs/uslin.382     > ../originals/t3694
echo ">>>>>>>>running test 3695"
../source/print_tokens2.exe ../inputs/uslin.384     > ../originals/t3695
echo ">>>>>>>>running test 3696"
../source/print_tokens2.exe ../inputs/uslin.385     > ../originals/t3696
echo ">>>>>>>>running test 3697"
../source/print_tokens2.exe ../inputs/uslin.389     > ../originals/t3697
echo ">>>>>>>>running test 3698"
../source/print_tokens2.exe ../inputs/uslin.39     > ../originals/t3698
echo ">>>>>>>>running test 3699"
../source/print_tokens2.exe ../inputs/uslin.390     > ../originals/t3699
echo ">>>>>>>>running test 3700"
../source/print_tokens2.exe ../inputs/uslin.391     > ../originals/t3700
echo ">>>>>>>>running test 3701"
../source/print_tokens2.exe ../inputs/uslin.393     > ../originals/t3701
echo ">>>>>>>>running test 3702"
../source/print_tokens2.exe ../inputs/uslin.394     > ../originals/t3702
echo ">>>>>>>>running test 3703"
../source/print_tokens2.exe ../inputs/uslin.396.noeof     > ../originals/t3703
echo ">>>>>>>>running test 3704"
../source/print_tokens2.exe ../inputs/uslin.397     > ../originals/t3704
echo ">>>>>>>>running test 3705"
../source/print_tokens2.exe ../inputs/uslin.400     > ../originals/t3705
echo ">>>>>>>>running test 3706"
../source/print_tokens2.exe ../inputs/uslin.401     > ../originals/t3706
echo ">>>>>>>>running test 3707"
../source/print_tokens2.exe ../inputs/uslin.403     > ../originals/t3707
echo ">>>>>>>>running test 3708"
../source/print_tokens2.exe ../inputs/uslin.404     > ../originals/t3708
echo ">>>>>>>>running test 3709"
../source/print_tokens2.exe ../inputs/uslin.405     > ../originals/t3709
echo ">>>>>>>>running test 3710"
../source/print_tokens2.exe ../inputs/uslin.406     > ../originals/t3710
echo ">>>>>>>>running test 3711"
../source/print_tokens2.exe ../inputs/uslin.408     > ../originals/t3711
echo ">>>>>>>>running test 3712"
../source/print_tokens2.exe ../inputs/uslin.409     > ../originals/t3712
echo ">>>>>>>>running test 3713"
../source/print_tokens2.exe ../inputs/uslin.410     > ../originals/t3713
echo ">>>>>>>>running test 3714"
../source/print_tokens2.exe ../inputs/uslin.411      > ../originals/t3714
echo ">>>>>>>>running test 3715"
../source/print_tokens2.exe ../inputs/uslin.414     > ../originals/t3715
echo ">>>>>>>>running test 3716"
../source/print_tokens2.exe ../inputs/uslin.416     > ../originals/t3716
echo ">>>>>>>>running test 3717"
../source/print_tokens2.exe ../inputs/uslin.416.noeof     > ../originals/t3717
echo ">>>>>>>>running test 3718"
../source/print_tokens2.exe ../inputs/uslin.417     > ../originals/t3718
echo ">>>>>>>>running test 3719"
../source/print_tokens2.exe ../inputs/uslin.420     > ../originals/t3719
echo ">>>>>>>>running test 3720"
../source/print_tokens2.exe ../inputs/uslin.422     > ../originals/t3720
echo ">>>>>>>>running test 3721"
../source/print_tokens2.exe ../inputs/uslin.426     > ../originals/t3721
echo ">>>>>>>>running test 3722"
../source/print_tokens2.exe ../inputs/uslin.427     > ../originals/t3722
echo ">>>>>>>>running test 3723"
../source/print_tokens2.exe ../inputs/uslin.429     > ../originals/t3723
echo ">>>>>>>>running test 3724"
../source/print_tokens2.exe ../inputs/uslin.43     > ../originals/t3724
echo ">>>>>>>>running test 3725"
../source/print_tokens2.exe ../inputs/uslin.431     > ../originals/t3725
echo ">>>>>>>>running test 3726"
../source/print_tokens2.exe ../inputs/uslin.437     > ../originals/t3726
echo ">>>>>>>>running test 3727"
../source/print_tokens2.exe ../inputs/uslin.439     > ../originals/t3727
echo ">>>>>>>>running test 3728"
../source/print_tokens2.exe ../inputs/uslin.44     > ../originals/t3728
echo ">>>>>>>>running test 3729"
../source/print_tokens2.exe ../inputs/uslin.440     > ../originals/t3729
echo ">>>>>>>>running test 3730"
../source/print_tokens2.exe ../inputs/uslin.441.noeof     > ../originals/t3730
echo ">>>>>>>>running test 3731"
../source/print_tokens2.exe ../inputs/uslin.443     > ../originals/t3731
echo ">>>>>>>>running test 3732"
../source/print_tokens2.exe ../inputs/uslin.444     > ../originals/t3732
echo ">>>>>>>>running test 3733"
../source/print_tokens2.exe ../inputs/uslin.445     > ../originals/t3733
echo ">>>>>>>>running test 3734"
../source/print_tokens2.exe ../inputs/uslin.446     > ../originals/t3734
echo ">>>>>>>>running test 3735"
../source/print_tokens2.exe ../inputs/uslin.45     > ../originals/t3735
echo ">>>>>>>>running test 3736"
../source/print_tokens2.exe ../inputs/uslin.452     > ../originals/t3736
echo ">>>>>>>>running test 3737"
../source/print_tokens2.exe ../inputs/uslin.453     > ../originals/t3737
echo ">>>>>>>>running test 3738"
../source/print_tokens2.exe ../inputs/uslin.454     > ../originals/t3738
echo ">>>>>>>>running test 3739"
../source/print_tokens2.exe ../inputs/uslin.458     > ../originals/t3739
echo ">>>>>>>>running test 3740"
../source/print_tokens2.exe ../inputs/uslin.46     > ../originals/t3740
echo ">>>>>>>>running test 3741"
../source/print_tokens2.exe ../inputs/uslin.460     > ../originals/t3741
echo ">>>>>>>>running test 3742"
../source/print_tokens2.exe ../inputs/uslin.461     > ../originals/t3742
echo ">>>>>>>>running test 3743"
../source/print_tokens2.exe ../inputs/uslin.464     > ../originals/t3743
echo ">>>>>>>>running test 3744"
../source/print_tokens2.exe ../inputs/uslin.465     > ../originals/t3744
echo ">>>>>>>>running test 3745"
../source/print_tokens2.exe ../inputs/uslin.466     > ../originals/t3745
echo ">>>>>>>>running test 3746"
../source/print_tokens2.exe ../inputs/uslin.470     > ../originals/t3746
echo ">>>>>>>>running test 3747"
../source/print_tokens2.exe ../inputs/uslin.471     > ../originals/t3747
echo ">>>>>>>>running test 3748"
../source/print_tokens2.exe ../inputs/uslin.472     > ../originals/t3748
echo ">>>>>>>>running test 3749"
../source/print_tokens2.exe ../inputs/uslin.473     > ../originals/t3749
echo ">>>>>>>>running test 3750"
../source/print_tokens2.exe ../inputs/uslin.474     > ../originals/t3750
echo ">>>>>>>>running test 3751"
../source/print_tokens2.exe ../inputs/uslin.478     > ../originals/t3751
echo ">>>>>>>>running test 3752"
../source/print_tokens2.exe ../inputs/uslin.481     > ../originals/t3752
echo ">>>>>>>>running test 3753"
../source/print_tokens2.exe ../inputs/uslin.482     > ../originals/t3753
echo ">>>>>>>>running test 3754"
../source/print_tokens2.exe ../inputs/uslin.484     > ../originals/t3754
echo ">>>>>>>>running test 3755"
../source/print_tokens2.exe ../inputs/uslin.485     > ../originals/t3755
echo ">>>>>>>>running test 3756"
../source/print_tokens2.exe ../inputs/uslin.486     > ../originals/t3756
echo ">>>>>>>>running test 3757"
../source/print_tokens2.exe ../inputs/uslin.488     > ../originals/t3757
echo ">>>>>>>>running test 3758"
../source/print_tokens2.exe ../inputs/uslin.49     > ../originals/t3758
echo ">>>>>>>>running test 3759"
../source/print_tokens2.exe ../inputs/uslin.490     > ../originals/t3759
echo ">>>>>>>>running test 3760"
../source/print_tokens2.exe ../inputs/uslin.491     > ../originals/t3760
echo ">>>>>>>>running test 3761"
../source/print_tokens2.exe ../inputs/uslin.492     > ../originals/t3761
echo ">>>>>>>>running test 3762"
../source/print_tokens2.exe ../inputs/uslin.495     > ../originals/t3762
echo ">>>>>>>>running test 3763"
../source/print_tokens2.exe ../inputs/uslin.497     > ../originals/t3763
echo ">>>>>>>>running test 3764"
../source/print_tokens2.exe ../inputs/uslin.498     > ../originals/t3764
echo ">>>>>>>>running test 3765"
../source/print_tokens2.exe ../inputs/uslin.499     > ../originals/t3765
echo ">>>>>>>>running test 3766"
../source/print_tokens2.exe ../inputs/uslin.5      > ../originals/t3766
echo ">>>>>>>>running test 3767"
../source/print_tokens2.exe ../inputs/uslin.5.noeof     > ../originals/t3767
echo ">>>>>>>>running test 3768"
../source/print_tokens2.exe ../inputs/uslin.500     > ../originals/t3768
echo ">>>>>>>>running test 3769"
../source/print_tokens2.exe ../inputs/uslin.501     > ../originals/t3769
echo ">>>>>>>>running test 3770"
../source/print_tokens2.exe ../inputs/uslin.503     > ../originals/t3770
echo ">>>>>>>>running test 3771"
../source/print_tokens2.exe ../inputs/uslin.505     > ../originals/t3771
echo ">>>>>>>>running test 3772"
../source/print_tokens2.exe ../inputs/uslin.508     > ../originals/t3772
echo ">>>>>>>>running test 3773"
../source/print_tokens2.exe ../inputs/uslin.509     > ../originals/t3773
echo ">>>>>>>>running test 3774"
../source/print_tokens2.exe ../inputs/uslin.51     > ../originals/t3774
echo ">>>>>>>>running test 3775"
../source/print_tokens2.exe ../inputs/uslin.516     > ../originals/t3775
echo ">>>>>>>>running test 3776"
../source/print_tokens2.exe ../inputs/uslin.517     > ../originals/t3776
echo ">>>>>>>>running test 3777"
../source/print_tokens2.exe ../inputs/uslin.521     > ../originals/t3777
echo ">>>>>>>>running test 3778"
../source/print_tokens2.exe ../inputs/uslin.523     > ../originals/t3778
echo ">>>>>>>>running test 3779"
../source/print_tokens2.exe ../inputs/uslin.524     > ../originals/t3779
echo ">>>>>>>>running test 3780"
../source/print_tokens2.exe ../inputs/uslin.529     > ../originals/t3780
echo ">>>>>>>>running test 3781"
../source/print_tokens2.exe ../inputs/uslin.53     > ../originals/t3781
echo ">>>>>>>>running test 3782"
../source/print_tokens2.exe ../inputs/uslin.530     > ../originals/t3782
echo ">>>>>>>>running test 3783"
../source/print_tokens2.exe ../inputs/uslin.531     > ../originals/t3783
echo ">>>>>>>>running test 3784"
../source/print_tokens2.exe ../inputs/uslin.532     > ../originals/t3784
echo ">>>>>>>>running test 3785"
../source/print_tokens2.exe ../inputs/uslin.535     > ../originals/t3785
echo ">>>>>>>>running test 3786"
../source/print_tokens2.exe ../inputs/uslin.536     > ../originals/t3786
echo ">>>>>>>>running test 3787"
../source/print_tokens2.exe ../inputs/uslin.541     > ../originals/t3787
echo ">>>>>>>>running test 3788"
../source/print_tokens2.exe ../inputs/uslin.542     > ../originals/t3788
echo ">>>>>>>>running test 3789"
../source/print_tokens2.exe ../inputs/uslin.545     > ../originals/t3789
echo ">>>>>>>>running test 3790"
../source/print_tokens2.exe ../inputs/uslin.546     > ../originals/t3790
echo ">>>>>>>>running test 3791"
../source/print_tokens2.exe ../inputs/uslin.547     > ../originals/t3791
echo ">>>>>>>>running test 3792"
../source/print_tokens2.exe ../inputs/uslin.548     > ../originals/t3792
echo ">>>>>>>>running test 3793"
../source/print_tokens2.exe ../inputs/uslin.549     > ../originals/t3793
echo ">>>>>>>>running test 3794"
../source/print_tokens2.exe ../inputs/uslin.55     > ../originals/t3794
echo ">>>>>>>>running test 3795"
../source/print_tokens2.exe ../inputs/uslin.550      > ../originals/t3795
echo ">>>>>>>>running test 3796"
../source/print_tokens2.exe ../inputs/uslin.551     > ../originals/t3796
echo ">>>>>>>>running test 3797"
../source/print_tokens2.exe ../inputs/uslin.554     > ../originals/t3797
echo ">>>>>>>>running test 3798"
../source/print_tokens2.exe ../inputs/uslin.555     > ../originals/t3798
echo ">>>>>>>>running test 3799"
../source/print_tokens2.exe ../inputs/uslin.556     > ../originals/t3799
echo ">>>>>>>>running test 3800"
../source/print_tokens2.exe ../inputs/uslin.559     > ../originals/t3800
echo ">>>>>>>>running test 3801"
../source/print_tokens2.exe ../inputs/uslin.56     > ../originals/t3801
echo ">>>>>>>>running test 3802"
../source/print_tokens2.exe ../inputs/uslin.560     > ../originals/t3802
echo ">>>>>>>>running test 3803"
../source/print_tokens2.exe ../inputs/uslin.561     > ../originals/t3803
echo ">>>>>>>>running test 3804"
../source/print_tokens2.exe ../inputs/uslin.563     > ../originals/t3804
echo ">>>>>>>>running test 3805"
../source/print_tokens2.exe ../inputs/uslin.564     > ../originals/t3805
echo ">>>>>>>>running test 3806"
../source/print_tokens2.exe ../inputs/uslin.565     > ../originals/t3806
echo ">>>>>>>>running test 3807"
../source/print_tokens2.exe ../inputs/uslin.567     > ../originals/t3807
echo ">>>>>>>>running test 3808"
../source/print_tokens2.exe ../inputs/uslin.57     > ../originals/t3808
echo ">>>>>>>>running test 3809"
../source/print_tokens2.exe ../inputs/uslin.575     > ../originals/t3809
echo ">>>>>>>>running test 3810"
../source/print_tokens2.exe ../inputs/uslin.578     > ../originals/t3810
echo ">>>>>>>>running test 3811"
../source/print_tokens2.exe ../inputs/uslin.587     > ../originals/t3811
echo ">>>>>>>>running test 3812"
../source/print_tokens2.exe ../inputs/uslin.588     > ../originals/t3812
echo ">>>>>>>>running test 3813"
../source/print_tokens2.exe ../inputs/uslin.589     > ../originals/t3813
echo ">>>>>>>>running test 3814"
../source/print_tokens2.exe ../inputs/uslin.59     > ../originals/t3814
echo ">>>>>>>>running test 3815"
../source/print_tokens2.exe ../inputs/uslin.590     > ../originals/t3815
echo ">>>>>>>>running test 3816"
../source/print_tokens2.exe ../inputs/uslin.591     > ../originals/t3816
echo ">>>>>>>>running test 3817"
../source/print_tokens2.exe ../inputs/uslin.595     > ../originals/t3817
echo ">>>>>>>>running test 3818"
../source/print_tokens2.exe ../inputs/uslin.599     > ../originals/t3818
echo ">>>>>>>>running test 3819"
../source/print_tokens2.exe ../inputs/uslin.6     > ../originals/t3819
echo ">>>>>>>>running test 3820"
../source/print_tokens2.exe ../inputs/uslin.600     > ../originals/t3820
echo ">>>>>>>>running test 3821"
../source/print_tokens2.exe ../inputs/uslin.601     > ../originals/t3821
echo ">>>>>>>>running test 3822"
../source/print_tokens2.exe ../inputs/uslin.603     > ../originals/t3822
echo ">>>>>>>>running test 3823"
../source/print_tokens2.exe ../inputs/uslin.604     > ../originals/t3823
echo ">>>>>>>>running test 3824"
../source/print_tokens2.exe ../inputs/uslin.606     > ../originals/t3824
echo ">>>>>>>>running test 3825"
../source/print_tokens2.exe ../inputs/uslin.608     > ../originals/t3825
echo ">>>>>>>>running test 3826"
../source/print_tokens2.exe ../inputs/uslin.609      > ../originals/t3826
echo ">>>>>>>>running test 3827"
../source/print_tokens2.exe ../inputs/uslin.61     > ../originals/t3827
echo ">>>>>>>>running test 3828"
../source/print_tokens2.exe ../inputs/uslin.610     > ../originals/t3828
echo ">>>>>>>>running test 3829"
../source/print_tokens2.exe ../inputs/uslin.612     > ../originals/t3829
echo ">>>>>>>>running test 3830"
../source/print_tokens2.exe ../inputs/uslin.613     > ../originals/t3830
echo ">>>>>>>>running test 3831"
../source/print_tokens2.exe ../inputs/uslin.618     > ../originals/t3831
echo ">>>>>>>>running test 3832"
../source/print_tokens2.exe ../inputs/uslin.620     > ../originals/t3832
echo ">>>>>>>>running test 3833"
../source/print_tokens2.exe ../inputs/uslin.622     > ../originals/t3833
echo ">>>>>>>>running test 3834"
../source/print_tokens2.exe ../inputs/uslin.628     > ../originals/t3834
echo ">>>>>>>>running test 3835"
../source/print_tokens2.exe ../inputs/uslin.629      > ../originals/t3835
echo ">>>>>>>>running test 3836"
../source/print_tokens2.exe ../inputs/uslin.631     > ../originals/t3836
echo ">>>>>>>>running test 3837"
../source/print_tokens2.exe ../inputs/uslin.632     > ../originals/t3837
echo ">>>>>>>>running test 3838"
../source/print_tokens2.exe ../inputs/uslin.634     > ../originals/t3838
echo ">>>>>>>>running test 3839"
../source/print_tokens2.exe ../inputs/uslin.635     > ../originals/t3839
echo ">>>>>>>>running test 3840"
../source/print_tokens2.exe ../inputs/uslin.637     > ../originals/t3840
echo ">>>>>>>>running test 3841"
../source/print_tokens2.exe ../inputs/uslin.637.noeof     > ../originals/t3841
echo ">>>>>>>>running test 3842"
../source/print_tokens2.exe ../inputs/uslin.638     > ../originals/t3842
echo ">>>>>>>>running test 3843"
../source/print_tokens2.exe ../inputs/uslin.639     > ../originals/t3843
echo ">>>>>>>>running test 3844"
../source/print_tokens2.exe ../inputs/uslin.639.noeof     > ../originals/t3844
echo ">>>>>>>>running test 3845"
../source/print_tokens2.exe ../inputs/uslin.641     > ../originals/t3845
echo ">>>>>>>>running test 3846"
../source/print_tokens2.exe ../inputs/uslin.643     > ../originals/t3846
echo ">>>>>>>>running test 3847"
../source/print_tokens2.exe ../inputs/uslin.644     > ../originals/t3847
echo ">>>>>>>>running test 3848"
../source/print_tokens2.exe ../inputs/uslin.645     > ../originals/t3848
echo ">>>>>>>>running test 3849"
../source/print_tokens2.exe ../inputs/uslin.646     > ../originals/t3849
echo ">>>>>>>>running test 3850"
../source/print_tokens2.exe ../inputs/uslin.649     > ../originals/t3850
echo ">>>>>>>>running test 3851"
../source/print_tokens2.exe ../inputs/uslin.65     > ../originals/t3851
echo ">>>>>>>>running test 3852"
../source/print_tokens2.exe ../inputs/uslin.651     > ../originals/t3852
echo ">>>>>>>>running test 3853"
../source/print_tokens2.exe ../inputs/uslin.652     > ../originals/t3853
echo ">>>>>>>>running test 3854"
../source/print_tokens2.exe ../inputs/uslin.653     > ../originals/t3854
echo ">>>>>>>>running test 3855"
../source/print_tokens2.exe ../inputs/uslin.654     > ../originals/t3855
echo ">>>>>>>>running test 3856"
../source/print_tokens2.exe ../inputs/uslin.657     > ../originals/t3856
echo ">>>>>>>>running test 3857"
../source/print_tokens2.exe ../inputs/uslin.658     > ../originals/t3857
echo ">>>>>>>>running test 3858"
../source/print_tokens2.exe ../inputs/uslin.66      > ../originals/t3858
echo ">>>>>>>>running test 3859"
../source/print_tokens2.exe ../inputs/uslin.660     > ../originals/t3859
echo ">>>>>>>>running test 3860"
../source/print_tokens2.exe ../inputs/uslin.661     > ../originals/t3860
echo ">>>>>>>>running test 3861"
../source/print_tokens2.exe ../inputs/uslin.664     > ../originals/t3861
echo ">>>>>>>>running test 3862"
../source/print_tokens2.exe ../inputs/uslin.666     > ../originals/t3862
echo ">>>>>>>>running test 3863"
../source/print_tokens2.exe ../inputs/uslin.667     > ../originals/t3863
echo ">>>>>>>>running test 3864"
../source/print_tokens2.exe ../inputs/uslin.671     > ../originals/t3864
echo ">>>>>>>>running test 3865"
../source/print_tokens2.exe ../inputs/uslin.672     > ../originals/t3865
echo ">>>>>>>>running test 3866"
../source/print_tokens2.exe ../inputs/uslin.675     > ../originals/t3866
echo ">>>>>>>>running test 3867"
../source/print_tokens2.exe ../inputs/uslin.678     > ../originals/t3867
echo ">>>>>>>>running test 3868"
../source/print_tokens2.exe ../inputs/uslin.681     > ../originals/t3868
echo ">>>>>>>>running test 3869"
../source/print_tokens2.exe ../inputs/uslin.683     > ../originals/t3869
echo ">>>>>>>>running test 3870"
../source/print_tokens2.exe ../inputs/uslin.684     > ../originals/t3870
echo ">>>>>>>>running test 3871"
../source/print_tokens2.exe ../inputs/uslin.685     > ../originals/t3871
echo ">>>>>>>>running test 3872"
../source/print_tokens2.exe ../inputs/uslin.687     > ../originals/t3872
echo ">>>>>>>>running test 3873"
../source/print_tokens2.exe ../inputs/uslin.688     > ../originals/t3873
echo ">>>>>>>>running test 3874"
../source/print_tokens2.exe ../inputs/uslin.689     > ../originals/t3874
echo ">>>>>>>>running test 3875"
../source/print_tokens2.exe ../inputs/uslin.69     > ../originals/t3875
echo ">>>>>>>>running test 3876"
../source/print_tokens2.exe ../inputs/uslin.690     > ../originals/t3876
echo ">>>>>>>>running test 3877"
../source/print_tokens2.exe ../inputs/uslin.692     > ../originals/t3877
echo ">>>>>>>>running test 3878"
../source/print_tokens2.exe ../inputs/uslin.693     > ../originals/t3878
echo ">>>>>>>>running test 3879"
../source/print_tokens2.exe ../inputs/uslin.694     > ../originals/t3879
echo ">>>>>>>>running test 3880"
../source/print_tokens2.exe ../inputs/uslin.696     > ../originals/t3880
echo ">>>>>>>>running test 3881"
../source/print_tokens2.exe ../inputs/uslin.697     > ../originals/t3881
echo ">>>>>>>>running test 3882"
../source/print_tokens2.exe ../inputs/uslin.698     > ../originals/t3882
echo ">>>>>>>>running test 3883"
../source/print_tokens2.exe ../inputs/uslin.699     > ../originals/t3883
echo ">>>>>>>>running test 3884"
../source/print_tokens2.exe ../inputs/uslin.700     > ../originals/t3884
echo ">>>>>>>>running test 3885"
../source/print_tokens2.exe ../inputs/uslin.702     > ../originals/t3885
echo ">>>>>>>>running test 3886"
../source/print_tokens2.exe ../inputs/uslin.703     > ../originals/t3886
echo ">>>>>>>>running test 3887"
../source/print_tokens2.exe ../inputs/uslin.705     > ../originals/t3887
echo ">>>>>>>>running test 3888"
../source/print_tokens2.exe ../inputs/uslin.707     > ../originals/t3888
echo ">>>>>>>>running test 3889"
../source/print_tokens2.exe ../inputs/uslin.710     > ../originals/t3889
echo ">>>>>>>>running test 3890"
../source/print_tokens2.exe ../inputs/uslin.714     > ../originals/t3890
echo ">>>>>>>>running test 3891"
../source/print_tokens2.exe ../inputs/uslin.715     > ../originals/t3891
echo ">>>>>>>>running test 3892"
../source/print_tokens2.exe ../inputs/uslin.718     > ../originals/t3892
echo ">>>>>>>>running test 3893"
../source/print_tokens2.exe ../inputs/uslin.720     > ../originals/t3893
echo ">>>>>>>>running test 3894"
../source/print_tokens2.exe ../inputs/uslin.722     > ../originals/t3894
echo ">>>>>>>>running test 3895"
../source/print_tokens2.exe ../inputs/uslin.724     > ../originals/t3895
echo ">>>>>>>>running test 3896"
../source/print_tokens2.exe ../inputs/uslin.724.noeof     > ../originals/t3896
echo ">>>>>>>>running test 3897"
../source/print_tokens2.exe ../inputs/uslin.725     > ../originals/t3897
echo ">>>>>>>>running test 3898"
../source/print_tokens2.exe ../inputs/uslin.726     > ../originals/t3898
echo ">>>>>>>>running test 3899"
../source/print_tokens2.exe ../inputs/uslin.729     > ../originals/t3899
echo ">>>>>>>>running test 3900"
../source/print_tokens2.exe ../inputs/uslin.73     > ../originals/t3900
echo ">>>>>>>>running test 3901"
../source/print_tokens2.exe ../inputs/uslin.730     > ../originals/t3901
echo ">>>>>>>>running test 3902"
../source/print_tokens2.exe ../inputs/uslin.731     > ../originals/t3902
echo ">>>>>>>>running test 3903"
../source/print_tokens2.exe ../inputs/uslin.732     > ../originals/t3903
echo ">>>>>>>>running test 3904"
../source/print_tokens2.exe ../inputs/uslin.733     > ../originals/t3904
echo ">>>>>>>>running test 3905"
../source/print_tokens2.exe ../inputs/uslin.735     > ../originals/t3905
echo ">>>>>>>>running test 3906"
../source/print_tokens2.exe ../inputs/uslin.737     > ../originals/t3906
echo ">>>>>>>>running test 3907"
../source/print_tokens2.exe ../inputs/uslin.739     > ../originals/t3907
echo ">>>>>>>>running test 3908"
../source/print_tokens2.exe ../inputs/uslin.740     > ../originals/t3908
echo ">>>>>>>>running test 3909"
../source/print_tokens2.exe ../inputs/uslin.741     > ../originals/t3909
echo ">>>>>>>>running test 3910"
../source/print_tokens2.exe ../inputs/uslin.743     > ../originals/t3910
echo ">>>>>>>>running test 3911"
../source/print_tokens2.exe ../inputs/uslin.745      > ../originals/t3911
echo ">>>>>>>>running test 3912"
../source/print_tokens2.exe ../inputs/uslin.749     > ../originals/t3912
echo ">>>>>>>>running test 3913"
../source/print_tokens2.exe ../inputs/uslin.750     > ../originals/t3913
echo ">>>>>>>>running test 3914"
../source/print_tokens2.exe ../inputs/uslin.754     > ../originals/t3914
echo ">>>>>>>>running test 3915"
../source/print_tokens2.exe ../inputs/uslin.755     > ../originals/t3915
echo ">>>>>>>>running test 3916"
../source/print_tokens2.exe ../inputs/uslin.757     > ../originals/t3916
echo ">>>>>>>>running test 3917"
../source/print_tokens2.exe ../inputs/uslin.759     > ../originals/t3917
echo ">>>>>>>>running test 3918"
../source/print_tokens2.exe ../inputs/uslin.762     > ../originals/t3918
echo ">>>>>>>>running test 3919"
../source/print_tokens2.exe ../inputs/uslin.763     > ../originals/t3919
echo ">>>>>>>>running test 3920"
../source/print_tokens2.exe ../inputs/uslin.764     > ../originals/t3920
echo ">>>>>>>>running test 3921"
../source/print_tokens2.exe ../inputs/uslin.77.noeof     > ../originals/t3921
echo ">>>>>>>>running test 3922"
../source/print_tokens2.exe ../inputs/uslin.770     > ../originals/t3922
echo ">>>>>>>>running test 3923"
../source/print_tokens2.exe ../inputs/uslin.771     > ../originals/t3923
echo ">>>>>>>>running test 3924"
../source/print_tokens2.exe ../inputs/uslin.774     > ../originals/t3924
echo ">>>>>>>>running test 3925"
../source/print_tokens2.exe ../inputs/uslin.780     > ../originals/t3925
echo ">>>>>>>>running test 3926"
../source/print_tokens2.exe ../inputs/uslin.782     > ../originals/t3926
echo ">>>>>>>>running test 3927"
../source/print_tokens2.exe ../inputs/uslin.783     > ../originals/t3927
echo ">>>>>>>>running test 3928"
../source/print_tokens2.exe ../inputs/uslin.785     > ../originals/t3928
echo ">>>>>>>>running test 3929"
../source/print_tokens2.exe ../inputs/uslin.792     > ../originals/t3929
echo ">>>>>>>>running test 3930"
../source/print_tokens2.exe ../inputs/uslin.794     > ../originals/t3930
echo ">>>>>>>>running test 3931"
../source/print_tokens2.exe ../inputs/uslin.795     > ../originals/t3931
echo ">>>>>>>>running test 3932"
../source/print_tokens2.exe ../inputs/uslin.796     > ../originals/t3932
echo ">>>>>>>>running test 3933"
../source/print_tokens2.exe ../inputs/uslin.797      > ../originals/t3933
echo ">>>>>>>>running test 3934"
../source/print_tokens2.exe ../inputs/uslin.799     > ../originals/t3934
echo ">>>>>>>>running test 3935"
../source/print_tokens2.exe ../inputs/uslin.800     > ../originals/t3935
echo ">>>>>>>>running test 3936"
../source/print_tokens2.exe ../inputs/uslin.801     > ../originals/t3936
echo ">>>>>>>>running test 3937"
../source/print_tokens2.exe ../inputs/uslin.802     > ../originals/t3937
echo ">>>>>>>>running test 3938"
../source/print_tokens2.exe ../inputs/uslin.804     > ../originals/t3938
echo ">>>>>>>>running test 3939"
../source/print_tokens2.exe ../inputs/uslin.805     > ../originals/t3939
echo ">>>>>>>>running test 3940"
../source/print_tokens2.exe ../inputs/uslin.806     > ../originals/t3940
echo ">>>>>>>>running test 3941"
../source/print_tokens2.exe ../inputs/uslin.809     > ../originals/t3941
echo ">>>>>>>>running test 3942"
../source/print_tokens2.exe ../inputs/uslin.81     > ../originals/t3942
echo ">>>>>>>>running test 3943"
../source/print_tokens2.exe ../inputs/uslin.810     > ../originals/t3943
echo ">>>>>>>>running test 3944"
../source/print_tokens2.exe ../inputs/uslin.812     > ../originals/t3944
echo ">>>>>>>>running test 3945"
../source/print_tokens2.exe ../inputs/uslin.813     > ../originals/t3945
echo ">>>>>>>>running test 3946"
../source/print_tokens2.exe ../inputs/uslin.815      > ../originals/t3946
echo ">>>>>>>>running test 3947"
../source/print_tokens2.exe ../inputs/uslin.817     > ../originals/t3947
echo ">>>>>>>>running test 3948"
../source/print_tokens2.exe ../inputs/uslin.819     > ../originals/t3948
echo ">>>>>>>>running test 3949"
../source/print_tokens2.exe ../inputs/uslin.820     > ../originals/t3949
echo ">>>>>>>>running test 3950"
../source/print_tokens2.exe ../inputs/uslin.822     > ../originals/t3950
echo ">>>>>>>>running test 3951"
../source/print_tokens2.exe ../inputs/uslin.824     > ../originals/t3951
echo ">>>>>>>>running test 3952"
../source/print_tokens2.exe ../inputs/uslin.826     > ../originals/t3952
echo ">>>>>>>>running test 3953"
../source/print_tokens2.exe ../inputs/uslin.827      > ../originals/t3953
echo ">>>>>>>>running test 3954"
../source/print_tokens2.exe ../inputs/uslin.830     > ../originals/t3954
echo ">>>>>>>>running test 3955"
../source/print_tokens2.exe ../inputs/uslin.833     > ../originals/t3955
echo ">>>>>>>>running test 3956"
../source/print_tokens2.exe ../inputs/uslin.835     > ../originals/t3956
echo ">>>>>>>>running test 3957"
../source/print_tokens2.exe ../inputs/uslin.838     > ../originals/t3957
echo ">>>>>>>>running test 3958"
../source/print_tokens2.exe ../inputs/uslin.839     > ../originals/t3958
echo ">>>>>>>>running test 3959"
../source/print_tokens2.exe ../inputs/uslin.84     > ../originals/t3959
echo ">>>>>>>>running test 3960"
../source/print_tokens2.exe ../inputs/uslin.841     > ../originals/t3960
echo ">>>>>>>>running test 3961"
../source/print_tokens2.exe ../inputs/uslin.842     > ../originals/t3961
echo ">>>>>>>>running test 3962"
../source/print_tokens2.exe ../inputs/uslin.844     > ../originals/t3962
echo ">>>>>>>>running test 3963"
../source/print_tokens2.exe ../inputs/uslin.845     > ../originals/t3963
echo ">>>>>>>>running test 3964"
../source/print_tokens2.exe ../inputs/uslin.846     > ../originals/t3964
echo ">>>>>>>>running test 3965"
../source/print_tokens2.exe ../inputs/uslin.847     > ../originals/t3965
echo ">>>>>>>>running test 3966"
../source/print_tokens2.exe ../inputs/uslin.848     > ../originals/t3966
echo ">>>>>>>>running test 3967"
../source/print_tokens2.exe ../inputs/uslin.849      > ../originals/t3967
echo ">>>>>>>>running test 3968"
../source/print_tokens2.exe ../inputs/uslin.850     > ../originals/t3968
echo ">>>>>>>>running test 3969"
../source/print_tokens2.exe ../inputs/uslin.852     > ../originals/t3969
echo ">>>>>>>>running test 3970"
../source/print_tokens2.exe ../inputs/uslin.853     > ../originals/t3970
echo ">>>>>>>>running test 3971"
../source/print_tokens2.exe ../inputs/uslin.854     > ../originals/t3971
echo ">>>>>>>>running test 3972"
../source/print_tokens2.exe ../inputs/uslin.856     > ../originals/t3972
echo ">>>>>>>>running test 3973"
../source/print_tokens2.exe ../inputs/uslin.857     > ../originals/t3973
echo ">>>>>>>>running test 3974"
../source/print_tokens2.exe ../inputs/uslin.859     > ../originals/t3974
echo ">>>>>>>>running test 3975"
../source/print_tokens2.exe ../inputs/uslin.86     > ../originals/t3975
echo ">>>>>>>>running test 3976"
../source/print_tokens2.exe ../inputs/uslin.861     > ../originals/t3976
echo ">>>>>>>>running test 3977"
../source/print_tokens2.exe ../inputs/uslin.863     > ../originals/t3977
echo ">>>>>>>>running test 3978"
../source/print_tokens2.exe ../inputs/uslin.867     > ../originals/t3978
echo ">>>>>>>>running test 3979"
../source/print_tokens2.exe ../inputs/uslin.868     > ../originals/t3979
echo ">>>>>>>>running test 3980"
../source/print_tokens2.exe ../inputs/uslin.869     > ../originals/t3980
echo ">>>>>>>>running test 3981"
../source/print_tokens2.exe ../inputs/uslin.870     > ../originals/t3981
echo ">>>>>>>>running test 3982"
../source/print_tokens2.exe ../inputs/uslin.870.noeof     > ../originals/t3982
echo ">>>>>>>>running test 3983"
../source/print_tokens2.exe ../inputs/uslin.873     > ../originals/t3983
echo ">>>>>>>>running test 3984"
../source/print_tokens2.exe ../inputs/uslin.874     > ../originals/t3984
echo ">>>>>>>>running test 3985"
../source/print_tokens2.exe ../inputs/uslin.877      > ../originals/t3985
echo ">>>>>>>>running test 3986"
../source/print_tokens2.exe ../inputs/uslin.878     > ../originals/t3986
echo ">>>>>>>>running test 3987"
../source/print_tokens2.exe ../inputs/uslin.879     > ../originals/t3987
echo ">>>>>>>>running test 3988"
../source/print_tokens2.exe ../inputs/uslin.881     > ../originals/t3988
echo ">>>>>>>>running test 3989"
../source/print_tokens2.exe ../inputs/uslin.882     > ../originals/t3989
echo ">>>>>>>>running test 3990"
../source/print_tokens2.exe ../inputs/uslin.883     > ../originals/t3990
echo ">>>>>>>>running test 3991"
../source/print_tokens2.exe ../inputs/uslin.884     > ../originals/t3991
echo ">>>>>>>>running test 3992"
../source/print_tokens2.exe ../inputs/uslin.885     > ../originals/t3992
echo ">>>>>>>>running test 3993"
../source/print_tokens2.exe ../inputs/uslin.885.noeof     > ../originals/t3993
echo ">>>>>>>>running test 3994"
../source/print_tokens2.exe ../inputs/uslin.886     > ../originals/t3994
echo ">>>>>>>>running test 3995"
../source/print_tokens2.exe ../inputs/uslin.887     > ../originals/t3995
echo ">>>>>>>>running test 3996"
../source/print_tokens2.exe ../inputs/uslin.889     > ../originals/t3996
echo ">>>>>>>>running test 3997"
../source/print_tokens2.exe ../inputs/uslin.890     > ../originals/t3997
echo ">>>>>>>>running test 3998"
../source/print_tokens2.exe ../inputs/uslin.891     > ../originals/t3998
echo ">>>>>>>>running test 3999"
../source/print_tokens2.exe ../inputs/uslin.893     > ../originals/t3999
echo ">>>>>>>>running test 4000"
../source/print_tokens2.exe ../inputs/uslin.894     > ../originals/t4000
echo ">>>>>>>>running test 4001"
../source/print_tokens2.exe ../inputs/uslin.897     > ../originals/t4001
echo ">>>>>>>>running test 4002"
../source/print_tokens2.exe ../inputs/uslin.899     > ../originals/t4002
echo ">>>>>>>>running test 4003"
../source/print_tokens2.exe ../inputs/uslin.90     > ../originals/t4003
echo ">>>>>>>>running test 4004"
../source/print_tokens2.exe ../inputs/uslin.900     > ../originals/t4004
echo ">>>>>>>>running test 4005"
../source/print_tokens2.exe ../inputs/uslin.901     > ../originals/t4005
echo ">>>>>>>>running test 4006"
../source/print_tokens2.exe ../inputs/uslin.902     > ../originals/t4006
echo ">>>>>>>>running test 4007"
../source/print_tokens2.exe ../inputs/uslin.907     > ../originals/t4007
echo ">>>>>>>>running test 4008"
../source/print_tokens2.exe ../inputs/uslin.908     > ../originals/t4008
echo ">>>>>>>>running test 4009"
../source/print_tokens2.exe ../inputs/uslin.909     > ../originals/t4009
echo ">>>>>>>>running test 4010"
../source/print_tokens2.exe ../inputs/uslin.91     > ../originals/t4010
echo ">>>>>>>>running test 4011"
../source/print_tokens2.exe ../inputs/uslin.911     > ../originals/t4011
echo ">>>>>>>>running test 4012"
../source/print_tokens2.exe ../inputs/uslin.912     > ../originals/t4012
echo ">>>>>>>>running test 4013"
../source/print_tokens2.exe ../inputs/uslin.916     > ../originals/t4013
echo ">>>>>>>>running test 4014"
../source/print_tokens2.exe ../inputs/uslin.917     > ../originals/t4014
echo ">>>>>>>>running test 4015"
../source/print_tokens2.exe ../inputs/uslin.918     > ../originals/t4015
echo ">>>>>>>>running test 4016"
../source/print_tokens2.exe ../inputs/uslin.919     > ../originals/t4016
echo ">>>>>>>>running test 4017"
../source/print_tokens2.exe ../inputs/uslin.921     > ../originals/t4017
echo ">>>>>>>>running test 4018"
../source/print_tokens2.exe ../inputs/uslin.925      > ../originals/t4018
echo ">>>>>>>>running test 4019"
../source/print_tokens2.exe ../inputs/uslin.928     > ../originals/t4019
echo ">>>>>>>>running test 4020"
../source/print_tokens2.exe ../inputs/uslin.929     > ../originals/t4020
echo ">>>>>>>>running test 4021"
../source/print_tokens2.exe ../inputs/uslin.931     > ../originals/t4021
echo ">>>>>>>>running test 4022"
../source/print_tokens2.exe ../inputs/uslin.932     > ../originals/t4022
echo ">>>>>>>>running test 4023"
../source/print_tokens2.exe ../inputs/uslin.934     > ../originals/t4023
echo ">>>>>>>>running test 4024"
../source/print_tokens2.exe ../inputs/uslin.935     > ../originals/t4024
echo ">>>>>>>>running test 4025"
../source/print_tokens2.exe ../inputs/uslin.936     > ../originals/t4025
echo ">>>>>>>>running test 4026"
../source/print_tokens2.exe ../inputs/uslin.938     > ../originals/t4026
echo ">>>>>>>>running test 4027"
../source/print_tokens2.exe ../inputs/uslin.939     > ../originals/t4027
echo ">>>>>>>>running test 4028"
../source/print_tokens2.exe ../inputs/uslin.940     > ../originals/t4028
echo ">>>>>>>>running test 4029"
../source/print_tokens2.exe ../inputs/uslin.941     > ../originals/t4029
echo ">>>>>>>>running test 4030"
../source/print_tokens2.exe ../inputs/uslin.943     > ../originals/t4030
echo ">>>>>>>>running test 4031"
../source/print_tokens2.exe ../inputs/uslin.946     > ../originals/t4031
echo ">>>>>>>>running test 4032"
../source/print_tokens2.exe ../inputs/uslin.947     > ../originals/t4032
echo ">>>>>>>>running test 4033"
../source/print_tokens2.exe ../inputs/uslin.948     > ../originals/t4033
echo ">>>>>>>>running test 4034"
../source/print_tokens2.exe ../inputs/uslin.95     > ../originals/t4034
echo ">>>>>>>>running test 4035"
../source/print_tokens2.exe ../inputs/uslin.950     > ../originals/t4035
echo ">>>>>>>>running test 4036"
../source/print_tokens2.exe ../inputs/uslin.951     > ../originals/t4036
echo ">>>>>>>>running test 4037"
../source/print_tokens2.exe ../inputs/uslin.952     > ../originals/t4037
echo ">>>>>>>>running test 4038"
../source/print_tokens2.exe ../inputs/uslin.956     > ../originals/t4038
echo ">>>>>>>>running test 4039"
../source/print_tokens2.exe ../inputs/uslin.959     > ../originals/t4039
echo ">>>>>>>>running test 4040"
../source/print_tokens2.exe ../inputs/uslin.963     > ../originals/t4040
echo ">>>>>>>>running test 4041"
../source/print_tokens2.exe ../inputs/uslin.965     > ../originals/t4041
echo ">>>>>>>>running test 4042"
../source/print_tokens2.exe ../inputs/uslin.967     > ../originals/t4042
echo ">>>>>>>>running test 4043"
../source/print_tokens2.exe ../inputs/uslin.970     > ../originals/t4043
echo ">>>>>>>>running test 4044"
../source/print_tokens2.exe ../inputs/uslin.972     > ../originals/t4044
echo ">>>>>>>>running test 4045"
../source/print_tokens2.exe ../inputs/uslin.975     > ../originals/t4045
echo ">>>>>>>>running test 4046"
../source/print_tokens2.exe ../inputs/uslin.976     > ../originals/t4046
echo ">>>>>>>>running test 4047"
../source/print_tokens2.exe ../inputs/uslin.977     > ../originals/t4047
echo ">>>>>>>>running test 4048"
../source/print_tokens2.exe ../inputs/uslin.979     > ../originals/t4048
echo ">>>>>>>>running test 4049"
../source/print_tokens2.exe ../inputs/uslin.980     > ../originals/t4049
echo ">>>>>>>>running test 4050"
../source/print_tokens2.exe ../inputs/uslin.983     > ../originals/t4050
echo ">>>>>>>>running test 4051"
../source/print_tokens2.exe ../inputs/uslin.985     > ../originals/t4051
echo ">>>>>>>>running test 4052"
../source/print_tokens2.exe ../inputs/uslin.986     > ../originals/t4052
echo ">>>>>>>>running test 4053"
../source/print_tokens2.exe ../inputs/uslin.988     > ../originals/t4053
echo ">>>>>>>>running test 4054"
../source/print_tokens2.exe ../inputs/uslin.990     > ../originals/t4054
echo ">>>>>>>>running test 4055"
../source/print_tokens2.exe ../inputs/uslin.997     > ../originals/t4055
echo ">>>>>>>>running test 4056"
../source/print_tokens2.exe ../inputs/uslin.998     > ../originals/t4056
echo ">>>>>>>>running test 4057"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4057
echo ">>>>>>>>running test 4058"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4058
echo ">>>>>>>>running test 4059"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4059
echo ">>>>>>>>running test 4060"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4060
echo ">>>>>>>>running test 4061"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4061
echo ">>>>>>>>running test 4062"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4062
echo ">>>>>>>>running test 4063"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4063
echo ">>>>>>>>running test 4064"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4064
echo ">>>>>>>>running test 4065"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4065
echo ">>>>>>>>running test 4066"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4066
echo ">>>>>>>>running test 4067"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4067
echo ">>>>>>>>running test 4068"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4068
echo ">>>>>>>>running test 4069"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4069
echo ">>>>>>>>running test 4070"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4070
echo ">>>>>>>>running test 4071"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4071
echo ">>>>>>>>running test 4072"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4072
echo ">>>>>>>>running test 4073"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4073
echo ">>>>>>>>running test 4074"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4074
echo ">>>>>>>>running test 4075"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4075
echo ">>>>>>>>running test 4076"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4076
echo ">>>>>>>>running test 4077"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4077
echo ">>>>>>>>running test 4078"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4078
echo ">>>>>>>>running test 4079"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4079
echo ">>>>>>>>running test 4080"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4080
echo ">>>>>>>>running test 4081"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4081
echo ">>>>>>>>running test 4082"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4082
echo ">>>>>>>>running test 4083"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4083
echo ">>>>>>>>running test 4084"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4084
echo ">>>>>>>>running test 4085"
../source/print_tokens2.exe ../inputs/garbage/nothing     > ../originals/t4085
echo ">>>>>>>>running test 4086"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4086
echo ">>>>>>>>running test 4087"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4087
echo ">>>>>>>>running test 4088"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4088
echo ">>>>>>>>running test 4089"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4089
echo ">>>>>>>>running test 4090"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4090
echo ">>>>>>>>running test 4091"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4091
echo ">>>>>>>>running test 4092"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4092
echo ">>>>>>>>running test 4093"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4093
echo ">>>>>>>>running test 4094"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4094
echo ">>>>>>>>running test 4095"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4095
echo ">>>>>>>>running test 4096"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4096
echo ">>>>>>>>running test 4097"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4097
echo ">>>>>>>>running test 4098"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4098
echo ">>>>>>>>running test 4099"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4099
echo ">>>>>>>>running test 4100"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4100
echo ">>>>>>>>running test 4101"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4101
echo ">>>>>>>>running test 4102"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4102
echo ">>>>>>>>running test 4103"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4103
echo ">>>>>>>>running test 4104"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4104
echo ">>>>>>>>running test 4105"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4105
echo ">>>>>>>>running test 4106"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4106
echo ">>>>>>>>running test 4107"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4107
echo ">>>>>>>>running test 4108"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4108
echo ">>>>>>>>running test 4109"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4109
echo ">>>>>>>>running test 4110"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4110
echo ">>>>>>>>running test 4111"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4111
echo ">>>>>>>>running test 4112"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4112
echo ">>>>>>>>running test 4113"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4113
echo ">>>>>>>>running test 4114"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4114
echo ">>>>>>>>running test 4115"
../source/print_tokens2.exe one doesntliketwo     > ../originals/t4115
