#!/bin/sh
cd `dirname "$0"`
case $1 in
  p1) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst148.tst > ../outputs/t1
    exec diff ../outputs/t1 ../golden/t1 >/dev/null 2>&1 ;;
  p2) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst1.tst > ../outputs/t2
    exec diff ../outputs/t2 ../golden/t2 >/dev/null 2>&1 ;;
  p3) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst1.tst.tst > ../outputs/t3
    exec diff ../outputs/t3 ../golden/t3 >/dev/null 2>&1 ;;
  p4) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst10.tst > ../outputs/t4
    exec diff ../outputs/t4 ../golden/t4 >/dev/null 2>&1 ;;
  p5) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst100.tst > ../outputs/t5
    exec diff ../outputs/t5 ../golden/t5 >/dev/null 2>&1 ;;
  p6) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst101.tst > ../outputs/t6
    exec diff ../outputs/t6 ../golden/t6 >/dev/null 2>&1 ;;
  p7) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst102.tst > ../outputs/t7
    exec diff ../outputs/t7 ../golden/t7 >/dev/null 2>&1 ;;
  p8) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst103.tst > ../outputs/t8
    exec diff ../outputs/t8 ../golden/t8 >/dev/null 2>&1 ;;
  p9) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst104.tst > ../outputs/t9
    exec diff ../outputs/t9 ../golden/t9 >/dev/null 2>&1 ;;
  p10) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst105.tst > ../outputs/t10
    exec diff ../outputs/t10 ../golden/t10 >/dev/null 2>&1 ;;
  p11) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst106.tst > ../outputs/t11
    exec diff ../outputs/t11 ../golden/t11 >/dev/null 2>&1 ;;
  p12) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst107.tst > ../outputs/t12
    exec diff ../outputs/t12 ../golden/t12 >/dev/null 2>&1 ;;
  p13) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst108.tst > ../outputs/t13
    exec diff ../outputs/t13 ../golden/t13 >/dev/null 2>&1 ;;
  p14) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst109.tst > ../outputs/t14
    exec diff ../outputs/t14 ../golden/t14 >/dev/null 2>&1 ;;
  p15) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst11.tst > ../outputs/t15
    exec diff ../outputs/t15 ../golden/t15 >/dev/null 2>&1 ;;
  p16) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst110.tst > ../outputs/t16
    exec diff ../outputs/t16 ../golden/t16 >/dev/null 2>&1 ;;
  p17) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst111.tst > ../outputs/t17
    exec diff ../outputs/t17 ../golden/t17 >/dev/null 2>&1 ;;
  p18) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst112.tst > ../outputs/t18
    exec diff ../outputs/t18 ../golden/t18 >/dev/null 2>&1 ;;
  p19) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst113.tst > ../outputs/t19
    exec diff ../outputs/t19 ../golden/t19 >/dev/null 2>&1 ;;
  p20) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst114.tst > ../outputs/t20
    exec diff ../outputs/t20 ../golden/t20 >/dev/null 2>&1 ;;
  p21) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst115.tst > ../outputs/t21
    exec diff ../outputs/t21 ../golden/t21 >/dev/null 2>&1 ;;
  p22) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst116.tst > ../outputs/t22
    exec diff ../outputs/t22 ../golden/t22 >/dev/null 2>&1 ;;
  p23) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst117.tst > ../outputs/t23
    exec diff ../outputs/t23 ../golden/t23 >/dev/null 2>&1 ;;
  p24) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst118.tst > ../outputs/t24
    exec diff ../outputs/t24 ../golden/t24 >/dev/null 2>&1 ;;
  p25) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst119.tst > ../outputs/t25
    exec diff ../outputs/t25 ../golden/t25 >/dev/null 2>&1 ;;
  p26) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst12.tst > ../outputs/t26
    exec diff ../outputs/t26 ../golden/t26 >/dev/null 2>&1 ;;
  p27) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst120.tst > ../outputs/t27
    exec diff ../outputs/t27 ../golden/t27 >/dev/null 2>&1 ;;
  p28) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst121.tst > ../outputs/t28
    exec diff ../outputs/t28 ../golden/t28 >/dev/null 2>&1 ;;
  p29) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst122.tst > ../outputs/t29
    exec diff ../outputs/t29 ../golden/t29 >/dev/null 2>&1 ;;
  p30) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst123.tst > ../outputs/t30
    exec diff ../outputs/t30 ../golden/t30 >/dev/null 2>&1 ;;
  p31) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst124.tst > ../outputs/t31
    exec diff ../outputs/t31 ../golden/t31 >/dev/null 2>&1 ;;
  p32) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst125.tst > ../outputs/t32
    exec diff ../outputs/t32 ../golden/t32 >/dev/null 2>&1 ;;
  p33) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst126.tst > ../outputs/t33
    exec diff ../outputs/t33 ../golden/t33 >/dev/null 2>&1 ;;
  p34) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst127.tst > ../outputs/t34
    exec diff ../outputs/t34 ../golden/t34 >/dev/null 2>&1 ;;
  p35) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst128.tst > ../outputs/t35
    exec diff ../outputs/t35 ../golden/t35 >/dev/null 2>&1 ;;
  p36) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst129.tst > ../outputs/t36
    exec diff ../outputs/t36 ../golden/t36 >/dev/null 2>&1 ;;
  p37) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst13.tst > ../outputs/t37
    exec diff ../outputs/t37 ../golden/t37 >/dev/null 2>&1 ;;
  p38) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst130.tst > ../outputs/t38
    exec diff ../outputs/t38 ../golden/t38 >/dev/null 2>&1 ;;
  p39) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst131.tst > ../outputs/t39
    exec diff ../outputs/t39 ../golden/t39 >/dev/null 2>&1 ;;
  p40) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst132.tst > ../outputs/t40
    exec diff ../outputs/t40 ../golden/t40 >/dev/null 2>&1 ;;
  p41) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst133.tst > ../outputs/t41
    exec diff ../outputs/t41 ../golden/t41 >/dev/null 2>&1 ;;
  p42) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst134.tst > ../outputs/t42
    exec diff ../outputs/t42 ../golden/t42 >/dev/null 2>&1 ;;
  p43) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst135.tst > ../outputs/t43
    exec diff ../outputs/t43 ../golden/t43 >/dev/null 2>&1 ;;
  p44) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst136.tst > ../outputs/t44
    exec diff ../outputs/t44 ../golden/t44 >/dev/null 2>&1 ;;
  p45) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst137.tst > ../outputs/t45
    exec diff ../outputs/t45 ../golden/t45 >/dev/null 2>&1 ;;
  p46) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst138.tst > ../outputs/t46
    exec diff ../outputs/t46 ../golden/t46 >/dev/null 2>&1 ;;
  p47) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst139.tst > ../outputs/t47
    exec diff ../outputs/t47 ../golden/t47 >/dev/null 2>&1 ;;
  p48) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst14.tst > ../outputs/t48
    exec diff ../outputs/t48 ../golden/t48 >/dev/null 2>&1 ;;
  p49) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst140.tst > ../outputs/t49
    exec diff ../outputs/t49 ../golden/t49 >/dev/null 2>&1 ;;
  p50) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst141.tst > ../outputs/t50
    exec diff ../outputs/t50 ../golden/t50 >/dev/null 2>&1 ;;
  p51) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst142.tst > ../outputs/t51
    exec diff ../outputs/t51 ../golden/t51 >/dev/null 2>&1 ;;
  p52) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst143.tst > ../outputs/t52
    exec diff ../outputs/t52 ../golden/t52 >/dev/null 2>&1 ;;
  p53) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst144.tst > ../outputs/t53
    exec diff ../outputs/t53 ../golden/t53 >/dev/null 2>&1 ;;
  p54) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst145.tst > ../outputs/t54
    exec diff ../outputs/t54 ../golden/t54 >/dev/null 2>&1 ;;
  p55) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst146.tst > ../outputs/t55
    exec diff ../outputs/t55 ../golden/t55 >/dev/null 2>&1 ;;
  p56) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst147.tst > ../outputs/t56
    exec diff ../outputs/t56 ../golden/t56 >/dev/null 2>&1 ;;
  p57) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst149.tst > ../outputs/t57
    exec diff ../outputs/t57 ../golden/t57 >/dev/null 2>&1 ;;
  p58) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst15.tst > ../outputs/t58
    exec diff ../outputs/t58 ../golden/t58 >/dev/null 2>&1 ;;
  p59) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst150.tst > ../outputs/t59
    exec diff ../outputs/t59 ../golden/t59 >/dev/null 2>&1 ;;
  p60) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst151.tst > ../outputs/t60
    exec diff ../outputs/t60 ../golden/t60 >/dev/null 2>&1 ;;
  p61) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst152.tst > ../outputs/t61
    exec diff ../outputs/t61 ../golden/t61 >/dev/null 2>&1 ;;
  p62) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst153.tst > ../outputs/t62
    exec diff ../outputs/t62 ../golden/t62 >/dev/null 2>&1 ;;
  p63) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst154.tst > ../outputs/t63
    exec diff ../outputs/t63 ../golden/t63 >/dev/null 2>&1 ;;
  p64) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst155.tst > ../outputs/t64
    exec diff ../outputs/t64 ../golden/t64 >/dev/null 2>&1 ;;
  p65) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst156.tst > ../outputs/t65
    exec diff ../outputs/t65 ../golden/t65 >/dev/null 2>&1 ;;
  p66) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst157.tst > ../outputs/t66
    exec diff ../outputs/t66 ../golden/t66 >/dev/null 2>&1 ;;
  p67) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst158.tst > ../outputs/t67
    exec diff ../outputs/t67 ../golden/t67 >/dev/null 2>&1 ;;
  p68) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst159.tst > ../outputs/t68
    exec diff ../outputs/t68 ../golden/t68 >/dev/null 2>&1 ;;
  p69) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst16.tst > ../outputs/t69
    exec diff ../outputs/t69 ../golden/t69 >/dev/null 2>&1 ;;
  p70) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst160.tst > ../outputs/t70
    exec diff ../outputs/t70 ../golden/t70 >/dev/null 2>&1 ;;
  p71) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst161.tst > ../outputs/t71
    exec diff ../outputs/t71 ../golden/t71 >/dev/null 2>&1 ;;
  p72) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst162.tst > ../outputs/t72
    exec diff ../outputs/t72 ../golden/t72 >/dev/null 2>&1 ;;
  p73) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst163.tst > ../outputs/t73
    exec diff ../outputs/t73 ../golden/t73 >/dev/null 2>&1 ;;
  p74) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst164.tst > ../outputs/t74
    exec diff ../outputs/t74 ../golden/t74 >/dev/null 2>&1 ;;
  p75) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst165.tst > ../outputs/t75
    exec diff ../outputs/t75 ../golden/t75 >/dev/null 2>&1 ;;
  p76) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst166.tst > ../outputs/t76
    exec diff ../outputs/t76 ../golden/t76 >/dev/null 2>&1 ;;
  p77) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst167.tst > ../outputs/t77
    exec diff ../outputs/t77 ../golden/t77 >/dev/null 2>&1 ;;
  p78) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst168.tst > ../outputs/t78
    exec diff ../outputs/t78 ../golden/t78 >/dev/null 2>&1 ;;
  p79) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst169.tst > ../outputs/t79
    exec diff ../outputs/t79 ../golden/t79 >/dev/null 2>&1 ;;
  p80) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst17.tst > ../outputs/t80
    exec diff ../outputs/t80 ../golden/t80 >/dev/null 2>&1 ;;
  p81) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst170.tst > ../outputs/t81
    exec diff ../outputs/t81 ../golden/t81 >/dev/null 2>&1 ;;
  p82) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst171.tst > ../outputs/t82
    exec diff ../outputs/t82 ../golden/t82 >/dev/null 2>&1 ;;
  p83) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst172.tst > ../outputs/t83
    exec diff ../outputs/t83 ../golden/t83 >/dev/null 2>&1 ;;
  p84) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst173.tst > ../outputs/t84
    exec diff ../outputs/t84 ../golden/t84 >/dev/null 2>&1 ;;
  p85) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst174.tst > ../outputs/t85
    exec diff ../outputs/t85 ../golden/t85 >/dev/null 2>&1 ;;
  p86) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst175.tst > ../outputs/t86
    exec diff ../outputs/t86 ../golden/t86 >/dev/null 2>&1 ;;
  p87) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst176.tst > ../outputs/t87
    exec diff ../outputs/t87 ../golden/t87 >/dev/null 2>&1 ;;
  p88) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst177.tst > ../outputs/t88
    exec diff ../outputs/t88 ../golden/t88 >/dev/null 2>&1 ;;
  p89) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst178.tst > ../outputs/t89
    exec diff ../outputs/t89 ../golden/t89 >/dev/null 2>&1 ;;
  p90) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst179.tst > ../outputs/t90
    exec diff ../outputs/t90 ../golden/t90 >/dev/null 2>&1 ;;
  p91) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst18.tst > ../outputs/t91
    exec diff ../outputs/t91 ../golden/t91 >/dev/null 2>&1 ;;
  p92) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst180.tst > ../outputs/t92
    exec diff ../outputs/t92 ../golden/t92 >/dev/null 2>&1 ;;
  p93) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst181.tst > ../outputs/t93
    exec diff ../outputs/t93 ../golden/t93 >/dev/null 2>&1 ;;
  p94) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst182.tst > ../outputs/t94
    exec diff ../outputs/t94 ../golden/t94 >/dev/null 2>&1 ;;
  p95) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst183.tst > ../outputs/t95
    exec diff ../outputs/t95 ../golden/t95 >/dev/null 2>&1 ;;
  p96) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst184.tst > ../outputs/t96
    exec diff ../outputs/t96 ../golden/t96 >/dev/null 2>&1 ;;
  p97) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst185.tst > ../outputs/t97
    exec diff ../outputs/t97 ../golden/t97 >/dev/null 2>&1 ;;
  p98) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst186.tst > ../outputs/t98
    exec diff ../outputs/t98 ../golden/t98 >/dev/null 2>&1 ;;
  p99) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst187.tst > ../outputs/t99
    exec diff ../outputs/t99 ../golden/t99 >/dev/null 2>&1 ;;
  p100) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst188.tst > ../outputs/t100
    exec diff ../outputs/t100 ../golden/t100 >/dev/null 2>&1 ;;
  p101) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst189.tst > ../outputs/t101
    exec diff ../outputs/t101 ../golden/t101 >/dev/null 2>&1 ;;
  p102) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst19.tst > ../outputs/t102
    exec diff ../outputs/t102 ../golden/t102 >/dev/null 2>&1 ;;
  p103) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst190.tst > ../outputs/t103
    exec diff ../outputs/t103 ../golden/t103 >/dev/null 2>&1 ;;
  p104) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst191.tst > ../outputs/t104
    exec diff ../outputs/t104 ../golden/t104 >/dev/null 2>&1 ;;
  p105) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst192.tst > ../outputs/t105
    exec diff ../outputs/t105 ../golden/t105 >/dev/null 2>&1 ;;
  p106) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst193.tst > ../outputs/t106
    exec diff ../outputs/t106 ../golden/t106 >/dev/null 2>&1 ;;
  p107) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst194.tst > ../outputs/t107
    exec diff ../outputs/t107 ../golden/t107 >/dev/null 2>&1 ;;
  p108) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst195.tst > ../outputs/t108
    exec diff ../outputs/t108 ../golden/t108 >/dev/null 2>&1 ;;
  p109) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst196.tst > ../outputs/t109
    exec diff ../outputs/t109 ../golden/t109 >/dev/null 2>&1 ;;
  p110) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst197.tst > ../outputs/t110
    exec diff ../outputs/t110 ../golden/t110 >/dev/null 2>&1 ;;
  p111) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst198.tst > ../outputs/t111
    exec diff ../outputs/t111 ../golden/t111 >/dev/null 2>&1 ;;
  p112) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst199.tst > ../outputs/t112
    exec diff ../outputs/t112 ../golden/t112 >/dev/null 2>&1 ;;
  p113) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst2.tst > ../outputs/t113
    exec diff ../outputs/t113 ../golden/t113 >/dev/null 2>&1 ;;
  p114) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst2.tst.tst > ../outputs/t114
    exec diff ../outputs/t114 ../golden/t114 >/dev/null 2>&1 ;;
  p115) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst20.tst > ../outputs/t115
    exec diff ../outputs/t115 ../golden/t115 >/dev/null 2>&1 ;;
  p116) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst200.tst > ../outputs/t116
    exec diff ../outputs/t116 ../golden/t116 >/dev/null 2>&1 ;;
  p117) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst201.tst > ../outputs/t117
    exec diff ../outputs/t117 ../golden/t117 >/dev/null 2>&1 ;;
  p118) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst203.tst > ../outputs/t118
    exec diff ../outputs/t118 ../golden/t118 >/dev/null 2>&1 ;;
  p119) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst204.tst > ../outputs/t119
    exec diff ../outputs/t119 ../golden/t119 >/dev/null 2>&1 ;;
  p120) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst205.tst > ../outputs/t120
    exec diff ../outputs/t120 ../golden/t120 >/dev/null 2>&1 ;;
  p121) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst206.tst > ../outputs/t121
    exec diff ../outputs/t121 ../golden/t121 >/dev/null 2>&1 ;;
  p122) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst207.tst > ../outputs/t122
    exec diff ../outputs/t122 ../golden/t122 >/dev/null 2>&1 ;;
  p123) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst208.tst > ../outputs/t123
    exec diff ../outputs/t123 ../golden/t123 >/dev/null 2>&1 ;;
  p124) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst209.tst > ../outputs/t124
    exec diff ../outputs/t124 ../golden/t124 >/dev/null 2>&1 ;;
  p125) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst21.tst > ../outputs/t125
    exec diff ../outputs/t125 ../golden/t125 >/dev/null 2>&1 ;;
  p126) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst21.tst.tst > ../outputs/t126
    exec diff ../outputs/t126 ../golden/t126 >/dev/null 2>&1 ;;
  p127) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst210.tst > ../outputs/t127
    exec diff ../outputs/t127 ../golden/t127 >/dev/null 2>&1 ;;
  p128) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst211.tst > ../outputs/t128
    exec diff ../outputs/t128 ../golden/t128 >/dev/null 2>&1 ;;
  p129) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst212.tst > ../outputs/t129
    exec diff ../outputs/t129 ../golden/t129 >/dev/null 2>&1 ;;
  p130) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst213.tst > ../outputs/t130
    exec diff ../outputs/t130 ../golden/t130 >/dev/null 2>&1 ;;
  p131) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst214.tst > ../outputs/t131
    exec diff ../outputs/t131 ../golden/t131 >/dev/null 2>&1 ;;
  p132) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst215.tst > ../outputs/t132
    exec diff ../outputs/t132 ../golden/t132 >/dev/null 2>&1 ;;
  p133) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst216.tst > ../outputs/t133
    exec diff ../outputs/t133 ../golden/t133 >/dev/null 2>&1 ;;
  p134) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst217.tst > ../outputs/t134
    exec diff ../outputs/t134 ../golden/t134 >/dev/null 2>&1 ;;
  p135) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst218.tst > ../outputs/t135
    exec diff ../outputs/t135 ../golden/t135 >/dev/null 2>&1 ;;
  p136) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst219.tst > ../outputs/t136
    exec diff ../outputs/t136 ../golden/t136 >/dev/null 2>&1 ;;
  p137) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst22.tst > ../outputs/t137
    exec diff ../outputs/t137 ../golden/t137 >/dev/null 2>&1 ;;
  p138) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst220.tst > ../outputs/t138
    exec diff ../outputs/t138 ../golden/t138 >/dev/null 2>&1 ;;
  p139) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst221.tst > ../outputs/t139
    exec diff ../outputs/t139 ../golden/t139 >/dev/null 2>&1 ;;
  p140) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst222.tst > ../outputs/t140
    exec diff ../outputs/t140 ../golden/t140 >/dev/null 2>&1 ;;
  p141) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst223.tst > ../outputs/t141
    exec diff ../outputs/t141 ../golden/t141 >/dev/null 2>&1 ;;
  p142) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst224.tst > ../outputs/t142
    exec diff ../outputs/t142 ../golden/t142 >/dev/null 2>&1 ;;
  p143) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst225.tst > ../outputs/t143
    exec diff ../outputs/t143 ../golden/t143 >/dev/null 2>&1 ;;
  p144) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst226.tst > ../outputs/t144
    exec diff ../outputs/t144 ../golden/t144 >/dev/null 2>&1 ;;
  p145) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst227.tst > ../outputs/t145
    exec diff ../outputs/t145 ../golden/t145 >/dev/null 2>&1 ;;
  p146) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst228.tst > ../outputs/t146
    exec diff ../outputs/t146 ../golden/t146 >/dev/null 2>&1 ;;
  p147) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst229.tst > ../outputs/t147
    exec diff ../outputs/t147 ../golden/t147 >/dev/null 2>&1 ;;
  p148) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst23.tst > ../outputs/t148
    exec diff ../outputs/t148 ../golden/t148 >/dev/null 2>&1 ;;
  p149) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst230.tst > ../outputs/t149
    exec diff ../outputs/t149 ../golden/t149 >/dev/null 2>&1 ;;
  p150) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst231.tst > ../outputs/t150
    exec diff ../outputs/t150 ../golden/t150 >/dev/null 2>&1 ;;
  p151) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst232.tst > ../outputs/t151
    exec diff ../outputs/t151 ../golden/t151 >/dev/null 2>&1 ;;
  p152) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst233.tst > ../outputs/t152
    exec diff ../outputs/t152 ../golden/t152 >/dev/null 2>&1 ;;
  p153) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst234.tst > ../outputs/t153
    exec diff ../outputs/t153 ../golden/t153 >/dev/null 2>&1 ;;
  p154) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst234.tst.tst > ../outputs/t154
    exec diff ../outputs/t154 ../golden/t154 >/dev/null 2>&1 ;;
  p155) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst235.tst > ../outputs/t155
    exec diff ../outputs/t155 ../golden/t155 >/dev/null 2>&1 ;;
  p156) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst236.tst > ../outputs/t156
    exec diff ../outputs/t156 ../golden/t156 >/dev/null 2>&1 ;;
  p157) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst237.tst > ../outputs/t157
    exec diff ../outputs/t157 ../golden/t157 >/dev/null 2>&1 ;;
  p158) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst238.tst > ../outputs/t158
    exec diff ../outputs/t158 ../golden/t158 >/dev/null 2>&1 ;;
  p159) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst239.tst > ../outputs/t159
    exec diff ../outputs/t159 ../golden/t159 >/dev/null 2>&1 ;;
  p160) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst24.tst > ../outputs/t160
    exec diff ../outputs/t160 ../golden/t160 >/dev/null 2>&1 ;;
  p161) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst240.tst > ../outputs/t161
    exec diff ../outputs/t161 ../golden/t161 >/dev/null 2>&1 ;;
  p162) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst240.tst.tst > ../outputs/t162
    exec diff ../outputs/t162 ../golden/t162 >/dev/null 2>&1 ;;
  p163) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst241.tst > ../outputs/t163
    exec diff ../outputs/t163 ../golden/t163 >/dev/null 2>&1 ;;
  p164) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst241.tst.tst > ../outputs/t164
    exec diff ../outputs/t164 ../golden/t164 >/dev/null 2>&1 ;;
  p165) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst242.tst > ../outputs/t165
    exec diff ../outputs/t165 ../golden/t165 >/dev/null 2>&1 ;;
  p166) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst242.tst.tst > ../outputs/t166
    exec diff ../outputs/t166 ../golden/t166 >/dev/null 2>&1 ;;
  p167) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst243.tst > ../outputs/t167
    exec diff ../outputs/t167 ../golden/t167 >/dev/null 2>&1 ;;
  p168) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst243.tst.tst > ../outputs/t168
    exec diff ../outputs/t168 ../golden/t168 >/dev/null 2>&1 ;;
  p169) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst244.tst > ../outputs/t169
    exec diff ../outputs/t169 ../golden/t169 >/dev/null 2>&1 ;;
  p170) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst244.tst.tst > ../outputs/t170
    exec diff ../outputs/t170 ../golden/t170 >/dev/null 2>&1 ;;
  p171) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst245.tst > ../outputs/t171
    exec diff ../outputs/t171 ../golden/t171 >/dev/null 2>&1 ;;
  p172) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst245.tst.tst > ../outputs/t172
    exec diff ../outputs/t172 ../golden/t172 >/dev/null 2>&1 ;;
  p173) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst246.tst > ../outputs/t173
    exec diff ../outputs/t173 ../golden/t173 >/dev/null 2>&1 ;;
  p174) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst246.tst.tst > ../outputs/t174
    exec diff ../outputs/t174 ../golden/t174 >/dev/null 2>&1 ;;
  p175) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst247.tst > ../outputs/t175
    exec diff ../outputs/t175 ../golden/t175 >/dev/null 2>&1 ;;
  p176) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst247.tst.tst > ../outputs/t176
    exec diff ../outputs/t176 ../golden/t176 >/dev/null 2>&1 ;;
  p177) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst248.tst > ../outputs/t177
    exec diff ../outputs/t177 ../golden/t177 >/dev/null 2>&1 ;;
  p178) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst248.tst.tst > ../outputs/t178
    exec diff ../outputs/t178 ../golden/t178 >/dev/null 2>&1 ;;
  p179) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst249.tst > ../outputs/t179
    exec diff ../outputs/t179 ../golden/t179 >/dev/null 2>&1 ;;
  p180) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst249.tst.tst > ../outputs/t180
    exec diff ../outputs/t180 ../golden/t180 >/dev/null 2>&1 ;;
  p181) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst25.tst > ../outputs/t181
    exec diff ../outputs/t181 ../golden/t181 >/dev/null 2>&1 ;;
  p182) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst250.tst > ../outputs/t182
    exec diff ../outputs/t182 ../golden/t182 >/dev/null 2>&1 ;;
  p183) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst251.tst > ../outputs/t183
    exec diff ../outputs/t183 ../golden/t183 >/dev/null 2>&1 ;;
  p184) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst252.tst > ../outputs/t184
    exec diff ../outputs/t184 ../golden/t184 >/dev/null 2>&1 ;;
  p185) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst253.tst > ../outputs/t185
    exec diff ../outputs/t185 ../golden/t185 >/dev/null 2>&1 ;;
  p186) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst254.tst > ../outputs/t186
    exec diff ../outputs/t186 ../golden/t186 >/dev/null 2>&1 ;;
  p187) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst254.tst.tst > ../outputs/t187
    exec diff ../outputs/t187 ../golden/t187 >/dev/null 2>&1 ;;
  p188) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst255.tst > ../outputs/t188
    exec diff ../outputs/t188 ../golden/t188 >/dev/null 2>&1 ;;
  p189) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst256.tst > ../outputs/t189
    exec diff ../outputs/t189 ../golden/t189 >/dev/null 2>&1 ;;
  p190) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst257.tst > ../outputs/t190
    exec diff ../outputs/t190 ../golden/t190 >/dev/null 2>&1 ;;
  p191) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst258.tst > ../outputs/t191
    exec diff ../outputs/t191 ../golden/t191 >/dev/null 2>&1 ;;
  p192) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst259.tst > ../outputs/t192
    exec diff ../outputs/t192 ../golden/t192 >/dev/null 2>&1 ;;
  p193) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst26.tst > ../outputs/t193
    exec diff ../outputs/t193 ../golden/t193 >/dev/null 2>&1 ;;
  p194) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst260.tst > ../outputs/t194
    exec diff ../outputs/t194 ../golden/t194 >/dev/null 2>&1 ;;
  p195) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst261.tst > ../outputs/t195
    exec diff ../outputs/t195 ../golden/t195 >/dev/null 2>&1 ;;
  p196) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst262.tst > ../outputs/t196
    exec diff ../outputs/t196 ../golden/t196 >/dev/null 2>&1 ;;
  p197) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst263.tst > ../outputs/t197
    exec diff ../outputs/t197 ../golden/t197 >/dev/null 2>&1 ;;
  p198) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst264.tst > ../outputs/t198
    exec diff ../outputs/t198 ../golden/t198 >/dev/null 2>&1 ;;
  p199) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst265.tst > ../outputs/t199
    exec diff ../outputs/t199 ../golden/t199 >/dev/null 2>&1 ;;
  p200) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst266.tst > ../outputs/t200
    exec diff ../outputs/t200 ../golden/t200 >/dev/null 2>&1 ;;
  p201) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst267.tst > ../outputs/t201
    exec diff ../outputs/t201 ../golden/t201 >/dev/null 2>&1 ;;
  p202) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst268.tst > ../outputs/t202
    exec diff ../outputs/t202 ../golden/t202 >/dev/null 2>&1 ;;
  p203) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst269.tst > ../outputs/t203
    exec diff ../outputs/t203 ../golden/t203 >/dev/null 2>&1 ;;
  p204) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst27.tst > ../outputs/t204
    exec diff ../outputs/t204 ../golden/t204 >/dev/null 2>&1 ;;
  p205) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst270.tst > ../outputs/t205
    exec diff ../outputs/t205 ../golden/t205 >/dev/null 2>&1 ;;
  p206) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst271.tst > ../outputs/t206
    exec diff ../outputs/t206 ../golden/t206 >/dev/null 2>&1 ;;
  p207) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst272.tst > ../outputs/t207
    exec diff ../outputs/t207 ../golden/t207 >/dev/null 2>&1 ;;
  p208) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst273.tst > ../outputs/t208
    exec diff ../outputs/t208 ../golden/t208 >/dev/null 2>&1 ;;
  p209) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst274.tst > ../outputs/t209
    exec diff ../outputs/t209 ../golden/t209 >/dev/null 2>&1 ;;
  p210) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst275.tst > ../outputs/t210
    exec diff ../outputs/t210 ../golden/t210 >/dev/null 2>&1 ;;
  p211) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst276.tst > ../outputs/t211
    exec diff ../outputs/t211 ../golden/t211 >/dev/null 2>&1 ;;
  p212) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst277.tst > ../outputs/t212
    exec diff ../outputs/t212 ../golden/t212 >/dev/null 2>&1 ;;
  p213) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst278.tst > ../outputs/t213
    exec diff ../outputs/t213 ../golden/t213 >/dev/null 2>&1 ;;
  p214) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst279.tst > ../outputs/t214
    exec diff ../outputs/t214 ../golden/t214 >/dev/null 2>&1 ;;
  p215) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst28.tst > ../outputs/t215
    exec diff ../outputs/t215 ../golden/t215 >/dev/null 2>&1 ;;
  p216) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst280.tst > ../outputs/t216
    exec diff ../outputs/t216 ../golden/t216 >/dev/null 2>&1 ;;
  p217) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst281.tst > ../outputs/t217
    exec diff ../outputs/t217 ../golden/t217 >/dev/null 2>&1 ;;
  p218) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst282.tst > ../outputs/t218
    exec diff ../outputs/t218 ../golden/t218 >/dev/null 2>&1 ;;
  p219) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst283.tst > ../outputs/t219
    exec diff ../outputs/t219 ../golden/t219 >/dev/null 2>&1 ;;
  p220) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst284.tst > ../outputs/t220
    exec diff ../outputs/t220 ../golden/t220 >/dev/null 2>&1 ;;
  p221) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst285.tst > ../outputs/t221
    exec diff ../outputs/t221 ../golden/t221 >/dev/null 2>&1 ;;
  p222) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst286.tst > ../outputs/t222
    exec diff ../outputs/t222 ../golden/t222 >/dev/null 2>&1 ;;
  p223) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst287.tst > ../outputs/t223
    exec diff ../outputs/t223 ../golden/t223 >/dev/null 2>&1 ;;
  p224) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst288.tst > ../outputs/t224
    exec diff ../outputs/t224 ../golden/t224 >/dev/null 2>&1 ;;
  p225) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst289.tst > ../outputs/t225
    exec diff ../outputs/t225 ../golden/t225 >/dev/null 2>&1 ;;
  p226) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst29.tst > ../outputs/t226
    exec diff ../outputs/t226 ../golden/t226 >/dev/null 2>&1 ;;
  p227) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst290.tst > ../outputs/t227
    exec diff ../outputs/t227 ../golden/t227 >/dev/null 2>&1 ;;
  p228) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst291.tst > ../outputs/t228
    exec diff ../outputs/t228 ../golden/t228 >/dev/null 2>&1 ;;
  p229) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst292.tst > ../outputs/t229
    exec diff ../outputs/t229 ../golden/t229 >/dev/null 2>&1 ;;
  p230) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst293.tst > ../outputs/t230
    exec diff ../outputs/t230 ../golden/t230 >/dev/null 2>&1 ;;
  p231) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst294.tst > ../outputs/t231
    exec diff ../outputs/t231 ../golden/t231 >/dev/null 2>&1 ;;
  p232) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst295.tst > ../outputs/t232
    exec diff ../outputs/t232 ../golden/t232 >/dev/null 2>&1 ;;
  p233) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst296.tst > ../outputs/t233
    exec diff ../outputs/t233 ../golden/t233 >/dev/null 2>&1 ;;
  p234) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst297.tst > ../outputs/t234
    exec diff ../outputs/t234 ../golden/t234 >/dev/null 2>&1 ;;
  p235) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst298.tst > ../outputs/t235
    exec diff ../outputs/t235 ../golden/t235 >/dev/null 2>&1 ;;
  p236) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst299.tst > ../outputs/t236
    exec diff ../outputs/t236 ../golden/t236 >/dev/null 2>&1 ;;
  p237) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst3.tst > ../outputs/t237
    exec diff ../outputs/t237 ../golden/t237 >/dev/null 2>&1 ;;
  p238) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst3.tst.tst > ../outputs/t238
    exec diff ../outputs/t238 ../golden/t238 >/dev/null 2>&1 ;;
  p239) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst30.tst > ../outputs/t239
    exec diff ../outputs/t239 ../golden/t239 >/dev/null 2>&1 ;;
  p240) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst300.tst > ../outputs/t240
    exec diff ../outputs/t240 ../golden/t240 >/dev/null 2>&1 ;;
  p241) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst301.tst > ../outputs/t241
    exec diff ../outputs/t241 ../golden/t241 >/dev/null 2>&1 ;;
  p242) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst302.tst > ../outputs/t242
    exec diff ../outputs/t242 ../golden/t242 >/dev/null 2>&1 ;;
  p243) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst303.tst > ../outputs/t243
    exec diff ../outputs/t243 ../golden/t243 >/dev/null 2>&1 ;;
  p244) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst304.tst > ../outputs/t244
    exec diff ../outputs/t244 ../golden/t244 >/dev/null 2>&1 ;;
  p245) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst305.tst > ../outputs/t245
    exec diff ../outputs/t245 ../golden/t245 >/dev/null 2>&1 ;;
  p246) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst306.tst > ../outputs/t246
    exec diff ../outputs/t246 ../golden/t246 >/dev/null 2>&1 ;;
  p247) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst307.tst > ../outputs/t247
    exec diff ../outputs/t247 ../golden/t247 >/dev/null 2>&1 ;;
  p248) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst308.tst > ../outputs/t248
    exec diff ../outputs/t248 ../golden/t248 >/dev/null 2>&1 ;;
  p249) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst309.tst > ../outputs/t249
    exec diff ../outputs/t249 ../golden/t249 >/dev/null 2>&1 ;;
  p250) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst31.tst > ../outputs/t250
    exec diff ../outputs/t250 ../golden/t250 >/dev/null 2>&1 ;;
  p251) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst31.tst.tst > ../outputs/t251
    exec diff ../outputs/t251 ../golden/t251 >/dev/null 2>&1 ;;
  p252) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst310.tst > ../outputs/t252
    exec diff ../outputs/t252 ../golden/t252 >/dev/null 2>&1 ;;
  p253) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst311.tst > ../outputs/t253
    exec diff ../outputs/t253 ../golden/t253 >/dev/null 2>&1 ;;
  p254) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst312.tst > ../outputs/t254
    exec diff ../outputs/t254 ../golden/t254 >/dev/null 2>&1 ;;
  p255) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst313.tst > ../outputs/t255
    exec diff ../outputs/t255 ../golden/t255 >/dev/null 2>&1 ;;
  p256) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst314.tst > ../outputs/t256
    exec diff ../outputs/t256 ../golden/t256 >/dev/null 2>&1 ;;
  p257) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst315.tst > ../outputs/t257
    exec diff ../outputs/t257 ../golden/t257 >/dev/null 2>&1 ;;
  p258) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst316.tst > ../outputs/t258
    exec diff ../outputs/t258 ../golden/t258 >/dev/null 2>&1 ;;
  p259) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst317.tst > ../outputs/t259
    exec diff ../outputs/t259 ../golden/t259 >/dev/null 2>&1 ;;
  p260) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst318.tst > ../outputs/t260
    exec diff ../outputs/t260 ../golden/t260 >/dev/null 2>&1 ;;
  p261) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst319.tst > ../outputs/t261
    exec diff ../outputs/t261 ../golden/t261 >/dev/null 2>&1 ;;
  p262) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst32.tst > ../outputs/t262
    exec diff ../outputs/t262 ../golden/t262 >/dev/null 2>&1 ;;
  p263) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst320.tst > ../outputs/t263
    exec diff ../outputs/t263 ../golden/t263 >/dev/null 2>&1 ;;
  p264) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst321.tst > ../outputs/t264
    exec diff ../outputs/t264 ../golden/t264 >/dev/null 2>&1 ;;
  p265) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst322.tst > ../outputs/t265
    exec diff ../outputs/t265 ../golden/t265 >/dev/null 2>&1 ;;
  p266) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst323.tst > ../outputs/t266
    exec diff ../outputs/t266 ../golden/t266 >/dev/null 2>&1 ;;
  p267) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst324.tst > ../outputs/t267
    exec diff ../outputs/t267 ../golden/t267 >/dev/null 2>&1 ;;
  p268) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst325.tst > ../outputs/t268
    exec diff ../outputs/t268 ../golden/t268 >/dev/null 2>&1 ;;
  p269) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst326.tst > ../outputs/t269
    exec diff ../outputs/t269 ../golden/t269 >/dev/null 2>&1 ;;
  p270) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst327.tst > ../outputs/t270
    exec diff ../outputs/t270 ../golden/t270 >/dev/null 2>&1 ;;
  p271) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst328.tst > ../outputs/t271
    exec diff ../outputs/t271 ../golden/t271 >/dev/null 2>&1 ;;
  p272) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst329.tst > ../outputs/t272
    exec diff ../outputs/t272 ../golden/t272 >/dev/null 2>&1 ;;
  p273) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst33.tst > ../outputs/t273
    exec diff ../outputs/t273 ../golden/t273 >/dev/null 2>&1 ;;
  p274) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst330.tst > ../outputs/t274
    exec diff ../outputs/t274 ../golden/t274 >/dev/null 2>&1 ;;
  p275) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst331.tst > ../outputs/t275
    exec diff ../outputs/t275 ../golden/t275 >/dev/null 2>&1 ;;
  p276) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst332.tst > ../outputs/t276
    exec diff ../outputs/t276 ../golden/t276 >/dev/null 2>&1 ;;
  p277) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst333.tst > ../outputs/t277
    exec diff ../outputs/t277 ../golden/t277 >/dev/null 2>&1 ;;
  p278) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst334.tst > ../outputs/t278
    exec diff ../outputs/t278 ../golden/t278 >/dev/null 2>&1 ;;
  p279) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst335.tst > ../outputs/t279
    exec diff ../outputs/t279 ../golden/t279 >/dev/null 2>&1 ;;
  p280) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst336.tst > ../outputs/t280
    exec diff ../outputs/t280 ../golden/t280 >/dev/null 2>&1 ;;
  p281) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst337.tst > ../outputs/t281
    exec diff ../outputs/t281 ../golden/t281 >/dev/null 2>&1 ;;
  p282) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst338.tst > ../outputs/t282
    exec diff ../outputs/t282 ../golden/t282 >/dev/null 2>&1 ;;
  p283) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst339.tst > ../outputs/t283
    exec diff ../outputs/t283 ../golden/t283 >/dev/null 2>&1 ;;
  p284) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst34.tst > ../outputs/t284
    exec diff ../outputs/t284 ../golden/t284 >/dev/null 2>&1 ;;
  p285) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst340.tst > ../outputs/t285
    exec diff ../outputs/t285 ../golden/t285 >/dev/null 2>&1 ;;
  p286) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst341.tst > ../outputs/t286
    exec diff ../outputs/t286 ../golden/t286 >/dev/null 2>&1 ;;
  p287) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst342.tst > ../outputs/t287
    exec diff ../outputs/t287 ../golden/t287 >/dev/null 2>&1 ;;
  p288) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst343.tst > ../outputs/t288
    exec diff ../outputs/t288 ../golden/t288 >/dev/null 2>&1 ;;
  p289) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst344.tst > ../outputs/t289
    exec diff ../outputs/t289 ../golden/t289 >/dev/null 2>&1 ;;
  p290) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst345.tst > ../outputs/t290
    exec diff ../outputs/t290 ../golden/t290 >/dev/null 2>&1 ;;
  p291) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst346.tst > ../outputs/t291
    exec diff ../outputs/t291 ../golden/t291 >/dev/null 2>&1 ;;
  p292) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst347.tst > ../outputs/t292
    exec diff ../outputs/t292 ../golden/t292 >/dev/null 2>&1 ;;
  p293) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst348.tst > ../outputs/t293
    exec diff ../outputs/t293 ../golden/t293 >/dev/null 2>&1 ;;
  p294) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst349.tst > ../outputs/t294
    exec diff ../outputs/t294 ../golden/t294 >/dev/null 2>&1 ;;
  p295) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst35.tst > ../outputs/t295
    exec diff ../outputs/t295 ../golden/t295 >/dev/null 2>&1 ;;
  p296) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst350.tst > ../outputs/t296
    exec diff ../outputs/t296 ../golden/t296 >/dev/null 2>&1 ;;
  p297) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst352.tst > ../outputs/t297
    exec diff ../outputs/t297 ../golden/t297 >/dev/null 2>&1 ;;
  p298) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst353.tst > ../outputs/t298
    exec diff ../outputs/t298 ../golden/t298 >/dev/null 2>&1 ;;
  p299) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst354.tst > ../outputs/t299
    exec diff ../outputs/t299 ../golden/t299 >/dev/null 2>&1 ;;
  p300) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst355.tst > ../outputs/t300
    exec diff ../outputs/t300 ../golden/t300 >/dev/null 2>&1 ;;
  p301) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst356.tst > ../outputs/t301
    exec diff ../outputs/t301 ../golden/t301 >/dev/null 2>&1 ;;
  p302) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst357.tst > ../outputs/t302
    exec diff ../outputs/t302 ../golden/t302 >/dev/null 2>&1 ;;
  p303) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst358.tst > ../outputs/t303
    exec diff ../outputs/t303 ../golden/t303 >/dev/null 2>&1 ;;
  p304) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst359.tst > ../outputs/t304
    exec diff ../outputs/t304 ../golden/t304 >/dev/null 2>&1 ;;
  p305) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst36.tst > ../outputs/t305
    exec diff ../outputs/t305 ../golden/t305 >/dev/null 2>&1 ;;
  p306) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst360.tst > ../outputs/t306
    exec diff ../outputs/t306 ../golden/t306 >/dev/null 2>&1 ;;
  p307) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst361.tst > ../outputs/t307
    exec diff ../outputs/t307 ../golden/t307 >/dev/null 2>&1 ;;
  p308) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst362.tst > ../outputs/t308
    exec diff ../outputs/t308 ../golden/t308 >/dev/null 2>&1 ;;
  p309) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst363.tst > ../outputs/t309
    exec diff ../outputs/t309 ../golden/t309 >/dev/null 2>&1 ;;
  p310) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst364.tst > ../outputs/t310
    exec diff ../outputs/t310 ../golden/t310 >/dev/null 2>&1 ;;
  p311) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst365.tst > ../outputs/t311
    exec diff ../outputs/t311 ../golden/t311 >/dev/null 2>&1 ;;
  p312) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst366.tst > ../outputs/t312
    exec diff ../outputs/t312 ../golden/t312 >/dev/null 2>&1 ;;
  p313) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst367.tst > ../outputs/t313
    exec diff ../outputs/t313 ../golden/t313 >/dev/null 2>&1 ;;
  p314) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst368.tst > ../outputs/t314
    exec diff ../outputs/t314 ../golden/t314 >/dev/null 2>&1 ;;
  p315) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst369.tst > ../outputs/t315
    exec diff ../outputs/t315 ../golden/t315 >/dev/null 2>&1 ;;
  p316) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst37.tst > ../outputs/t316
    exec diff ../outputs/t316 ../golden/t316 >/dev/null 2>&1 ;;
  p317) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst370.tst > ../outputs/t317
    exec diff ../outputs/t317 ../golden/t317 >/dev/null 2>&1 ;;
  p318) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst371.tst > ../outputs/t318
    exec diff ../outputs/t318 ../golden/t318 >/dev/null 2>&1 ;;
  p319) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst372.tst > ../outputs/t319
    exec diff ../outputs/t319 ../golden/t319 >/dev/null 2>&1 ;;
  p320) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst373.tst > ../outputs/t320
    exec diff ../outputs/t320 ../golden/t320 >/dev/null 2>&1 ;;
  p321) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst374.tst > ../outputs/t321
    exec diff ../outputs/t321 ../golden/t321 >/dev/null 2>&1 ;;
  p322) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst375.tst > ../outputs/t322
    exec diff ../outputs/t322 ../golden/t322 >/dev/null 2>&1 ;;
  p323) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst376.tst > ../outputs/t323
    exec diff ../outputs/t323 ../golden/t323 >/dev/null 2>&1 ;;
  p324) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst377.tst > ../outputs/t324
    exec diff ../outputs/t324 ../golden/t324 >/dev/null 2>&1 ;;
  p325) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst378.tst > ../outputs/t325
    exec diff ../outputs/t325 ../golden/t325 >/dev/null 2>&1 ;;
  p326) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst379.tst > ../outputs/t326
    exec diff ../outputs/t326 ../golden/t326 >/dev/null 2>&1 ;;
  p327) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst38.tst > ../outputs/t327
    exec diff ../outputs/t327 ../golden/t327 >/dev/null 2>&1 ;;
  p328) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst380.tst > ../outputs/t328
    exec diff ../outputs/t328 ../golden/t328 >/dev/null 2>&1 ;;
  p329) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst381.tst > ../outputs/t329
    exec diff ../outputs/t329 ../golden/t329 >/dev/null 2>&1 ;;
  p330) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst382.tst > ../outputs/t330
    exec diff ../outputs/t330 ../golden/t330 >/dev/null 2>&1 ;;
  p331) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst383.tst > ../outputs/t331
    exec diff ../outputs/t331 ../golden/t331 >/dev/null 2>&1 ;;
  p332) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst384.tst > ../outputs/t332
    exec diff ../outputs/t332 ../golden/t332 >/dev/null 2>&1 ;;
  p333) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst385.tst > ../outputs/t333
    exec diff ../outputs/t333 ../golden/t333 >/dev/null 2>&1 ;;
  p334) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst386.tst > ../outputs/t334
    exec diff ../outputs/t334 ../golden/t334 >/dev/null 2>&1 ;;
  p335) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst387.tst > ../outputs/t335
    exec diff ../outputs/t335 ../golden/t335 >/dev/null 2>&1 ;;
  p336) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst388.tst > ../outputs/t336
    exec diff ../outputs/t336 ../golden/t336 >/dev/null 2>&1 ;;
  p337) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst389.tst > ../outputs/t337
    exec diff ../outputs/t337 ../golden/t337 >/dev/null 2>&1 ;;
  p338) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst39.tst > ../outputs/t338
    exec diff ../outputs/t338 ../golden/t338 >/dev/null 2>&1 ;;
  p339) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst390.tst > ../outputs/t339
    exec diff ../outputs/t339 ../golden/t339 >/dev/null 2>&1 ;;
  p340) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst391.tst > ../outputs/t340
    exec diff ../outputs/t340 ../golden/t340 >/dev/null 2>&1 ;;
  p341) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst392.tst > ../outputs/t341
    exec diff ../outputs/t341 ../golden/t341 >/dev/null 2>&1 ;;
  p342) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst393.tst > ../outputs/t342
    exec diff ../outputs/t342 ../golden/t342 >/dev/null 2>&1 ;;
  p343) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst394.tst > ../outputs/t343
    exec diff ../outputs/t343 ../golden/t343 >/dev/null 2>&1 ;;
  p344) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst395.tst > ../outputs/t344
    exec diff ../outputs/t344 ../golden/t344 >/dev/null 2>&1 ;;
  p345) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst396.tst > ../outputs/t345
    exec diff ../outputs/t345 ../golden/t345 >/dev/null 2>&1 ;;
  p346) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst397.tst > ../outputs/t346
    exec diff ../outputs/t346 ../golden/t346 >/dev/null 2>&1 ;;
  p347) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst398.tst > ../outputs/t347
    exec diff ../outputs/t347 ../golden/t347 >/dev/null 2>&1 ;;
  p348) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst399.tst > ../outputs/t348
    exec diff ../outputs/t348 ../golden/t348 >/dev/null 2>&1 ;;
  p349) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst4.tst > ../outputs/t349
    exec diff ../outputs/t349 ../golden/t349 >/dev/null 2>&1 ;;
  p350) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst4.tst.tst > ../outputs/t350
    exec diff ../outputs/t350 ../golden/t350 >/dev/null 2>&1 ;;
  p351) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst40.tst > ../outputs/t351
    exec diff ../outputs/t351 ../golden/t351 >/dev/null 2>&1 ;;
  p352) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst400.tst > ../outputs/t352
    exec diff ../outputs/t352 ../golden/t352 >/dev/null 2>&1 ;;
  p353) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst401.tst > ../outputs/t353
    exec diff ../outputs/t353 ../golden/t353 >/dev/null 2>&1 ;;
  p354) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst402.tst > ../outputs/t354
    exec diff ../outputs/t354 ../golden/t354 >/dev/null 2>&1 ;;
  p355) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst403.tst > ../outputs/t355
    exec diff ../outputs/t355 ../golden/t355 >/dev/null 2>&1 ;;
  p356) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst404.tst > ../outputs/t356
    exec diff ../outputs/t356 ../golden/t356 >/dev/null 2>&1 ;;
  p357) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst405.tst > ../outputs/t357
    exec diff ../outputs/t357 ../golden/t357 >/dev/null 2>&1 ;;
  p358) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst406.tst > ../outputs/t358
    exec diff ../outputs/t358 ../golden/t358 >/dev/null 2>&1 ;;
  p359) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst407.tst > ../outputs/t359
    exec diff ../outputs/t359 ../golden/t359 >/dev/null 2>&1 ;;
  p360) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst408.tst > ../outputs/t360
    exec diff ../outputs/t360 ../golden/t360 >/dev/null 2>&1 ;;
  p361) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst409.tst > ../outputs/t361
    exec diff ../outputs/t361 ../golden/t361 >/dev/null 2>&1 ;;
  p362) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst41.tst > ../outputs/t362
    exec diff ../outputs/t362 ../golden/t362 >/dev/null 2>&1 ;;
  p363) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst410.tst > ../outputs/t363
    exec diff ../outputs/t363 ../golden/t363 >/dev/null 2>&1 ;;
  p364) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst411.tst > ../outputs/t364
    exec diff ../outputs/t364 ../golden/t364 >/dev/null 2>&1 ;;
  p365) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst412.tst > ../outputs/t365
    exec diff ../outputs/t365 ../golden/t365 >/dev/null 2>&1 ;;
  p366) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst413.tst > ../outputs/t366
    exec diff ../outputs/t366 ../golden/t366 >/dev/null 2>&1 ;;
  p367) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst414.tst > ../outputs/t367
    exec diff ../outputs/t367 ../golden/t367 >/dev/null 2>&1 ;;
  p368) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst415.tst > ../outputs/t368
    exec diff ../outputs/t368 ../golden/t368 >/dev/null 2>&1 ;;
  p369) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst416.tst > ../outputs/t369
    exec diff ../outputs/t369 ../golden/t369 >/dev/null 2>&1 ;;
  p370) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst417.tst > ../outputs/t370
    exec diff ../outputs/t370 ../golden/t370 >/dev/null 2>&1 ;;
  p371) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst418.tst > ../outputs/t371
    exec diff ../outputs/t371 ../golden/t371 >/dev/null 2>&1 ;;
  p372) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst419.tst > ../outputs/t372
    exec diff ../outputs/t372 ../golden/t372 >/dev/null 2>&1 ;;
  p373) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst42.tst > ../outputs/t373
    exec diff ../outputs/t373 ../golden/t373 >/dev/null 2>&1 ;;
  p374) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst420.tst > ../outputs/t374
    exec diff ../outputs/t374 ../golden/t374 >/dev/null 2>&1 ;;
  p375) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst421.tst > ../outputs/t375
    exec diff ../outputs/t375 ../golden/t375 >/dev/null 2>&1 ;;
  p376) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst422.tst > ../outputs/t376
    exec diff ../outputs/t376 ../golden/t376 >/dev/null 2>&1 ;;
  p377) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst423.tst > ../outputs/t377
    exec diff ../outputs/t377 ../golden/t377 >/dev/null 2>&1 ;;
  p378) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst424.tst > ../outputs/t378
    exec diff ../outputs/t378 ../golden/t378 >/dev/null 2>&1 ;;
  p379) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst425.tst > ../outputs/t379
    exec diff ../outputs/t379 ../golden/t379 >/dev/null 2>&1 ;;
  p380) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst426.tst > ../outputs/t380
    exec diff ../outputs/t380 ../golden/t380 >/dev/null 2>&1 ;;
  p381) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst427.tst > ../outputs/t381
    exec diff ../outputs/t381 ../golden/t381 >/dev/null 2>&1 ;;
  p382) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst428.tst > ../outputs/t382
    exec diff ../outputs/t382 ../golden/t382 >/dev/null 2>&1 ;;
  p383) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst429.tst > ../outputs/t383
    exec diff ../outputs/t383 ../golden/t383 >/dev/null 2>&1 ;;
  p384) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst43.tst > ../outputs/t384
    exec diff ../outputs/t384 ../golden/t384 >/dev/null 2>&1 ;;
  p385) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst430.tst > ../outputs/t385
    exec diff ../outputs/t385 ../golden/t385 >/dev/null 2>&1 ;;
  p386) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst431.tst > ../outputs/t386
    exec diff ../outputs/t386 ../golden/t386 >/dev/null 2>&1 ;;
  p387) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst432.tst > ../outputs/t387
    exec diff ../outputs/t387 ../golden/t387 >/dev/null 2>&1 ;;
  p388) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst433.tst > ../outputs/t388
    exec diff ../outputs/t388 ../golden/t388 >/dev/null 2>&1 ;;
  p389) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst434.tst > ../outputs/t389
    exec diff ../outputs/t389 ../golden/t389 >/dev/null 2>&1 ;;
  p390) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst435.tst > ../outputs/t390
    exec diff ../outputs/t390 ../golden/t390 >/dev/null 2>&1 ;;
  p391) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst436.tst > ../outputs/t391
    exec diff ../outputs/t391 ../golden/t391 >/dev/null 2>&1 ;;
  p392) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst437.tst > ../outputs/t392
    exec diff ../outputs/t392 ../golden/t392 >/dev/null 2>&1 ;;
  p393) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst438.tst > ../outputs/t393
    exec diff ../outputs/t393 ../golden/t393 >/dev/null 2>&1 ;;
  p394) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst439.tst > ../outputs/t394
    exec diff ../outputs/t394 ../golden/t394 >/dev/null 2>&1 ;;
  p395) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst44.tst > ../outputs/t395
    exec diff ../outputs/t395 ../golden/t395 >/dev/null 2>&1 ;;
  p396) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst440.tst > ../outputs/t396
    exec diff ../outputs/t396 ../golden/t396 >/dev/null 2>&1 ;;
  p397) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst441.tst > ../outputs/t397
    exec diff ../outputs/t397 ../golden/t397 >/dev/null 2>&1 ;;
  p398) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst442.tst > ../outputs/t398
    exec diff ../outputs/t398 ../golden/t398 >/dev/null 2>&1 ;;
  p399) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst443.tst > ../outputs/t399
    exec diff ../outputs/t399 ../golden/t399 >/dev/null 2>&1 ;;
  p400) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst444.tst > ../outputs/t400
    exec diff ../outputs/t400 ../golden/t400 >/dev/null 2>&1 ;;
  p401) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst445.tst > ../outputs/t401
    exec diff ../outputs/t401 ../golden/t401 >/dev/null 2>&1 ;;
  p402) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst446.tst > ../outputs/t402
    exec diff ../outputs/t402 ../golden/t402 >/dev/null 2>&1 ;;
  p403) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst447.tst > ../outputs/t403
    exec diff ../outputs/t403 ../golden/t403 >/dev/null 2>&1 ;;
  p404) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst448.tst > ../outputs/t404
    exec diff ../outputs/t404 ../golden/t404 >/dev/null 2>&1 ;;
  p405) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst449.tst > ../outputs/t405
    exec diff ../outputs/t405 ../golden/t405 >/dev/null 2>&1 ;;
  p406) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst45.tst > ../outputs/t406
    exec diff ../outputs/t406 ../golden/t406 >/dev/null 2>&1 ;;
  p407) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst450.tst > ../outputs/t407
    exec diff ../outputs/t407 ../golden/t407 >/dev/null 2>&1 ;;
  p408) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst451.tst > ../outputs/t408
    exec diff ../outputs/t408 ../golden/t408 >/dev/null 2>&1 ;;
  p409) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst452.tst > ../outputs/t409
    exec diff ../outputs/t409 ../golden/t409 >/dev/null 2>&1 ;;
  p410) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst453.tst > ../outputs/t410
    exec diff ../outputs/t410 ../golden/t410 >/dev/null 2>&1 ;;
  p411) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst454.tst > ../outputs/t411
    exec diff ../outputs/t411 ../golden/t411 >/dev/null 2>&1 ;;
  p412) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst455.tst > ../outputs/t412
    exec diff ../outputs/t412 ../golden/t412 >/dev/null 2>&1 ;;
  p413) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst456.tst > ../outputs/t413
    exec diff ../outputs/t413 ../golden/t413 >/dev/null 2>&1 ;;
  p414) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst457.tst > ../outputs/t414
    exec diff ../outputs/t414 ../golden/t414 >/dev/null 2>&1 ;;
  p415) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst458.tst > ../outputs/t415
    exec diff ../outputs/t415 ../golden/t415 >/dev/null 2>&1 ;;
  p416) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst459.tst > ../outputs/t416
    exec diff ../outputs/t416 ../golden/t416 >/dev/null 2>&1 ;;
  p417) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst46.tst > ../outputs/t417
    exec diff ../outputs/t417 ../golden/t417 >/dev/null 2>&1 ;;
  p418) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst460.tst > ../outputs/t418
    exec diff ../outputs/t418 ../golden/t418 >/dev/null 2>&1 ;;
  p419) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst461.tst > ../outputs/t419
    exec diff ../outputs/t419 ../golden/t419 >/dev/null 2>&1 ;;
  p420) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst462.tst > ../outputs/t420
    exec diff ../outputs/t420 ../golden/t420 >/dev/null 2>&1 ;;
  p421) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst463.tst > ../outputs/t421
    exec diff ../outputs/t421 ../golden/t421 >/dev/null 2>&1 ;;
  p422) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst464.tst > ../outputs/t422
    exec diff ../outputs/t422 ../golden/t422 >/dev/null 2>&1 ;;
  p423) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst465.tst > ../outputs/t423
    exec diff ../outputs/t423 ../golden/t423 >/dev/null 2>&1 ;;
  p424) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst466.tst > ../outputs/t424
    exec diff ../outputs/t424 ../golden/t424 >/dev/null 2>&1 ;;
  p425) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst467.tst > ../outputs/t425
    exec diff ../outputs/t425 ../golden/t425 >/dev/null 2>&1 ;;
  p426) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst468.tst > ../outputs/t426
    exec diff ../outputs/t426 ../golden/t426 >/dev/null 2>&1 ;;
  p427) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst469.tst > ../outputs/t427
    exec diff ../outputs/t427 ../golden/t427 >/dev/null 2>&1 ;;
  p428) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst47.tst > ../outputs/t428
    exec diff ../outputs/t428 ../golden/t428 >/dev/null 2>&1 ;;
  p429) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst470.tst > ../outputs/t429
    exec diff ../outputs/t429 ../golden/t429 >/dev/null 2>&1 ;;
  p430) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst471.tst > ../outputs/t430
    exec diff ../outputs/t430 ../golden/t430 >/dev/null 2>&1 ;;
  p431) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst472.tst > ../outputs/t431
    exec diff ../outputs/t431 ../golden/t431 >/dev/null 2>&1 ;;
  p432) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst473.tst > ../outputs/t432
    exec diff ../outputs/t432 ../golden/t432 >/dev/null 2>&1 ;;
  p433) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst474.tst > ../outputs/t433
    exec diff ../outputs/t433 ../golden/t433 >/dev/null 2>&1 ;;
  p434) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst475.tst > ../outputs/t434
    exec diff ../outputs/t434 ../golden/t434 >/dev/null 2>&1 ;;
  p435) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst476.tst > ../outputs/t435
    exec diff ../outputs/t435 ../golden/t435 >/dev/null 2>&1 ;;
  p436) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst477.tst > ../outputs/t436
    exec diff ../outputs/t436 ../golden/t436 >/dev/null 2>&1 ;;
  p437) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst478.tst > ../outputs/t437
    exec diff ../outputs/t437 ../golden/t437 >/dev/null 2>&1 ;;
  p438) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst479.tst > ../outputs/t438
    exec diff ../outputs/t438 ../golden/t438 >/dev/null 2>&1 ;;
  p439) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst48.tst > ../outputs/t439
    exec diff ../outputs/t439 ../golden/t439 >/dev/null 2>&1 ;;
  p440) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst480.tst > ../outputs/t440
    exec diff ../outputs/t440 ../golden/t440 >/dev/null 2>&1 ;;
  p441) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst481.tst > ../outputs/t441
    exec diff ../outputs/t441 ../golden/t441 >/dev/null 2>&1 ;;
  p442) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst482.tst > ../outputs/t442
    exec diff ../outputs/t442 ../golden/t442 >/dev/null 2>&1 ;;
  p443) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst483.tst > ../outputs/t443
    exec diff ../outputs/t443 ../golden/t443 >/dev/null 2>&1 ;;
  p444) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst484.tst > ../outputs/t444
    exec diff ../outputs/t444 ../golden/t444 >/dev/null 2>&1 ;;
  p445) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst485.tst > ../outputs/t445
    exec diff ../outputs/t445 ../golden/t445 >/dev/null 2>&1 ;;
  p446) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst486.tst > ../outputs/t446
    exec diff ../outputs/t446 ../golden/t446 >/dev/null 2>&1 ;;
  p447) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst487.tst > ../outputs/t447
    exec diff ../outputs/t447 ../golden/t447 >/dev/null 2>&1 ;;
  p448) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst488.tst > ../outputs/t448
    exec diff ../outputs/t448 ../golden/t448 >/dev/null 2>&1 ;;
  p449) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst489.tst > ../outputs/t449
    exec diff ../outputs/t449 ../golden/t449 >/dev/null 2>&1 ;;
  p450) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst49.tst > ../outputs/t450
    exec diff ../outputs/t450 ../golden/t450 >/dev/null 2>&1 ;;
  p451) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst490.tst > ../outputs/t451
    exec diff ../outputs/t451 ../golden/t451 >/dev/null 2>&1 ;;
  p452) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst491.tst > ../outputs/t452
    exec diff ../outputs/t452 ../golden/t452 >/dev/null 2>&1 ;;
  p453) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst492.tst > ../outputs/t453
    exec diff ../outputs/t453 ../golden/t453 >/dev/null 2>&1 ;;
  p454) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst493.tst > ../outputs/t454
    exec diff ../outputs/t454 ../golden/t454 >/dev/null 2>&1 ;;
  p455) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst494.tst > ../outputs/t455
    exec diff ../outputs/t455 ../golden/t455 >/dev/null 2>&1 ;;
  p456) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst495.tst > ../outputs/t456
    exec diff ../outputs/t456 ../golden/t456 >/dev/null 2>&1 ;;
  p457) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst496.tst > ../outputs/t457
    exec diff ../outputs/t457 ../golden/t457 >/dev/null 2>&1 ;;
  p458) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst497.tst > ../outputs/t458
    exec diff ../outputs/t458 ../golden/t458 >/dev/null 2>&1 ;;
  p459) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst498.tst > ../outputs/t459
    exec diff ../outputs/t459 ../golden/t459 >/dev/null 2>&1 ;;
  p460) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst499.tst > ../outputs/t460
    exec diff ../outputs/t460 ../golden/t460 >/dev/null 2>&1 ;;
  p461) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst5.tst > ../outputs/t461
    exec diff ../outputs/t461 ../golden/t461 >/dev/null 2>&1 ;;
  p462) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst5.tst.tst > ../outputs/t462
    exec diff ../outputs/t462 ../golden/t462 >/dev/null 2>&1 ;;
  p463) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst50.tst > ../outputs/t463
    exec diff ../outputs/t463 ../golden/t463 >/dev/null 2>&1 ;;
  p464) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst500.tst > ../outputs/t464
    exec diff ../outputs/t464 ../golden/t464 >/dev/null 2>&1 ;;
  p465) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst501.tst > ../outputs/t465
    exec diff ../outputs/t465 ../golden/t465 >/dev/null 2>&1 ;;
  p466) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst502.tst > ../outputs/t466
    exec diff ../outputs/t466 ../golden/t466 >/dev/null 2>&1 ;;
  p467) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst503.tst > ../outputs/t467
    exec diff ../outputs/t467 ../golden/t467 >/dev/null 2>&1 ;;
  p468) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst504.tst > ../outputs/t468
    exec diff ../outputs/t468 ../golden/t468 >/dev/null 2>&1 ;;
  p469) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst505.tst > ../outputs/t469
    exec diff ../outputs/t469 ../golden/t469 >/dev/null 2>&1 ;;
  p470) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst506.tst > ../outputs/t470
    exec diff ../outputs/t470 ../golden/t470 >/dev/null 2>&1 ;;
  p471) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst507.tst > ../outputs/t471
    exec diff ../outputs/t471 ../golden/t471 >/dev/null 2>&1 ;;
  p472) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst508.tst > ../outputs/t472
    exec diff ../outputs/t472 ../golden/t472 >/dev/null 2>&1 ;;
  p473) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst509.tst > ../outputs/t473
    exec diff ../outputs/t473 ../golden/t473 >/dev/null 2>&1 ;;
  p474) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst51.tst > ../outputs/t474
    exec diff ../outputs/t474 ../golden/t474 >/dev/null 2>&1 ;;
  p475) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst510.tst > ../outputs/t475
    exec diff ../outputs/t475 ../golden/t475 >/dev/null 2>&1 ;;
  p476) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst511.tst > ../outputs/t476
    exec diff ../outputs/t476 ../golden/t476 >/dev/null 2>&1 ;;
  p477) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst512.tst > ../outputs/t477
    exec diff ../outputs/t477 ../golden/t477 >/dev/null 2>&1 ;;
  p478) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst513.tst > ../outputs/t478
    exec diff ../outputs/t478 ../golden/t478 >/dev/null 2>&1 ;;
  p479) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst514.tst > ../outputs/t479
    exec diff ../outputs/t479 ../golden/t479 >/dev/null 2>&1 ;;
  p480) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst515.tst > ../outputs/t480
    exec diff ../outputs/t480 ../golden/t480 >/dev/null 2>&1 ;;
  p481) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst516.tst > ../outputs/t481
    exec diff ../outputs/t481 ../golden/t481 >/dev/null 2>&1 ;;
  p482) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst517.tst > ../outputs/t482
    exec diff ../outputs/t482 ../golden/t482 >/dev/null 2>&1 ;;
  p483) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst518.tst > ../outputs/t483
    exec diff ../outputs/t483 ../golden/t483 >/dev/null 2>&1 ;;
  p484) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst519.tst > ../outputs/t484
    exec diff ../outputs/t484 ../golden/t484 >/dev/null 2>&1 ;;
  p485) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst52.tst > ../outputs/t485
    exec diff ../outputs/t485 ../golden/t485 >/dev/null 2>&1 ;;
  p486) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst520.tst > ../outputs/t486
    exec diff ../outputs/t486 ../golden/t486 >/dev/null 2>&1 ;;
  p487) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst521.tst > ../outputs/t487
    exec diff ../outputs/t487 ../golden/t487 >/dev/null 2>&1 ;;
  p488) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst522.tst > ../outputs/t488
    exec diff ../outputs/t488 ../golden/t488 >/dev/null 2>&1 ;;
  p489) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst523.tst > ../outputs/t489
    exec diff ../outputs/t489 ../golden/t489 >/dev/null 2>&1 ;;
  p490) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst524.tst > ../outputs/t490
    exec diff ../outputs/t490 ../golden/t490 >/dev/null 2>&1 ;;
  p491) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst525.tst > ../outputs/t491
    exec diff ../outputs/t491 ../golden/t491 >/dev/null 2>&1 ;;
  p492) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst526.tst > ../outputs/t492
    exec diff ../outputs/t492 ../golden/t492 >/dev/null 2>&1 ;;
  p493) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst527.tst > ../outputs/t493
    exec diff ../outputs/t493 ../golden/t493 >/dev/null 2>&1 ;;
  p494) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst528.tst > ../outputs/t494
    exec diff ../outputs/t494 ../golden/t494 >/dev/null 2>&1 ;;
  p495) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst529.tst > ../outputs/t495
    exec diff ../outputs/t495 ../golden/t495 >/dev/null 2>&1 ;;
  p496) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst53.tst > ../outputs/t496
    exec diff ../outputs/t496 ../golden/t496 >/dev/null 2>&1 ;;
  p497) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst530.tst > ../outputs/t497
    exec diff ../outputs/t497 ../golden/t497 >/dev/null 2>&1 ;;
  p498) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst531.tst > ../outputs/t498
    exec diff ../outputs/t498 ../golden/t498 >/dev/null 2>&1 ;;
  p499) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst532.tst > ../outputs/t499
    exec diff ../outputs/t499 ../golden/t499 >/dev/null 2>&1 ;;
  p500) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst533.tst > ../outputs/t500
    exec diff ../outputs/t500 ../golden/t500 >/dev/null 2>&1 ;;
  p501) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst534.tst > ../outputs/t501
    exec diff ../outputs/t501 ../golden/t501 >/dev/null 2>&1 ;;
  p502) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst535.tst > ../outputs/t502
    exec diff ../outputs/t502 ../golden/t502 >/dev/null 2>&1 ;;
  p503) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst536.tst > ../outputs/t503
    exec diff ../outputs/t503 ../golden/t503 >/dev/null 2>&1 ;;
  p504) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst537.tst > ../outputs/t504
    exec diff ../outputs/t504 ../golden/t504 >/dev/null 2>&1 ;;
  p505) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst538.tst > ../outputs/t505
    exec diff ../outputs/t505 ../golden/t505 >/dev/null 2>&1 ;;
  p506) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst539.tst > ../outputs/t506
    exec diff ../outputs/t506 ../golden/t506 >/dev/null 2>&1 ;;
  p507) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst54.tst > ../outputs/t507
    exec diff ../outputs/t507 ../golden/t507 >/dev/null 2>&1 ;;
  p508) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst540.tst > ../outputs/t508
    exec diff ../outputs/t508 ../golden/t508 >/dev/null 2>&1 ;;
  p509) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst541.tst > ../outputs/t509
    exec diff ../outputs/t509 ../golden/t509 >/dev/null 2>&1 ;;
  p510) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst542.tst > ../outputs/t510
    exec diff ../outputs/t510 ../golden/t510 >/dev/null 2>&1 ;;
  p511) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst543.tst > ../outputs/t511
    exec diff ../outputs/t511 ../golden/t511 >/dev/null 2>&1 ;;
  p512) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst544.tst > ../outputs/t512
    exec diff ../outputs/t512 ../golden/t512 >/dev/null 2>&1 ;;
  p513) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst545.tst > ../outputs/t513
    exec diff ../outputs/t513 ../golden/t513 >/dev/null 2>&1 ;;
  p514) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst546.tst > ../outputs/t514
    exec diff ../outputs/t514 ../golden/t514 >/dev/null 2>&1 ;;
  p515) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst547.tst > ../outputs/t515
    exec diff ../outputs/t515 ../golden/t515 >/dev/null 2>&1 ;;
  p516) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst548.tst > ../outputs/t516
    exec diff ../outputs/t516 ../golden/t516 >/dev/null 2>&1 ;;
  p517) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst549.tst > ../outputs/t517
    exec diff ../outputs/t517 ../golden/t517 >/dev/null 2>&1 ;;
  p518) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst55.tst > ../outputs/t518
    exec diff ../outputs/t518 ../golden/t518 >/dev/null 2>&1 ;;
  p519) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst550.tst > ../outputs/t519
    exec diff ../outputs/t519 ../golden/t519 >/dev/null 2>&1 ;;
  p520) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst551.tst > ../outputs/t520
    exec diff ../outputs/t520 ../golden/t520 >/dev/null 2>&1 ;;
  p521) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst552.tst > ../outputs/t521
    exec diff ../outputs/t521 ../golden/t521 >/dev/null 2>&1 ;;
  p522) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst553.tst > ../outputs/t522
    exec diff ../outputs/t522 ../golden/t522 >/dev/null 2>&1 ;;
  p523) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst554.tst > ../outputs/t523
    exec diff ../outputs/t523 ../golden/t523 >/dev/null 2>&1 ;;
  p524) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst555.tst > ../outputs/t524
    exec diff ../outputs/t524 ../golden/t524 >/dev/null 2>&1 ;;
  p525) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst556.tst > ../outputs/t525
    exec diff ../outputs/t525 ../golden/t525 >/dev/null 2>&1 ;;
  p526) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst557.tst > ../outputs/t526
    exec diff ../outputs/t526 ../golden/t526 >/dev/null 2>&1 ;;
  p527) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst558.tst > ../outputs/t527
    exec diff ../outputs/t527 ../golden/t527 >/dev/null 2>&1 ;;
  p528) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst559.tst > ../outputs/t528
    exec diff ../outputs/t528 ../golden/t528 >/dev/null 2>&1 ;;
  p529) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst56.tst > ../outputs/t529
    exec diff ../outputs/t529 ../golden/t529 >/dev/null 2>&1 ;;
  p530) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst560.tst > ../outputs/t530
    exec diff ../outputs/t530 ../golden/t530 >/dev/null 2>&1 ;;
  p531) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst561.tst > ../outputs/t531
    exec diff ../outputs/t531 ../golden/t531 >/dev/null 2>&1 ;;
  p532) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst562.tst > ../outputs/t532
    exec diff ../outputs/t532 ../golden/t532 >/dev/null 2>&1 ;;
  p533) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst563.tst > ../outputs/t533
    exec diff ../outputs/t533 ../golden/t533 >/dev/null 2>&1 ;;
  p534) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst564.tst > ../outputs/t534
    exec diff ../outputs/t534 ../golden/t534 >/dev/null 2>&1 ;;
  p535) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst565.tst > ../outputs/t535
    exec diff ../outputs/t535 ../golden/t535 >/dev/null 2>&1 ;;
  p536) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst566.tst > ../outputs/t536
    exec diff ../outputs/t536 ../golden/t536 >/dev/null 2>&1 ;;
  p537) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst567.tst > ../outputs/t537
    exec diff ../outputs/t537 ../golden/t537 >/dev/null 2>&1 ;;
  p538) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst568.tst > ../outputs/t538
    exec diff ../outputs/t538 ../golden/t538 >/dev/null 2>&1 ;;
  p539) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst569.tst > ../outputs/t539
    exec diff ../outputs/t539 ../golden/t539 >/dev/null 2>&1 ;;
  p540) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst57.tst > ../outputs/t540
    exec diff ../outputs/t540 ../golden/t540 >/dev/null 2>&1 ;;
  p541) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst570.tst > ../outputs/t541
    exec diff ../outputs/t541 ../golden/t541 >/dev/null 2>&1 ;;
  p542) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst571.tst > ../outputs/t542
    exec diff ../outputs/t542 ../golden/t542 >/dev/null 2>&1 ;;
  p543) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst572.tst > ../outputs/t543
    exec diff ../outputs/t543 ../golden/t543 >/dev/null 2>&1 ;;
  p544) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst573.tst > ../outputs/t544
    exec diff ../outputs/t544 ../golden/t544 >/dev/null 2>&1 ;;
  p545) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst574.tst > ../outputs/t545
    exec diff ../outputs/t545 ../golden/t545 >/dev/null 2>&1 ;;
  p546) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst575.tst > ../outputs/t546
    exec diff ../outputs/t546 ../golden/t546 >/dev/null 2>&1 ;;
  p547) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst576.tst > ../outputs/t547
    exec diff ../outputs/t547 ../golden/t547 >/dev/null 2>&1 ;;
  p548) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst577.tst > ../outputs/t548
    exec diff ../outputs/t548 ../golden/t548 >/dev/null 2>&1 ;;
  p549) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst578.tst > ../outputs/t549
    exec diff ../outputs/t549 ../golden/t549 >/dev/null 2>&1 ;;
  p550) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst579.tst > ../outputs/t550
    exec diff ../outputs/t550 ../golden/t550 >/dev/null 2>&1 ;;
  p551) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst58.tst > ../outputs/t551
    exec diff ../outputs/t551 ../golden/t551 >/dev/null 2>&1 ;;
  p552) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst580.tst > ../outputs/t552
    exec diff ../outputs/t552 ../golden/t552 >/dev/null 2>&1 ;;
  p553) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst581.tst > ../outputs/t553
    exec diff ../outputs/t553 ../golden/t553 >/dev/null 2>&1 ;;
  p554) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst582.tst > ../outputs/t554
    exec diff ../outputs/t554 ../golden/t554 >/dev/null 2>&1 ;;
  p555) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst583.tst > ../outputs/t555
    exec diff ../outputs/t555 ../golden/t555 >/dev/null 2>&1 ;;
  p556) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst584.tst > ../outputs/t556
    exec diff ../outputs/t556 ../golden/t556 >/dev/null 2>&1 ;;
  p557) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst585.tst > ../outputs/t557
    exec diff ../outputs/t557 ../golden/t557 >/dev/null 2>&1 ;;
  p558) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst586.tst > ../outputs/t558
    exec diff ../outputs/t558 ../golden/t558 >/dev/null 2>&1 ;;
  p559) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst587.tst > ../outputs/t559
    exec diff ../outputs/t559 ../golden/t559 >/dev/null 2>&1 ;;
  p560) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst588.tst > ../outputs/t560
    exec diff ../outputs/t560 ../golden/t560 >/dev/null 2>&1 ;;
  p561) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst589.tst > ../outputs/t561
    exec diff ../outputs/t561 ../golden/t561 >/dev/null 2>&1 ;;
  p562) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst59.tst > ../outputs/t562
    exec diff ../outputs/t562 ../golden/t562 >/dev/null 2>&1 ;;
  p563) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst590.tst > ../outputs/t563
    exec diff ../outputs/t563 ../golden/t563 >/dev/null 2>&1 ;;
  p564) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst591.tst > ../outputs/t564
    exec diff ../outputs/t564 ../golden/t564 >/dev/null 2>&1 ;;
  p565) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst592.tst > ../outputs/t565
    exec diff ../outputs/t565 ../golden/t565 >/dev/null 2>&1 ;;
  p566) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst593.tst > ../outputs/t566
    exec diff ../outputs/t566 ../golden/t566 >/dev/null 2>&1 ;;
  p567) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst594.tst > ../outputs/t567
    exec diff ../outputs/t567 ../golden/t567 >/dev/null 2>&1 ;;
  p568) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst595.tst > ../outputs/t568
    exec diff ../outputs/t568 ../golden/t568 >/dev/null 2>&1 ;;
  p569) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst596.tst > ../outputs/t569
    exec diff ../outputs/t569 ../golden/t569 >/dev/null 2>&1 ;;
  p570) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst597.tst > ../outputs/t570
    exec diff ../outputs/t570 ../golden/t570 >/dev/null 2>&1 ;;
  p571) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst598.tst > ../outputs/t571
    exec diff ../outputs/t571 ../golden/t571 >/dev/null 2>&1 ;;
  p572) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst599.tst > ../outputs/t572
    exec diff ../outputs/t572 ../golden/t572 >/dev/null 2>&1 ;;
  p573) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst6.tst > ../outputs/t573
    exec diff ../outputs/t573 ../golden/t573 >/dev/null 2>&1 ;;
  p574) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst6.tst.tst > ../outputs/t574
    exec diff ../outputs/t574 ../golden/t574 >/dev/null 2>&1 ;;
  p575) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst60.tst > ../outputs/t575
    exec diff ../outputs/t575 ../golden/t575 >/dev/null 2>&1 ;;
  p576) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst600.tst > ../outputs/t576
    exec diff ../outputs/t576 ../golden/t576 >/dev/null 2>&1 ;;
  p577) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst61.tst > ../outputs/t577
    exec diff ../outputs/t577 ../golden/t577 >/dev/null 2>&1 ;;
  p578) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst62.tst > ../outputs/t578
    exec diff ../outputs/t578 ../golden/t578 >/dev/null 2>&1 ;;
  p579) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst63.tst > ../outputs/t579
    exec diff ../outputs/t579 ../golden/t579 >/dev/null 2>&1 ;;
  p580) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst64.tst > ../outputs/t580
    exec diff ../outputs/t580 ../golden/t580 >/dev/null 2>&1 ;;
  p581) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst65.tst > ../outputs/t581
    exec diff ../outputs/t581 ../golden/t581 >/dev/null 2>&1 ;;
  p582) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst66.tst > ../outputs/t582
    exec diff ../outputs/t582 ../golden/t582 >/dev/null 2>&1 ;;
  p583) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst67.tst > ../outputs/t583
    exec diff ../outputs/t583 ../golden/t583 >/dev/null 2>&1 ;;
  p584) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst68.tst > ../outputs/t584
    exec diff ../outputs/t584 ../golden/t584 >/dev/null 2>&1 ;;
  p585) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst69.tst > ../outputs/t585
    exec diff ../outputs/t585 ../golden/t585 >/dev/null 2>&1 ;;
  p586) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst7.tst > ../outputs/t586
    exec diff ../outputs/t586 ../golden/t586 >/dev/null 2>&1 ;;
  p587) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst7.tst.tst > ../outputs/t587
    exec diff ../outputs/t587 ../golden/t587 >/dev/null 2>&1 ;;
  p588) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst70.tst > ../outputs/t588
    exec diff ../outputs/t588 ../golden/t588 >/dev/null 2>&1 ;;
  p589) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst71.tst > ../outputs/t589
    exec diff ../outputs/t589 ../golden/t589 >/dev/null 2>&1 ;;
  p590) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst72.tst > ../outputs/t590
    exec diff ../outputs/t590 ../golden/t590 >/dev/null 2>&1 ;;
  p591) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst73.tst > ../outputs/t591
    exec diff ../outputs/t591 ../golden/t591 >/dev/null 2>&1 ;;
  p592) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst74.tst > ../outputs/t592
    exec diff ../outputs/t592 ../golden/t592 >/dev/null 2>&1 ;;
  p593) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst75.tst > ../outputs/t593
    exec diff ../outputs/t593 ../golden/t593 >/dev/null 2>&1 ;;
  p594) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst76.tst > ../outputs/t594
    exec diff ../outputs/t594 ../golden/t594 >/dev/null 2>&1 ;;
  p595) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst77.tst > ../outputs/t595
    exec diff ../outputs/t595 ../golden/t595 >/dev/null 2>&1 ;;
  p596) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst78.tst > ../outputs/t596
    exec diff ../outputs/t596 ../golden/t596 >/dev/null 2>&1 ;;
  p597) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst79.tst > ../outputs/t597
    exec diff ../outputs/t597 ../golden/t597 >/dev/null 2>&1 ;;
  p598) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst8.tst > ../outputs/t598
    exec diff ../outputs/t598 ../golden/t598 >/dev/null 2>&1 ;;
  p599) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst8.tst.tst > ../outputs/t599
    exec diff ../outputs/t599 ../golden/t599 >/dev/null 2>&1 ;;
  p600) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst80.tst > ../outputs/t600
    exec diff ../outputs/t600 ../golden/t600 >/dev/null 2>&1 ;;
  p601) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst81.tst > ../outputs/t601
    exec diff ../outputs/t601 ../golden/t601 >/dev/null 2>&1 ;;
  p602) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst82.tst > ../outputs/t602
    exec diff ../outputs/t602 ../golden/t602 >/dev/null 2>&1 ;;
  p603) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst83.tst > ../outputs/t603
    exec diff ../outputs/t603 ../golden/t603 >/dev/null 2>&1 ;;
  p604) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst84.tst > ../outputs/t604
    exec diff ../outputs/t604 ../golden/t604 >/dev/null 2>&1 ;;
  p605) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst85.tst > ../outputs/t605
    exec diff ../outputs/t605 ../golden/t605 >/dev/null 2>&1 ;;
  p606) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst86.tst > ../outputs/t606
    exec diff ../outputs/t606 ../golden/t606 >/dev/null 2>&1 ;;
  p607) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst87.tst > ../outputs/t607
    exec diff ../outputs/t607 ../golden/t607 >/dev/null 2>&1 ;;
  p608) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst88.tst > ../outputs/t608
    exec diff ../outputs/t608 ../golden/t608 >/dev/null 2>&1 ;;
  p609) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst89.tst > ../outputs/t609
    exec diff ../outputs/t609 ../golden/t609 >/dev/null 2>&1 ;;
  p610) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst9.tst > ../outputs/t610
    exec diff ../outputs/t610 ../golden/t610 >/dev/null 2>&1 ;;
  p611) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst9.tst.tst > ../outputs/t611
    exec diff ../outputs/t611 ../golden/t611 >/dev/null 2>&1 ;;
  p612) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst90.tst > ../outputs/t612
    exec diff ../outputs/t612 ../golden/t612 >/dev/null 2>&1 ;;
  p613) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst91.tst > ../outputs/t613
    exec diff ../outputs/t613 ../golden/t613 >/dev/null 2>&1 ;;
  p614) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst92.tst > ../outputs/t614
    exec diff ../outputs/t614 ../golden/t614 >/dev/null 2>&1 ;;
  p615) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst93.tst > ../outputs/t615
    exec diff ../outputs/t615 ../golden/t615 >/dev/null 2>&1 ;;
  p616) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst94.tst > ../outputs/t616
    exec diff ../outputs/t616 ../golden/t616 >/dev/null 2>&1 ;;
  p617) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst95.tst > ../outputs/t617
    exec diff ../outputs/t617 ../golden/t617 >/dev/null 2>&1 ;;
  p618) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst96.tst > ../outputs/t618
    exec diff ../outputs/t618 ../golden/t618 >/dev/null 2>&1 ;;
  p619) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst97.tst > ../outputs/t619
    exec diff ../outputs/t619 ../golden/t619 >/dev/null 2>&1 ;;
  p620) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst98.tst > ../outputs/t620
    exec diff ../outputs/t620 ../golden/t620 >/dev/null 2>&1 ;;
  p621) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/newtst99.tst > ../outputs/t621
    exec diff ../outputs/t621 ../golden/t621 >/dev/null 2>&1 ;;
  p622) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc1 > ../outputs/t622
    exec diff ../outputs/t622 ../golden/t622 >/dev/null 2>&1 ;;
  p623) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc10 > ../outputs/t623
    exec diff ../outputs/t623 ../golden/t623 >/dev/null 2>&1 ;;
  p624) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc100 > ../outputs/t624
    exec diff ../outputs/t624 ../golden/t624 >/dev/null 2>&1 ;;
  p625) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc101 > ../outputs/t625
    exec diff ../outputs/t625 ../golden/t625 >/dev/null 2>&1 ;;
  p626) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc102 > ../outputs/t626
    exec diff ../outputs/t626 ../golden/t626 >/dev/null 2>&1 ;;
  p627) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc103 > ../outputs/t627
    exec diff ../outputs/t627 ../golden/t627 >/dev/null 2>&1 ;;
  p628) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc104 > ../outputs/t628
    exec diff ../outputs/t628 ../golden/t628 >/dev/null 2>&1 ;;
  p629) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc105 > ../outputs/t629
    exec diff ../outputs/t629 ../golden/t629 >/dev/null 2>&1 ;;
  p630) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc106 > ../outputs/t630
    exec diff ../outputs/t630 ../golden/t630 >/dev/null 2>&1 ;;
  p631) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc107 > ../outputs/t631
    exec diff ../outputs/t631 ../golden/t631 >/dev/null 2>&1 ;;
  p632) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc108 > ../outputs/t632
    exec diff ../outputs/t632 ../golden/t632 >/dev/null 2>&1 ;;
  p633) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc109 > ../outputs/t633
    exec diff ../outputs/t633 ../golden/t633 >/dev/null 2>&1 ;;
  p634) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc11 > ../outputs/t634
    exec diff ../outputs/t634 ../golden/t634 >/dev/null 2>&1 ;;
  p635) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc110 > ../outputs/t635
    exec diff ../outputs/t635 ../golden/t635 >/dev/null 2>&1 ;;
  p636) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc111 > ../outputs/t636
    exec diff ../outputs/t636 ../golden/t636 >/dev/null 2>&1 ;;
  p637) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc112 > ../outputs/t637
    exec diff ../outputs/t637 ../golden/t637 >/dev/null 2>&1 ;;
  p638) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc113 > ../outputs/t638
    exec diff ../outputs/t638 ../golden/t638 >/dev/null 2>&1 ;;
  p639) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc114 > ../outputs/t639
    exec diff ../outputs/t639 ../golden/t639 >/dev/null 2>&1 ;;
  p640) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc115 > ../outputs/t640
    exec diff ../outputs/t640 ../golden/t640 >/dev/null 2>&1 ;;
  p641) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc116 > ../outputs/t641
    exec diff ../outputs/t641 ../golden/t641 >/dev/null 2>&1 ;;
  p642) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc117 > ../outputs/t642
    exec diff ../outputs/t642 ../golden/t642 >/dev/null 2>&1 ;;
  p643) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc118 > ../outputs/t643
    exec diff ../outputs/t643 ../golden/t643 >/dev/null 2>&1 ;;
  p644) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc119 > ../outputs/t644
    exec diff ../outputs/t644 ../golden/t644 >/dev/null 2>&1 ;;
  p645) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc12 > ../outputs/t645
    exec diff ../outputs/t645 ../golden/t645 >/dev/null 2>&1 ;;
  p646) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc120 > ../outputs/t646
    exec diff ../outputs/t646 ../golden/t646 >/dev/null 2>&1 ;;
  p647) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc121 > ../outputs/t647
    exec diff ../outputs/t647 ../golden/t647 >/dev/null 2>&1 ;;
  p648) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc122 > ../outputs/t648
    exec diff ../outputs/t648 ../golden/t648 >/dev/null 2>&1 ;;
  p649) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc123 > ../outputs/t649
    exec diff ../outputs/t649 ../golden/t649 >/dev/null 2>&1 ;;
  p650) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc124 > ../outputs/t650
    exec diff ../outputs/t650 ../golden/t650 >/dev/null 2>&1 ;;
  p651) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc125 > ../outputs/t651
    exec diff ../outputs/t651 ../golden/t651 >/dev/null 2>&1 ;;
  p652) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc126 > ../outputs/t652
    exec diff ../outputs/t652 ../golden/t652 >/dev/null 2>&1 ;;
  p653) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc127 > ../outputs/t653
    exec diff ../outputs/t653 ../golden/t653 >/dev/null 2>&1 ;;
  p654) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc128 > ../outputs/t654
    exec diff ../outputs/t654 ../golden/t654 >/dev/null 2>&1 ;;
  p655) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc129 > ../outputs/t655
    exec diff ../outputs/t655 ../golden/t655 >/dev/null 2>&1 ;;
  p656) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc13 > ../outputs/t656
    exec diff ../outputs/t656 ../golden/t656 >/dev/null 2>&1 ;;
  p657) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc130 > ../outputs/t657
    exec diff ../outputs/t657 ../golden/t657 >/dev/null 2>&1 ;;
  p658) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc131 > ../outputs/t658
    exec diff ../outputs/t658 ../golden/t658 >/dev/null 2>&1 ;;
  p659) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc132 > ../outputs/t659
    exec diff ../outputs/t659 ../golden/t659 >/dev/null 2>&1 ;;
  p660) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc133 > ../outputs/t660
    exec diff ../outputs/t660 ../golden/t660 >/dev/null 2>&1 ;;
  p661) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc134 > ../outputs/t661
    exec diff ../outputs/t661 ../golden/t661 >/dev/null 2>&1 ;;
  p662) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc135 > ../outputs/t662
    exec diff ../outputs/t662 ../golden/t662 >/dev/null 2>&1 ;;
  p663) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc136 > ../outputs/t663
    exec diff ../outputs/t663 ../golden/t663 >/dev/null 2>&1 ;;
  p664) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc137 > ../outputs/t664
    exec diff ../outputs/t664 ../golden/t664 >/dev/null 2>&1 ;;
  p665) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc138 > ../outputs/t665
    exec diff ../outputs/t665 ../golden/t665 >/dev/null 2>&1 ;;
  p666) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc139 > ../outputs/t666
    exec diff ../outputs/t666 ../golden/t666 >/dev/null 2>&1 ;;
  p667) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc14 > ../outputs/t667
    exec diff ../outputs/t667 ../golden/t667 >/dev/null 2>&1 ;;
  p668) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc140 > ../outputs/t668
    exec diff ../outputs/t668 ../golden/t668 >/dev/null 2>&1 ;;
  p669) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc141 > ../outputs/t669
    exec diff ../outputs/t669 ../golden/t669 >/dev/null 2>&1 ;;
  p670) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc142 > ../outputs/t670
    exec diff ../outputs/t670 ../golden/t670 >/dev/null 2>&1 ;;
  p671) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc143 > ../outputs/t671
    exec diff ../outputs/t671 ../golden/t671 >/dev/null 2>&1 ;;
  p672) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc144 > ../outputs/t672
    exec diff ../outputs/t672 ../golden/t672 >/dev/null 2>&1 ;;
  p673) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc145 > ../outputs/t673
    exec diff ../outputs/t673 ../golden/t673 >/dev/null 2>&1 ;;
  p674) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc146 > ../outputs/t674
    exec diff ../outputs/t674 ../golden/t674 >/dev/null 2>&1 ;;
  p675) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc147 > ../outputs/t675
    exec diff ../outputs/t675 ../golden/t675 >/dev/null 2>&1 ;;
  p676) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc148 > ../outputs/t676
    exec diff ../outputs/t676 ../golden/t676 >/dev/null 2>&1 ;;
  p677) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc149 > ../outputs/t677
    exec diff ../outputs/t677 ../golden/t677 >/dev/null 2>&1 ;;
  p678) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc15 > ../outputs/t678
    exec diff ../outputs/t678 ../golden/t678 >/dev/null 2>&1 ;;
  p679) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc150 > ../outputs/t679
    exec diff ../outputs/t679 ../golden/t679 >/dev/null 2>&1 ;;
  p680) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc151 > ../outputs/t680
    exec diff ../outputs/t680 ../golden/t680 >/dev/null 2>&1 ;;
  p681) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc152 > ../outputs/t681
    exec diff ../outputs/t681 ../golden/t681 >/dev/null 2>&1 ;;
  p682) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc153 > ../outputs/t682
    exec diff ../outputs/t682 ../golden/t682 >/dev/null 2>&1 ;;
  p683) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc154 > ../outputs/t683
    exec diff ../outputs/t683 ../golden/t683 >/dev/null 2>&1 ;;
  p684) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc155 > ../outputs/t684
    exec diff ../outputs/t684 ../golden/t684 >/dev/null 2>&1 ;;
  p685) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc156 > ../outputs/t685
    exec diff ../outputs/t685 ../golden/t685 >/dev/null 2>&1 ;;
  p686) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc157 > ../outputs/t686
    exec diff ../outputs/t686 ../golden/t686 >/dev/null 2>&1 ;;
  p687) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc158 > ../outputs/t687
    exec diff ../outputs/t687 ../golden/t687 >/dev/null 2>&1 ;;
  p688) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc159 > ../outputs/t688
    exec diff ../outputs/t688 ../golden/t688 >/dev/null 2>&1 ;;
  p689) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc16 > ../outputs/t689
    exec diff ../outputs/t689 ../golden/t689 >/dev/null 2>&1 ;;
  p690) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc160 > ../outputs/t690
    exec diff ../outputs/t690 ../golden/t690 >/dev/null 2>&1 ;;
  p691) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc161 > ../outputs/t691
    exec diff ../outputs/t691 ../golden/t691 >/dev/null 2>&1 ;;
  p692) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc162 > ../outputs/t692
    exec diff ../outputs/t692 ../golden/t692 >/dev/null 2>&1 ;;
  p693) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc163 > ../outputs/t693
    exec diff ../outputs/t693 ../golden/t693 >/dev/null 2>&1 ;;
  p694) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc164 > ../outputs/t694
    exec diff ../outputs/t694 ../golden/t694 >/dev/null 2>&1 ;;
  p695) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc165 > ../outputs/t695
    exec diff ../outputs/t695 ../golden/t695 >/dev/null 2>&1 ;;
  p696) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc166 > ../outputs/t696
    exec diff ../outputs/t696 ../golden/t696 >/dev/null 2>&1 ;;
  p697) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc167 > ../outputs/t697
    exec diff ../outputs/t697 ../golden/t697 >/dev/null 2>&1 ;;
  p698) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc168 > ../outputs/t698
    exec diff ../outputs/t698 ../golden/t698 >/dev/null 2>&1 ;;
  p699) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc169 > ../outputs/t699
    exec diff ../outputs/t699 ../golden/t699 >/dev/null 2>&1 ;;
  p700) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc17 > ../outputs/t700
    exec diff ../outputs/t700 ../golden/t700 >/dev/null 2>&1 ;;
  p701) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc170 > ../outputs/t701
    exec diff ../outputs/t701 ../golden/t701 >/dev/null 2>&1 ;;
  p702) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc171 > ../outputs/t702
    exec diff ../outputs/t702 ../golden/t702 >/dev/null 2>&1 ;;
  p703) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc172 > ../outputs/t703
    exec diff ../outputs/t703 ../golden/t703 >/dev/null 2>&1 ;;
  p704) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc173 > ../outputs/t704
    exec diff ../outputs/t704 ../golden/t704 >/dev/null 2>&1 ;;
  p705) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc174 > ../outputs/t705
    exec diff ../outputs/t705 ../golden/t705 >/dev/null 2>&1 ;;
  p706) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc175 > ../outputs/t706
    exec diff ../outputs/t706 ../golden/t706 >/dev/null 2>&1 ;;
  p707) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc176 > ../outputs/t707
    exec diff ../outputs/t707 ../golden/t707 >/dev/null 2>&1 ;;
  p708) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc177 > ../outputs/t708
    exec diff ../outputs/t708 ../golden/t708 >/dev/null 2>&1 ;;
  p709) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc178 > ../outputs/t709
    exec diff ../outputs/t709 ../golden/t709 >/dev/null 2>&1 ;;
  p710) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc179 > ../outputs/t710
    exec diff ../outputs/t710 ../golden/t710 >/dev/null 2>&1 ;;
  p711) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc18 > ../outputs/t711
    exec diff ../outputs/t711 ../golden/t711 >/dev/null 2>&1 ;;
  p712) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc180 > ../outputs/t712
    exec diff ../outputs/t712 ../golden/t712 >/dev/null 2>&1 ;;
  p713) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc181 > ../outputs/t713
    exec diff ../outputs/t713 ../golden/t713 >/dev/null 2>&1 ;;
  p714) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc182 > ../outputs/t714
    exec diff ../outputs/t714 ../golden/t714 >/dev/null 2>&1 ;;
  p715) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc183 > ../outputs/t715
    exec diff ../outputs/t715 ../golden/t715 >/dev/null 2>&1 ;;
  p716) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc184 > ../outputs/t716
    exec diff ../outputs/t716 ../golden/t716 >/dev/null 2>&1 ;;
  p717) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc185 > ../outputs/t717
    exec diff ../outputs/t717 ../golden/t717 >/dev/null 2>&1 ;;
  p718) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc186 > ../outputs/t718
    exec diff ../outputs/t718 ../golden/t718 >/dev/null 2>&1 ;;
  p719) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc187 > ../outputs/t719
    exec diff ../outputs/t719 ../golden/t719 >/dev/null 2>&1 ;;
  p720) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc188 > ../outputs/t720
    exec diff ../outputs/t720 ../golden/t720 >/dev/null 2>&1 ;;
  p721) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc189 > ../outputs/t721
    exec diff ../outputs/t721 ../golden/t721 >/dev/null 2>&1 ;;
  p722) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc19 > ../outputs/t722
    exec diff ../outputs/t722 ../golden/t722 >/dev/null 2>&1 ;;
  p723) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc190 > ../outputs/t723
    exec diff ../outputs/t723 ../golden/t723 >/dev/null 2>&1 ;;
  p724) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc191 > ../outputs/t724
    exec diff ../outputs/t724 ../golden/t724 >/dev/null 2>&1 ;;
  p725) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc192 > ../outputs/t725
    exec diff ../outputs/t725 ../golden/t725 >/dev/null 2>&1 ;;
  p726) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc193 > ../outputs/t726
    exec diff ../outputs/t726 ../golden/t726 >/dev/null 2>&1 ;;
  p727) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc194 > ../outputs/t727
    exec diff ../outputs/t727 ../golden/t727 >/dev/null 2>&1 ;;
  p728) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc195 > ../outputs/t728
    exec diff ../outputs/t728 ../golden/t728 >/dev/null 2>&1 ;;
  p729) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc196 > ../outputs/t729
    exec diff ../outputs/t729 ../golden/t729 >/dev/null 2>&1 ;;
  p730) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc197 > ../outputs/t730
    exec diff ../outputs/t730 ../golden/t730 >/dev/null 2>&1 ;;
  p731) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc198 > ../outputs/t731
    exec diff ../outputs/t731 ../golden/t731 >/dev/null 2>&1 ;;
  p732) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc199 > ../outputs/t732
    exec diff ../outputs/t732 ../golden/t732 >/dev/null 2>&1 ;;
  p733) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc2 > ../outputs/t733
    exec diff ../outputs/t733 ../golden/t733 >/dev/null 2>&1 ;;
  p734) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc20 > ../outputs/t734
    exec diff ../outputs/t734 ../golden/t734 >/dev/null 2>&1 ;;
  p735) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc200 > ../outputs/t735
    exec diff ../outputs/t735 ../golden/t735 >/dev/null 2>&1 ;;
  p736) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc201 > ../outputs/t736
    exec diff ../outputs/t736 ../golden/t736 >/dev/null 2>&1 ;;
  p737) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc202 > ../outputs/t737
    exec diff ../outputs/t737 ../golden/t737 >/dev/null 2>&1 ;;
  p738) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc203 > ../outputs/t738
    exec diff ../outputs/t738 ../golden/t738 >/dev/null 2>&1 ;;
  p739) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc204 > ../outputs/t739
    exec diff ../outputs/t739 ../golden/t739 >/dev/null 2>&1 ;;
  p740) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc205 > ../outputs/t740
    exec diff ../outputs/t740 ../golden/t740 >/dev/null 2>&1 ;;
  p741) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc206 > ../outputs/t741
    exec diff ../outputs/t741 ../golden/t741 >/dev/null 2>&1 ;;
  p742) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc207 > ../outputs/t742
    exec diff ../outputs/t742 ../golden/t742 >/dev/null 2>&1 ;;
  p743) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc208 > ../outputs/t743
    exec diff ../outputs/t743 ../golden/t743 >/dev/null 2>&1 ;;
  p744) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc209 > ../outputs/t744
    exec diff ../outputs/t744 ../golden/t744 >/dev/null 2>&1 ;;
  p745) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc21 > ../outputs/t745
    exec diff ../outputs/t745 ../golden/t745 >/dev/null 2>&1 ;;
  p746) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc210 > ../outputs/t746
    exec diff ../outputs/t746 ../golden/t746 >/dev/null 2>&1 ;;
  p747) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc211 > ../outputs/t747
    exec diff ../outputs/t747 ../golden/t747 >/dev/null 2>&1 ;;
  p748) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc212 > ../outputs/t748
    exec diff ../outputs/t748 ../golden/t748 >/dev/null 2>&1 ;;
  p749) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc213 > ../outputs/t749
    exec diff ../outputs/t749 ../golden/t749 >/dev/null 2>&1 ;;
  p750) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc214 > ../outputs/t750
    exec diff ../outputs/t750 ../golden/t750 >/dev/null 2>&1 ;;
  p751) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc215 > ../outputs/t751
    exec diff ../outputs/t751 ../golden/t751 >/dev/null 2>&1 ;;
  p752) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc216 > ../outputs/t752
    exec diff ../outputs/t752 ../golden/t752 >/dev/null 2>&1 ;;
  p753) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc217 > ../outputs/t753
    exec diff ../outputs/t753 ../golden/t753 >/dev/null 2>&1 ;;
  p754) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc218 > ../outputs/t754
    exec diff ../outputs/t754 ../golden/t754 >/dev/null 2>&1 ;;
  p755) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc219 > ../outputs/t755
    exec diff ../outputs/t755 ../golden/t755 >/dev/null 2>&1 ;;
  p756) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc22 > ../outputs/t756
    exec diff ../outputs/t756 ../golden/t756 >/dev/null 2>&1 ;;
  p757) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc220 > ../outputs/t757
    exec diff ../outputs/t757 ../golden/t757 >/dev/null 2>&1 ;;
  p758) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc221 > ../outputs/t758
    exec diff ../outputs/t758 ../golden/t758 >/dev/null 2>&1 ;;
  p759) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc222 > ../outputs/t759
    exec diff ../outputs/t759 ../golden/t759 >/dev/null 2>&1 ;;
  p760) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc223 > ../outputs/t760
    exec diff ../outputs/t760 ../golden/t760 >/dev/null 2>&1 ;;
  p761) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc224 > ../outputs/t761
    exec diff ../outputs/t761 ../golden/t761 >/dev/null 2>&1 ;;
  p762) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc225 > ../outputs/t762
    exec diff ../outputs/t762 ../golden/t762 >/dev/null 2>&1 ;;
  p763) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc226 > ../outputs/t763
    exec diff ../outputs/t763 ../golden/t763 >/dev/null 2>&1 ;;
  p764) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc227 > ../outputs/t764
    exec diff ../outputs/t764 ../golden/t764 >/dev/null 2>&1 ;;
  p765) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc228 > ../outputs/t765
    exec diff ../outputs/t765 ../golden/t765 >/dev/null 2>&1 ;;
  p766) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc229 > ../outputs/t766
    exec diff ../outputs/t766 ../golden/t766 >/dev/null 2>&1 ;;
  p767) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc23 > ../outputs/t767
    exec diff ../outputs/t767 ../golden/t767 >/dev/null 2>&1 ;;
  p768) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc230 > ../outputs/t768
    exec diff ../outputs/t768 ../golden/t768 >/dev/null 2>&1 ;;
  p769) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc231 > ../outputs/t769
    exec diff ../outputs/t769 ../golden/t769 >/dev/null 2>&1 ;;
  p770) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc232 > ../outputs/t770
    exec diff ../outputs/t770 ../golden/t770 >/dev/null 2>&1 ;;
  p771) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc233 > ../outputs/t771
    exec diff ../outputs/t771 ../golden/t771 >/dev/null 2>&1 ;;
  p772) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc234 > ../outputs/t772
    exec diff ../outputs/t772 ../golden/t772 >/dev/null 2>&1 ;;
  p773) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc235 > ../outputs/t773
    exec diff ../outputs/t773 ../golden/t773 >/dev/null 2>&1 ;;
  p774) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc236 > ../outputs/t774
    exec diff ../outputs/t774 ../golden/t774 >/dev/null 2>&1 ;;
  p775) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc237 > ../outputs/t775
    exec diff ../outputs/t775 ../golden/t775 >/dev/null 2>&1 ;;
  p776) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc238 > ../outputs/t776
    exec diff ../outputs/t776 ../golden/t776 >/dev/null 2>&1 ;;
  p777) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc239 > ../outputs/t777
    exec diff ../outputs/t777 ../golden/t777 >/dev/null 2>&1 ;;
  p778) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc24 > ../outputs/t778
    exec diff ../outputs/t778 ../golden/t778 >/dev/null 2>&1 ;;
  p779) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc240 > ../outputs/t779
    exec diff ../outputs/t779 ../golden/t779 >/dev/null 2>&1 ;;
  p780) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc241 > ../outputs/t780
    exec diff ../outputs/t780 ../golden/t780 >/dev/null 2>&1 ;;
  p781) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc242 > ../outputs/t781
    exec diff ../outputs/t781 ../golden/t781 >/dev/null 2>&1 ;;
  p782) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc243 > ../outputs/t782
    exec diff ../outputs/t782 ../golden/t782 >/dev/null 2>&1 ;;
  p783) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc244 > ../outputs/t783
    exec diff ../outputs/t783 ../golden/t783 >/dev/null 2>&1 ;;
  p784) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc245 > ../outputs/t784
    exec diff ../outputs/t784 ../golden/t784 >/dev/null 2>&1 ;;
  p785) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc246 > ../outputs/t785
    exec diff ../outputs/t785 ../golden/t785 >/dev/null 2>&1 ;;
  p786) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc247 > ../outputs/t786
    exec diff ../outputs/t786 ../golden/t786 >/dev/null 2>&1 ;;
  p787) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc248 > ../outputs/t787
    exec diff ../outputs/t787 ../golden/t787 >/dev/null 2>&1 ;;
  p788) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc249 > ../outputs/t788
    exec diff ../outputs/t788 ../golden/t788 >/dev/null 2>&1 ;;
  p789) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc25 > ../outputs/t789
    exec diff ../outputs/t789 ../golden/t789 >/dev/null 2>&1 ;;
  p790) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc250 > ../outputs/t790
    exec diff ../outputs/t790 ../golden/t790 >/dev/null 2>&1 ;;
  p791) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc251 > ../outputs/t791
    exec diff ../outputs/t791 ../golden/t791 >/dev/null 2>&1 ;;
  p792) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc252 > ../outputs/t792
    exec diff ../outputs/t792 ../golden/t792 >/dev/null 2>&1 ;;
  p793) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc253 > ../outputs/t793
    exec diff ../outputs/t793 ../golden/t793 >/dev/null 2>&1 ;;
  p794) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc254 > ../outputs/t794
    exec diff ../outputs/t794 ../golden/t794 >/dev/null 2>&1 ;;
  p795) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc255 > ../outputs/t795
    exec diff ../outputs/t795 ../golden/t795 >/dev/null 2>&1 ;;
  p796) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc256 > ../outputs/t796
    exec diff ../outputs/t796 ../golden/t796 >/dev/null 2>&1 ;;
  p797) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc257 > ../outputs/t797
    exec diff ../outputs/t797 ../golden/t797 >/dev/null 2>&1 ;;
  p798) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc258 > ../outputs/t798
    exec diff ../outputs/t798 ../golden/t798 >/dev/null 2>&1 ;;
  p799) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc259 > ../outputs/t799
    exec diff ../outputs/t799 ../golden/t799 >/dev/null 2>&1 ;;
  p800) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc26 > ../outputs/t800
    exec diff ../outputs/t800 ../golden/t800 >/dev/null 2>&1 ;;
  p801) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc260 > ../outputs/t801
    exec diff ../outputs/t801 ../golden/t801 >/dev/null 2>&1 ;;
  p802) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc261 > ../outputs/t802
    exec diff ../outputs/t802 ../golden/t802 >/dev/null 2>&1 ;;
  p803) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc262 > ../outputs/t803
    exec diff ../outputs/t803 ../golden/t803 >/dev/null 2>&1 ;;
  p804) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc263 > ../outputs/t804
    exec diff ../outputs/t804 ../golden/t804 >/dev/null 2>&1 ;;
  p805) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc264 > ../outputs/t805
    exec diff ../outputs/t805 ../golden/t805 >/dev/null 2>&1 ;;
  p806) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc265 > ../outputs/t806
    exec diff ../outputs/t806 ../golden/t806 >/dev/null 2>&1 ;;
  p807) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc266 > ../outputs/t807
    exec diff ../outputs/t807 ../golden/t807 >/dev/null 2>&1 ;;
  p808) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc267 > ../outputs/t808
    exec diff ../outputs/t808 ../golden/t808 >/dev/null 2>&1 ;;
  p809) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc268 > ../outputs/t809
    exec diff ../outputs/t809 ../golden/t809 >/dev/null 2>&1 ;;
  p810) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc269 > ../outputs/t810
    exec diff ../outputs/t810 ../golden/t810 >/dev/null 2>&1 ;;
  p811) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc27 > ../outputs/t811
    exec diff ../outputs/t811 ../golden/t811 >/dev/null 2>&1 ;;
  p812) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc270 > ../outputs/t812
    exec diff ../outputs/t812 ../golden/t812 >/dev/null 2>&1 ;;
  p813) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc271 > ../outputs/t813
    exec diff ../outputs/t813 ../golden/t813 >/dev/null 2>&1 ;;
  p814) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc272 > ../outputs/t814
    exec diff ../outputs/t814 ../golden/t814 >/dev/null 2>&1 ;;
  p815) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc273 > ../outputs/t815
    exec diff ../outputs/t815 ../golden/t815 >/dev/null 2>&1 ;;
  p816) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc274 > ../outputs/t816
    exec diff ../outputs/t816 ../golden/t816 >/dev/null 2>&1 ;;
  p817) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc275 > ../outputs/t817
    exec diff ../outputs/t817 ../golden/t817 >/dev/null 2>&1 ;;
  p818) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc276 > ../outputs/t818
    exec diff ../outputs/t818 ../golden/t818 >/dev/null 2>&1 ;;
  p819) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc277 > ../outputs/t819
    exec diff ../outputs/t819 ../golden/t819 >/dev/null 2>&1 ;;
  p820) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc278 > ../outputs/t820
    exec diff ../outputs/t820 ../golden/t820 >/dev/null 2>&1 ;;
  p821) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc279 > ../outputs/t821
    exec diff ../outputs/t821 ../golden/t821 >/dev/null 2>&1 ;;
  p822) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc28 > ../outputs/t822
    exec diff ../outputs/t822 ../golden/t822 >/dev/null 2>&1 ;;
  p823) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc280 > ../outputs/t823
    exec diff ../outputs/t823 ../golden/t823 >/dev/null 2>&1 ;;
  p824) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc281 > ../outputs/t824
    exec diff ../outputs/t824 ../golden/t824 >/dev/null 2>&1 ;;
  p825) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc282 > ../outputs/t825
    exec diff ../outputs/t825 ../golden/t825 >/dev/null 2>&1 ;;
  p826) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc283 > ../outputs/t826
    exec diff ../outputs/t826 ../golden/t826 >/dev/null 2>&1 ;;
  p827) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc284 > ../outputs/t827
    exec diff ../outputs/t827 ../golden/t827 >/dev/null 2>&1 ;;
  p828) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc285 > ../outputs/t828
    exec diff ../outputs/t828 ../golden/t828 >/dev/null 2>&1 ;;
  p829) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc286 > ../outputs/t829
    exec diff ../outputs/t829 ../golden/t829 >/dev/null 2>&1 ;;
  p830) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc287 > ../outputs/t830
    exec diff ../outputs/t830 ../golden/t830 >/dev/null 2>&1 ;;
  p831) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc288 > ../outputs/t831
    exec diff ../outputs/t831 ../golden/t831 >/dev/null 2>&1 ;;
  p832) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc289 > ../outputs/t832
    exec diff ../outputs/t832 ../golden/t832 >/dev/null 2>&1 ;;
  p833) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc29 > ../outputs/t833
    exec diff ../outputs/t833 ../golden/t833 >/dev/null 2>&1 ;;
  p834) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc290 > ../outputs/t834
    exec diff ../outputs/t834 ../golden/t834 >/dev/null 2>&1 ;;
  p835) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc291 > ../outputs/t835
    exec diff ../outputs/t835 ../golden/t835 >/dev/null 2>&1 ;;
  p836) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc292 > ../outputs/t836
    exec diff ../outputs/t836 ../golden/t836 >/dev/null 2>&1 ;;
  p837) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc293 > ../outputs/t837
    exec diff ../outputs/t837 ../golden/t837 >/dev/null 2>&1 ;;
  p838) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc294 > ../outputs/t838
    exec diff ../outputs/t838 ../golden/t838 >/dev/null 2>&1 ;;
  p839) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc295 > ../outputs/t839
    exec diff ../outputs/t839 ../golden/t839 >/dev/null 2>&1 ;;
  p840) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc296 > ../outputs/t840
    exec diff ../outputs/t840 ../golden/t840 >/dev/null 2>&1 ;;
  p841) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc297 > ../outputs/t841
    exec diff ../outputs/t841 ../golden/t841 >/dev/null 2>&1 ;;
  p842) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc298 > ../outputs/t842
    exec diff ../outputs/t842 ../golden/t842 >/dev/null 2>&1 ;;
  p843) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc299 > ../outputs/t843
    exec diff ../outputs/t843 ../golden/t843 >/dev/null 2>&1 ;;
  p844) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc3 > ../outputs/t844
    exec diff ../outputs/t844 ../golden/t844 >/dev/null 2>&1 ;;
  p845) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc30 > ../outputs/t845
    exec diff ../outputs/t845 ../golden/t845 >/dev/null 2>&1 ;;
  p846) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc300 > ../outputs/t846
    exec diff ../outputs/t846 ../golden/t846 >/dev/null 2>&1 ;;
  p847) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc301 > ../outputs/t847
    exec diff ../outputs/t847 ../golden/t847 >/dev/null 2>&1 ;;
  p848) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc302 > ../outputs/t848
    exec diff ../outputs/t848 ../golden/t848 >/dev/null 2>&1 ;;
  p849) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc303 > ../outputs/t849
    exec diff ../outputs/t849 ../golden/t849 >/dev/null 2>&1 ;;
  p850) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc304 > ../outputs/t850
    exec diff ../outputs/t850 ../golden/t850 >/dev/null 2>&1 ;;
  p851) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc305 > ../outputs/t851
    exec diff ../outputs/t851 ../golden/t851 >/dev/null 2>&1 ;;
  p852) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc306 > ../outputs/t852
    exec diff ../outputs/t852 ../golden/t852 >/dev/null 2>&1 ;;
  p853) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc307 > ../outputs/t853
    exec diff ../outputs/t853 ../golden/t853 >/dev/null 2>&1 ;;
  p854) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc308 > ../outputs/t854
    exec diff ../outputs/t854 ../golden/t854 >/dev/null 2>&1 ;;
  p855) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc309 > ../outputs/t855
    exec diff ../outputs/t855 ../golden/t855 >/dev/null 2>&1 ;;
  p856) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc31 > ../outputs/t856
    exec diff ../outputs/t856 ../golden/t856 >/dev/null 2>&1 ;;
  p857) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc310 > ../outputs/t857
    exec diff ../outputs/t857 ../golden/t857 >/dev/null 2>&1 ;;
  p858) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc311 > ../outputs/t858
    exec diff ../outputs/t858 ../golden/t858 >/dev/null 2>&1 ;;
  p859) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc312 > ../outputs/t859
    exec diff ../outputs/t859 ../golden/t859 >/dev/null 2>&1 ;;
  p860) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc313 > ../outputs/t860
    exec diff ../outputs/t860 ../golden/t860 >/dev/null 2>&1 ;;
  p861) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc314 > ../outputs/t861
    exec diff ../outputs/t861 ../golden/t861 >/dev/null 2>&1 ;;
  p862) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc315 > ../outputs/t862
    exec diff ../outputs/t862 ../golden/t862 >/dev/null 2>&1 ;;
  p863) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc316 > ../outputs/t863
    exec diff ../outputs/t863 ../golden/t863 >/dev/null 2>&1 ;;
  p864) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc317 > ../outputs/t864
    exec diff ../outputs/t864 ../golden/t864 >/dev/null 2>&1 ;;
  p865) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc318 > ../outputs/t865
    exec diff ../outputs/t865 ../golden/t865 >/dev/null 2>&1 ;;
  p866) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc319 > ../outputs/t866
    exec diff ../outputs/t866 ../golden/t866 >/dev/null 2>&1 ;;
  p867) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc32 > ../outputs/t867
    exec diff ../outputs/t867 ../golden/t867 >/dev/null 2>&1 ;;
  p868) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc320 > ../outputs/t868
    exec diff ../outputs/t868 ../golden/t868 >/dev/null 2>&1 ;;
  p869) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc321 > ../outputs/t869
    exec diff ../outputs/t869 ../golden/t869 >/dev/null 2>&1 ;;
  p870) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc322 > ../outputs/t870
    exec diff ../outputs/t870 ../golden/t870 >/dev/null 2>&1 ;;
  p871) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc323 > ../outputs/t871
    exec diff ../outputs/t871 ../golden/t871 >/dev/null 2>&1 ;;
  p872) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc324 > ../outputs/t872
    exec diff ../outputs/t872 ../golden/t872 >/dev/null 2>&1 ;;
  p873) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc325 > ../outputs/t873
    exec diff ../outputs/t873 ../golden/t873 >/dev/null 2>&1 ;;
  p874) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc326 > ../outputs/t874
    exec diff ../outputs/t874 ../golden/t874 >/dev/null 2>&1 ;;
  p875) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc327 > ../outputs/t875
    exec diff ../outputs/t875 ../golden/t875 >/dev/null 2>&1 ;;
  p876) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc328 > ../outputs/t876
    exec diff ../outputs/t876 ../golden/t876 >/dev/null 2>&1 ;;
  p877) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc329 > ../outputs/t877
    exec diff ../outputs/t877 ../golden/t877 >/dev/null 2>&1 ;;
  p878) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc33 > ../outputs/t878
    exec diff ../outputs/t878 ../golden/t878 >/dev/null 2>&1 ;;
  p879) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc330 > ../outputs/t879
    exec diff ../outputs/t879 ../golden/t879 >/dev/null 2>&1 ;;
  p880) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc331 > ../outputs/t880
    exec diff ../outputs/t880 ../golden/t880 >/dev/null 2>&1 ;;
  p881) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc332 > ../outputs/t881
    exec diff ../outputs/t881 ../golden/t881 >/dev/null 2>&1 ;;
  p882) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc333 > ../outputs/t882
    exec diff ../outputs/t882 ../golden/t882 >/dev/null 2>&1 ;;
  p883) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc334 > ../outputs/t883
    exec diff ../outputs/t883 ../golden/t883 >/dev/null 2>&1 ;;
  p884) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc335 > ../outputs/t884
    exec diff ../outputs/t884 ../golden/t884 >/dev/null 2>&1 ;;
  p885) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc336 > ../outputs/t885
    exec diff ../outputs/t885 ../golden/t885 >/dev/null 2>&1 ;;
  p886) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc337 > ../outputs/t886
    exec diff ../outputs/t886 ../golden/t886 >/dev/null 2>&1 ;;
  p887) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc338 > ../outputs/t887
    exec diff ../outputs/t887 ../golden/t887 >/dev/null 2>&1 ;;
  p888) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc339 > ../outputs/t888
    exec diff ../outputs/t888 ../golden/t888 >/dev/null 2>&1 ;;
  p889) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc34 > ../outputs/t889
    exec diff ../outputs/t889 ../golden/t889 >/dev/null 2>&1 ;;
  p890) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc340 > ../outputs/t890
    exec diff ../outputs/t890 ../golden/t890 >/dev/null 2>&1 ;;
  p891) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc341 > ../outputs/t891
    exec diff ../outputs/t891 ../golden/t891 >/dev/null 2>&1 ;;
  p892) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc342 > ../outputs/t892
    exec diff ../outputs/t892 ../golden/t892 >/dev/null 2>&1 ;;
  p893) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc343 > ../outputs/t893
    exec diff ../outputs/t893 ../golden/t893 >/dev/null 2>&1 ;;
  p894) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc344 > ../outputs/t894
    exec diff ../outputs/t894 ../golden/t894 >/dev/null 2>&1 ;;
  p895) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc345 > ../outputs/t895
    exec diff ../outputs/t895 ../golden/t895 >/dev/null 2>&1 ;;
  p896) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc346 > ../outputs/t896
    exec diff ../outputs/t896 ../golden/t896 >/dev/null 2>&1 ;;
  p897) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc347 > ../outputs/t897
    exec diff ../outputs/t897 ../golden/t897 >/dev/null 2>&1 ;;
  p898) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc348 > ../outputs/t898
    exec diff ../outputs/t898 ../golden/t898 >/dev/null 2>&1 ;;
  p899) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc349 > ../outputs/t899
    exec diff ../outputs/t899 ../golden/t899 >/dev/null 2>&1 ;;
  p900) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc35 > ../outputs/t900
    exec diff ../outputs/t900 ../golden/t900 >/dev/null 2>&1 ;;
  p901) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc350 > ../outputs/t901
    exec diff ../outputs/t901 ../golden/t901 >/dev/null 2>&1 ;;
  p902) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc351 > ../outputs/t902
    exec diff ../outputs/t902 ../golden/t902 >/dev/null 2>&1 ;;
  p903) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc352 > ../outputs/t903
    exec diff ../outputs/t903 ../golden/t903 >/dev/null 2>&1 ;;
  p904) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc353 > ../outputs/t904
    exec diff ../outputs/t904 ../golden/t904 >/dev/null 2>&1 ;;
  p905) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc354 > ../outputs/t905
    exec diff ../outputs/t905 ../golden/t905 >/dev/null 2>&1 ;;
  p906) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc355 > ../outputs/t906
    exec diff ../outputs/t906 ../golden/t906 >/dev/null 2>&1 ;;
  p907) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc356 > ../outputs/t907
    exec diff ../outputs/t907 ../golden/t907 >/dev/null 2>&1 ;;
  p908) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc357 > ../outputs/t908
    exec diff ../outputs/t908 ../golden/t908 >/dev/null 2>&1 ;;
  p909) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc358 > ../outputs/t909
    exec diff ../outputs/t909 ../golden/t909 >/dev/null 2>&1 ;;
  p910) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc359 > ../outputs/t910
    exec diff ../outputs/t910 ../golden/t910 >/dev/null 2>&1 ;;
  p911) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc36 > ../outputs/t911
    exec diff ../outputs/t911 ../golden/t911 >/dev/null 2>&1 ;;
  p912) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc360 > ../outputs/t912
    exec diff ../outputs/t912 ../golden/t912 >/dev/null 2>&1 ;;
  p913) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc361 > ../outputs/t913
    exec diff ../outputs/t913 ../golden/t913 >/dev/null 2>&1 ;;
  p914) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc362 > ../outputs/t914
    exec diff ../outputs/t914 ../golden/t914 >/dev/null 2>&1 ;;
  p915) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc363 > ../outputs/t915
    exec diff ../outputs/t915 ../golden/t915 >/dev/null 2>&1 ;;
  p916) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc364 > ../outputs/t916
    exec diff ../outputs/t916 ../golden/t916 >/dev/null 2>&1 ;;
  p917) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc365 > ../outputs/t917
    exec diff ../outputs/t917 ../golden/t917 >/dev/null 2>&1 ;;
  p918) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc366 > ../outputs/t918
    exec diff ../outputs/t918 ../golden/t918 >/dev/null 2>&1 ;;
  p919) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc367 > ../outputs/t919
    exec diff ../outputs/t919 ../golden/t919 >/dev/null 2>&1 ;;
  p920) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc368 > ../outputs/t920
    exec diff ../outputs/t920 ../golden/t920 >/dev/null 2>&1 ;;
  p921) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc369 > ../outputs/t921
    exec diff ../outputs/t921 ../golden/t921 >/dev/null 2>&1 ;;
  p922) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc37 > ../outputs/t922
    exec diff ../outputs/t922 ../golden/t922 >/dev/null 2>&1 ;;
  p923) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc370 > ../outputs/t923
    exec diff ../outputs/t923 ../golden/t923 >/dev/null 2>&1 ;;
  p924) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc371 > ../outputs/t924
    exec diff ../outputs/t924 ../golden/t924 >/dev/null 2>&1 ;;
  p925) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc372 > ../outputs/t925
    exec diff ../outputs/t925 ../golden/t925 >/dev/null 2>&1 ;;
  p926) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc373 > ../outputs/t926
    exec diff ../outputs/t926 ../golden/t926 >/dev/null 2>&1 ;;
  p927) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc374 > ../outputs/t927
    exec diff ../outputs/t927 ../golden/t927 >/dev/null 2>&1 ;;
  p928) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc375 > ../outputs/t928
    exec diff ../outputs/t928 ../golden/t928 >/dev/null 2>&1 ;;
  p929) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc376 > ../outputs/t929
    exec diff ../outputs/t929 ../golden/t929 >/dev/null 2>&1 ;;
  p930) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc377 > ../outputs/t930
    exec diff ../outputs/t930 ../golden/t930 >/dev/null 2>&1 ;;
  p931) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc378 > ../outputs/t931
    exec diff ../outputs/t931 ../golden/t931 >/dev/null 2>&1 ;;
  p932) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc379 > ../outputs/t932
    exec diff ../outputs/t932 ../golden/t932 >/dev/null 2>&1 ;;
  p933) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc38 > ../outputs/t933
    exec diff ../outputs/t933 ../golden/t933 >/dev/null 2>&1 ;;
  p934) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc380 > ../outputs/t934
    exec diff ../outputs/t934 ../golden/t934 >/dev/null 2>&1 ;;
  p935) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc381 > ../outputs/t935
    exec diff ../outputs/t935 ../golden/t935 >/dev/null 2>&1 ;;
  p936) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc382 > ../outputs/t936
    exec diff ../outputs/t936 ../golden/t936 >/dev/null 2>&1 ;;
  p937) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc383 > ../outputs/t937
    exec diff ../outputs/t937 ../golden/t937 >/dev/null 2>&1 ;;
  p938) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc384 > ../outputs/t938
    exec diff ../outputs/t938 ../golden/t938 >/dev/null 2>&1 ;;
  p939) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc385 > ../outputs/t939
    exec diff ../outputs/t939 ../golden/t939 >/dev/null 2>&1 ;;
  p940) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc386 > ../outputs/t940
    exec diff ../outputs/t940 ../golden/t940 >/dev/null 2>&1 ;;
  p941) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc387 > ../outputs/t941
    exec diff ../outputs/t941 ../golden/t941 >/dev/null 2>&1 ;;
  p942) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc388 > ../outputs/t942
    exec diff ../outputs/t942 ../golden/t942 >/dev/null 2>&1 ;;
  p943) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc389 > ../outputs/t943
    exec diff ../outputs/t943 ../golden/t943 >/dev/null 2>&1 ;;
  p944) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc39 > ../outputs/t944
    exec diff ../outputs/t944 ../golden/t944 >/dev/null 2>&1 ;;
  p945) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc390 > ../outputs/t945
    exec diff ../outputs/t945 ../golden/t945 >/dev/null 2>&1 ;;
  p946) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc391 > ../outputs/t946
    exec diff ../outputs/t946 ../golden/t946 >/dev/null 2>&1 ;;
  p947) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc392 > ../outputs/t947
    exec diff ../outputs/t947 ../golden/t947 >/dev/null 2>&1 ;;
  p948) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc393 > ../outputs/t948
    exec diff ../outputs/t948 ../golden/t948 >/dev/null 2>&1 ;;
  p949) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc394 > ../outputs/t949
    exec diff ../outputs/t949 ../golden/t949 >/dev/null 2>&1 ;;
  p950) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc395 > ../outputs/t950
    exec diff ../outputs/t950 ../golden/t950 >/dev/null 2>&1 ;;
  p951) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc396 > ../outputs/t951
    exec diff ../outputs/t951 ../golden/t951 >/dev/null 2>&1 ;;
  p952) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc397 > ../outputs/t952
    exec diff ../outputs/t952 ../golden/t952 >/dev/null 2>&1 ;;
  p953) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc398 > ../outputs/t953
    exec diff ../outputs/t953 ../golden/t953 >/dev/null 2>&1 ;;
  p954) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc399 > ../outputs/t954
    exec diff ../outputs/t954 ../golden/t954 >/dev/null 2>&1 ;;
  p955) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc4 > ../outputs/t955
    exec diff ../outputs/t955 ../golden/t955 >/dev/null 2>&1 ;;
  p956) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc40 > ../outputs/t956
    exec diff ../outputs/t956 ../golden/t956 >/dev/null 2>&1 ;;
  p957) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc400 > ../outputs/t957
    exec diff ../outputs/t957 ../golden/t957 >/dev/null 2>&1 ;;
  p958) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc41 > ../outputs/t958
    exec diff ../outputs/t958 ../golden/t958 >/dev/null 2>&1 ;;
  p959) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc42 > ../outputs/t959
    exec diff ../outputs/t959 ../golden/t959 >/dev/null 2>&1 ;;
  p960) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc43 > ../outputs/t960
    exec diff ../outputs/t960 ../golden/t960 >/dev/null 2>&1 ;;
  p961) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc44 > ../outputs/t961
    exec diff ../outputs/t961 ../golden/t961 >/dev/null 2>&1 ;;
  p962) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc45 > ../outputs/t962
    exec diff ../outputs/t962 ../golden/t962 >/dev/null 2>&1 ;;
  p963) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc46 > ../outputs/t963
    exec diff ../outputs/t963 ../golden/t963 >/dev/null 2>&1 ;;
  p964) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc47 > ../outputs/t964
    exec diff ../outputs/t964 ../golden/t964 >/dev/null 2>&1 ;;
  p965) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc48 > ../outputs/t965
    exec diff ../outputs/t965 ../golden/t965 >/dev/null 2>&1 ;;
  p966) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc49 > ../outputs/t966
    exec diff ../outputs/t966 ../golden/t966 >/dev/null 2>&1 ;;
  p967) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc5 > ../outputs/t967
    exec diff ../outputs/t967 ../golden/t967 >/dev/null 2>&1 ;;
  p968) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc50 > ../outputs/t968
    exec diff ../outputs/t968 ../golden/t968 >/dev/null 2>&1 ;;
  p969) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc51 > ../outputs/t969
    exec diff ../outputs/t969 ../golden/t969 >/dev/null 2>&1 ;;
  p970) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc52 > ../outputs/t970
    exec diff ../outputs/t970 ../golden/t970 >/dev/null 2>&1 ;;
  p971) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc53 > ../outputs/t971
    exec diff ../outputs/t971 ../golden/t971 >/dev/null 2>&1 ;;
  p972) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc54 > ../outputs/t972
    exec diff ../outputs/t972 ../golden/t972 >/dev/null 2>&1 ;;
  p973) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc55 > ../outputs/t973
    exec diff ../outputs/t973 ../golden/t973 >/dev/null 2>&1 ;;
  p974) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc56 > ../outputs/t974
    exec diff ../outputs/t974 ../golden/t974 >/dev/null 2>&1 ;;
  p975) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc57 > ../outputs/t975
    exec diff ../outputs/t975 ../golden/t975 >/dev/null 2>&1 ;;
  p976) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc58 > ../outputs/t976
    exec diff ../outputs/t976 ../golden/t976 >/dev/null 2>&1 ;;
  p977) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc59 > ../outputs/t977
    exec diff ../outputs/t977 ../golden/t977 >/dev/null 2>&1 ;;
  p978) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc6 > ../outputs/t978
    exec diff ../outputs/t978 ../golden/t978 >/dev/null 2>&1 ;;
  p979) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc60 > ../outputs/t979
    exec diff ../outputs/t979 ../golden/t979 >/dev/null 2>&1 ;;
  p980) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc61 > ../outputs/t980
    exec diff ../outputs/t980 ../golden/t980 >/dev/null 2>&1 ;;
  p981) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc62 > ../outputs/t981
    exec diff ../outputs/t981 ../golden/t981 >/dev/null 2>&1 ;;
  p982) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc63 > ../outputs/t982
    exec diff ../outputs/t982 ../golden/t982 >/dev/null 2>&1 ;;
  p983) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc64 > ../outputs/t983
    exec diff ../outputs/t983 ../golden/t983 >/dev/null 2>&1 ;;
  p984) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc65 > ../outputs/t984
    exec diff ../outputs/t984 ../golden/t984 >/dev/null 2>&1 ;;
  p985) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc66 > ../outputs/t985
    exec diff ../outputs/t985 ../golden/t985 >/dev/null 2>&1 ;;
  p986) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc67 > ../outputs/t986
    exec diff ../outputs/t986 ../golden/t986 >/dev/null 2>&1 ;;
  p987) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc68 > ../outputs/t987
    exec diff ../outputs/t987 ../golden/t987 >/dev/null 2>&1 ;;
  p988) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc69 > ../outputs/t988
    exec diff ../outputs/t988 ../golden/t988 >/dev/null 2>&1 ;;
  p989) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc7 > ../outputs/t989
    exec diff ../outputs/t989 ../golden/t989 >/dev/null 2>&1 ;;
  p990) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc70 > ../outputs/t990
    exec diff ../outputs/t990 ../golden/t990 >/dev/null 2>&1 ;;
  p991) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc71 > ../outputs/t991
    exec diff ../outputs/t991 ../golden/t991 >/dev/null 2>&1 ;;
  p992) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc72 > ../outputs/t992
    exec diff ../outputs/t992 ../golden/t992 >/dev/null 2>&1 ;;
  p993) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc73 > ../outputs/t993
    exec diff ../outputs/t993 ../golden/t993 >/dev/null 2>&1 ;;
  p994) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc74 > ../outputs/t994
    exec diff ../outputs/t994 ../golden/t994 >/dev/null 2>&1 ;;
  p995) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc75 > ../outputs/t995
    exec diff ../outputs/t995 ../golden/t995 >/dev/null 2>&1 ;;
  p996) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc76 > ../outputs/t996
    exec diff ../outputs/t996 ../golden/t996 >/dev/null 2>&1 ;;
  p997) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc77 > ../outputs/t997
    exec diff ../outputs/t997 ../golden/t997 >/dev/null 2>&1 ;;
  p998) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc78 > ../outputs/t998
    exec diff ../outputs/t998 ../golden/t998 >/dev/null 2>&1 ;;
  p999) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc79 > ../outputs/t999
    exec diff ../outputs/t999 ../golden/t999 >/dev/null 2>&1 ;;
  p1000) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc8 > ../outputs/t1000
    exec diff ../outputs/t1000 ../golden/t1000 >/dev/null 2>&1 ;;
  p1001) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc80 > ../outputs/t1001
    exec diff ../outputs/t1001 ../golden/t1001 >/dev/null 2>&1 ;;
  p1002) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc81 > ../outputs/t1002
    exec diff ../outputs/t1002 ../golden/t1002 >/dev/null 2>&1 ;;
  p1003) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc82 > ../outputs/t1003
    exec diff ../outputs/t1003 ../golden/t1003 >/dev/null 2>&1 ;;
  p1004) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc83 > ../outputs/t1004
    exec diff ../outputs/t1004 ../golden/t1004 >/dev/null 2>&1 ;;
  p1005) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc84 > ../outputs/t1005
    exec diff ../outputs/t1005 ../golden/t1005 >/dev/null 2>&1 ;;
  p1006) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc85 > ../outputs/t1006
    exec diff ../outputs/t1006 ../golden/t1006 >/dev/null 2>&1 ;;
  p1007) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc86 > ../outputs/t1007
    exec diff ../outputs/t1007 ../golden/t1007 >/dev/null 2>&1 ;;
  p1008) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc87 > ../outputs/t1008
    exec diff ../outputs/t1008 ../golden/t1008 >/dev/null 2>&1 ;;
  p1009) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc88 > ../outputs/t1009
    exec diff ../outputs/t1009 ../golden/t1009 >/dev/null 2>&1 ;;
  p1010) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc89 > ../outputs/t1010
    exec diff ../outputs/t1010 ../golden/t1010 >/dev/null 2>&1 ;;
  p1011) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc9 > ../outputs/t1011
    exec diff ../outputs/t1011 ../golden/t1011 >/dev/null 2>&1 ;;
  p1012) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc90 > ../outputs/t1012
    exec diff ../outputs/t1012 ../golden/t1012 >/dev/null 2>&1 ;;
  p1013) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc91 > ../outputs/t1013
    exec diff ../outputs/t1013 ../golden/t1013 >/dev/null 2>&1 ;;
  p1014) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc92 > ../outputs/t1014
    exec diff ../outputs/t1014 ../golden/t1014 >/dev/null 2>&1 ;;
  p1015) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc93 > ../outputs/t1015
    exec diff ../outputs/t1015 ../golden/t1015 >/dev/null 2>&1 ;;
  p1016) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc94 > ../outputs/t1016
    exec diff ../outputs/t1016 ../golden/t1016 >/dev/null 2>&1 ;;
  p1017) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc95 > ../outputs/t1017
    exec diff ../outputs/t1017 ../golden/t1017 >/dev/null 2>&1 ;;
  p1018) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc96 > ../outputs/t1018
    exec diff ../outputs/t1018 ../golden/t1018 >/dev/null 2>&1 ;;
  p1019) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc97 > ../outputs/t1019
    exec diff ../outputs/t1019 ../golden/t1019 >/dev/null 2>&1 ;;
  p1020) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc98 > ../outputs/t1020
    exec diff ../outputs/t1020 ../golden/t1020 >/dev/null 2>&1 ;;
  p1021) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tc99 > ../outputs/t1021
    exec diff ../outputs/t1021 ../golden/t1021 >/dev/null 2>&1 ;;
  p1022) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test1 > ../outputs/t1022
    exec diff ../outputs/t1022 ../golden/t1022 >/dev/null 2>&1 ;;
  p1023) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test10 > ../outputs/t1023
    exec diff ../outputs/t1023 ../golden/t1023 >/dev/null 2>&1 ;;
  p1024) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test100 > ../outputs/t1024
    exec diff ../outputs/t1024 ../golden/t1024 >/dev/null 2>&1 ;;
  p1025) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test101 > ../outputs/t1025
    exec diff ../outputs/t1025 ../golden/t1025 >/dev/null 2>&1 ;;
  p1026) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test102 > ../outputs/t1026
    exec diff ../outputs/t1026 ../golden/t1026 >/dev/null 2>&1 ;;
  p1027) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test103 > ../outputs/t1027
    exec diff ../outputs/t1027 ../golden/t1027 >/dev/null 2>&1 ;;
  p1028) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test104 > ../outputs/t1028
    exec diff ../outputs/t1028 ../golden/t1028 >/dev/null 2>&1 ;;
  p1029) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test105 > ../outputs/t1029
    exec diff ../outputs/t1029 ../golden/t1029 >/dev/null 2>&1 ;;
  p1030) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test106 > ../outputs/t1030
    exec diff ../outputs/t1030 ../golden/t1030 >/dev/null 2>&1 ;;
  p1031) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test107 > ../outputs/t1031
    exec diff ../outputs/t1031 ../golden/t1031 >/dev/null 2>&1 ;;
  p1032) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test108 > ../outputs/t1032
    exec diff ../outputs/t1032 ../golden/t1032 >/dev/null 2>&1 ;;
  p1033) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test109 > ../outputs/t1033
    exec diff ../outputs/t1033 ../golden/t1033 >/dev/null 2>&1 ;;
  p1034) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test11 > ../outputs/t1034
    exec diff ../outputs/t1034 ../golden/t1034 >/dev/null 2>&1 ;;
  p1035) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test110 > ../outputs/t1035
    exec diff ../outputs/t1035 ../golden/t1035 >/dev/null 2>&1 ;;
  p1036) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test111 > ../outputs/t1036
    exec diff ../outputs/t1036 ../golden/t1036 >/dev/null 2>&1 ;;
  p1037) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test112 > ../outputs/t1037
    exec diff ../outputs/t1037 ../golden/t1037 >/dev/null 2>&1 ;;
  p1038) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test113 > ../outputs/t1038
    exec diff ../outputs/t1038 ../golden/t1038 >/dev/null 2>&1 ;;
  p1039) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test114 > ../outputs/t1039
    exec diff ../outputs/t1039 ../golden/t1039 >/dev/null 2>&1 ;;
  p1040) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test115 > ../outputs/t1040
    exec diff ../outputs/t1040 ../golden/t1040 >/dev/null 2>&1 ;;
  p1041) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test116 > ../outputs/t1041
    exec diff ../outputs/t1041 ../golden/t1041 >/dev/null 2>&1 ;;
  p1042) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test117 > ../outputs/t1042
    exec diff ../outputs/t1042 ../golden/t1042 >/dev/null 2>&1 ;;
  p1043) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test118 > ../outputs/t1043
    exec diff ../outputs/t1043 ../golden/t1043 >/dev/null 2>&1 ;;
  p1044) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test119 > ../outputs/t1044
    exec diff ../outputs/t1044 ../golden/t1044 >/dev/null 2>&1 ;;
  p1045) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test12 > ../outputs/t1045
    exec diff ../outputs/t1045 ../golden/t1045 >/dev/null 2>&1 ;;
  p1046) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test120 > ../outputs/t1046
    exec diff ../outputs/t1046 ../golden/t1046 >/dev/null 2>&1 ;;
  p1047) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test121 > ../outputs/t1047
    exec diff ../outputs/t1047 ../golden/t1047 >/dev/null 2>&1 ;;
  p1048) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test122 > ../outputs/t1048
    exec diff ../outputs/t1048 ../golden/t1048 >/dev/null 2>&1 ;;
  p1049) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test123 > ../outputs/t1049
    exec diff ../outputs/t1049 ../golden/t1049 >/dev/null 2>&1 ;;
  p1050) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test124 > ../outputs/t1050
    exec diff ../outputs/t1050 ../golden/t1050 >/dev/null 2>&1 ;;
  p1051) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test125 > ../outputs/t1051
    exec diff ../outputs/t1051 ../golden/t1051 >/dev/null 2>&1 ;;
  p1052) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test126 > ../outputs/t1052
    exec diff ../outputs/t1052 ../golden/t1052 >/dev/null 2>&1 ;;
  p1053) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test127 > ../outputs/t1053
    exec diff ../outputs/t1053 ../golden/t1053 >/dev/null 2>&1 ;;
  p1054) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test128 > ../outputs/t1054
    exec diff ../outputs/t1054 ../golden/t1054 >/dev/null 2>&1 ;;
  p1055) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test129 > ../outputs/t1055
    exec diff ../outputs/t1055 ../golden/t1055 >/dev/null 2>&1 ;;
  p1056) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test13 > ../outputs/t1056
    exec diff ../outputs/t1056 ../golden/t1056 >/dev/null 2>&1 ;;
  p1057) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test130 > ../outputs/t1057
    exec diff ../outputs/t1057 ../golden/t1057 >/dev/null 2>&1 ;;
  p1058) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test131 > ../outputs/t1058
    exec diff ../outputs/t1058 ../golden/t1058 >/dev/null 2>&1 ;;
  p1059) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test132 > ../outputs/t1059
    exec diff ../outputs/t1059 ../golden/t1059 >/dev/null 2>&1 ;;
  p1060) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test133 > ../outputs/t1060
    exec diff ../outputs/t1060 ../golden/t1060 >/dev/null 2>&1 ;;
  p1061) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test134 > ../outputs/t1061
    exec diff ../outputs/t1061 ../golden/t1061 >/dev/null 2>&1 ;;
  p1062) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test135 > ../outputs/t1062
    exec diff ../outputs/t1062 ../golden/t1062 >/dev/null 2>&1 ;;
  p1063) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test136 > ../outputs/t1063
    exec diff ../outputs/t1063 ../golden/t1063 >/dev/null 2>&1 ;;
  p1064) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test137 > ../outputs/t1064
    exec diff ../outputs/t1064 ../golden/t1064 >/dev/null 2>&1 ;;
  p1065) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test138 > ../outputs/t1065
    exec diff ../outputs/t1065 ../golden/t1065 >/dev/null 2>&1 ;;
  p1066) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test139 > ../outputs/t1066
    exec diff ../outputs/t1066 ../golden/t1066 >/dev/null 2>&1 ;;
  p1067) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test14 > ../outputs/t1067
    exec diff ../outputs/t1067 ../golden/t1067 >/dev/null 2>&1 ;;
  p1068) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test140 > ../outputs/t1068
    exec diff ../outputs/t1068 ../golden/t1068 >/dev/null 2>&1 ;;
  p1069) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test141 > ../outputs/t1069
    exec diff ../outputs/t1069 ../golden/t1069 >/dev/null 2>&1 ;;
  p1070) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test142 > ../outputs/t1070
    exec diff ../outputs/t1070 ../golden/t1070 >/dev/null 2>&1 ;;
  p1071) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test143 > ../outputs/t1071
    exec diff ../outputs/t1071 ../golden/t1071 >/dev/null 2>&1 ;;
  p1072) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test144 > ../outputs/t1072
    exec diff ../outputs/t1072 ../golden/t1072 >/dev/null 2>&1 ;;
  p1073) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test145 > ../outputs/t1073
    exec diff ../outputs/t1073 ../golden/t1073 >/dev/null 2>&1 ;;
  p1074) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test146 > ../outputs/t1074
    exec diff ../outputs/t1074 ../golden/t1074 >/dev/null 2>&1 ;;
  p1075) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test147 > ../outputs/t1075
    exec diff ../outputs/t1075 ../golden/t1075 >/dev/null 2>&1 ;;
  p1076) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test148 > ../outputs/t1076
    exec diff ../outputs/t1076 ../golden/t1076 >/dev/null 2>&1 ;;
  p1077) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test149 > ../outputs/t1077
    exec diff ../outputs/t1077 ../golden/t1077 >/dev/null 2>&1 ;;
  p1078) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test15 > ../outputs/t1078
    exec diff ../outputs/t1078 ../golden/t1078 >/dev/null 2>&1 ;;
  p1079) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test150 > ../outputs/t1079
    exec diff ../outputs/t1079 ../golden/t1079 >/dev/null 2>&1 ;;
  p1080) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test151 > ../outputs/t1080
    exec diff ../outputs/t1080 ../golden/t1080 >/dev/null 2>&1 ;;
  p1081) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test152 > ../outputs/t1081
    exec diff ../outputs/t1081 ../golden/t1081 >/dev/null 2>&1 ;;
  p1082) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test153 > ../outputs/t1082
    exec diff ../outputs/t1082 ../golden/t1082 >/dev/null 2>&1 ;;
  p1083) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test154 > ../outputs/t1083
    exec diff ../outputs/t1083 ../golden/t1083 >/dev/null 2>&1 ;;
  p1084) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test155 > ../outputs/t1084
    exec diff ../outputs/t1084 ../golden/t1084 >/dev/null 2>&1 ;;
  p1085) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test156 > ../outputs/t1085
    exec diff ../outputs/t1085 ../golden/t1085 >/dev/null 2>&1 ;;
  p1086) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test157 > ../outputs/t1086
    exec diff ../outputs/t1086 ../golden/t1086 >/dev/null 2>&1 ;;
  p1087) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test158 > ../outputs/t1087
    exec diff ../outputs/t1087 ../golden/t1087 >/dev/null 2>&1 ;;
  p1088) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test159 > ../outputs/t1088
    exec diff ../outputs/t1088 ../golden/t1088 >/dev/null 2>&1 ;;
  p1089) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test16 > ../outputs/t1089
    exec diff ../outputs/t1089 ../golden/t1089 >/dev/null 2>&1 ;;
  p1090) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test160 > ../outputs/t1090
    exec diff ../outputs/t1090 ../golden/t1090 >/dev/null 2>&1 ;;
  p1091) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test161 > ../outputs/t1091
    exec diff ../outputs/t1091 ../golden/t1091 >/dev/null 2>&1 ;;
  p1092) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test162 > ../outputs/t1092
    exec diff ../outputs/t1092 ../golden/t1092 >/dev/null 2>&1 ;;
  p1093) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test163 > ../outputs/t1093
    exec diff ../outputs/t1093 ../golden/t1093 >/dev/null 2>&1 ;;
  p1094) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test164 > ../outputs/t1094
    exec diff ../outputs/t1094 ../golden/t1094 >/dev/null 2>&1 ;;
  p1095) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test165 > ../outputs/t1095
    exec diff ../outputs/t1095 ../golden/t1095 >/dev/null 2>&1 ;;
  p1096) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test166 > ../outputs/t1096
    exec diff ../outputs/t1096 ../golden/t1096 >/dev/null 2>&1 ;;
  p1097) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test167 > ../outputs/t1097
    exec diff ../outputs/t1097 ../golden/t1097 >/dev/null 2>&1 ;;
  p1098) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test168 > ../outputs/t1098
    exec diff ../outputs/t1098 ../golden/t1098 >/dev/null 2>&1 ;;
  p1099) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test169 > ../outputs/t1099
    exec diff ../outputs/t1099 ../golden/t1099 >/dev/null 2>&1 ;;
  p1100) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test17 > ../outputs/t1100
    exec diff ../outputs/t1100 ../golden/t1100 >/dev/null 2>&1 ;;
  p1101) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test170 > ../outputs/t1101
    exec diff ../outputs/t1101 ../golden/t1101 >/dev/null 2>&1 ;;
  p1102) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test171 > ../outputs/t1102
    exec diff ../outputs/t1102 ../golden/t1102 >/dev/null 2>&1 ;;
  p1103) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test172 > ../outputs/t1103
    exec diff ../outputs/t1103 ../golden/t1103 >/dev/null 2>&1 ;;
  p1104) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test173 > ../outputs/t1104
    exec diff ../outputs/t1104 ../golden/t1104 >/dev/null 2>&1 ;;
  p1105) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test174 > ../outputs/t1105
    exec diff ../outputs/t1105 ../golden/t1105 >/dev/null 2>&1 ;;
  p1106) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test175 > ../outputs/t1106
    exec diff ../outputs/t1106 ../golden/t1106 >/dev/null 2>&1 ;;
  p1107) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test176 > ../outputs/t1107
    exec diff ../outputs/t1107 ../golden/t1107 >/dev/null 2>&1 ;;
  p1108) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test177 > ../outputs/t1108
    exec diff ../outputs/t1108 ../golden/t1108 >/dev/null 2>&1 ;;
  p1109) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test178 > ../outputs/t1109
    exec diff ../outputs/t1109 ../golden/t1109 >/dev/null 2>&1 ;;
  p1110) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test179 > ../outputs/t1110
    exec diff ../outputs/t1110 ../golden/t1110 >/dev/null 2>&1 ;;
  p1111) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test18 > ../outputs/t1111
    exec diff ../outputs/t1111 ../golden/t1111 >/dev/null 2>&1 ;;
  p1112) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test180 > ../outputs/t1112
    exec diff ../outputs/t1112 ../golden/t1112 >/dev/null 2>&1 ;;
  p1113) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test181 > ../outputs/t1113
    exec diff ../outputs/t1113 ../golden/t1113 >/dev/null 2>&1 ;;
  p1114) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test182 > ../outputs/t1114
    exec diff ../outputs/t1114 ../golden/t1114 >/dev/null 2>&1 ;;
  p1115) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test183 > ../outputs/t1115
    exec diff ../outputs/t1115 ../golden/t1115 >/dev/null 2>&1 ;;
  p1116) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test184 > ../outputs/t1116
    exec diff ../outputs/t1116 ../golden/t1116 >/dev/null 2>&1 ;;
  p1117) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test185 > ../outputs/t1117
    exec diff ../outputs/t1117 ../golden/t1117 >/dev/null 2>&1 ;;
  p1118) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test186 > ../outputs/t1118
    exec diff ../outputs/t1118 ../golden/t1118 >/dev/null 2>&1 ;;
  p1119) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test187 > ../outputs/t1119
    exec diff ../outputs/t1119 ../golden/t1119 >/dev/null 2>&1 ;;
  p1120) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test188 > ../outputs/t1120
    exec diff ../outputs/t1120 ../golden/t1120 >/dev/null 2>&1 ;;
  p1121) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test189 > ../outputs/t1121
    exec diff ../outputs/t1121 ../golden/t1121 >/dev/null 2>&1 ;;
  p1122) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test19 > ../outputs/t1122
    exec diff ../outputs/t1122 ../golden/t1122 >/dev/null 2>&1 ;;
  p1123) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test190 > ../outputs/t1123
    exec diff ../outputs/t1123 ../golden/t1123 >/dev/null 2>&1 ;;
  p1124) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test191 > ../outputs/t1124
    exec diff ../outputs/t1124 ../golden/t1124 >/dev/null 2>&1 ;;
  p1125) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test192 > ../outputs/t1125
    exec diff ../outputs/t1125 ../golden/t1125 >/dev/null 2>&1 ;;
  p1126) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test193 > ../outputs/t1126
    exec diff ../outputs/t1126 ../golden/t1126 >/dev/null 2>&1 ;;
  p1127) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test194 > ../outputs/t1127
    exec diff ../outputs/t1127 ../golden/t1127 >/dev/null 2>&1 ;;
  p1128) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test195 > ../outputs/t1128
    exec diff ../outputs/t1128 ../golden/t1128 >/dev/null 2>&1 ;;
  p1129) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test196 > ../outputs/t1129
    exec diff ../outputs/t1129 ../golden/t1129 >/dev/null 2>&1 ;;
  p1130) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test197 > ../outputs/t1130
    exec diff ../outputs/t1130 ../golden/t1130 >/dev/null 2>&1 ;;
  p1131) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test198 > ../outputs/t1131
    exec diff ../outputs/t1131 ../golden/t1131 >/dev/null 2>&1 ;;
  p1132) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test199 > ../outputs/t1132
    exec diff ../outputs/t1132 ../golden/t1132 >/dev/null 2>&1 ;;
  p1133) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test2 > ../outputs/t1133
    exec diff ../outputs/t1133 ../golden/t1133 >/dev/null 2>&1 ;;
  p1134) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test20 > ../outputs/t1134
    exec diff ../outputs/t1134 ../golden/t1134 >/dev/null 2>&1 ;;
  p1135) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test200 > ../outputs/t1135
    exec diff ../outputs/t1135 ../golden/t1135 >/dev/null 2>&1 ;;
  p1136) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test201 > ../outputs/t1136
    exec diff ../outputs/t1136 ../golden/t1136 >/dev/null 2>&1 ;;
  p1137) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test202 > ../outputs/t1137
    exec diff ../outputs/t1137 ../golden/t1137 >/dev/null 2>&1 ;;
  p1138) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test203 > ../outputs/t1138
    exec diff ../outputs/t1138 ../golden/t1138 >/dev/null 2>&1 ;;
  p1139) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test204 > ../outputs/t1139
    exec diff ../outputs/t1139 ../golden/t1139 >/dev/null 2>&1 ;;
  p1140) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test205 > ../outputs/t1140
    exec diff ../outputs/t1140 ../golden/t1140 >/dev/null 2>&1 ;;
  p1141) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test206 > ../outputs/t1141
    exec diff ../outputs/t1141 ../golden/t1141 >/dev/null 2>&1 ;;
  p1142) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test207 > ../outputs/t1142
    exec diff ../outputs/t1142 ../golden/t1142 >/dev/null 2>&1 ;;
  p1143) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test208 > ../outputs/t1143
    exec diff ../outputs/t1143 ../golden/t1143 >/dev/null 2>&1 ;;
  p1144) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test209 > ../outputs/t1144
    exec diff ../outputs/t1144 ../golden/t1144 >/dev/null 2>&1 ;;
  p1145) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test21 > ../outputs/t1145
    exec diff ../outputs/t1145 ../golden/t1145 >/dev/null 2>&1 ;;
  p1146) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test210 > ../outputs/t1146
    exec diff ../outputs/t1146 ../golden/t1146 >/dev/null 2>&1 ;;
  p1147) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test211 > ../outputs/t1147
    exec diff ../outputs/t1147 ../golden/t1147 >/dev/null 2>&1 ;;
  p1148) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test212 > ../outputs/t1148
    exec diff ../outputs/t1148 ../golden/t1148 >/dev/null 2>&1 ;;
  p1149) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test213 > ../outputs/t1149
    exec diff ../outputs/t1149 ../golden/t1149 >/dev/null 2>&1 ;;
  p1150) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test214 > ../outputs/t1150
    exec diff ../outputs/t1150 ../golden/t1150 >/dev/null 2>&1 ;;
  p1151) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test215 > ../outputs/t1151
    exec diff ../outputs/t1151 ../golden/t1151 >/dev/null 2>&1 ;;
  p1152) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test216 > ../outputs/t1152
    exec diff ../outputs/t1152 ../golden/t1152 >/dev/null 2>&1 ;;
  p1153) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test217 > ../outputs/t1153
    exec diff ../outputs/t1153 ../golden/t1153 >/dev/null 2>&1 ;;
  p1154) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test218 > ../outputs/t1154
    exec diff ../outputs/t1154 ../golden/t1154 >/dev/null 2>&1 ;;
  p1155) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test219 > ../outputs/t1155
    exec diff ../outputs/t1155 ../golden/t1155 >/dev/null 2>&1 ;;
  p1156) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test22 > ../outputs/t1156
    exec diff ../outputs/t1156 ../golden/t1156 >/dev/null 2>&1 ;;
  p1157) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test220 > ../outputs/t1157
    exec diff ../outputs/t1157 ../golden/t1157 >/dev/null 2>&1 ;;
  p1158) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test221 > ../outputs/t1158
    exec diff ../outputs/t1158 ../golden/t1158 >/dev/null 2>&1 ;;
  p1159) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test222 > ../outputs/t1159
    exec diff ../outputs/t1159 ../golden/t1159 >/dev/null 2>&1 ;;
  p1160) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test223 > ../outputs/t1160
    exec diff ../outputs/t1160 ../golden/t1160 >/dev/null 2>&1 ;;
  p1161) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test224 > ../outputs/t1161
    exec diff ../outputs/t1161 ../golden/t1161 >/dev/null 2>&1 ;;
  p1162) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test225 > ../outputs/t1162
    exec diff ../outputs/t1162 ../golden/t1162 >/dev/null 2>&1 ;;
  p1163) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test226 > ../outputs/t1163
    exec diff ../outputs/t1163 ../golden/t1163 >/dev/null 2>&1 ;;
  p1164) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test227 > ../outputs/t1164
    exec diff ../outputs/t1164 ../golden/t1164 >/dev/null 2>&1 ;;
  p1165) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test228 > ../outputs/t1165
    exec diff ../outputs/t1165 ../golden/t1165 >/dev/null 2>&1 ;;
  p1166) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test229 > ../outputs/t1166
    exec diff ../outputs/t1166 ../golden/t1166 >/dev/null 2>&1 ;;
  p1167) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test23 > ../outputs/t1167
    exec diff ../outputs/t1167 ../golden/t1167 >/dev/null 2>&1 ;;
  p1168) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test230 > ../outputs/t1168
    exec diff ../outputs/t1168 ../golden/t1168 >/dev/null 2>&1 ;;
  p1169) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test231 > ../outputs/t1169
    exec diff ../outputs/t1169 ../golden/t1169 >/dev/null 2>&1 ;;
  p1170) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test232 > ../outputs/t1170
    exec diff ../outputs/t1170 ../golden/t1170 >/dev/null 2>&1 ;;
  p1171) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test233 > ../outputs/t1171
    exec diff ../outputs/t1171 ../golden/t1171 >/dev/null 2>&1 ;;
  p1172) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test234 > ../outputs/t1172
    exec diff ../outputs/t1172 ../golden/t1172 >/dev/null 2>&1 ;;
  p1173) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test235 > ../outputs/t1173
    exec diff ../outputs/t1173 ../golden/t1173 >/dev/null 2>&1 ;;
  p1174) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test236 > ../outputs/t1174
    exec diff ../outputs/t1174 ../golden/t1174 >/dev/null 2>&1 ;;
  p1175) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test237 > ../outputs/t1175
    exec diff ../outputs/t1175 ../golden/t1175 >/dev/null 2>&1 ;;
  p1176) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test238 > ../outputs/t1176
    exec diff ../outputs/t1176 ../golden/t1176 >/dev/null 2>&1 ;;
  p1177) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test239 > ../outputs/t1177
    exec diff ../outputs/t1177 ../golden/t1177 >/dev/null 2>&1 ;;
  p1178) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test24 > ../outputs/t1178
    exec diff ../outputs/t1178 ../golden/t1178 >/dev/null 2>&1 ;;
  p1179) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test240 > ../outputs/t1179
    exec diff ../outputs/t1179 ../golden/t1179 >/dev/null 2>&1 ;;
  p1180) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test241 > ../outputs/t1180
    exec diff ../outputs/t1180 ../golden/t1180 >/dev/null 2>&1 ;;
  p1181) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test242 > ../outputs/t1181
    exec diff ../outputs/t1181 ../golden/t1181 >/dev/null 2>&1 ;;
  p1182) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test243 > ../outputs/t1182
    exec diff ../outputs/t1182 ../golden/t1182 >/dev/null 2>&1 ;;
  p1183) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test244 > ../outputs/t1183
    exec diff ../outputs/t1183 ../golden/t1183 >/dev/null 2>&1 ;;
  p1184) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test245 > ../outputs/t1184
    exec diff ../outputs/t1184 ../golden/t1184 >/dev/null 2>&1 ;;
  p1185) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test246 > ../outputs/t1185
    exec diff ../outputs/t1185 ../golden/t1185 >/dev/null 2>&1 ;;
  p1186) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test247 > ../outputs/t1186
    exec diff ../outputs/t1186 ../golden/t1186 >/dev/null 2>&1 ;;
  p1187) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test248 > ../outputs/t1187
    exec diff ../outputs/t1187 ../golden/t1187 >/dev/null 2>&1 ;;
  p1188) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test249 > ../outputs/t1188
    exec diff ../outputs/t1188 ../golden/t1188 >/dev/null 2>&1 ;;
  p1189) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test25 > ../outputs/t1189
    exec diff ../outputs/t1189 ../golden/t1189 >/dev/null 2>&1 ;;
  p1190) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test250 > ../outputs/t1190
    exec diff ../outputs/t1190 ../golden/t1190 >/dev/null 2>&1 ;;
  p1191) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test251 > ../outputs/t1191
    exec diff ../outputs/t1191 ../golden/t1191 >/dev/null 2>&1 ;;
  p1192) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test252 > ../outputs/t1192
    exec diff ../outputs/t1192 ../golden/t1192 >/dev/null 2>&1 ;;
  p1193) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test253 > ../outputs/t1193
    exec diff ../outputs/t1193 ../golden/t1193 >/dev/null 2>&1 ;;
  p1194) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test254 > ../outputs/t1194
    exec diff ../outputs/t1194 ../golden/t1194 >/dev/null 2>&1 ;;
  p1195) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test255 > ../outputs/t1195
    exec diff ../outputs/t1195 ../golden/t1195 >/dev/null 2>&1 ;;
  p1196) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test256 > ../outputs/t1196
    exec diff ../outputs/t1196 ../golden/t1196 >/dev/null 2>&1 ;;
  p1197) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test257 > ../outputs/t1197
    exec diff ../outputs/t1197 ../golden/t1197 >/dev/null 2>&1 ;;
  p1198) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test258 > ../outputs/t1198
    exec diff ../outputs/t1198 ../golden/t1198 >/dev/null 2>&1 ;;
  p1199) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test259 > ../outputs/t1199
    exec diff ../outputs/t1199 ../golden/t1199 >/dev/null 2>&1 ;;
  p1200) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test26 > ../outputs/t1200
    exec diff ../outputs/t1200 ../golden/t1200 >/dev/null 2>&1 ;;
  p1201) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test260 > ../outputs/t1201
    exec diff ../outputs/t1201 ../golden/t1201 >/dev/null 2>&1 ;;
  p1202) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test261 > ../outputs/t1202
    exec diff ../outputs/t1202 ../golden/t1202 >/dev/null 2>&1 ;;
  p1203) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test262 > ../outputs/t1203
    exec diff ../outputs/t1203 ../golden/t1203 >/dev/null 2>&1 ;;
  p1204) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test263 > ../outputs/t1204
    exec diff ../outputs/t1204 ../golden/t1204 >/dev/null 2>&1 ;;
  p1205) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test264 > ../outputs/t1205
    exec diff ../outputs/t1205 ../golden/t1205 >/dev/null 2>&1 ;;
  p1206) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test265 > ../outputs/t1206
    exec diff ../outputs/t1206 ../golden/t1206 >/dev/null 2>&1 ;;
  p1207) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test266 > ../outputs/t1207
    exec diff ../outputs/t1207 ../golden/t1207 >/dev/null 2>&1 ;;
  p1208) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test267 > ../outputs/t1208
    exec diff ../outputs/t1208 ../golden/t1208 >/dev/null 2>&1 ;;
  p1209) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test268 > ../outputs/t1209
    exec diff ../outputs/t1209 ../golden/t1209 >/dev/null 2>&1 ;;
  p1210) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test269 > ../outputs/t1210
    exec diff ../outputs/t1210 ../golden/t1210 >/dev/null 2>&1 ;;
  p1211) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test27 > ../outputs/t1211
    exec diff ../outputs/t1211 ../golden/t1211 >/dev/null 2>&1 ;;
  p1212) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test270 > ../outputs/t1212
    exec diff ../outputs/t1212 ../golden/t1212 >/dev/null 2>&1 ;;
  p1213) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test271 > ../outputs/t1213
    exec diff ../outputs/t1213 ../golden/t1213 >/dev/null 2>&1 ;;
  p1214) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test272 > ../outputs/t1214
    exec diff ../outputs/t1214 ../golden/t1214 >/dev/null 2>&1 ;;
  p1215) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test273 > ../outputs/t1215
    exec diff ../outputs/t1215 ../golden/t1215 >/dev/null 2>&1 ;;
  p1216) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test274 > ../outputs/t1216
    exec diff ../outputs/t1216 ../golden/t1216 >/dev/null 2>&1 ;;
  p1217) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test275 > ../outputs/t1217
    exec diff ../outputs/t1217 ../golden/t1217 >/dev/null 2>&1 ;;
  p1218) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test276 > ../outputs/t1218
    exec diff ../outputs/t1218 ../golden/t1218 >/dev/null 2>&1 ;;
  p1219) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test277 > ../outputs/t1219
    exec diff ../outputs/t1219 ../golden/t1219 >/dev/null 2>&1 ;;
  p1220) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test278 > ../outputs/t1220
    exec diff ../outputs/t1220 ../golden/t1220 >/dev/null 2>&1 ;;
  p1221) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test279 > ../outputs/t1221
    exec diff ../outputs/t1221 ../golden/t1221 >/dev/null 2>&1 ;;
  p1222) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test28 > ../outputs/t1222
    exec diff ../outputs/t1222 ../golden/t1222 >/dev/null 2>&1 ;;
  p1223) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test280 > ../outputs/t1223
    exec diff ../outputs/t1223 ../golden/t1223 >/dev/null 2>&1 ;;
  p1224) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test281 > ../outputs/t1224
    exec diff ../outputs/t1224 ../golden/t1224 >/dev/null 2>&1 ;;
  p1225) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test282 > ../outputs/t1225
    exec diff ../outputs/t1225 ../golden/t1225 >/dev/null 2>&1 ;;
  p1226) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test283 > ../outputs/t1226
    exec diff ../outputs/t1226 ../golden/t1226 >/dev/null 2>&1 ;;
  p1227) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test284 > ../outputs/t1227
    exec diff ../outputs/t1227 ../golden/t1227 >/dev/null 2>&1 ;;
  p1228) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test285 > ../outputs/t1228
    exec diff ../outputs/t1228 ../golden/t1228 >/dev/null 2>&1 ;;
  p1229) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test286 > ../outputs/t1229
    exec diff ../outputs/t1229 ../golden/t1229 >/dev/null 2>&1 ;;
  p1230) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test287 > ../outputs/t1230
    exec diff ../outputs/t1230 ../golden/t1230 >/dev/null 2>&1 ;;
  p1231) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test288 > ../outputs/t1231
    exec diff ../outputs/t1231 ../golden/t1231 >/dev/null 2>&1 ;;
  p1232) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test289 > ../outputs/t1232
    exec diff ../outputs/t1232 ../golden/t1232 >/dev/null 2>&1 ;;
  p1233) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test29 > ../outputs/t1233
    exec diff ../outputs/t1233 ../golden/t1233 >/dev/null 2>&1 ;;
  p1234) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test290 > ../outputs/t1234
    exec diff ../outputs/t1234 ../golden/t1234 >/dev/null 2>&1 ;;
  p1235) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test291 > ../outputs/t1235
    exec diff ../outputs/t1235 ../golden/t1235 >/dev/null 2>&1 ;;
  p1236) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test292 > ../outputs/t1236
    exec diff ../outputs/t1236 ../golden/t1236 >/dev/null 2>&1 ;;
  p1237) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test293 > ../outputs/t1237
    exec diff ../outputs/t1237 ../golden/t1237 >/dev/null 2>&1 ;;
  p1238) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test294 > ../outputs/t1238
    exec diff ../outputs/t1238 ../golden/t1238 >/dev/null 2>&1 ;;
  p1239) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test295 > ../outputs/t1239
    exec diff ../outputs/t1239 ../golden/t1239 >/dev/null 2>&1 ;;
  p1240) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test296 > ../outputs/t1240
    exec diff ../outputs/t1240 ../golden/t1240 >/dev/null 2>&1 ;;
  p1241) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test297 > ../outputs/t1241
    exec diff ../outputs/t1241 ../golden/t1241 >/dev/null 2>&1 ;;
  p1242) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test298 > ../outputs/t1242
    exec diff ../outputs/t1242 ../golden/t1242 >/dev/null 2>&1 ;;
  p1243) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test299 > ../outputs/t1243
    exec diff ../outputs/t1243 ../golden/t1243 >/dev/null 2>&1 ;;
  p1244) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test3 > ../outputs/t1244
    exec diff ../outputs/t1244 ../golden/t1244 >/dev/null 2>&1 ;;
  p1245) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test30 > ../outputs/t1245
    exec diff ../outputs/t1245 ../golden/t1245 >/dev/null 2>&1 ;;
  p1246) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test300 > ../outputs/t1246
    exec diff ../outputs/t1246 ../golden/t1246 >/dev/null 2>&1 ;;
  p1247) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test301 > ../outputs/t1247
    exec diff ../outputs/t1247 ../golden/t1247 >/dev/null 2>&1 ;;
  p1248) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test302 > ../outputs/t1248
    exec diff ../outputs/t1248 ../golden/t1248 >/dev/null 2>&1 ;;
  p1249) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test303 > ../outputs/t1249
    exec diff ../outputs/t1249 ../golden/t1249 >/dev/null 2>&1 ;;
  p1250) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test304 > ../outputs/t1250
    exec diff ../outputs/t1250 ../golden/t1250 >/dev/null 2>&1 ;;
  p1251) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test305 > ../outputs/t1251
    exec diff ../outputs/t1251 ../golden/t1251 >/dev/null 2>&1 ;;
  p1252) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test306 > ../outputs/t1252
    exec diff ../outputs/t1252 ../golden/t1252 >/dev/null 2>&1 ;;
  p1253) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test307 > ../outputs/t1253
    exec diff ../outputs/t1253 ../golden/t1253 >/dev/null 2>&1 ;;
  p1254) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test308 > ../outputs/t1254
    exec diff ../outputs/t1254 ../golden/t1254 >/dev/null 2>&1 ;;
  p1255) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test309 > ../outputs/t1255
    exec diff ../outputs/t1255 ../golden/t1255 >/dev/null 2>&1 ;;
  p1256) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test31 > ../outputs/t1256
    exec diff ../outputs/t1256 ../golden/t1256 >/dev/null 2>&1 ;;
  p1257) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test310 > ../outputs/t1257
    exec diff ../outputs/t1257 ../golden/t1257 >/dev/null 2>&1 ;;
  p1258) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test311 > ../outputs/t1258
    exec diff ../outputs/t1258 ../golden/t1258 >/dev/null 2>&1 ;;
  p1259) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test312 > ../outputs/t1259
    exec diff ../outputs/t1259 ../golden/t1259 >/dev/null 2>&1 ;;
  p1260) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test313 > ../outputs/t1260
    exec diff ../outputs/t1260 ../golden/t1260 >/dev/null 2>&1 ;;
  p1261) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test314 > ../outputs/t1261
    exec diff ../outputs/t1261 ../golden/t1261 >/dev/null 2>&1 ;;
  p1262) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test315 > ../outputs/t1262
    exec diff ../outputs/t1262 ../golden/t1262 >/dev/null 2>&1 ;;
  p1263) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test316 > ../outputs/t1263
    exec diff ../outputs/t1263 ../golden/t1263 >/dev/null 2>&1 ;;
  p1264) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test317 > ../outputs/t1264
    exec diff ../outputs/t1264 ../golden/t1264 >/dev/null 2>&1 ;;
  p1265) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test318 > ../outputs/t1265
    exec diff ../outputs/t1265 ../golden/t1265 >/dev/null 2>&1 ;;
  p1266) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test319 > ../outputs/t1266
    exec diff ../outputs/t1266 ../golden/t1266 >/dev/null 2>&1 ;;
  p1267) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test32 > ../outputs/t1267
    exec diff ../outputs/t1267 ../golden/t1267 >/dev/null 2>&1 ;;
  p1268) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test320 > ../outputs/t1268
    exec diff ../outputs/t1268 ../golden/t1268 >/dev/null 2>&1 ;;
  p1269) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test321 > ../outputs/t1269
    exec diff ../outputs/t1269 ../golden/t1269 >/dev/null 2>&1 ;;
  p1270) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test322 > ../outputs/t1270
    exec diff ../outputs/t1270 ../golden/t1270 >/dev/null 2>&1 ;;
  p1271) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test323 > ../outputs/t1271
    exec diff ../outputs/t1271 ../golden/t1271 >/dev/null 2>&1 ;;
  p1272) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test324 > ../outputs/t1272
    exec diff ../outputs/t1272 ../golden/t1272 >/dev/null 2>&1 ;;
  p1273) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test325 > ../outputs/t1273
    exec diff ../outputs/t1273 ../golden/t1273 >/dev/null 2>&1 ;;
  p1274) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test326 > ../outputs/t1274
    exec diff ../outputs/t1274 ../golden/t1274 >/dev/null 2>&1 ;;
  p1275) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test327 > ../outputs/t1275
    exec diff ../outputs/t1275 ../golden/t1275 >/dev/null 2>&1 ;;
  p1276) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test328 > ../outputs/t1276
    exec diff ../outputs/t1276 ../golden/t1276 >/dev/null 2>&1 ;;
  p1277) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test329 > ../outputs/t1277
    exec diff ../outputs/t1277 ../golden/t1277 >/dev/null 2>&1 ;;
  p1278) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test33 > ../outputs/t1278
    exec diff ../outputs/t1278 ../golden/t1278 >/dev/null 2>&1 ;;
  p1279) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test330 > ../outputs/t1279
    exec diff ../outputs/t1279 ../golden/t1279 >/dev/null 2>&1 ;;
  p1280) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test331 > ../outputs/t1280
    exec diff ../outputs/t1280 ../golden/t1280 >/dev/null 2>&1 ;;
  p1281) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test332 > ../outputs/t1281
    exec diff ../outputs/t1281 ../golden/t1281 >/dev/null 2>&1 ;;
  p1282) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test333 > ../outputs/t1282
    exec diff ../outputs/t1282 ../golden/t1282 >/dev/null 2>&1 ;;
  p1283) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test334 > ../outputs/t1283
    exec diff ../outputs/t1283 ../golden/t1283 >/dev/null 2>&1 ;;
  p1284) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test335 > ../outputs/t1284
    exec diff ../outputs/t1284 ../golden/t1284 >/dev/null 2>&1 ;;
  p1285) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test336 > ../outputs/t1285
    exec diff ../outputs/t1285 ../golden/t1285 >/dev/null 2>&1 ;;
  p1286) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test337 > ../outputs/t1286
    exec diff ../outputs/t1286 ../golden/t1286 >/dev/null 2>&1 ;;
  p1287) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test338 > ../outputs/t1287
    exec diff ../outputs/t1287 ../golden/t1287 >/dev/null 2>&1 ;;
  p1288) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test339 > ../outputs/t1288
    exec diff ../outputs/t1288 ../golden/t1288 >/dev/null 2>&1 ;;
  p1289) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test34 > ../outputs/t1289
    exec diff ../outputs/t1289 ../golden/t1289 >/dev/null 2>&1 ;;
  p1290) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test340 > ../outputs/t1290
    exec diff ../outputs/t1290 ../golden/t1290 >/dev/null 2>&1 ;;
  p1291) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test341 > ../outputs/t1291
    exec diff ../outputs/t1291 ../golden/t1291 >/dev/null 2>&1 ;;
  p1292) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test342 > ../outputs/t1292
    exec diff ../outputs/t1292 ../golden/t1292 >/dev/null 2>&1 ;;
  p1293) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test343 > ../outputs/t1293
    exec diff ../outputs/t1293 ../golden/t1293 >/dev/null 2>&1 ;;
  p1294) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test344 > ../outputs/t1294
    exec diff ../outputs/t1294 ../golden/t1294 >/dev/null 2>&1 ;;
  p1295) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test345 > ../outputs/t1295
    exec diff ../outputs/t1295 ../golden/t1295 >/dev/null 2>&1 ;;
  p1296) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test346 > ../outputs/t1296
    exec diff ../outputs/t1296 ../golden/t1296 >/dev/null 2>&1 ;;
  p1297) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test347 > ../outputs/t1297
    exec diff ../outputs/t1297 ../golden/t1297 >/dev/null 2>&1 ;;
  p1298) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test348 > ../outputs/t1298
    exec diff ../outputs/t1298 ../golden/t1298 >/dev/null 2>&1 ;;
  p1299) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test349 > ../outputs/t1299
    exec diff ../outputs/t1299 ../golden/t1299 >/dev/null 2>&1 ;;
  p1300) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test35 > ../outputs/t1300
    exec diff ../outputs/t1300 ../golden/t1300 >/dev/null 2>&1 ;;
  p1301) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test350 > ../outputs/t1301
    exec diff ../outputs/t1301 ../golden/t1301 >/dev/null 2>&1 ;;
  p1302) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test351 > ../outputs/t1302
    exec diff ../outputs/t1302 ../golden/t1302 >/dev/null 2>&1 ;;
  p1303) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test352 > ../outputs/t1303
    exec diff ../outputs/t1303 ../golden/t1303 >/dev/null 2>&1 ;;
  p1304) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test353 > ../outputs/t1304
    exec diff ../outputs/t1304 ../golden/t1304 >/dev/null 2>&1 ;;
  p1305) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test354 > ../outputs/t1305
    exec diff ../outputs/t1305 ../golden/t1305 >/dev/null 2>&1 ;;
  p1306) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test355 > ../outputs/t1306
    exec diff ../outputs/t1306 ../golden/t1306 >/dev/null 2>&1 ;;
  p1307) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test356 > ../outputs/t1307
    exec diff ../outputs/t1307 ../golden/t1307 >/dev/null 2>&1 ;;
  p1308) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test357 > ../outputs/t1308
    exec diff ../outputs/t1308 ../golden/t1308 >/dev/null 2>&1 ;;
  p1309) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test358 > ../outputs/t1309
    exec diff ../outputs/t1309 ../golden/t1309 >/dev/null 2>&1 ;;
  p1310) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test359 > ../outputs/t1310
    exec diff ../outputs/t1310 ../golden/t1310 >/dev/null 2>&1 ;;
  p1311) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test36 > ../outputs/t1311
    exec diff ../outputs/t1311 ../golden/t1311 >/dev/null 2>&1 ;;
  p1312) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test360 > ../outputs/t1312
    exec diff ../outputs/t1312 ../golden/t1312 >/dev/null 2>&1 ;;
  p1313) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test361 > ../outputs/t1313
    exec diff ../outputs/t1313 ../golden/t1313 >/dev/null 2>&1 ;;
  p1314) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test362 > ../outputs/t1314
    exec diff ../outputs/t1314 ../golden/t1314 >/dev/null 2>&1 ;;
  p1315) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test363 > ../outputs/t1315
    exec diff ../outputs/t1315 ../golden/t1315 >/dev/null 2>&1 ;;
  p1316) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test364 > ../outputs/t1316
    exec diff ../outputs/t1316 ../golden/t1316 >/dev/null 2>&1 ;;
  p1317) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test365 > ../outputs/t1317
    exec diff ../outputs/t1317 ../golden/t1317 >/dev/null 2>&1 ;;
  p1318) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test366 > ../outputs/t1318
    exec diff ../outputs/t1318 ../golden/t1318 >/dev/null 2>&1 ;;
  p1319) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test367 > ../outputs/t1319
    exec diff ../outputs/t1319 ../golden/t1319 >/dev/null 2>&1 ;;
  p1320) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test368 > ../outputs/t1320
    exec diff ../outputs/t1320 ../golden/t1320 >/dev/null 2>&1 ;;
  p1321) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test369 > ../outputs/t1321
    exec diff ../outputs/t1321 ../golden/t1321 >/dev/null 2>&1 ;;
  p1322) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test37 > ../outputs/t1322
    exec diff ../outputs/t1322 ../golden/t1322 >/dev/null 2>&1 ;;
  p1323) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test370 > ../outputs/t1323
    exec diff ../outputs/t1323 ../golden/t1323 >/dev/null 2>&1 ;;
  p1324) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test371 > ../outputs/t1324
    exec diff ../outputs/t1324 ../golden/t1324 >/dev/null 2>&1 ;;
  p1325) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test372 > ../outputs/t1325
    exec diff ../outputs/t1325 ../golden/t1325 >/dev/null 2>&1 ;;
  p1326) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test373 > ../outputs/t1326
    exec diff ../outputs/t1326 ../golden/t1326 >/dev/null 2>&1 ;;
  p1327) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test374 > ../outputs/t1327
    exec diff ../outputs/t1327 ../golden/t1327 >/dev/null 2>&1 ;;
  p1328) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test375 > ../outputs/t1328
    exec diff ../outputs/t1328 ../golden/t1328 >/dev/null 2>&1 ;;
  p1329) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test376 > ../outputs/t1329
    exec diff ../outputs/t1329 ../golden/t1329 >/dev/null 2>&1 ;;
  p1330) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test377 > ../outputs/t1330
    exec diff ../outputs/t1330 ../golden/t1330 >/dev/null 2>&1 ;;
  p1331) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test378 > ../outputs/t1331
    exec diff ../outputs/t1331 ../golden/t1331 >/dev/null 2>&1 ;;
  p1332) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test379 > ../outputs/t1332
    exec diff ../outputs/t1332 ../golden/t1332 >/dev/null 2>&1 ;;
  p1333) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test38 > ../outputs/t1333
    exec diff ../outputs/t1333 ../golden/t1333 >/dev/null 2>&1 ;;
  p1334) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test380 > ../outputs/t1334
    exec diff ../outputs/t1334 ../golden/t1334 >/dev/null 2>&1 ;;
  p1335) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test381 > ../outputs/t1335
    exec diff ../outputs/t1335 ../golden/t1335 >/dev/null 2>&1 ;;
  p1336) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test382 > ../outputs/t1336
    exec diff ../outputs/t1336 ../golden/t1336 >/dev/null 2>&1 ;;
  p1337) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test383 > ../outputs/t1337
    exec diff ../outputs/t1337 ../golden/t1337 >/dev/null 2>&1 ;;
  p1338) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test384 > ../outputs/t1338
    exec diff ../outputs/t1338 ../golden/t1338 >/dev/null 2>&1 ;;
  p1339) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test385 > ../outputs/t1339
    exec diff ../outputs/t1339 ../golden/t1339 >/dev/null 2>&1 ;;
  p1340) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test386 > ../outputs/t1340
    exec diff ../outputs/t1340 ../golden/t1340 >/dev/null 2>&1 ;;
  p1341) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test387 > ../outputs/t1341
    exec diff ../outputs/t1341 ../golden/t1341 >/dev/null 2>&1 ;;
  p1342) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test388 > ../outputs/t1342
    exec diff ../outputs/t1342 ../golden/t1342 >/dev/null 2>&1 ;;
  p1343) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test389 > ../outputs/t1343
    exec diff ../outputs/t1343 ../golden/t1343 >/dev/null 2>&1 ;;
  p1344) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test39 > ../outputs/t1344
    exec diff ../outputs/t1344 ../golden/t1344 >/dev/null 2>&1 ;;
  p1345) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test390 > ../outputs/t1345
    exec diff ../outputs/t1345 ../golden/t1345 >/dev/null 2>&1 ;;
  p1346) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test391 > ../outputs/t1346
    exec diff ../outputs/t1346 ../golden/t1346 >/dev/null 2>&1 ;;
  p1347) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test392 > ../outputs/t1347
    exec diff ../outputs/t1347 ../golden/t1347 >/dev/null 2>&1 ;;
  p1348) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test393 > ../outputs/t1348
    exec diff ../outputs/t1348 ../golden/t1348 >/dev/null 2>&1 ;;
  p1349) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test394 > ../outputs/t1349
    exec diff ../outputs/t1349 ../golden/t1349 >/dev/null 2>&1 ;;
  p1350) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test395 > ../outputs/t1350
    exec diff ../outputs/t1350 ../golden/t1350 >/dev/null 2>&1 ;;
  p1351) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test396 > ../outputs/t1351
    exec diff ../outputs/t1351 ../golden/t1351 >/dev/null 2>&1 ;;
  p1352) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test397 > ../outputs/t1352
    exec diff ../outputs/t1352 ../golden/t1352 >/dev/null 2>&1 ;;
  p1353) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test398 > ../outputs/t1353
    exec diff ../outputs/t1353 ../golden/t1353 >/dev/null 2>&1 ;;
  p1354) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test399 > ../outputs/t1354
    exec diff ../outputs/t1354 ../golden/t1354 >/dev/null 2>&1 ;;
  p1355) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test4 > ../outputs/t1355
    exec diff ../outputs/t1355 ../golden/t1355 >/dev/null 2>&1 ;;
  p1356) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test40 > ../outputs/t1356
    exec diff ../outputs/t1356 ../golden/t1356 >/dev/null 2>&1 ;;
  p1357) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test400 > ../outputs/t1357
    exec diff ../outputs/t1357 ../golden/t1357 >/dev/null 2>&1 ;;
  p1358) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test41 > ../outputs/t1358
    exec diff ../outputs/t1358 ../golden/t1358 >/dev/null 2>&1 ;;
  p1359) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test42 > ../outputs/t1359
    exec diff ../outputs/t1359 ../golden/t1359 >/dev/null 2>&1 ;;
  p1360) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test43 > ../outputs/t1360
    exec diff ../outputs/t1360 ../golden/t1360 >/dev/null 2>&1 ;;
  p1361) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test44 > ../outputs/t1361
    exec diff ../outputs/t1361 ../golden/t1361 >/dev/null 2>&1 ;;
  p1362) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test45 > ../outputs/t1362
    exec diff ../outputs/t1362 ../golden/t1362 >/dev/null 2>&1 ;;
  p1363) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test46 > ../outputs/t1363
    exec diff ../outputs/t1363 ../golden/t1363 >/dev/null 2>&1 ;;
  p1364) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test47 > ../outputs/t1364
    exec diff ../outputs/t1364 ../golden/t1364 >/dev/null 2>&1 ;;
  p1365) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test48 > ../outputs/t1365
    exec diff ../outputs/t1365 ../golden/t1365 >/dev/null 2>&1 ;;
  p1366) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test49 > ../outputs/t1366
    exec diff ../outputs/t1366 ../golden/t1366 >/dev/null 2>&1 ;;
  p1367) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test5 > ../outputs/t1367
    exec diff ../outputs/t1367 ../golden/t1367 >/dev/null 2>&1 ;;
  p1368) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test50 > ../outputs/t1368
    exec diff ../outputs/t1368 ../golden/t1368 >/dev/null 2>&1 ;;
  p1369) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test51 > ../outputs/t1369
    exec diff ../outputs/t1369 ../golden/t1369 >/dev/null 2>&1 ;;
  p1370) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test52 > ../outputs/t1370
    exec diff ../outputs/t1370 ../golden/t1370 >/dev/null 2>&1 ;;
  p1371) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test53 > ../outputs/t1371
    exec diff ../outputs/t1371 ../golden/t1371 >/dev/null 2>&1 ;;
  p1372) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test54 > ../outputs/t1372
    exec diff ../outputs/t1372 ../golden/t1372 >/dev/null 2>&1 ;;
  p1373) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test55 > ../outputs/t1373
    exec diff ../outputs/t1373 ../golden/t1373 >/dev/null 2>&1 ;;
  p1374) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test56 > ../outputs/t1374
    exec diff ../outputs/t1374 ../golden/t1374 >/dev/null 2>&1 ;;
  p1375) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test57 > ../outputs/t1375
    exec diff ../outputs/t1375 ../golden/t1375 >/dev/null 2>&1 ;;
  p1376) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test58 > ../outputs/t1376
    exec diff ../outputs/t1376 ../golden/t1376 >/dev/null 2>&1 ;;
  p1377) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test59 > ../outputs/t1377
    exec diff ../outputs/t1377 ../golden/t1377 >/dev/null 2>&1 ;;
  p1378) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test6 > ../outputs/t1378
    exec diff ../outputs/t1378 ../golden/t1378 >/dev/null 2>&1 ;;
  p1379) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test60 > ../outputs/t1379
    exec diff ../outputs/t1379 ../golden/t1379 >/dev/null 2>&1 ;;
  p1380) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test61 > ../outputs/t1380
    exec diff ../outputs/t1380 ../golden/t1380 >/dev/null 2>&1 ;;
  p1381) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test62 > ../outputs/t1381
    exec diff ../outputs/t1381 ../golden/t1381 >/dev/null 2>&1 ;;
  p1382) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test63 > ../outputs/t1382
    exec diff ../outputs/t1382 ../golden/t1382 >/dev/null 2>&1 ;;
  p1383) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test64 > ../outputs/t1383
    exec diff ../outputs/t1383 ../golden/t1383 >/dev/null 2>&1 ;;
  p1384) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test65 > ../outputs/t1384
    exec diff ../outputs/t1384 ../golden/t1384 >/dev/null 2>&1 ;;
  p1385) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test66 > ../outputs/t1385
    exec diff ../outputs/t1385 ../golden/t1385 >/dev/null 2>&1 ;;
  p1386) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test67 > ../outputs/t1386
    exec diff ../outputs/t1386 ../golden/t1386 >/dev/null 2>&1 ;;
  p1387) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test68 > ../outputs/t1387
    exec diff ../outputs/t1387 ../golden/t1387 >/dev/null 2>&1 ;;
  p1388) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test69 > ../outputs/t1388
    exec diff ../outputs/t1388 ../golden/t1388 >/dev/null 2>&1 ;;
  p1389) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test7 > ../outputs/t1389
    exec diff ../outputs/t1389 ../golden/t1389 >/dev/null 2>&1 ;;
  p1390) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test70 > ../outputs/t1390
    exec diff ../outputs/t1390 ../golden/t1390 >/dev/null 2>&1 ;;
  p1391) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test71 > ../outputs/t1391
    exec diff ../outputs/t1391 ../golden/t1391 >/dev/null 2>&1 ;;
  p1392) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test72 > ../outputs/t1392
    exec diff ../outputs/t1392 ../golden/t1392 >/dev/null 2>&1 ;;
  p1393) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test73 > ../outputs/t1393
    exec diff ../outputs/t1393 ../golden/t1393 >/dev/null 2>&1 ;;
  p1394) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test74 > ../outputs/t1394
    exec diff ../outputs/t1394 ../golden/t1394 >/dev/null 2>&1 ;;
  p1395) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test75 > ../outputs/t1395
    exec diff ../outputs/t1395 ../golden/t1395 >/dev/null 2>&1 ;;
  p1396) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test76 > ../outputs/t1396
    exec diff ../outputs/t1396 ../golden/t1396 >/dev/null 2>&1 ;;
  p1397) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test77 > ../outputs/t1397
    exec diff ../outputs/t1397 ../golden/t1397 >/dev/null 2>&1 ;;
  p1398) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test78 > ../outputs/t1398
    exec diff ../outputs/t1398 ../golden/t1398 >/dev/null 2>&1 ;;
  p1399) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test79 > ../outputs/t1399
    exec diff ../outputs/t1399 ../golden/t1399 >/dev/null 2>&1 ;;
  p1400) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test8 > ../outputs/t1400
    exec diff ../outputs/t1400 ../golden/t1400 >/dev/null 2>&1 ;;
  p1401) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test80 > ../outputs/t1401
    exec diff ../outputs/t1401 ../golden/t1401 >/dev/null 2>&1 ;;
  p1402) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test81 > ../outputs/t1402
    exec diff ../outputs/t1402 ../golden/t1402 >/dev/null 2>&1 ;;
  p1403) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test82 > ../outputs/t1403
    exec diff ../outputs/t1403 ../golden/t1403 >/dev/null 2>&1 ;;
  p1404) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test83 > ../outputs/t1404
    exec diff ../outputs/t1404 ../golden/t1404 >/dev/null 2>&1 ;;
  p1405) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test84 > ../outputs/t1405
    exec diff ../outputs/t1405 ../golden/t1405 >/dev/null 2>&1 ;;
  p1406) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test85 > ../outputs/t1406
    exec diff ../outputs/t1406 ../golden/t1406 >/dev/null 2>&1 ;;
  p1407) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test86 > ../outputs/t1407
    exec diff ../outputs/t1407 ../golden/t1407 >/dev/null 2>&1 ;;
  p1408) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test87 > ../outputs/t1408
    exec diff ../outputs/t1408 ../golden/t1408 >/dev/null 2>&1 ;;
  p1409) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test88 > ../outputs/t1409
    exec diff ../outputs/t1409 ../golden/t1409 >/dev/null 2>&1 ;;
  p1410) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test89 > ../outputs/t1410
    exec diff ../outputs/t1410 ../golden/t1410 >/dev/null 2>&1 ;;
  p1411) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test9 > ../outputs/t1411
    exec diff ../outputs/t1411 ../golden/t1411 >/dev/null 2>&1 ;;
  p1412) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test90 > ../outputs/t1412
    exec diff ../outputs/t1412 ../golden/t1412 >/dev/null 2>&1 ;;
  p1413) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test91 > ../outputs/t1413
    exec diff ../outputs/t1413 ../golden/t1413 >/dev/null 2>&1 ;;
  p1414) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test92 > ../outputs/t1414
    exec diff ../outputs/t1414 ../golden/t1414 >/dev/null 2>&1 ;;
  p1415) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test93 > ../outputs/t1415
    exec diff ../outputs/t1415 ../golden/t1415 >/dev/null 2>&1 ;;
  p1416) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test94 > ../outputs/t1416
    exec diff ../outputs/t1416 ../golden/t1416 >/dev/null 2>&1 ;;
  p1417) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test95 > ../outputs/t1417
    exec diff ../outputs/t1417 ../golden/t1417 >/dev/null 2>&1 ;;
  p1418) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test96 > ../outputs/t1418
    exec diff ../outputs/t1418 ../golden/t1418 >/dev/null 2>&1 ;;
  p1419) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test97 > ../outputs/t1419
    exec diff ../outputs/t1419 ../golden/t1419 >/dev/null 2>&1 ;;
  p1420) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test98 > ../outputs/t1420
    exec diff ../outputs/t1420 ../golden/t1420 >/dev/null 2>&1 ;;
  p1421) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/test99 > ../outputs/t1421
    exec diff ../outputs/t1421 ../golden/t1421 >/dev/null 2>&1 ;;
  p1422) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts500 > ../outputs/t1422
    exec diff ../outputs/t1422 ../golden/t1422 >/dev/null 2>&1 ;;
  p1423) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts501 > ../outputs/t1423
    exec diff ../outputs/t1423 ../golden/t1423 >/dev/null 2>&1 ;;
  p1424) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts502 > ../outputs/t1424
    exec diff ../outputs/t1424 ../golden/t1424 >/dev/null 2>&1 ;;
  p1425) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts503 > ../outputs/t1425
    exec diff ../outputs/t1425 ../golden/t1425 >/dev/null 2>&1 ;;
  p1426) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts504 > ../outputs/t1426
    exec diff ../outputs/t1426 ../golden/t1426 >/dev/null 2>&1 ;;
  p1427) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts505 > ../outputs/t1427
    exec diff ../outputs/t1427 ../golden/t1427 >/dev/null 2>&1 ;;
  p1428) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts506 > ../outputs/t1428
    exec diff ../outputs/t1428 ../golden/t1428 >/dev/null 2>&1 ;;
  p1429) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts507 > ../outputs/t1429
    exec diff ../outputs/t1429 ../golden/t1429 >/dev/null 2>&1 ;;
  p1430) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts508 > ../outputs/t1430
    exec diff ../outputs/t1430 ../golden/t1430 >/dev/null 2>&1 ;;
  p1431) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts509 > ../outputs/t1431
    exec diff ../outputs/t1431 ../golden/t1431 >/dev/null 2>&1 ;;
  p1432) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts510 > ../outputs/t1432
    exec diff ../outputs/t1432 ../golden/t1432 >/dev/null 2>&1 ;;
  p1433) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts511 > ../outputs/t1433
    exec diff ../outputs/t1433 ../golden/t1433 >/dev/null 2>&1 ;;
  p1434) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts512 > ../outputs/t1434
    exec diff ../outputs/t1434 ../golden/t1434 >/dev/null 2>&1 ;;
  p1435) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts513 > ../outputs/t1435
    exec diff ../outputs/t1435 ../golden/t1435 >/dev/null 2>&1 ;;
  p1436) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts514 > ../outputs/t1436
    exec diff ../outputs/t1436 ../golden/t1436 >/dev/null 2>&1 ;;
  p1437) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts515 > ../outputs/t1437
    exec diff ../outputs/t1437 ../golden/t1437 >/dev/null 2>&1 ;;
  p1438) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts516 > ../outputs/t1438
    exec diff ../outputs/t1438 ../golden/t1438 >/dev/null 2>&1 ;;
  p1439) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts517 > ../outputs/t1439
    exec diff ../outputs/t1439 ../golden/t1439 >/dev/null 2>&1 ;;
  p1440) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts518 > ../outputs/t1440
    exec diff ../outputs/t1440 ../golden/t1440 >/dev/null 2>&1 ;;
  p1441) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts519 > ../outputs/t1441
    exec diff ../outputs/t1441 ../golden/t1441 >/dev/null 2>&1 ;;
  p1442) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts520 > ../outputs/t1442
    exec diff ../outputs/t1442 ../golden/t1442 >/dev/null 2>&1 ;;
  p1443) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts521 > ../outputs/t1443
    exec diff ../outputs/t1443 ../golden/t1443 >/dev/null 2>&1 ;;
  p1444) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts522 > ../outputs/t1444
    exec diff ../outputs/t1444 ../golden/t1444 >/dev/null 2>&1 ;;
  p1445) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts523 > ../outputs/t1445
    exec diff ../outputs/t1445 ../golden/t1445 >/dev/null 2>&1 ;;
  p1446) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts524 > ../outputs/t1446
    exec diff ../outputs/t1446 ../golden/t1446 >/dev/null 2>&1 ;;
  p1447) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts525 > ../outputs/t1447
    exec diff ../outputs/t1447 ../golden/t1447 >/dev/null 2>&1 ;;
  p1448) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts526 > ../outputs/t1448
    exec diff ../outputs/t1448 ../golden/t1448 >/dev/null 2>&1 ;;
  p1449) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts527 > ../outputs/t1449
    exec diff ../outputs/t1449 ../golden/t1449 >/dev/null 2>&1 ;;
  p1450) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts528 > ../outputs/t1450
    exec diff ../outputs/t1450 ../golden/t1450 >/dev/null 2>&1 ;;
  p1451) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts529 > ../outputs/t1451
    exec diff ../outputs/t1451 ../golden/t1451 >/dev/null 2>&1 ;;
  p1452) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts530 > ../outputs/t1452
    exec diff ../outputs/t1452 ../golden/t1452 >/dev/null 2>&1 ;;
  p1453) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts531 > ../outputs/t1453
    exec diff ../outputs/t1453 ../golden/t1453 >/dev/null 2>&1 ;;
  p1454) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts532 > ../outputs/t1454
    exec diff ../outputs/t1454 ../golden/t1454 >/dev/null 2>&1 ;;
  p1455) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts533 > ../outputs/t1455
    exec diff ../outputs/t1455 ../golden/t1455 >/dev/null 2>&1 ;;
  p1456) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts534 > ../outputs/t1456
    exec diff ../outputs/t1456 ../golden/t1456 >/dev/null 2>&1 ;;
  p1457) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts535 > ../outputs/t1457
    exec diff ../outputs/t1457 ../golden/t1457 >/dev/null 2>&1 ;;
  p1458) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts536 > ../outputs/t1458
    exec diff ../outputs/t1458 ../golden/t1458 >/dev/null 2>&1 ;;
  p1459) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts537 > ../outputs/t1459
    exec diff ../outputs/t1459 ../golden/t1459 >/dev/null 2>&1 ;;
  p1460) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts538 > ../outputs/t1460
    exec diff ../outputs/t1460 ../golden/t1460 >/dev/null 2>&1 ;;
  p1461) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts539 > ../outputs/t1461
    exec diff ../outputs/t1461 ../golden/t1461 >/dev/null 2>&1 ;;
  p1462) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts540 > ../outputs/t1462
    exec diff ../outputs/t1462 ../golden/t1462 >/dev/null 2>&1 ;;
  p1463) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts541 > ../outputs/t1463
    exec diff ../outputs/t1463 ../golden/t1463 >/dev/null 2>&1 ;;
  p1464) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts542 > ../outputs/t1464
    exec diff ../outputs/t1464 ../golden/t1464 >/dev/null 2>&1 ;;
  p1465) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts543 > ../outputs/t1465
    exec diff ../outputs/t1465 ../golden/t1465 >/dev/null 2>&1 ;;
  p1466) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts544 > ../outputs/t1466
    exec diff ../outputs/t1466 ../golden/t1466 >/dev/null 2>&1 ;;
  p1467) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts545 > ../outputs/t1467
    exec diff ../outputs/t1467 ../golden/t1467 >/dev/null 2>&1 ;;
  p1468) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts546 > ../outputs/t1468
    exec diff ../outputs/t1468 ../golden/t1468 >/dev/null 2>&1 ;;
  p1469) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts547 > ../outputs/t1469
    exec diff ../outputs/t1469 ../golden/t1469 >/dev/null 2>&1 ;;
  p1470) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts548 > ../outputs/t1470
    exec diff ../outputs/t1470 ../golden/t1470 >/dev/null 2>&1 ;;
  p1471) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts549 > ../outputs/t1471
    exec diff ../outputs/t1471 ../golden/t1471 >/dev/null 2>&1 ;;
  p1472) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts550 > ../outputs/t1472
    exec diff ../outputs/t1472 ../golden/t1472 >/dev/null 2>&1 ;;
  p1473) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts551 > ../outputs/t1473
    exec diff ../outputs/t1473 ../golden/t1473 >/dev/null 2>&1 ;;
  p1474) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts552 > ../outputs/t1474
    exec diff ../outputs/t1474 ../golden/t1474 >/dev/null 2>&1 ;;
  p1475) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts553 > ../outputs/t1475
    exec diff ../outputs/t1475 ../golden/t1475 >/dev/null 2>&1 ;;
  p1476) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts554 > ../outputs/t1476
    exec diff ../outputs/t1476 ../golden/t1476 >/dev/null 2>&1 ;;
  p1477) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts555 > ../outputs/t1477
    exec diff ../outputs/t1477 ../golden/t1477 >/dev/null 2>&1 ;;
  p1478) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts556 > ../outputs/t1478
    exec diff ../outputs/t1478 ../golden/t1478 >/dev/null 2>&1 ;;
  p1479) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts557 > ../outputs/t1479
    exec diff ../outputs/t1479 ../golden/t1479 >/dev/null 2>&1 ;;
  p1480) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts558 > ../outputs/t1480
    exec diff ../outputs/t1480 ../golden/t1480 >/dev/null 2>&1 ;;
  p1481) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts559 > ../outputs/t1481
    exec diff ../outputs/t1481 ../golden/t1481 >/dev/null 2>&1 ;;
  p1482) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts560 > ../outputs/t1482
    exec diff ../outputs/t1482 ../golden/t1482 >/dev/null 2>&1 ;;
  p1483) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts561 > ../outputs/t1483
    exec diff ../outputs/t1483 ../golden/t1483 >/dev/null 2>&1 ;;
  p1484) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts562 > ../outputs/t1484
    exec diff ../outputs/t1484 ../golden/t1484 >/dev/null 2>&1 ;;
  p1485) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts563 > ../outputs/t1485
    exec diff ../outputs/t1485 ../golden/t1485 >/dev/null 2>&1 ;;
  p1486) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts564 > ../outputs/t1486
    exec diff ../outputs/t1486 ../golden/t1486 >/dev/null 2>&1 ;;
  p1487) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts565 > ../outputs/t1487
    exec diff ../outputs/t1487 ../golden/t1487 >/dev/null 2>&1 ;;
  p1488) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts566 > ../outputs/t1488
    exec diff ../outputs/t1488 ../golden/t1488 >/dev/null 2>&1 ;;
  p1489) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts567 > ../outputs/t1489
    exec diff ../outputs/t1489 ../golden/t1489 >/dev/null 2>&1 ;;
  p1490) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts568 > ../outputs/t1490
    exec diff ../outputs/t1490 ../golden/t1490 >/dev/null 2>&1 ;;
  p1491) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts569 > ../outputs/t1491
    exec diff ../outputs/t1491 ../golden/t1491 >/dev/null 2>&1 ;;
  p1492) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts570 > ../outputs/t1492
    exec diff ../outputs/t1492 ../golden/t1492 >/dev/null 2>&1 ;;
  p1493) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts571 > ../outputs/t1493
    exec diff ../outputs/t1493 ../golden/t1493 >/dev/null 2>&1 ;;
  p1494) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts572 > ../outputs/t1494
    exec diff ../outputs/t1494 ../golden/t1494 >/dev/null 2>&1 ;;
  p1495) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts573 > ../outputs/t1495
    exec diff ../outputs/t1495 ../golden/t1495 >/dev/null 2>&1 ;;
  p1496) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts574 > ../outputs/t1496
    exec diff ../outputs/t1496 ../golden/t1496 >/dev/null 2>&1 ;;
  p1497) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts575 > ../outputs/t1497
    exec diff ../outputs/t1497 ../golden/t1497 >/dev/null 2>&1 ;;
  p1498) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts576 > ../outputs/t1498
    exec diff ../outputs/t1498 ../golden/t1498 >/dev/null 2>&1 ;;
  p1499) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts577 > ../outputs/t1499
    exec diff ../outputs/t1499 ../golden/t1499 >/dev/null 2>&1 ;;
  p1500) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts578 > ../outputs/t1500
    exec diff ../outputs/t1500 ../golden/t1500 >/dev/null 2>&1 ;;
  p1501) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts579 > ../outputs/t1501
    exec diff ../outputs/t1501 ../golden/t1501 >/dev/null 2>&1 ;;
  p1502) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts580 > ../outputs/t1502
    exec diff ../outputs/t1502 ../golden/t1502 >/dev/null 2>&1 ;;
  p1503) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts581 > ../outputs/t1503
    exec diff ../outputs/t1503 ../golden/t1503 >/dev/null 2>&1 ;;
  p1504) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts582 > ../outputs/t1504
    exec diff ../outputs/t1504 ../golden/t1504 >/dev/null 2>&1 ;;
  p1505) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts583 > ../outputs/t1505
    exec diff ../outputs/t1505 ../golden/t1505 >/dev/null 2>&1 ;;
  p1506) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts584 > ../outputs/t1506
    exec diff ../outputs/t1506 ../golden/t1506 >/dev/null 2>&1 ;;
  p1507) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts585 > ../outputs/t1507
    exec diff ../outputs/t1507 ../golden/t1507 >/dev/null 2>&1 ;;
  p1508) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts586 > ../outputs/t1508
    exec diff ../outputs/t1508 ../golden/t1508 >/dev/null 2>&1 ;;
  p1509) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts587 > ../outputs/t1509
    exec diff ../outputs/t1509 ../golden/t1509 >/dev/null 2>&1 ;;
  p1510) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts588 > ../outputs/t1510
    exec diff ../outputs/t1510 ../golden/t1510 >/dev/null 2>&1 ;;
  p1511) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts589 > ../outputs/t1511
    exec diff ../outputs/t1511 ../golden/t1511 >/dev/null 2>&1 ;;
  p1512) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts590 > ../outputs/t1512
    exec diff ../outputs/t1512 ../golden/t1512 >/dev/null 2>&1 ;;
  p1513) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts591 > ../outputs/t1513
    exec diff ../outputs/t1513 ../golden/t1513 >/dev/null 2>&1 ;;
  p1514) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts592 > ../outputs/t1514
    exec diff ../outputs/t1514 ../golden/t1514 >/dev/null 2>&1 ;;
  p1515) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts593 > ../outputs/t1515
    exec diff ../outputs/t1515 ../golden/t1515 >/dev/null 2>&1 ;;
  p1516) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts594 > ../outputs/t1516
    exec diff ../outputs/t1516 ../golden/t1516 >/dev/null 2>&1 ;;
  p1517) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts595 > ../outputs/t1517
    exec diff ../outputs/t1517 ../golden/t1517 >/dev/null 2>&1 ;;
  p1518) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts596 > ../outputs/t1518
    exec diff ../outputs/t1518 ../golden/t1518 >/dev/null 2>&1 ;;
  p1519) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts597 > ../outputs/t1519
    exec diff ../outputs/t1519 ../golden/t1519 >/dev/null 2>&1 ;;
  p1520) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts598 > ../outputs/t1520
    exec diff ../outputs/t1520 ../golden/t1520 >/dev/null 2>&1 ;;
  p1521) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts599 > ../outputs/t1521
    exec diff ../outputs/t1521 ../golden/t1521 >/dev/null 2>&1 ;;
  p1522) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts600 > ../outputs/t1522
    exec diff ../outputs/t1522 ../golden/t1522 >/dev/null 2>&1 ;;
  p1523) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts601 > ../outputs/t1523
    exec diff ../outputs/t1523 ../golden/t1523 >/dev/null 2>&1 ;;
  p1524) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts603 > ../outputs/t1524
    exec diff ../outputs/t1524 ../golden/t1524 >/dev/null 2>&1 ;;
  p1525) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts604 > ../outputs/t1525
    exec diff ../outputs/t1525 ../golden/t1525 >/dev/null 2>&1 ;;
  p1526) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts605 > ../outputs/t1526
    exec diff ../outputs/t1526 ../golden/t1526 >/dev/null 2>&1 ;;
  p1527) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts606 > ../outputs/t1527
    exec diff ../outputs/t1527 ../golden/t1527 >/dev/null 2>&1 ;;
  p1528) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts607 > ../outputs/t1528
    exec diff ../outputs/t1528 ../golden/t1528 >/dev/null 2>&1 ;;
  p1529) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts608 > ../outputs/t1529
    exec diff ../outputs/t1529 ../golden/t1529 >/dev/null 2>&1 ;;
  p1530) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts609 > ../outputs/t1530
    exec diff ../outputs/t1530 ../golden/t1530 >/dev/null 2>&1 ;;
  p1531) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts610 > ../outputs/t1531
    exec diff ../outputs/t1531 ../golden/t1531 >/dev/null 2>&1 ;;
  p1532) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts611 > ../outputs/t1532
    exec diff ../outputs/t1532 ../golden/t1532 >/dev/null 2>&1 ;;
  p1533) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts612 > ../outputs/t1533
    exec diff ../outputs/t1533 ../golden/t1533 >/dev/null 2>&1 ;;
  p1534) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts613 > ../outputs/t1534
    exec diff ../outputs/t1534 ../golden/t1534 >/dev/null 2>&1 ;;
  p1535) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts614 > ../outputs/t1535
    exec diff ../outputs/t1535 ../golden/t1535 >/dev/null 2>&1 ;;
  p1536) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts615 > ../outputs/t1536
    exec diff ../outputs/t1536 ../golden/t1536 >/dev/null 2>&1 ;;
  p1537) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts616 > ../outputs/t1537
    exec diff ../outputs/t1537 ../golden/t1537 >/dev/null 2>&1 ;;
  p1538) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts617 > ../outputs/t1538
    exec diff ../outputs/t1538 ../golden/t1538 >/dev/null 2>&1 ;;
  p1539) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts618 > ../outputs/t1539
    exec diff ../outputs/t1539 ../golden/t1539 >/dev/null 2>&1 ;;
  p1540) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts619 > ../outputs/t1540
    exec diff ../outputs/t1540 ../golden/t1540 >/dev/null 2>&1 ;;
  p1541) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts620 > ../outputs/t1541
    exec diff ../outputs/t1541 ../golden/t1541 >/dev/null 2>&1 ;;
  p1542) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts621 > ../outputs/t1542
    exec diff ../outputs/t1542 ../golden/t1542 >/dev/null 2>&1 ;;
  p1543) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts622 > ../outputs/t1543
    exec diff ../outputs/t1543 ../golden/t1543 >/dev/null 2>&1 ;;
  p1544) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts623 > ../outputs/t1544
    exec diff ../outputs/t1544 ../golden/t1544 >/dev/null 2>&1 ;;
  p1545) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts624 > ../outputs/t1545
    exec diff ../outputs/t1545 ../golden/t1545 >/dev/null 2>&1 ;;
  p1546) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts625 > ../outputs/t1546
    exec diff ../outputs/t1546 ../golden/t1546 >/dev/null 2>&1 ;;
  p1547) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts626 > ../outputs/t1547
    exec diff ../outputs/t1547 ../golden/t1547 >/dev/null 2>&1 ;;
  p1548) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts627 > ../outputs/t1548
    exec diff ../outputs/t1548 ../golden/t1548 >/dev/null 2>&1 ;;
  p1549) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts628 > ../outputs/t1549
    exec diff ../outputs/t1549 ../golden/t1549 >/dev/null 2>&1 ;;
  p1550) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts629 > ../outputs/t1550
    exec diff ../outputs/t1550 ../golden/t1550 >/dev/null 2>&1 ;;
  p1551) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts630 > ../outputs/t1551
    exec diff ../outputs/t1551 ../golden/t1551 >/dev/null 2>&1 ;;
  p1552) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts631 > ../outputs/t1552
    exec diff ../outputs/t1552 ../golden/t1552 >/dev/null 2>&1 ;;
  p1553) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts632 > ../outputs/t1553
    exec diff ../outputs/t1553 ../golden/t1553 >/dev/null 2>&1 ;;
  p1554) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts633 > ../outputs/t1554
    exec diff ../outputs/t1554 ../golden/t1554 >/dev/null 2>&1 ;;
  p1555) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts634 > ../outputs/t1555
    exec diff ../outputs/t1555 ../golden/t1555 >/dev/null 2>&1 ;;
  p1556) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts635 > ../outputs/t1556
    exec diff ../outputs/t1556 ../golden/t1556 >/dev/null 2>&1 ;;
  p1557) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts636 > ../outputs/t1557
    exec diff ../outputs/t1557 ../golden/t1557 >/dev/null 2>&1 ;;
  p1558) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts637 > ../outputs/t1558
    exec diff ../outputs/t1558 ../golden/t1558 >/dev/null 2>&1 ;;
  p1559) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts638 > ../outputs/t1559
    exec diff ../outputs/t1559 ../golden/t1559 >/dev/null 2>&1 ;;
  p1560) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts639 > ../outputs/t1560
    exec diff ../outputs/t1560 ../golden/t1560 >/dev/null 2>&1 ;;
  p1561) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts640 > ../outputs/t1561
    exec diff ../outputs/t1561 ../golden/t1561 >/dev/null 2>&1 ;;
  p1562) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts641 > ../outputs/t1562
    exec diff ../outputs/t1562 ../golden/t1562 >/dev/null 2>&1 ;;
  p1563) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts642 > ../outputs/t1563
    exec diff ../outputs/t1563 ../golden/t1563 >/dev/null 2>&1 ;;
  p1564) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts643 > ../outputs/t1564
    exec diff ../outputs/t1564 ../golden/t1564 >/dev/null 2>&1 ;;
  p1565) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts644 > ../outputs/t1565
    exec diff ../outputs/t1565 ../golden/t1565 >/dev/null 2>&1 ;;
  p1566) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts645 > ../outputs/t1566
    exec diff ../outputs/t1566 ../golden/t1566 >/dev/null 2>&1 ;;
  p1567) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts646 > ../outputs/t1567
    exec diff ../outputs/t1567 ../golden/t1567 >/dev/null 2>&1 ;;
  p1568) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts647 > ../outputs/t1568
    exec diff ../outputs/t1568 ../golden/t1568 >/dev/null 2>&1 ;;
  p1569) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts648 > ../outputs/t1569
    exec diff ../outputs/t1569 ../golden/t1569 >/dev/null 2>&1 ;;
  p1570) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts649 > ../outputs/t1570
    exec diff ../outputs/t1570 ../golden/t1570 >/dev/null 2>&1 ;;
  p1571) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts650 > ../outputs/t1571
    exec diff ../outputs/t1571 ../golden/t1571 >/dev/null 2>&1 ;;
  p1572) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts651 > ../outputs/t1572
    exec diff ../outputs/t1572 ../golden/t1572 >/dev/null 2>&1 ;;
  p1573) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts652 > ../outputs/t1573
    exec diff ../outputs/t1573 ../golden/t1573 >/dev/null 2>&1 ;;
  p1574) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts653 > ../outputs/t1574
    exec diff ../outputs/t1574 ../golden/t1574 >/dev/null 2>&1 ;;
  p1575) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts654 > ../outputs/t1575
    exec diff ../outputs/t1575 ../golden/t1575 >/dev/null 2>&1 ;;
  p1576) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts655 > ../outputs/t1576
    exec diff ../outputs/t1576 ../golden/t1576 >/dev/null 2>&1 ;;
  p1577) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts656 > ../outputs/t1577
    exec diff ../outputs/t1577 ../golden/t1577 >/dev/null 2>&1 ;;
  p1578) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts657 > ../outputs/t1578
    exec diff ../outputs/t1578 ../golden/t1578 >/dev/null 2>&1 ;;
  p1579) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts658 > ../outputs/t1579
    exec diff ../outputs/t1579 ../golden/t1579 >/dev/null 2>&1 ;;
  p1580) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts659 > ../outputs/t1580
    exec diff ../outputs/t1580 ../golden/t1580 >/dev/null 2>&1 ;;
  p1581) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts660 > ../outputs/t1581
    exec diff ../outputs/t1581 ../golden/t1581 >/dev/null 2>&1 ;;
  p1582) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts661 > ../outputs/t1582
    exec diff ../outputs/t1582 ../golden/t1582 >/dev/null 2>&1 ;;
  p1583) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts662 > ../outputs/t1583
    exec diff ../outputs/t1583 ../golden/t1583 >/dev/null 2>&1 ;;
  p1584) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts663 > ../outputs/t1584
    exec diff ../outputs/t1584 ../golden/t1584 >/dev/null 2>&1 ;;
  p1585) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts664 > ../outputs/t1585
    exec diff ../outputs/t1585 ../golden/t1585 >/dev/null 2>&1 ;;
  p1586) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts665 > ../outputs/t1586
    exec diff ../outputs/t1586 ../golden/t1586 >/dev/null 2>&1 ;;
  p1587) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts666 > ../outputs/t1587
    exec diff ../outputs/t1587 ../golden/t1587 >/dev/null 2>&1 ;;
  p1588) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts667 > ../outputs/t1588
    exec diff ../outputs/t1588 ../golden/t1588 >/dev/null 2>&1 ;;
  p1589) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts668 > ../outputs/t1589
    exec diff ../outputs/t1589 ../golden/t1589 >/dev/null 2>&1 ;;
  p1590) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts669 > ../outputs/t1590
    exec diff ../outputs/t1590 ../golden/t1590 >/dev/null 2>&1 ;;
  p1591) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts670 > ../outputs/t1591
    exec diff ../outputs/t1591 ../golden/t1591 >/dev/null 2>&1 ;;
  p1592) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts671 > ../outputs/t1592
    exec diff ../outputs/t1592 ../golden/t1592 >/dev/null 2>&1 ;;
  p1593) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts672 > ../outputs/t1593
    exec diff ../outputs/t1593 ../golden/t1593 >/dev/null 2>&1 ;;
  p1594) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts673 > ../outputs/t1594
    exec diff ../outputs/t1594 ../golden/t1594 >/dev/null 2>&1 ;;
  p1595) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts674 > ../outputs/t1595
    exec diff ../outputs/t1595 ../golden/t1595 >/dev/null 2>&1 ;;
  p1596) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts675 > ../outputs/t1596
    exec diff ../outputs/t1596 ../golden/t1596 >/dev/null 2>&1 ;;
  p1597) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts676 > ../outputs/t1597
    exec diff ../outputs/t1597 ../golden/t1597 >/dev/null 2>&1 ;;
  p1598) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts677 > ../outputs/t1598
    exec diff ../outputs/t1598 ../golden/t1598 >/dev/null 2>&1 ;;
  p1599) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts678 > ../outputs/t1599
    exec diff ../outputs/t1599 ../golden/t1599 >/dev/null 2>&1 ;;
  p1600) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts679 > ../outputs/t1600
    exec diff ../outputs/t1600 ../golden/t1600 >/dev/null 2>&1 ;;
  p1601) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts680 > ../outputs/t1601
    exec diff ../outputs/t1601 ../golden/t1601 >/dev/null 2>&1 ;;
  p1602) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts681 > ../outputs/t1602
    exec diff ../outputs/t1602 ../golden/t1602 >/dev/null 2>&1 ;;
  p1603) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts682 > ../outputs/t1603
    exec diff ../outputs/t1603 ../golden/t1603 >/dev/null 2>&1 ;;
  p1604) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts683 > ../outputs/t1604
    exec diff ../outputs/t1604 ../golden/t1604 >/dev/null 2>&1 ;;
  p1605) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts684 > ../outputs/t1605
    exec diff ../outputs/t1605 ../golden/t1605 >/dev/null 2>&1 ;;
  p1606) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts685 > ../outputs/t1606
    exec diff ../outputs/t1606 ../golden/t1606 >/dev/null 2>&1 ;;
  p1607) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts686 > ../outputs/t1607
    exec diff ../outputs/t1607 ../golden/t1607 >/dev/null 2>&1 ;;
  p1608) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts687 > ../outputs/t1608
    exec diff ../outputs/t1608 ../golden/t1608 >/dev/null 2>&1 ;;
  p1609) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts688 > ../outputs/t1609
    exec diff ../outputs/t1609 ../golden/t1609 >/dev/null 2>&1 ;;
  p1610) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts689 > ../outputs/t1610
    exec diff ../outputs/t1610 ../golden/t1610 >/dev/null 2>&1 ;;
  p1611) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts690 > ../outputs/t1611
    exec diff ../outputs/t1611 ../golden/t1611 >/dev/null 2>&1 ;;
  p1612) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts691 > ../outputs/t1612
    exec diff ../outputs/t1612 ../golden/t1612 >/dev/null 2>&1 ;;
  p1613) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts692 > ../outputs/t1613
    exec diff ../outputs/t1613 ../golden/t1613 >/dev/null 2>&1 ;;
  p1614) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts693 > ../outputs/t1614
    exec diff ../outputs/t1614 ../golden/t1614 >/dev/null 2>&1 ;;
  p1615) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts694 > ../outputs/t1615
    exec diff ../outputs/t1615 ../golden/t1615 >/dev/null 2>&1 ;;
  p1616) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts695 > ../outputs/t1616
    exec diff ../outputs/t1616 ../golden/t1616 >/dev/null 2>&1 ;;
  p1617) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts696 > ../outputs/t1617
    exec diff ../outputs/t1617 ../golden/t1617 >/dev/null 2>&1 ;;
  p1618) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts697 > ../outputs/t1618
    exec diff ../outputs/t1618 ../golden/t1618 >/dev/null 2>&1 ;;
  p1619) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts698 > ../outputs/t1619
    exec diff ../outputs/t1619 ../golden/t1619 >/dev/null 2>&1 ;;
  p1620) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts699 > ../outputs/t1620
    exec diff ../outputs/t1620 ../golden/t1620 >/dev/null 2>&1 ;;
  p1621) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts701 > ../outputs/t1621
    exec diff ../outputs/t1621 ../golden/t1621 >/dev/null 2>&1 ;;
  p1622) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts702 > ../outputs/t1622
    exec diff ../outputs/t1622 ../golden/t1622 >/dev/null 2>&1 ;;
  p1623) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts703 > ../outputs/t1623
    exec diff ../outputs/t1623 ../golden/t1623 >/dev/null 2>&1 ;;
  p1624) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts704 > ../outputs/t1624
    exec diff ../outputs/t1624 ../golden/t1624 >/dev/null 2>&1 ;;
  p1625) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts705 > ../outputs/t1625
    exec diff ../outputs/t1625 ../golden/t1625 >/dev/null 2>&1 ;;
  p1626) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts706 > ../outputs/t1626
    exec diff ../outputs/t1626 ../golden/t1626 >/dev/null 2>&1 ;;
  p1627) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts707 > ../outputs/t1627
    exec diff ../outputs/t1627 ../golden/t1627 >/dev/null 2>&1 ;;
  p1628) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts708 > ../outputs/t1628
    exec diff ../outputs/t1628 ../golden/t1628 >/dev/null 2>&1 ;;
  p1629) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts709 > ../outputs/t1629
    exec diff ../outputs/t1629 ../golden/t1629 >/dev/null 2>&1 ;;
  p1630) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts710 > ../outputs/t1630
    exec diff ../outputs/t1630 ../golden/t1630 >/dev/null 2>&1 ;;
  p1631) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts711 > ../outputs/t1631
    exec diff ../outputs/t1631 ../golden/t1631 >/dev/null 2>&1 ;;
  p1632) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts712 > ../outputs/t1632
    exec diff ../outputs/t1632 ../golden/t1632 >/dev/null 2>&1 ;;
  p1633) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts713 > ../outputs/t1633
    exec diff ../outputs/t1633 ../golden/t1633 >/dev/null 2>&1 ;;
  p1634) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts714 > ../outputs/t1634
    exec diff ../outputs/t1634 ../golden/t1634 >/dev/null 2>&1 ;;
  p1635) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts715 > ../outputs/t1635
    exec diff ../outputs/t1635 ../golden/t1635 >/dev/null 2>&1 ;;
  p1636) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts716 > ../outputs/t1636
    exec diff ../outputs/t1636 ../golden/t1636 >/dev/null 2>&1 ;;
  p1637) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts717 > ../outputs/t1637
    exec diff ../outputs/t1637 ../golden/t1637 >/dev/null 2>&1 ;;
  p1638) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts718 > ../outputs/t1638
    exec diff ../outputs/t1638 ../golden/t1638 >/dev/null 2>&1 ;;
  p1639) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts719 > ../outputs/t1639
    exec diff ../outputs/t1639 ../golden/t1639 >/dev/null 2>&1 ;;
  p1640) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts720 > ../outputs/t1640
    exec diff ../outputs/t1640 ../golden/t1640 >/dev/null 2>&1 ;;
  p1641) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts721 > ../outputs/t1641
    exec diff ../outputs/t1641 ../golden/t1641 >/dev/null 2>&1 ;;
  p1642) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts722 > ../outputs/t1642
    exec diff ../outputs/t1642 ../golden/t1642 >/dev/null 2>&1 ;;
  p1643) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts723 > ../outputs/t1643
    exec diff ../outputs/t1643 ../golden/t1643 >/dev/null 2>&1 ;;
  p1644) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts724 > ../outputs/t1644
    exec diff ../outputs/t1644 ../golden/t1644 >/dev/null 2>&1 ;;
  p1645) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts725 > ../outputs/t1645
    exec diff ../outputs/t1645 ../golden/t1645 >/dev/null 2>&1 ;;
  p1646) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts726 > ../outputs/t1646
    exec diff ../outputs/t1646 ../golden/t1646 >/dev/null 2>&1 ;;
  p1647) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts727 > ../outputs/t1647
    exec diff ../outputs/t1647 ../golden/t1647 >/dev/null 2>&1 ;;
  p1648) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts728 > ../outputs/t1648
    exec diff ../outputs/t1648 ../golden/t1648 >/dev/null 2>&1 ;;
  p1649) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts729 > ../outputs/t1649
    exec diff ../outputs/t1649 ../golden/t1649 >/dev/null 2>&1 ;;
  p1650) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts730 > ../outputs/t1650
    exec diff ../outputs/t1650 ../golden/t1650 >/dev/null 2>&1 ;;
  p1651) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts731 > ../outputs/t1651
    exec diff ../outputs/t1651 ../golden/t1651 >/dev/null 2>&1 ;;
  p1652) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts732 > ../outputs/t1652
    exec diff ../outputs/t1652 ../golden/t1652 >/dev/null 2>&1 ;;
  p1653) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts733 > ../outputs/t1653
    exec diff ../outputs/t1653 ../golden/t1653 >/dev/null 2>&1 ;;
  p1654) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts734 > ../outputs/t1654
    exec diff ../outputs/t1654 ../golden/t1654 >/dev/null 2>&1 ;;
  p1655) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts735 > ../outputs/t1655
    exec diff ../outputs/t1655 ../golden/t1655 >/dev/null 2>&1 ;;
  p1656) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts736 > ../outputs/t1656
    exec diff ../outputs/t1656 ../golden/t1656 >/dev/null 2>&1 ;;
  p1657) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts737 > ../outputs/t1657
    exec diff ../outputs/t1657 ../golden/t1657 >/dev/null 2>&1 ;;
  p1658) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts738 > ../outputs/t1658
    exec diff ../outputs/t1658 ../golden/t1658 >/dev/null 2>&1 ;;
  p1659) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts739 > ../outputs/t1659
    exec diff ../outputs/t1659 ../golden/t1659 >/dev/null 2>&1 ;;
  p1660) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts740 > ../outputs/t1660
    exec diff ../outputs/t1660 ../golden/t1660 >/dev/null 2>&1 ;;
  p1661) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts741 > ../outputs/t1661
    exec diff ../outputs/t1661 ../golden/t1661 >/dev/null 2>&1 ;;
  p1662) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts742 > ../outputs/t1662
    exec diff ../outputs/t1662 ../golden/t1662 >/dev/null 2>&1 ;;
  p1663) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts743 > ../outputs/t1663
    exec diff ../outputs/t1663 ../golden/t1663 >/dev/null 2>&1 ;;
  p1664) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts744 > ../outputs/t1664
    exec diff ../outputs/t1664 ../golden/t1664 >/dev/null 2>&1 ;;
  p1665) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts745 > ../outputs/t1665
    exec diff ../outputs/t1665 ../golden/t1665 >/dev/null 2>&1 ;;
  p1666) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts746 > ../outputs/t1666
    exec diff ../outputs/t1666 ../golden/t1666 >/dev/null 2>&1 ;;
  p1667) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts747 > ../outputs/t1667
    exec diff ../outputs/t1667 ../golden/t1667 >/dev/null 2>&1 ;;
  p1668) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts748 > ../outputs/t1668
    exec diff ../outputs/t1668 ../golden/t1668 >/dev/null 2>&1 ;;
  p1669) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts749 > ../outputs/t1669
    exec diff ../outputs/t1669 ../golden/t1669 >/dev/null 2>&1 ;;
  p1670) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts750 > ../outputs/t1670
    exec diff ../outputs/t1670 ../golden/t1670 >/dev/null 2>&1 ;;
  p1671) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts751 > ../outputs/t1671
    exec diff ../outputs/t1671 ../golden/t1671 >/dev/null 2>&1 ;;
  p1672) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts752 > ../outputs/t1672
    exec diff ../outputs/t1672 ../golden/t1672 >/dev/null 2>&1 ;;
  p1673) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts753 > ../outputs/t1673
    exec diff ../outputs/t1673 ../golden/t1673 >/dev/null 2>&1 ;;
  p1674) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts754 > ../outputs/t1674
    exec diff ../outputs/t1674 ../golden/t1674 >/dev/null 2>&1 ;;
  p1675) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts755 > ../outputs/t1675
    exec diff ../outputs/t1675 ../golden/t1675 >/dev/null 2>&1 ;;
  p1676) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts756 > ../outputs/t1676
    exec diff ../outputs/t1676 ../golden/t1676 >/dev/null 2>&1 ;;
  p1677) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts757 > ../outputs/t1677
    exec diff ../outputs/t1677 ../golden/t1677 >/dev/null 2>&1 ;;
  p1678) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts758 > ../outputs/t1678
    exec diff ../outputs/t1678 ../golden/t1678 >/dev/null 2>&1 ;;
  p1679) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts759 > ../outputs/t1679
    exec diff ../outputs/t1679 ../golden/t1679 >/dev/null 2>&1 ;;
  p1680) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts760 > ../outputs/t1680
    exec diff ../outputs/t1680 ../golden/t1680 >/dev/null 2>&1 ;;
  p1681) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts761 > ../outputs/t1681
    exec diff ../outputs/t1681 ../golden/t1681 >/dev/null 2>&1 ;;
  p1682) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts762 > ../outputs/t1682
    exec diff ../outputs/t1682 ../golden/t1682 >/dev/null 2>&1 ;;
  p1683) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts763 > ../outputs/t1683
    exec diff ../outputs/t1683 ../golden/t1683 >/dev/null 2>&1 ;;
  p1684) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts764 > ../outputs/t1684
    exec diff ../outputs/t1684 ../golden/t1684 >/dev/null 2>&1 ;;
  p1685) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts765 > ../outputs/t1685
    exec diff ../outputs/t1685 ../golden/t1685 >/dev/null 2>&1 ;;
  p1686) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts766 > ../outputs/t1686
    exec diff ../outputs/t1686 ../golden/t1686 >/dev/null 2>&1 ;;
  p1687) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts767 > ../outputs/t1687
    exec diff ../outputs/t1687 ../golden/t1687 >/dev/null 2>&1 ;;
  p1688) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts768 > ../outputs/t1688
    exec diff ../outputs/t1688 ../golden/t1688 >/dev/null 2>&1 ;;
  p1689) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts769 > ../outputs/t1689
    exec diff ../outputs/t1689 ../golden/t1689 >/dev/null 2>&1 ;;
  p1690) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts770 > ../outputs/t1690
    exec diff ../outputs/t1690 ../golden/t1690 >/dev/null 2>&1 ;;
  p1691) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts771 > ../outputs/t1691
    exec diff ../outputs/t1691 ../golden/t1691 >/dev/null 2>&1 ;;
  p1692) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts772 > ../outputs/t1692
    exec diff ../outputs/t1692 ../golden/t1692 >/dev/null 2>&1 ;;
  p1693) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts773 > ../outputs/t1693
    exec diff ../outputs/t1693 ../golden/t1693 >/dev/null 2>&1 ;;
  p1694) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts774 > ../outputs/t1694
    exec diff ../outputs/t1694 ../golden/t1694 >/dev/null 2>&1 ;;
  p1695) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts775 > ../outputs/t1695
    exec diff ../outputs/t1695 ../golden/t1695 >/dev/null 2>&1 ;;
  p1696) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts776 > ../outputs/t1696
    exec diff ../outputs/t1696 ../golden/t1696 >/dev/null 2>&1 ;;
  p1697) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts777 > ../outputs/t1697
    exec diff ../outputs/t1697 ../golden/t1697 >/dev/null 2>&1 ;;
  p1698) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts778 > ../outputs/t1698
    exec diff ../outputs/t1698 ../golden/t1698 >/dev/null 2>&1 ;;
  p1699) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts779 > ../outputs/t1699
    exec diff ../outputs/t1699 ../golden/t1699 >/dev/null 2>&1 ;;
  p1700) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts780 > ../outputs/t1700
    exec diff ../outputs/t1700 ../golden/t1700 >/dev/null 2>&1 ;;
  p1701) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts781 > ../outputs/t1701
    exec diff ../outputs/t1701 ../golden/t1701 >/dev/null 2>&1 ;;
  p1702) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts782 > ../outputs/t1702
    exec diff ../outputs/t1702 ../golden/t1702 >/dev/null 2>&1 ;;
  p1703) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts783 > ../outputs/t1703
    exec diff ../outputs/t1703 ../golden/t1703 >/dev/null 2>&1 ;;
  p1704) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts784 > ../outputs/t1704
    exec diff ../outputs/t1704 ../golden/t1704 >/dev/null 2>&1 ;;
  p1705) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts785 > ../outputs/t1705
    exec diff ../outputs/t1705 ../golden/t1705 >/dev/null 2>&1 ;;
  p1706) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts786 > ../outputs/t1706
    exec diff ../outputs/t1706 ../golden/t1706 >/dev/null 2>&1 ;;
  p1707) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts787 > ../outputs/t1707
    exec diff ../outputs/t1707 ../golden/t1707 >/dev/null 2>&1 ;;
  p1708) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts788 > ../outputs/t1708
    exec diff ../outputs/t1708 ../golden/t1708 >/dev/null 2>&1 ;;
  p1709) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts789 > ../outputs/t1709
    exec diff ../outputs/t1709 ../golden/t1709 >/dev/null 2>&1 ;;
  p1710) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts790 > ../outputs/t1710
    exec diff ../outputs/t1710 ../golden/t1710 >/dev/null 2>&1 ;;
  p1711) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts791 > ../outputs/t1711
    exec diff ../outputs/t1711 ../golden/t1711 >/dev/null 2>&1 ;;
  p1712) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts792 > ../outputs/t1712
    exec diff ../outputs/t1712 ../golden/t1712 >/dev/null 2>&1 ;;
  p1713) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts793 > ../outputs/t1713
    exec diff ../outputs/t1713 ../golden/t1713 >/dev/null 2>&1 ;;
  p1714) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts794 > ../outputs/t1714
    exec diff ../outputs/t1714 ../golden/t1714 >/dev/null 2>&1 ;;
  p1715) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts795 > ../outputs/t1715
    exec diff ../outputs/t1715 ../golden/t1715 >/dev/null 2>&1 ;;
  p1716) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts796 > ../outputs/t1716
    exec diff ../outputs/t1716 ../golden/t1716 >/dev/null 2>&1 ;;
  p1717) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts797 > ../outputs/t1717
    exec diff ../outputs/t1717 ../golden/t1717 >/dev/null 2>&1 ;;
  p1718) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts798 > ../outputs/t1718
    exec diff ../outputs/t1718 ../golden/t1718 >/dev/null 2>&1 ;;
  p1719) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts799 > ../outputs/t1719
    exec diff ../outputs/t1719 ../golden/t1719 >/dev/null 2>&1 ;;
  p1720) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/ts800 > ../outputs/t1720
    exec diff ../outputs/t1720 ../golden/t1720 >/dev/null 2>&1 ;;
  p1721) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst1 > ../outputs/t1721
    exec diff ../outputs/t1721 ../golden/t1721 >/dev/null 2>&1 ;;
  p1722) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst10 > ../outputs/t1722
    exec diff ../outputs/t1722 ../golden/t1722 >/dev/null 2>&1 ;;
  p1723) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst100 > ../outputs/t1723
    exec diff ../outputs/t1723 ../golden/t1723 >/dev/null 2>&1 ;;
  p1724) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst101 > ../outputs/t1724
    exec diff ../outputs/t1724 ../golden/t1724 >/dev/null 2>&1 ;;
  p1725) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst102 > ../outputs/t1725
    exec diff ../outputs/t1725 ../golden/t1725 >/dev/null 2>&1 ;;
  p1726) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst103 > ../outputs/t1726
    exec diff ../outputs/t1726 ../golden/t1726 >/dev/null 2>&1 ;;
  p1727) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst104 > ../outputs/t1727
    exec diff ../outputs/t1727 ../golden/t1727 >/dev/null 2>&1 ;;
  p1728) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst105 > ../outputs/t1728
    exec diff ../outputs/t1728 ../golden/t1728 >/dev/null 2>&1 ;;
  p1729) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst106 > ../outputs/t1729
    exec diff ../outputs/t1729 ../golden/t1729 >/dev/null 2>&1 ;;
  p1730) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst107 > ../outputs/t1730
    exec diff ../outputs/t1730 ../golden/t1730 >/dev/null 2>&1 ;;
  p1731) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst108 > ../outputs/t1731
    exec diff ../outputs/t1731 ../golden/t1731 >/dev/null 2>&1 ;;
  p1732) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst109 > ../outputs/t1732
    exec diff ../outputs/t1732 ../golden/t1732 >/dev/null 2>&1 ;;
  p1733) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst11 > ../outputs/t1733
    exec diff ../outputs/t1733 ../golden/t1733 >/dev/null 2>&1 ;;
  p1734) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst110 > ../outputs/t1734
    exec diff ../outputs/t1734 ../golden/t1734 >/dev/null 2>&1 ;;
  p1735) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst111 > ../outputs/t1735
    exec diff ../outputs/t1735 ../golden/t1735 >/dev/null 2>&1 ;;
  p1736) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst112 > ../outputs/t1736
    exec diff ../outputs/t1736 ../golden/t1736 >/dev/null 2>&1 ;;
  p1737) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst113 > ../outputs/t1737
    exec diff ../outputs/t1737 ../golden/t1737 >/dev/null 2>&1 ;;
  p1738) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst114 > ../outputs/t1738
    exec diff ../outputs/t1738 ../golden/t1738 >/dev/null 2>&1 ;;
  p1739) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst115 > ../outputs/t1739
    exec diff ../outputs/t1739 ../golden/t1739 >/dev/null 2>&1 ;;
  p1740) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst116 > ../outputs/t1740
    exec diff ../outputs/t1740 ../golden/t1740 >/dev/null 2>&1 ;;
  p1741) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst117 > ../outputs/t1741
    exec diff ../outputs/t1741 ../golden/t1741 >/dev/null 2>&1 ;;
  p1742) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst118 > ../outputs/t1742
    exec diff ../outputs/t1742 ../golden/t1742 >/dev/null 2>&1 ;;
  p1743) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst119 > ../outputs/t1743
    exec diff ../outputs/t1743 ../golden/t1743 >/dev/null 2>&1 ;;
  p1744) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst12 > ../outputs/t1744
    exec diff ../outputs/t1744 ../golden/t1744 >/dev/null 2>&1 ;;
  p1745) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst120 > ../outputs/t1745
    exec diff ../outputs/t1745 ../golden/t1745 >/dev/null 2>&1 ;;
  p1746) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst121 > ../outputs/t1746
    exec diff ../outputs/t1746 ../golden/t1746 >/dev/null 2>&1 ;;
  p1747) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst122 > ../outputs/t1747
    exec diff ../outputs/t1747 ../golden/t1747 >/dev/null 2>&1 ;;
  p1748) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst123 > ../outputs/t1748
    exec diff ../outputs/t1748 ../golden/t1748 >/dev/null 2>&1 ;;
  p1749) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst124 > ../outputs/t1749
    exec diff ../outputs/t1749 ../golden/t1749 >/dev/null 2>&1 ;;
  p1750) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst125 > ../outputs/t1750
    exec diff ../outputs/t1750 ../golden/t1750 >/dev/null 2>&1 ;;
  p1751) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst126 > ../outputs/t1751
    exec diff ../outputs/t1751 ../golden/t1751 >/dev/null 2>&1 ;;
  p1752) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst127 > ../outputs/t1752
    exec diff ../outputs/t1752 ../golden/t1752 >/dev/null 2>&1 ;;
  p1753) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst128 > ../outputs/t1753
    exec diff ../outputs/t1753 ../golden/t1753 >/dev/null 2>&1 ;;
  p1754) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst129 > ../outputs/t1754
    exec diff ../outputs/t1754 ../golden/t1754 >/dev/null 2>&1 ;;
  p1755) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst13 > ../outputs/t1755
    exec diff ../outputs/t1755 ../golden/t1755 >/dev/null 2>&1 ;;
  p1756) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst130 > ../outputs/t1756
    exec diff ../outputs/t1756 ../golden/t1756 >/dev/null 2>&1 ;;
  p1757) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst131 > ../outputs/t1757
    exec diff ../outputs/t1757 ../golden/t1757 >/dev/null 2>&1 ;;
  p1758) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst132 > ../outputs/t1758
    exec diff ../outputs/t1758 ../golden/t1758 >/dev/null 2>&1 ;;
  p1759) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst133 > ../outputs/t1759
    exec diff ../outputs/t1759 ../golden/t1759 >/dev/null 2>&1 ;;
  p1760) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst134 > ../outputs/t1760
    exec diff ../outputs/t1760 ../golden/t1760 >/dev/null 2>&1 ;;
  p1761) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst135 > ../outputs/t1761
    exec diff ../outputs/t1761 ../golden/t1761 >/dev/null 2>&1 ;;
  p1762) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst136 > ../outputs/t1762
    exec diff ../outputs/t1762 ../golden/t1762 >/dev/null 2>&1 ;;
  p1763) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst137 > ../outputs/t1763
    exec diff ../outputs/t1763 ../golden/t1763 >/dev/null 2>&1 ;;
  p1764) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst138 > ../outputs/t1764
    exec diff ../outputs/t1764 ../golden/t1764 >/dev/null 2>&1 ;;
  p1765) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst139 > ../outputs/t1765
    exec diff ../outputs/t1765 ../golden/t1765 >/dev/null 2>&1 ;;
  p1766) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst14 > ../outputs/t1766
    exec diff ../outputs/t1766 ../golden/t1766 >/dev/null 2>&1 ;;
  p1767) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst140 > ../outputs/t1767
    exec diff ../outputs/t1767 ../golden/t1767 >/dev/null 2>&1 ;;
  p1768) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst141 > ../outputs/t1768
    exec diff ../outputs/t1768 ../golden/t1768 >/dev/null 2>&1 ;;
  p1769) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst142 > ../outputs/t1769
    exec diff ../outputs/t1769 ../golden/t1769 >/dev/null 2>&1 ;;
  p1770) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst143 > ../outputs/t1770
    exec diff ../outputs/t1770 ../golden/t1770 >/dev/null 2>&1 ;;
  p1771) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst144 > ../outputs/t1771
    exec diff ../outputs/t1771 ../golden/t1771 >/dev/null 2>&1 ;;
  p1772) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst145 > ../outputs/t1772
    exec diff ../outputs/t1772 ../golden/t1772 >/dev/null 2>&1 ;;
  p1773) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst146 > ../outputs/t1773
    exec diff ../outputs/t1773 ../golden/t1773 >/dev/null 2>&1 ;;
  p1774) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst147 > ../outputs/t1774
    exec diff ../outputs/t1774 ../golden/t1774 >/dev/null 2>&1 ;;
  p1775) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst148 > ../outputs/t1775
    exec diff ../outputs/t1775 ../golden/t1775 >/dev/null 2>&1 ;;
  p1776) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst149 > ../outputs/t1776
    exec diff ../outputs/t1776 ../golden/t1776 >/dev/null 2>&1 ;;
  p1777) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst15 > ../outputs/t1777
    exec diff ../outputs/t1777 ../golden/t1777 >/dev/null 2>&1 ;;
  p1778) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst150 > ../outputs/t1778
    exec diff ../outputs/t1778 ../golden/t1778 >/dev/null 2>&1 ;;
  p1779) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst151 > ../outputs/t1779
    exec diff ../outputs/t1779 ../golden/t1779 >/dev/null 2>&1 ;;
  p1780) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst152 > ../outputs/t1780
    exec diff ../outputs/t1780 ../golden/t1780 >/dev/null 2>&1 ;;
  p1781) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst153 > ../outputs/t1781
    exec diff ../outputs/t1781 ../golden/t1781 >/dev/null 2>&1 ;;
  p1782) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst154 > ../outputs/t1782
    exec diff ../outputs/t1782 ../golden/t1782 >/dev/null 2>&1 ;;
  p1783) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst155 > ../outputs/t1783
    exec diff ../outputs/t1783 ../golden/t1783 >/dev/null 2>&1 ;;
  p1784) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst156 > ../outputs/t1784
    exec diff ../outputs/t1784 ../golden/t1784 >/dev/null 2>&1 ;;
  p1785) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst157 > ../outputs/t1785
    exec diff ../outputs/t1785 ../golden/t1785 >/dev/null 2>&1 ;;
  p1786) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst158 > ../outputs/t1786
    exec diff ../outputs/t1786 ../golden/t1786 >/dev/null 2>&1 ;;
  p1787) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst159 > ../outputs/t1787
    exec diff ../outputs/t1787 ../golden/t1787 >/dev/null 2>&1 ;;
  p1788) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst16 > ../outputs/t1788
    exec diff ../outputs/t1788 ../golden/t1788 >/dev/null 2>&1 ;;
  p1789) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst160 > ../outputs/t1789
    exec diff ../outputs/t1789 ../golden/t1789 >/dev/null 2>&1 ;;
  p1790) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst161 > ../outputs/t1790
    exec diff ../outputs/t1790 ../golden/t1790 >/dev/null 2>&1 ;;
  p1791) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst162 > ../outputs/t1791
    exec diff ../outputs/t1791 ../golden/t1791 >/dev/null 2>&1 ;;
  p1792) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst163 > ../outputs/t1792
    exec diff ../outputs/t1792 ../golden/t1792 >/dev/null 2>&1 ;;
  p1793) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst164 > ../outputs/t1793
    exec diff ../outputs/t1793 ../golden/t1793 >/dev/null 2>&1 ;;
  p1794) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst165 > ../outputs/t1794
    exec diff ../outputs/t1794 ../golden/t1794 >/dev/null 2>&1 ;;
  p1795) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst166 > ../outputs/t1795
    exec diff ../outputs/t1795 ../golden/t1795 >/dev/null 2>&1 ;;
  p1796) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst167 > ../outputs/t1796
    exec diff ../outputs/t1796 ../golden/t1796 >/dev/null 2>&1 ;;
  p1797) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst168 > ../outputs/t1797
    exec diff ../outputs/t1797 ../golden/t1797 >/dev/null 2>&1 ;;
  p1798) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst169 > ../outputs/t1798
    exec diff ../outputs/t1798 ../golden/t1798 >/dev/null 2>&1 ;;
  p1799) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst17 > ../outputs/t1799
    exec diff ../outputs/t1799 ../golden/t1799 >/dev/null 2>&1 ;;
  p1800) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst170 > ../outputs/t1800
    exec diff ../outputs/t1800 ../golden/t1800 >/dev/null 2>&1 ;;
  p1801) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst171 > ../outputs/t1801
    exec diff ../outputs/t1801 ../golden/t1801 >/dev/null 2>&1 ;;
  p1802) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst172 > ../outputs/t1802
    exec diff ../outputs/t1802 ../golden/t1802 >/dev/null 2>&1 ;;
  p1803) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst173 > ../outputs/t1803
    exec diff ../outputs/t1803 ../golden/t1803 >/dev/null 2>&1 ;;
  p1804) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst174 > ../outputs/t1804
    exec diff ../outputs/t1804 ../golden/t1804 >/dev/null 2>&1 ;;
  p1805) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst175 > ../outputs/t1805
    exec diff ../outputs/t1805 ../golden/t1805 >/dev/null 2>&1 ;;
  p1806) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst176 > ../outputs/t1806
    exec diff ../outputs/t1806 ../golden/t1806 >/dev/null 2>&1 ;;
  p1807) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst177 > ../outputs/t1807
    exec diff ../outputs/t1807 ../golden/t1807 >/dev/null 2>&1 ;;
  p1808) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst178 > ../outputs/t1808
    exec diff ../outputs/t1808 ../golden/t1808 >/dev/null 2>&1 ;;
  p1809) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst179 > ../outputs/t1809
    exec diff ../outputs/t1809 ../golden/t1809 >/dev/null 2>&1 ;;
  p1810) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst18 > ../outputs/t1810
    exec diff ../outputs/t1810 ../golden/t1810 >/dev/null 2>&1 ;;
  p1811) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst180 > ../outputs/t1811
    exec diff ../outputs/t1811 ../golden/t1811 >/dev/null 2>&1 ;;
  p1812) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst181 > ../outputs/t1812
    exec diff ../outputs/t1812 ../golden/t1812 >/dev/null 2>&1 ;;
  p1813) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst182 > ../outputs/t1813
    exec diff ../outputs/t1813 ../golden/t1813 >/dev/null 2>&1 ;;
  p1814) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst183 > ../outputs/t1814
    exec diff ../outputs/t1814 ../golden/t1814 >/dev/null 2>&1 ;;
  p1815) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst184 > ../outputs/t1815
    exec diff ../outputs/t1815 ../golden/t1815 >/dev/null 2>&1 ;;
  p1816) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst185 > ../outputs/t1816
    exec diff ../outputs/t1816 ../golden/t1816 >/dev/null 2>&1 ;;
  p1817) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst186 > ../outputs/t1817
    exec diff ../outputs/t1817 ../golden/t1817 >/dev/null 2>&1 ;;
  p1818) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst187 > ../outputs/t1818
    exec diff ../outputs/t1818 ../golden/t1818 >/dev/null 2>&1 ;;
  p1819) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst188 > ../outputs/t1819
    exec diff ../outputs/t1819 ../golden/t1819 >/dev/null 2>&1 ;;
  p1820) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst189 > ../outputs/t1820
    exec diff ../outputs/t1820 ../golden/t1820 >/dev/null 2>&1 ;;
  p1821) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst19 > ../outputs/t1821
    exec diff ../outputs/t1821 ../golden/t1821 >/dev/null 2>&1 ;;
  p1822) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst190 > ../outputs/t1822
    exec diff ../outputs/t1822 ../golden/t1822 >/dev/null 2>&1 ;;
  p1823) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst191 > ../outputs/t1823
    exec diff ../outputs/t1823 ../golden/t1823 >/dev/null 2>&1 ;;
  p1824) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst192 > ../outputs/t1824
    exec diff ../outputs/t1824 ../golden/t1824 >/dev/null 2>&1 ;;
  p1825) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst193 > ../outputs/t1825
    exec diff ../outputs/t1825 ../golden/t1825 >/dev/null 2>&1 ;;
  p1826) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst194 > ../outputs/t1826
    exec diff ../outputs/t1826 ../golden/t1826 >/dev/null 2>&1 ;;
  p1827) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst195 > ../outputs/t1827
    exec diff ../outputs/t1827 ../golden/t1827 >/dev/null 2>&1 ;;
  p1828) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst196 > ../outputs/t1828
    exec diff ../outputs/t1828 ../golden/t1828 >/dev/null 2>&1 ;;
  p1829) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst197 > ../outputs/t1829
    exec diff ../outputs/t1829 ../golden/t1829 >/dev/null 2>&1 ;;
  p1830) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst198 > ../outputs/t1830
    exec diff ../outputs/t1830 ../golden/t1830 >/dev/null 2>&1 ;;
  p1831) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst199 > ../outputs/t1831
    exec diff ../outputs/t1831 ../golden/t1831 >/dev/null 2>&1 ;;
  p1832) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst2 > ../outputs/t1832
    exec diff ../outputs/t1832 ../golden/t1832 >/dev/null 2>&1 ;;
  p1833) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst20 > ../outputs/t1833
    exec diff ../outputs/t1833 ../golden/t1833 >/dev/null 2>&1 ;;
  p1834) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst200 > ../outputs/t1834
    exec diff ../outputs/t1834 ../golden/t1834 >/dev/null 2>&1 ;;
  p1835) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst201 > ../outputs/t1835
    exec diff ../outputs/t1835 ../golden/t1835 >/dev/null 2>&1 ;;
  p1836) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst203 > ../outputs/t1836
    exec diff ../outputs/t1836 ../golden/t1836 >/dev/null 2>&1 ;;
  p1837) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst204 > ../outputs/t1837
    exec diff ../outputs/t1837 ../golden/t1837 >/dev/null 2>&1 ;;
  p1838) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst205 > ../outputs/t1838
    exec diff ../outputs/t1838 ../golden/t1838 >/dev/null 2>&1 ;;
  p1839) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst206 > ../outputs/t1839
    exec diff ../outputs/t1839 ../golden/t1839 >/dev/null 2>&1 ;;
  p1840) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst207 > ../outputs/t1840
    exec diff ../outputs/t1840 ../golden/t1840 >/dev/null 2>&1 ;;
  p1841) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst208 > ../outputs/t1841
    exec diff ../outputs/t1841 ../golden/t1841 >/dev/null 2>&1 ;;
  p1842) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst209 > ../outputs/t1842
    exec diff ../outputs/t1842 ../golden/t1842 >/dev/null 2>&1 ;;
  p1843) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst21 > ../outputs/t1843
    exec diff ../outputs/t1843 ../golden/t1843 >/dev/null 2>&1 ;;
  p1844) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst210 > ../outputs/t1844
    exec diff ../outputs/t1844 ../golden/t1844 >/dev/null 2>&1 ;;
  p1845) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst211 > ../outputs/t1845
    exec diff ../outputs/t1845 ../golden/t1845 >/dev/null 2>&1 ;;
  p1846) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst212 > ../outputs/t1846
    exec diff ../outputs/t1846 ../golden/t1846 >/dev/null 2>&1 ;;
  p1847) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst213 > ../outputs/t1847
    exec diff ../outputs/t1847 ../golden/t1847 >/dev/null 2>&1 ;;
  p1848) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst214 > ../outputs/t1848
    exec diff ../outputs/t1848 ../golden/t1848 >/dev/null 2>&1 ;;
  p1849) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst215 > ../outputs/t1849
    exec diff ../outputs/t1849 ../golden/t1849 >/dev/null 2>&1 ;;
  p1850) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst216 > ../outputs/t1850
    exec diff ../outputs/t1850 ../golden/t1850 >/dev/null 2>&1 ;;
  p1851) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst217 > ../outputs/t1851
    exec diff ../outputs/t1851 ../golden/t1851 >/dev/null 2>&1 ;;
  p1852) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst218 > ../outputs/t1852
    exec diff ../outputs/t1852 ../golden/t1852 >/dev/null 2>&1 ;;
  p1853) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst219 > ../outputs/t1853
    exec diff ../outputs/t1853 ../golden/t1853 >/dev/null 2>&1 ;;
  p1854) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst22 > ../outputs/t1854
    exec diff ../outputs/t1854 ../golden/t1854 >/dev/null 2>&1 ;;
  p1855) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst220 > ../outputs/t1855
    exec diff ../outputs/t1855 ../golden/t1855 >/dev/null 2>&1 ;;
  p1856) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst221 > ../outputs/t1856
    exec diff ../outputs/t1856 ../golden/t1856 >/dev/null 2>&1 ;;
  p1857) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst222 > ../outputs/t1857
    exec diff ../outputs/t1857 ../golden/t1857 >/dev/null 2>&1 ;;
  p1858) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst223 > ../outputs/t1858
    exec diff ../outputs/t1858 ../golden/t1858 >/dev/null 2>&1 ;;
  p1859) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst224 > ../outputs/t1859
    exec diff ../outputs/t1859 ../golden/t1859 >/dev/null 2>&1 ;;
  p1860) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst225 > ../outputs/t1860
    exec diff ../outputs/t1860 ../golden/t1860 >/dev/null 2>&1 ;;
  p1861) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst226 > ../outputs/t1861
    exec diff ../outputs/t1861 ../golden/t1861 >/dev/null 2>&1 ;;
  p1862) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst227 > ../outputs/t1862
    exec diff ../outputs/t1862 ../golden/t1862 >/dev/null 2>&1 ;;
  p1863) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst228 > ../outputs/t1863
    exec diff ../outputs/t1863 ../golden/t1863 >/dev/null 2>&1 ;;
  p1864) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst229 > ../outputs/t1864
    exec diff ../outputs/t1864 ../golden/t1864 >/dev/null 2>&1 ;;
  p1865) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst23 > ../outputs/t1865
    exec diff ../outputs/t1865 ../golden/t1865 >/dev/null 2>&1 ;;
  p1866) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst230 > ../outputs/t1866
    exec diff ../outputs/t1866 ../golden/t1866 >/dev/null 2>&1 ;;
  p1867) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst231 > ../outputs/t1867
    exec diff ../outputs/t1867 ../golden/t1867 >/dev/null 2>&1 ;;
  p1868) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst232 > ../outputs/t1868
    exec diff ../outputs/t1868 ../golden/t1868 >/dev/null 2>&1 ;;
  p1869) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst233 > ../outputs/t1869
    exec diff ../outputs/t1869 ../golden/t1869 >/dev/null 2>&1 ;;
  p1870) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst234 > ../outputs/t1870
    exec diff ../outputs/t1870 ../golden/t1870 >/dev/null 2>&1 ;;
  p1871) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst235 > ../outputs/t1871
    exec diff ../outputs/t1871 ../golden/t1871 >/dev/null 2>&1 ;;
  p1872) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst236 > ../outputs/t1872
    exec diff ../outputs/t1872 ../golden/t1872 >/dev/null 2>&1 ;;
  p1873) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst237 > ../outputs/t1873
    exec diff ../outputs/t1873 ../golden/t1873 >/dev/null 2>&1 ;;
  p1874) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst238 > ../outputs/t1874
    exec diff ../outputs/t1874 ../golden/t1874 >/dev/null 2>&1 ;;
  p1875) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst239 > ../outputs/t1875
    exec diff ../outputs/t1875 ../golden/t1875 >/dev/null 2>&1 ;;
  p1876) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst24 > ../outputs/t1876
    exec diff ../outputs/t1876 ../golden/t1876 >/dev/null 2>&1 ;;
  p1877) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst240 > ../outputs/t1877
    exec diff ../outputs/t1877 ../golden/t1877 >/dev/null 2>&1 ;;
  p1878) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst241 > ../outputs/t1878
    exec diff ../outputs/t1878 ../golden/t1878 >/dev/null 2>&1 ;;
  p1879) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst242 > ../outputs/t1879
    exec diff ../outputs/t1879 ../golden/t1879 >/dev/null 2>&1 ;;
  p1880) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst243 > ../outputs/t1880
    exec diff ../outputs/t1880 ../golden/t1880 >/dev/null 2>&1 ;;
  p1881) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst244 > ../outputs/t1881
    exec diff ../outputs/t1881 ../golden/t1881 >/dev/null 2>&1 ;;
  p1882) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst245 > ../outputs/t1882
    exec diff ../outputs/t1882 ../golden/t1882 >/dev/null 2>&1 ;;
  p1883) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst246 > ../outputs/t1883
    exec diff ../outputs/t1883 ../golden/t1883 >/dev/null 2>&1 ;;
  p1884) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst247 > ../outputs/t1884
    exec diff ../outputs/t1884 ../golden/t1884 >/dev/null 2>&1 ;;
  p1885) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst248 > ../outputs/t1885
    exec diff ../outputs/t1885 ../golden/t1885 >/dev/null 2>&1 ;;
  p1886) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst249 > ../outputs/t1886
    exec diff ../outputs/t1886 ../golden/t1886 >/dev/null 2>&1 ;;
  p1887) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst25 > ../outputs/t1887
    exec diff ../outputs/t1887 ../golden/t1887 >/dev/null 2>&1 ;;
  p1888) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst250 > ../outputs/t1888
    exec diff ../outputs/t1888 ../golden/t1888 >/dev/null 2>&1 ;;
  p1889) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst251 > ../outputs/t1889
    exec diff ../outputs/t1889 ../golden/t1889 >/dev/null 2>&1 ;;
  p1890) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst252 > ../outputs/t1890
    exec diff ../outputs/t1890 ../golden/t1890 >/dev/null 2>&1 ;;
  p1891) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst253 > ../outputs/t1891
    exec diff ../outputs/t1891 ../golden/t1891 >/dev/null 2>&1 ;;
  p1892) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst254 > ../outputs/t1892
    exec diff ../outputs/t1892 ../golden/t1892 >/dev/null 2>&1 ;;
  p1893) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst255 > ../outputs/t1893
    exec diff ../outputs/t1893 ../golden/t1893 >/dev/null 2>&1 ;;
  p1894) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst256 > ../outputs/t1894
    exec diff ../outputs/t1894 ../golden/t1894 >/dev/null 2>&1 ;;
  p1895) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst257 > ../outputs/t1895
    exec diff ../outputs/t1895 ../golden/t1895 >/dev/null 2>&1 ;;
  p1896) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst258 > ../outputs/t1896
    exec diff ../outputs/t1896 ../golden/t1896 >/dev/null 2>&1 ;;
  p1897) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst259 > ../outputs/t1897
    exec diff ../outputs/t1897 ../golden/t1897 >/dev/null 2>&1 ;;
  p1898) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst26 > ../outputs/t1898
    exec diff ../outputs/t1898 ../golden/t1898 >/dev/null 2>&1 ;;
  p1899) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst260 > ../outputs/t1899
    exec diff ../outputs/t1899 ../golden/t1899 >/dev/null 2>&1 ;;
  p1900) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst261 > ../outputs/t1900
    exec diff ../outputs/t1900 ../golden/t1900 >/dev/null 2>&1 ;;
  p1901) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst262 > ../outputs/t1901
    exec diff ../outputs/t1901 ../golden/t1901 >/dev/null 2>&1 ;;
  p1902) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst263 > ../outputs/t1902
    exec diff ../outputs/t1902 ../golden/t1902 >/dev/null 2>&1 ;;
  p1903) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst264 > ../outputs/t1903
    exec diff ../outputs/t1903 ../golden/t1903 >/dev/null 2>&1 ;;
  p1904) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst265 > ../outputs/t1904
    exec diff ../outputs/t1904 ../golden/t1904 >/dev/null 2>&1 ;;
  p1905) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst266 > ../outputs/t1905
    exec diff ../outputs/t1905 ../golden/t1905 >/dev/null 2>&1 ;;
  p1906) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst267 > ../outputs/t1906
    exec diff ../outputs/t1906 ../golden/t1906 >/dev/null 2>&1 ;;
  p1907) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst268 > ../outputs/t1907
    exec diff ../outputs/t1907 ../golden/t1907 >/dev/null 2>&1 ;;
  p1908) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst269 > ../outputs/t1908
    exec diff ../outputs/t1908 ../golden/t1908 >/dev/null 2>&1 ;;
  p1909) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst27 > ../outputs/t1909
    exec diff ../outputs/t1909 ../golden/t1909 >/dev/null 2>&1 ;;
  p1910) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst270 > ../outputs/t1910
    exec diff ../outputs/t1910 ../golden/t1910 >/dev/null 2>&1 ;;
  p1911) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst271 > ../outputs/t1911
    exec diff ../outputs/t1911 ../golden/t1911 >/dev/null 2>&1 ;;
  p1912) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst272 > ../outputs/t1912
    exec diff ../outputs/t1912 ../golden/t1912 >/dev/null 2>&1 ;;
  p1913) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst273 > ../outputs/t1913
    exec diff ../outputs/t1913 ../golden/t1913 >/dev/null 2>&1 ;;
  p1914) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst274 > ../outputs/t1914
    exec diff ../outputs/t1914 ../golden/t1914 >/dev/null 2>&1 ;;
  p1915) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst275 > ../outputs/t1915
    exec diff ../outputs/t1915 ../golden/t1915 >/dev/null 2>&1 ;;
  p1916) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst276 > ../outputs/t1916
    exec diff ../outputs/t1916 ../golden/t1916 >/dev/null 2>&1 ;;
  p1917) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst277 > ../outputs/t1917
    exec diff ../outputs/t1917 ../golden/t1917 >/dev/null 2>&1 ;;
  p1918) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst278 > ../outputs/t1918
    exec diff ../outputs/t1918 ../golden/t1918 >/dev/null 2>&1 ;;
  p1919) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst279 > ../outputs/t1919
    exec diff ../outputs/t1919 ../golden/t1919 >/dev/null 2>&1 ;;
  p1920) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst28 > ../outputs/t1920
    exec diff ../outputs/t1920 ../golden/t1920 >/dev/null 2>&1 ;;
  p1921) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst280 > ../outputs/t1921
    exec diff ../outputs/t1921 ../golden/t1921 >/dev/null 2>&1 ;;
  p1922) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst281 > ../outputs/t1922
    exec diff ../outputs/t1922 ../golden/t1922 >/dev/null 2>&1 ;;
  p1923) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst282 > ../outputs/t1923
    exec diff ../outputs/t1923 ../golden/t1923 >/dev/null 2>&1 ;;
  p1924) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst283 > ../outputs/t1924
    exec diff ../outputs/t1924 ../golden/t1924 >/dev/null 2>&1 ;;
  p1925) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst284 > ../outputs/t1925
    exec diff ../outputs/t1925 ../golden/t1925 >/dev/null 2>&1 ;;
  p1926) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst285 > ../outputs/t1926
    exec diff ../outputs/t1926 ../golden/t1926 >/dev/null 2>&1 ;;
  p1927) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst286 > ../outputs/t1927
    exec diff ../outputs/t1927 ../golden/t1927 >/dev/null 2>&1 ;;
  p1928) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst287 > ../outputs/t1928
    exec diff ../outputs/t1928 ../golden/t1928 >/dev/null 2>&1 ;;
  p1929) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst288 > ../outputs/t1929
    exec diff ../outputs/t1929 ../golden/t1929 >/dev/null 2>&1 ;;
  p1930) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst289 > ../outputs/t1930
    exec diff ../outputs/t1930 ../golden/t1930 >/dev/null 2>&1 ;;
  p1931) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst29 > ../outputs/t1931
    exec diff ../outputs/t1931 ../golden/t1931 >/dev/null 2>&1 ;;
  p1932) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst290 > ../outputs/t1932
    exec diff ../outputs/t1932 ../golden/t1932 >/dev/null 2>&1 ;;
  p1933) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst291 > ../outputs/t1933
    exec diff ../outputs/t1933 ../golden/t1933 >/dev/null 2>&1 ;;
  p1934) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst292 > ../outputs/t1934
    exec diff ../outputs/t1934 ../golden/t1934 >/dev/null 2>&1 ;;
  p1935) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst293 > ../outputs/t1935
    exec diff ../outputs/t1935 ../golden/t1935 >/dev/null 2>&1 ;;
  p1936) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst294 > ../outputs/t1936
    exec diff ../outputs/t1936 ../golden/t1936 >/dev/null 2>&1 ;;
  p1937) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst295 > ../outputs/t1937
    exec diff ../outputs/t1937 ../golden/t1937 >/dev/null 2>&1 ;;
  p1938) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst296 > ../outputs/t1938
    exec diff ../outputs/t1938 ../golden/t1938 >/dev/null 2>&1 ;;
  p1939) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst297 > ../outputs/t1939
    exec diff ../outputs/t1939 ../golden/t1939 >/dev/null 2>&1 ;;
  p1940) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst298 > ../outputs/t1940
    exec diff ../outputs/t1940 ../golden/t1940 >/dev/null 2>&1 ;;
  p1941) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst299 > ../outputs/t1941
    exec diff ../outputs/t1941 ../golden/t1941 >/dev/null 2>&1 ;;
  p1942) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst3 > ../outputs/t1942
    exec diff ../outputs/t1942 ../golden/t1942 >/dev/null 2>&1 ;;
  p1943) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst30 > ../outputs/t1943
    exec diff ../outputs/t1943 ../golden/t1943 >/dev/null 2>&1 ;;
  p1944) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst300 > ../outputs/t1944
    exec diff ../outputs/t1944 ../golden/t1944 >/dev/null 2>&1 ;;
  p1945) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst31 > ../outputs/t1945
    exec diff ../outputs/t1945 ../golden/t1945 >/dev/null 2>&1 ;;
  p1946) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst32 > ../outputs/t1946
    exec diff ../outputs/t1946 ../golden/t1946 >/dev/null 2>&1 ;;
  p1947) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst33 > ../outputs/t1947
    exec diff ../outputs/t1947 ../golden/t1947 >/dev/null 2>&1 ;;
  p1948) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst34 > ../outputs/t1948
    exec diff ../outputs/t1948 ../golden/t1948 >/dev/null 2>&1 ;;
  p1949) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst35 > ../outputs/t1949
    exec diff ../outputs/t1949 ../golden/t1949 >/dev/null 2>&1 ;;
  p1950) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst36 > ../outputs/t1950
    exec diff ../outputs/t1950 ../golden/t1950 >/dev/null 2>&1 ;;
  p1951) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst37 > ../outputs/t1951
    exec diff ../outputs/t1951 ../golden/t1951 >/dev/null 2>&1 ;;
  p1952) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst38 > ../outputs/t1952
    exec diff ../outputs/t1952 ../golden/t1952 >/dev/null 2>&1 ;;
  p1953) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst39 > ../outputs/t1953
    exec diff ../outputs/t1953 ../golden/t1953 >/dev/null 2>&1 ;;
  p1954) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst4 > ../outputs/t1954
    exec diff ../outputs/t1954 ../golden/t1954 >/dev/null 2>&1 ;;
  p1955) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst40 > ../outputs/t1955
    exec diff ../outputs/t1955 ../golden/t1955 >/dev/null 2>&1 ;;
  p1956) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst41 > ../outputs/t1956
    exec diff ../outputs/t1956 ../golden/t1956 >/dev/null 2>&1 ;;
  p1957) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst42 > ../outputs/t1957
    exec diff ../outputs/t1957 ../golden/t1957 >/dev/null 2>&1 ;;
  p1958) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst43 > ../outputs/t1958
    exec diff ../outputs/t1958 ../golden/t1958 >/dev/null 2>&1 ;;
  p1959) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst44 > ../outputs/t1959
    exec diff ../outputs/t1959 ../golden/t1959 >/dev/null 2>&1 ;;
  p1960) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst45 > ../outputs/t1960
    exec diff ../outputs/t1960 ../golden/t1960 >/dev/null 2>&1 ;;
  p1961) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst46 > ../outputs/t1961
    exec diff ../outputs/t1961 ../golden/t1961 >/dev/null 2>&1 ;;
  p1962) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst47 > ../outputs/t1962
    exec diff ../outputs/t1962 ../golden/t1962 >/dev/null 2>&1 ;;
  p1963) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst48 > ../outputs/t1963
    exec diff ../outputs/t1963 ../golden/t1963 >/dev/null 2>&1 ;;
  p1964) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst49 > ../outputs/t1964
    exec diff ../outputs/t1964 ../golden/t1964 >/dev/null 2>&1 ;;
  p1965) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst5 > ../outputs/t1965
    exec diff ../outputs/t1965 ../golden/t1965 >/dev/null 2>&1 ;;
  p1966) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst50 > ../outputs/t1966
    exec diff ../outputs/t1966 ../golden/t1966 >/dev/null 2>&1 ;;
  p1967) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst51 > ../outputs/t1967
    exec diff ../outputs/t1967 ../golden/t1967 >/dev/null 2>&1 ;;
  p1968) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst52 > ../outputs/t1968
    exec diff ../outputs/t1968 ../golden/t1968 >/dev/null 2>&1 ;;
  p1969) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst53 > ../outputs/t1969
    exec diff ../outputs/t1969 ../golden/t1969 >/dev/null 2>&1 ;;
  p1970) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst54 > ../outputs/t1970
    exec diff ../outputs/t1970 ../golden/t1970 >/dev/null 2>&1 ;;
  p1971) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst55 > ../outputs/t1971
    exec diff ../outputs/t1971 ../golden/t1971 >/dev/null 2>&1 ;;
  p1972) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst56 > ../outputs/t1972
    exec diff ../outputs/t1972 ../golden/t1972 >/dev/null 2>&1 ;;
  p1973) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst57 > ../outputs/t1973
    exec diff ../outputs/t1973 ../golden/t1973 >/dev/null 2>&1 ;;
  p1974) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst58 > ../outputs/t1974
    exec diff ../outputs/t1974 ../golden/t1974 >/dev/null 2>&1 ;;
  p1975) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst59 > ../outputs/t1975
    exec diff ../outputs/t1975 ../golden/t1975 >/dev/null 2>&1 ;;
  p1976) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst6 > ../outputs/t1976
    exec diff ../outputs/t1976 ../golden/t1976 >/dev/null 2>&1 ;;
  p1977) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst60 > ../outputs/t1977
    exec diff ../outputs/t1977 ../golden/t1977 >/dev/null 2>&1 ;;
  p1978) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst61 > ../outputs/t1978
    exec diff ../outputs/t1978 ../golden/t1978 >/dev/null 2>&1 ;;
  p1979) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst62 > ../outputs/t1979
    exec diff ../outputs/t1979 ../golden/t1979 >/dev/null 2>&1 ;;
  p1980) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst63 > ../outputs/t1980
    exec diff ../outputs/t1980 ../golden/t1980 >/dev/null 2>&1 ;;
  p1981) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst64 > ../outputs/t1981
    exec diff ../outputs/t1981 ../golden/t1981 >/dev/null 2>&1 ;;
  p1982) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst65 > ../outputs/t1982
    exec diff ../outputs/t1982 ../golden/t1982 >/dev/null 2>&1 ;;
  p1983) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst66 > ../outputs/t1983
    exec diff ../outputs/t1983 ../golden/t1983 >/dev/null 2>&1 ;;
  p1984) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst67 > ../outputs/t1984
    exec diff ../outputs/t1984 ../golden/t1984 >/dev/null 2>&1 ;;
  p1985) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst68 > ../outputs/t1985
    exec diff ../outputs/t1985 ../golden/t1985 >/dev/null 2>&1 ;;
  p1986) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst69 > ../outputs/t1986
    exec diff ../outputs/t1986 ../golden/t1986 >/dev/null 2>&1 ;;
  p1987) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst7 > ../outputs/t1987
    exec diff ../outputs/t1987 ../golden/t1987 >/dev/null 2>&1 ;;
  p1988) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst70 > ../outputs/t1988
    exec diff ../outputs/t1988 ../golden/t1988 >/dev/null 2>&1 ;;
  p1989) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst71 > ../outputs/t1989
    exec diff ../outputs/t1989 ../golden/t1989 >/dev/null 2>&1 ;;
  p1990) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst72 > ../outputs/t1990
    exec diff ../outputs/t1990 ../golden/t1990 >/dev/null 2>&1 ;;
  p1991) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst73 > ../outputs/t1991
    exec diff ../outputs/t1991 ../golden/t1991 >/dev/null 2>&1 ;;
  p1992) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst74 > ../outputs/t1992
    exec diff ../outputs/t1992 ../golden/t1992 >/dev/null 2>&1 ;;
  p1993) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst75 > ../outputs/t1993
    exec diff ../outputs/t1993 ../golden/t1993 >/dev/null 2>&1 ;;
  p1994) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst76 > ../outputs/t1994
    exec diff ../outputs/t1994 ../golden/t1994 >/dev/null 2>&1 ;;
  p1995) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst77 > ../outputs/t1995
    exec diff ../outputs/t1995 ../golden/t1995 >/dev/null 2>&1 ;;
  p1996) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst78 > ../outputs/t1996
    exec diff ../outputs/t1996 ../golden/t1996 >/dev/null 2>&1 ;;
  p1997) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst79 > ../outputs/t1997
    exec diff ../outputs/t1997 ../golden/t1997 >/dev/null 2>&1 ;;
  p1998) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst8 > ../outputs/t1998
    exec diff ../outputs/t1998 ../golden/t1998 >/dev/null 2>&1 ;;
  p1999) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst80 > ../outputs/t1999
    exec diff ../outputs/t1999 ../golden/t1999 >/dev/null 2>&1 ;;
  p2000) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst81 > ../outputs/t2000
    exec diff ../outputs/t2000 ../golden/t2000 >/dev/null 2>&1 ;;
  p2001) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst82 > ../outputs/t2001
    exec diff ../outputs/t2001 ../golden/t2001 >/dev/null 2>&1 ;;
  p2002) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst83 > ../outputs/t2002
    exec diff ../outputs/t2002 ../golden/t2002 >/dev/null 2>&1 ;;
  p2003) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst84 > ../outputs/t2003
    exec diff ../outputs/t2003 ../golden/t2003 >/dev/null 2>&1 ;;
  p2004) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst85 > ../outputs/t2004
    exec diff ../outputs/t2004 ../golden/t2004 >/dev/null 2>&1 ;;
  p2005) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst86 > ../outputs/t2005
    exec diff ../outputs/t2005 ../golden/t2005 >/dev/null 2>&1 ;;
  p2006) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst87 > ../outputs/t2006
    exec diff ../outputs/t2006 ../golden/t2006 >/dev/null 2>&1 ;;
  p2007) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst88 > ../outputs/t2007
    exec diff ../outputs/t2007 ../golden/t2007 >/dev/null 2>&1 ;;
  p2008) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst89 > ../outputs/t2008
    exec diff ../outputs/t2008 ../golden/t2008 >/dev/null 2>&1 ;;
  p2009) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst9 > ../outputs/t2009
    exec diff ../outputs/t2009 ../golden/t2009 >/dev/null 2>&1 ;;
  p2010) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst90 > ../outputs/t2010
    exec diff ../outputs/t2010 ../golden/t2010 >/dev/null 2>&1 ;;
  p2011) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst91 > ../outputs/t2011
    exec diff ../outputs/t2011 ../golden/t2011 >/dev/null 2>&1 ;;
  p2012) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst92 > ../outputs/t2012
    exec diff ../outputs/t2012 ../golden/t2012 >/dev/null 2>&1 ;;
  p2013) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst93 > ../outputs/t2013
    exec diff ../outputs/t2013 ../golden/t2013 >/dev/null 2>&1 ;;
  p2014) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst94 > ../outputs/t2014
    exec diff ../outputs/t2014 ../golden/t2014 >/dev/null 2>&1 ;;
  p2015) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst95 > ../outputs/t2015
    exec diff ../outputs/t2015 ../golden/t2015 >/dev/null 2>&1 ;;
  p2016) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst96 > ../outputs/t2016
    exec diff ../outputs/t2016 ../golden/t2016 >/dev/null 2>&1 ;;
  p2017) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst97 > ../outputs/t2017
    exec diff ../outputs/t2017 ../golden/t2017 >/dev/null 2>&1 ;;
  p2018) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst98 > ../outputs/t2018
    exec diff ../outputs/t2018 ../golden/t2018 >/dev/null 2>&1 ;;
  p2019) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/tst99 > ../outputs/t2019
    exec diff ../outputs/t2019 ../golden/t2019 >/dev/null 2>&1 ;;
  p2020) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.100 > ../outputs/t2020
    exec diff ../outputs/t2020 ../golden/t2020 >/dev/null 2>&1 ;;
  p2021) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1002 > ../outputs/t2021
    exec diff ../outputs/t2021 ../golden/t2021 >/dev/null 2>&1 ;;
  p2022) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1006 > ../outputs/t2022
    exec diff ../outputs/t2022 ../golden/t2022 >/dev/null 2>&1 ;;
  p2023) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1007 > ../outputs/t2023
    exec diff ../outputs/t2023 ../golden/t2023 >/dev/null 2>&1 ;;
  p2024) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.101 > ../outputs/t2024
    exec diff ../outputs/t2024 ../golden/t2024 >/dev/null 2>&1 ;;
  p2025) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1011 > ../outputs/t2025
    exec diff ../outputs/t2025 ../golden/t2025 >/dev/null 2>&1 ;;
  p2026) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1012 > ../outputs/t2026
    exec diff ../outputs/t2026 ../golden/t2026 >/dev/null 2>&1 ;;
  p2027) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1013 > ../outputs/t2027
    exec diff ../outputs/t2027 ../golden/t2027 >/dev/null 2>&1 ;;
  p2028) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1016 > ../outputs/t2028
    exec diff ../outputs/t2028 ../golden/t2028 >/dev/null 2>&1 ;;
  p2029) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1017 > ../outputs/t2029
    exec diff ../outputs/t2029 ../golden/t2029 >/dev/null 2>&1 ;;
  p2030) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1019 > ../outputs/t2030
    exec diff ../outputs/t2030 ../golden/t2030 >/dev/null 2>&1 ;;
  p2031) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.102 > ../outputs/t2031
    exec diff ../outputs/t2031 ../golden/t2031 >/dev/null 2>&1 ;;
  p2032) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1021 > ../outputs/t2032
    exec diff ../outputs/t2032 ../golden/t2032 >/dev/null 2>&1 ;;
  p2033) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1022 > ../outputs/t2033
    exec diff ../outputs/t2033 ../golden/t2033 >/dev/null 2>&1 ;;
  p2034) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1023 > ../outputs/t2034
    exec diff ../outputs/t2034 ../golden/t2034 >/dev/null 2>&1 ;;
  p2035) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1026 > ../outputs/t2035
    exec diff ../outputs/t2035 ../golden/t2035 >/dev/null 2>&1 ;;
  p2036) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1027 > ../outputs/t2036
    exec diff ../outputs/t2036 ../golden/t2036 >/dev/null 2>&1 ;;
  p2037) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1028 > ../outputs/t2037
    exec diff ../outputs/t2037 ../golden/t2037 >/dev/null 2>&1 ;;
  p2038) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1029 > ../outputs/t2038
    exec diff ../outputs/t2038 ../golden/t2038 >/dev/null 2>&1 ;;
  p2039) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.103 > ../outputs/t2039
    exec diff ../outputs/t2039 ../golden/t2039 >/dev/null 2>&1 ;;
  p2040) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1033 > ../outputs/t2040
    exec diff ../outputs/t2040 ../golden/t2040 >/dev/null 2>&1 ;;
  p2041) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1037 > ../outputs/t2041
    exec diff ../outputs/t2041 ../golden/t2041 >/dev/null 2>&1 ;;
  p2042) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.104 > ../outputs/t2042
    exec diff ../outputs/t2042 ../golden/t2042 >/dev/null 2>&1 ;;
  p2043) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1041 > ../outputs/t2043
    exec diff ../outputs/t2043 ../golden/t2043 >/dev/null 2>&1 ;;
  p2044) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1044 > ../outputs/t2044
    exec diff ../outputs/t2044 ../golden/t2044 >/dev/null 2>&1 ;;
  p2045) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1051 > ../outputs/t2045
    exec diff ../outputs/t2045 ../golden/t2045 >/dev/null 2>&1 ;;
  p2046) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1052 > ../outputs/t2046
    exec diff ../outputs/t2046 ../golden/t2046 >/dev/null 2>&1 ;;
  p2047) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1053 > ../outputs/t2047
    exec diff ../outputs/t2047 ../golden/t2047 >/dev/null 2>&1 ;;
  p2048) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1056 > ../outputs/t2048
    exec diff ../outputs/t2048 ../golden/t2048 >/dev/null 2>&1 ;;
  p2049) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1058 > ../outputs/t2049
    exec diff ../outputs/t2049 ../golden/t2049 >/dev/null 2>&1 ;;
  p2050) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1062 > ../outputs/t2050
    exec diff ../outputs/t2050 ../golden/t2050 >/dev/null 2>&1 ;;
  p2051) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1063 > ../outputs/t2051
    exec diff ../outputs/t2051 ../golden/t2051 >/dev/null 2>&1 ;;
  p2052) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1064 > ../outputs/t2052
    exec diff ../outputs/t2052 ../golden/t2052 >/dev/null 2>&1 ;;
  p2053) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1066 > ../outputs/t2053
    exec diff ../outputs/t2053 ../golden/t2053 >/dev/null 2>&1 ;;
  p2054) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1070 > ../outputs/t2054
    exec diff ../outputs/t2054 ../golden/t2054 >/dev/null 2>&1 ;;
  p2055) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1072 > ../outputs/t2055
    exec diff ../outputs/t2055 ../golden/t2055 >/dev/null 2>&1 ;;
  p2056) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1073 > ../outputs/t2056
    exec diff ../outputs/t2056 ../golden/t2056 >/dev/null 2>&1 ;;
  p2057) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1079 > ../outputs/t2057
    exec diff ../outputs/t2057 ../golden/t2057 >/dev/null 2>&1 ;;
  p2058) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.108 > ../outputs/t2058
    exec diff ../outputs/t2058 ../golden/t2058 >/dev/null 2>&1 ;;
  p2059) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1081 > ../outputs/t2059
    exec diff ../outputs/t2059 ../golden/t2059 >/dev/null 2>&1 ;;
  p2060) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1083 > ../outputs/t2060
    exec diff ../outputs/t2060 ../golden/t2060 >/dev/null 2>&1 ;;
  p2061) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1086 > ../outputs/t2061
    exec diff ../outputs/t2061 ../golden/t2061 >/dev/null 2>&1 ;;
  p2062) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1087 > ../outputs/t2062
    exec diff ../outputs/t2062 ../golden/t2062 >/dev/null 2>&1 ;;
  p2063) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1088 > ../outputs/t2063
    exec diff ../outputs/t2063 ../golden/t2063 >/dev/null 2>&1 ;;
  p2064) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1089 > ../outputs/t2064
    exec diff ../outputs/t2064 ../golden/t2064 >/dev/null 2>&1 ;;
  p2065) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1090 > ../outputs/t2065
    exec diff ../outputs/t2065 ../golden/t2065 >/dev/null 2>&1 ;;
  p2066) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1097 > ../outputs/t2066
    exec diff ../outputs/t2066 ../golden/t2066 >/dev/null 2>&1 ;;
  p2067) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1098 > ../outputs/t2067
    exec diff ../outputs/t2067 ../golden/t2067 >/dev/null 2>&1 ;;
  p2068) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1099 > ../outputs/t2068
    exec diff ../outputs/t2068 ../golden/t2068 >/dev/null 2>&1 ;;
  p2069) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.11 > ../outputs/t2069
    exec diff ../outputs/t2069 ../golden/t2069 >/dev/null 2>&1 ;;
  p2070) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.110 > ../outputs/t2070
    exec diff ../outputs/t2070 ../golden/t2070 >/dev/null 2>&1 ;;
  p2071) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1100 > ../outputs/t2071
    exec diff ../outputs/t2071 ../golden/t2071 >/dev/null 2>&1 ;;
  p2072) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1102 > ../outputs/t2072
    exec diff ../outputs/t2072 ../golden/t2072 >/dev/null 2>&1 ;;
  p2073) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1104 > ../outputs/t2073
    exec diff ../outputs/t2073 ../golden/t2073 >/dev/null 2>&1 ;;
  p2074) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1106 > ../outputs/t2074
    exec diff ../outputs/t2074 ../golden/t2074 >/dev/null 2>&1 ;;
  p2075) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1107 > ../outputs/t2075
    exec diff ../outputs/t2075 ../golden/t2075 >/dev/null 2>&1 ;;
  p2076) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1108 > ../outputs/t2076
    exec diff ../outputs/t2076 ../golden/t2076 >/dev/null 2>&1 ;;
  p2077) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1111 > ../outputs/t2077
    exec diff ../outputs/t2077 ../golden/t2077 >/dev/null 2>&1 ;;
  p2078) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1116 > ../outputs/t2078
    exec diff ../outputs/t2078 ../golden/t2078 >/dev/null 2>&1 ;;
  p2079) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1117 > ../outputs/t2079
    exec diff ../outputs/t2079 ../golden/t2079 >/dev/null 2>&1 ;;
  p2080) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1118 > ../outputs/t2080
    exec diff ../outputs/t2080 ../golden/t2080 >/dev/null 2>&1 ;;
  p2081) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.112 > ../outputs/t2081
    exec diff ../outputs/t2081 ../golden/t2081 >/dev/null 2>&1 ;;
  p2082) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1122 > ../outputs/t2082
    exec diff ../outputs/t2082 ../golden/t2082 >/dev/null 2>&1 ;;
  p2083) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1123 > ../outputs/t2083
    exec diff ../outputs/t2083 ../golden/t2083 >/dev/null 2>&1 ;;
  p2084) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1128 > ../outputs/t2084
    exec diff ../outputs/t2084 ../golden/t2084 >/dev/null 2>&1 ;;
  p2085) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1129 > ../outputs/t2085
    exec diff ../outputs/t2085 ../golden/t2085 >/dev/null 2>&1 ;;
  p2086) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.113 > ../outputs/t2086
    exec diff ../outputs/t2086 ../golden/t2086 >/dev/null 2>&1 ;;
  p2087) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1131 > ../outputs/t2087
    exec diff ../outputs/t2087 ../golden/t2087 >/dev/null 2>&1 ;;
  p2088) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1132 > ../outputs/t2088
    exec diff ../outputs/t2088 ../golden/t2088 >/dev/null 2>&1 ;;
  p2089) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1133 > ../outputs/t2089
    exec diff ../outputs/t2089 ../golden/t2089 >/dev/null 2>&1 ;;
  p2090) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1134 > ../outputs/t2090
    exec diff ../outputs/t2090 ../golden/t2090 >/dev/null 2>&1 ;;
  p2091) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1135 > ../outputs/t2091
    exec diff ../outputs/t2091 ../golden/t2091 >/dev/null 2>&1 ;;
  p2092) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1136 > ../outputs/t2092
    exec diff ../outputs/t2092 ../golden/t2092 >/dev/null 2>&1 ;;
  p2093) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1137 > ../outputs/t2093
    exec diff ../outputs/t2093 ../golden/t2093 >/dev/null 2>&1 ;;
  p2094) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1138 > ../outputs/t2094
    exec diff ../outputs/t2094 ../golden/t2094 >/dev/null 2>&1 ;;
  p2095) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1143 > ../outputs/t2095
    exec diff ../outputs/t2095 ../golden/t2095 >/dev/null 2>&1 ;;
  p2096) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1145 > ../outputs/t2096
    exec diff ../outputs/t2096 ../golden/t2096 >/dev/null 2>&1 ;;
  p2097) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1146 > ../outputs/t2097
    exec diff ../outputs/t2097 ../golden/t2097 >/dev/null 2>&1 ;;
  p2098) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1147 > ../outputs/t2098
    exec diff ../outputs/t2098 ../golden/t2098 >/dev/null 2>&1 ;;
  p2099) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1148 > ../outputs/t2099
    exec diff ../outputs/t2099 ../golden/t2099 >/dev/null 2>&1 ;;
  p2100) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1149 > ../outputs/t2100
    exec diff ../outputs/t2100 ../golden/t2100 >/dev/null 2>&1 ;;
  p2101) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1150 > ../outputs/t2101
    exec diff ../outputs/t2101 ../golden/t2101 >/dev/null 2>&1 ;;
  p2102) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1151 > ../outputs/t2102
    exec diff ../outputs/t2102 ../golden/t2102 >/dev/null 2>&1 ;;
  p2103) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1152 > ../outputs/t2103
    exec diff ../outputs/t2103 ../golden/t2103 >/dev/null 2>&1 ;;
  p2104) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1153 > ../outputs/t2104
    exec diff ../outputs/t2104 ../golden/t2104 >/dev/null 2>&1 ;;
  p2105) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1154 > ../outputs/t2105
    exec diff ../outputs/t2105 ../golden/t2105 >/dev/null 2>&1 ;;
  p2106) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1157 > ../outputs/t2106
    exec diff ../outputs/t2106 ../golden/t2106 >/dev/null 2>&1 ;;
  p2107) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1158 > ../outputs/t2107
    exec diff ../outputs/t2107 ../golden/t2107 >/dev/null 2>&1 ;;
  p2108) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.116 > ../outputs/t2108
    exec diff ../outputs/t2108 ../golden/t2108 >/dev/null 2>&1 ;;
  p2109) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1161 > ../outputs/t2109
    exec diff ../outputs/t2109 ../golden/t2109 >/dev/null 2>&1 ;;
  p2110) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1164 > ../outputs/t2110
    exec diff ../outputs/t2110 ../golden/t2110 >/dev/null 2>&1 ;;
  p2111) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1168 > ../outputs/t2111
    exec diff ../outputs/t2111 ../golden/t2111 >/dev/null 2>&1 ;;
  p2112) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1169 > ../outputs/t2112
    exec diff ../outputs/t2112 ../golden/t2112 >/dev/null 2>&1 ;;
  p2113) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1170 > ../outputs/t2113
    exec diff ../outputs/t2113 ../golden/t2113 >/dev/null 2>&1 ;;
  p2114) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1171 > ../outputs/t2114
    exec diff ../outputs/t2114 ../golden/t2114 >/dev/null 2>&1 ;;
  p2115) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1172 > ../outputs/t2115
    exec diff ../outputs/t2115 ../golden/t2115 >/dev/null 2>&1 ;;
  p2116) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1175 > ../outputs/t2116
    exec diff ../outputs/t2116 ../golden/t2116 >/dev/null 2>&1 ;;
  p2117) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1176 > ../outputs/t2117
    exec diff ../outputs/t2117 ../golden/t2117 >/dev/null 2>&1 ;;
  p2118) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1177 > ../outputs/t2118
    exec diff ../outputs/t2118 ../golden/t2118 >/dev/null 2>&1 ;;
  p2119) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1178 > ../outputs/t2119
    exec diff ../outputs/t2119 ../golden/t2119 >/dev/null 2>&1 ;;
  p2120) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.118 > ../outputs/t2120
    exec diff ../outputs/t2120 ../golden/t2120 >/dev/null 2>&1 ;;
  p2121) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1181 > ../outputs/t2121
    exec diff ../outputs/t2121 ../golden/t2121 >/dev/null 2>&1 ;;
  p2122) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1183 > ../outputs/t2122
    exec diff ../outputs/t2122 ../golden/t2122 >/dev/null 2>&1 ;;
  p2123) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1188 > ../outputs/t2123
    exec diff ../outputs/t2123 ../golden/t2123 >/dev/null 2>&1 ;;
  p2124) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1190 > ../outputs/t2124
    exec diff ../outputs/t2124 ../golden/t2124 >/dev/null 2>&1 ;;
  p2125) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1194 > ../outputs/t2125
    exec diff ../outputs/t2125 ../golden/t2125 >/dev/null 2>&1 ;;
  p2126) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1195 > ../outputs/t2126
    exec diff ../outputs/t2126 ../golden/t2126 >/dev/null 2>&1 ;;
  p2127) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1197 > ../outputs/t2127
    exec diff ../outputs/t2127 ../golden/t2127 >/dev/null 2>&1 ;;
  p2128) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1199 > ../outputs/t2128
    exec diff ../outputs/t2128 ../golden/t2128 >/dev/null 2>&1 ;;
  p2129) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.12 > ../outputs/t2129
    exec diff ../outputs/t2129 ../golden/t2129 >/dev/null 2>&1 ;;
  p2130) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.120 > ../outputs/t2130
    exec diff ../outputs/t2130 ../golden/t2130 >/dev/null 2>&1 ;;
  p2131) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1201 > ../outputs/t2131
    exec diff ../outputs/t2131 ../golden/t2131 >/dev/null 2>&1 ;;
  p2132) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1203 > ../outputs/t2132
    exec diff ../outputs/t2132 ../golden/t2132 >/dev/null 2>&1 ;;
  p2133) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1204 > ../outputs/t2133
    exec diff ../outputs/t2133 ../golden/t2133 >/dev/null 2>&1 ;;
  p2134) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1205 > ../outputs/t2134
    exec diff ../outputs/t2134 ../golden/t2134 >/dev/null 2>&1 ;;
  p2135) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1208 > ../outputs/t2135
    exec diff ../outputs/t2135 ../golden/t2135 >/dev/null 2>&1 ;;
  p2136) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1210 > ../outputs/t2136
    exec diff ../outputs/t2136 ../golden/t2136 >/dev/null 2>&1 ;;
  p2137) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1211 > ../outputs/t2137
    exec diff ../outputs/t2137 ../golden/t2137 >/dev/null 2>&1 ;;
  p2138) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1213 > ../outputs/t2138
    exec diff ../outputs/t2138 ../golden/t2138 >/dev/null 2>&1 ;;
  p2139) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1214 > ../outputs/t2139
    exec diff ../outputs/t2139 ../golden/t2139 >/dev/null 2>&1 ;;
  p2140) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1215 > ../outputs/t2140
    exec diff ../outputs/t2140 ../golden/t2140 >/dev/null 2>&1 ;;
  p2141) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1216 > ../outputs/t2141
    exec diff ../outputs/t2141 ../golden/t2141 >/dev/null 2>&1 ;;
  p2142) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1218 > ../outputs/t2142
    exec diff ../outputs/t2142 ../golden/t2142 >/dev/null 2>&1 ;;
  p2143) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.122 > ../outputs/t2143
    exec diff ../outputs/t2143 ../golden/t2143 >/dev/null 2>&1 ;;
  p2144) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1220 > ../outputs/t2144
    exec diff ../outputs/t2144 ../golden/t2144 >/dev/null 2>&1 ;;
  p2145) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1221 > ../outputs/t2145
    exec diff ../outputs/t2145 ../golden/t2145 >/dev/null 2>&1 ;;
  p2146) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1222 > ../outputs/t2146
    exec diff ../outputs/t2146 ../golden/t2146 >/dev/null 2>&1 ;;
  p2147) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1225 > ../outputs/t2147
    exec diff ../outputs/t2147 ../golden/t2147 >/dev/null 2>&1 ;;
  p2148) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1227 > ../outputs/t2148
    exec diff ../outputs/t2148 ../golden/t2148 >/dev/null 2>&1 ;;
  p2149) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1229 > ../outputs/t2149
    exec diff ../outputs/t2149 ../golden/t2149 >/dev/null 2>&1 ;;
  p2150) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.123 > ../outputs/t2150
    exec diff ../outputs/t2150 ../golden/t2150 >/dev/null 2>&1 ;;
  p2151) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1230 > ../outputs/t2151
    exec diff ../outputs/t2151 ../golden/t2151 >/dev/null 2>&1 ;;
  p2152) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1231 > ../outputs/t2152
    exec diff ../outputs/t2152 ../golden/t2152 >/dev/null 2>&1 ;;
  p2153) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1232 > ../outputs/t2153
    exec diff ../outputs/t2153 ../golden/t2153 >/dev/null 2>&1 ;;
  p2154) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1236 > ../outputs/t2154
    exec diff ../outputs/t2154 ../golden/t2154 >/dev/null 2>&1 ;;
  p2155) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1238 > ../outputs/t2155
    exec diff ../outputs/t2155 ../golden/t2155 >/dev/null 2>&1 ;;
  p2156) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.124 > ../outputs/t2156
    exec diff ../outputs/t2156 ../golden/t2156 >/dev/null 2>&1 ;;
  p2157) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1240 > ../outputs/t2157
    exec diff ../outputs/t2157 ../golden/t2157 >/dev/null 2>&1 ;;
  p2158) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1242 > ../outputs/t2158
    exec diff ../outputs/t2158 ../golden/t2158 >/dev/null 2>&1 ;;
  p2159) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1244 > ../outputs/t2159
    exec diff ../outputs/t2159 ../golden/t2159 >/dev/null 2>&1 ;;
  p2160) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1247 > ../outputs/t2160
    exec diff ../outputs/t2160 ../golden/t2160 >/dev/null 2>&1 ;;
  p2161) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1248 > ../outputs/t2161
    exec diff ../outputs/t2161 ../golden/t2161 >/dev/null 2>&1 ;;
  p2162) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1251 > ../outputs/t2162
    exec diff ../outputs/t2162 ../golden/t2162 >/dev/null 2>&1 ;;
  p2163) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1254 > ../outputs/t2163
    exec diff ../outputs/t2163 ../golden/t2163 >/dev/null 2>&1 ;;
  p2164) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1257 > ../outputs/t2164
    exec diff ../outputs/t2164 ../golden/t2164 >/dev/null 2>&1 ;;
  p2165) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1259 > ../outputs/t2165
    exec diff ../outputs/t2165 ../golden/t2165 >/dev/null 2>&1 ;;
  p2166) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1261 > ../outputs/t2166
    exec diff ../outputs/t2166 ../golden/t2166 >/dev/null 2>&1 ;;
  p2167) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1262 > ../outputs/t2167
    exec diff ../outputs/t2167 ../golden/t2167 >/dev/null 2>&1 ;;
  p2168) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1263 > ../outputs/t2168
    exec diff ../outputs/t2168 ../golden/t2168 >/dev/null 2>&1 ;;
  p2169) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1269 > ../outputs/t2169
    exec diff ../outputs/t2169 ../golden/t2169 >/dev/null 2>&1 ;;
  p2170) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1271 > ../outputs/t2170
    exec diff ../outputs/t2170 ../golden/t2170 >/dev/null 2>&1 ;;
  p2171) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1273 > ../outputs/t2171
    exec diff ../outputs/t2171 ../golden/t2171 >/dev/null 2>&1 ;;
  p2172) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1274 > ../outputs/t2172
    exec diff ../outputs/t2172 ../golden/t2172 >/dev/null 2>&1 ;;
  p2173) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1275 > ../outputs/t2173
    exec diff ../outputs/t2173 ../golden/t2173 >/dev/null 2>&1 ;;
  p2174) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1277 > ../outputs/t2174
    exec diff ../outputs/t2174 ../golden/t2174 >/dev/null 2>&1 ;;
  p2175) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1279 > ../outputs/t2175
    exec diff ../outputs/t2175 ../golden/t2175 >/dev/null 2>&1 ;;
  p2176) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1280 > ../outputs/t2176
    exec diff ../outputs/t2176 ../golden/t2176 >/dev/null 2>&1 ;;
  p2177) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1282 > ../outputs/t2177
    exec diff ../outputs/t2177 ../golden/t2177 >/dev/null 2>&1 ;;
  p2178) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1284 > ../outputs/t2178
    exec diff ../outputs/t2178 ../golden/t2178 >/dev/null 2>&1 ;;
  p2179) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1285 > ../outputs/t2179
    exec diff ../outputs/t2179 ../golden/t2179 >/dev/null 2>&1 ;;
  p2180) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1286 > ../outputs/t2180
    exec diff ../outputs/t2180 ../golden/t2180 >/dev/null 2>&1 ;;
  p2181) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1288 > ../outputs/t2181
    exec diff ../outputs/t2181 ../golden/t2181 >/dev/null 2>&1 ;;
  p2182) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1293 > ../outputs/t2182
    exec diff ../outputs/t2182 ../golden/t2182 >/dev/null 2>&1 ;;
  p2183) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1295 > ../outputs/t2183
    exec diff ../outputs/t2183 ../golden/t2183 >/dev/null 2>&1 ;;
  p2184) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1296 > ../outputs/t2184
    exec diff ../outputs/t2184 ../golden/t2184 >/dev/null 2>&1 ;;
  p2185) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1297 > ../outputs/t2185
    exec diff ../outputs/t2185 ../golden/t2185 >/dev/null 2>&1 ;;
  p2186) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1299 > ../outputs/t2186
    exec diff ../outputs/t2186 ../golden/t2186 >/dev/null 2>&1 ;;
  p2187) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.13 > ../outputs/t2187
    exec diff ../outputs/t2187 ../golden/t2187 >/dev/null 2>&1 ;;
  p2188) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.130 > ../outputs/t2188
    exec diff ../outputs/t2188 ../golden/t2188 >/dev/null 2>&1 ;;
  p2189) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1300 > ../outputs/t2189
    exec diff ../outputs/t2189 ../golden/t2189 >/dev/null 2>&1 ;;
  p2190) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1301 > ../outputs/t2190
    exec diff ../outputs/t2190 ../golden/t2190 >/dev/null 2>&1 ;;
  p2191) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1304 > ../outputs/t2191
    exec diff ../outputs/t2191 ../golden/t2191 >/dev/null 2>&1 ;;
  p2192) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1307 > ../outputs/t2192
    exec diff ../outputs/t2192 ../golden/t2192 >/dev/null 2>&1 ;;
  p2193) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1308 > ../outputs/t2193
    exec diff ../outputs/t2193 ../golden/t2193 >/dev/null 2>&1 ;;
  p2194) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1309 > ../outputs/t2194
    exec diff ../outputs/t2194 ../golden/t2194 >/dev/null 2>&1 ;;
  p2195) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1310 > ../outputs/t2195
    exec diff ../outputs/t2195 ../golden/t2195 >/dev/null 2>&1 ;;
  p2196) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1311 > ../outputs/t2196
    exec diff ../outputs/t2196 ../golden/t2196 >/dev/null 2>&1 ;;
  p2197) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1312 > ../outputs/t2197
    exec diff ../outputs/t2197 ../golden/t2197 >/dev/null 2>&1 ;;
  p2198) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1313 > ../outputs/t2198
    exec diff ../outputs/t2198 ../golden/t2198 >/dev/null 2>&1 ;;
  p2199) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1314 > ../outputs/t2199
    exec diff ../outputs/t2199 ../golden/t2199 >/dev/null 2>&1 ;;
  p2200) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1315 > ../outputs/t2200
    exec diff ../outputs/t2200 ../golden/t2200 >/dev/null 2>&1 ;;
  p2201) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1318 > ../outputs/t2201
    exec diff ../outputs/t2201 ../golden/t2201 >/dev/null 2>&1 ;;
  p2202) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1319 > ../outputs/t2202
    exec diff ../outputs/t2202 ../golden/t2202 >/dev/null 2>&1 ;;
  p2203) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1320 > ../outputs/t2203
    exec diff ../outputs/t2203 ../golden/t2203 >/dev/null 2>&1 ;;
  p2204) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1323 > ../outputs/t2204
    exec diff ../outputs/t2204 ../golden/t2204 >/dev/null 2>&1 ;;
  p2205) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1326 > ../outputs/t2205
    exec diff ../outputs/t2205 ../golden/t2205 >/dev/null 2>&1 ;;
  p2206) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1329 > ../outputs/t2206
    exec diff ../outputs/t2206 ../golden/t2206 >/dev/null 2>&1 ;;
  p2207) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.133 > ../outputs/t2207
    exec diff ../outputs/t2207 ../golden/t2207 >/dev/null 2>&1 ;;
  p2208) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1331 > ../outputs/t2208
    exec diff ../outputs/t2208 ../golden/t2208 >/dev/null 2>&1 ;;
  p2209) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1332 > ../outputs/t2209
    exec diff ../outputs/t2209 ../golden/t2209 >/dev/null 2>&1 ;;
  p2210) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1336 > ../outputs/t2210
    exec diff ../outputs/t2210 ../golden/t2210 >/dev/null 2>&1 ;;
  p2211) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1338 > ../outputs/t2211
    exec diff ../outputs/t2211 ../golden/t2211 >/dev/null 2>&1 ;;
  p2212) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1343 > ../outputs/t2212
    exec diff ../outputs/t2212 ../golden/t2212 >/dev/null 2>&1 ;;
  p2213) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1344 > ../outputs/t2213
    exec diff ../outputs/t2213 ../golden/t2213 >/dev/null 2>&1 ;;
  p2214) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1345 > ../outputs/t2214
    exec diff ../outputs/t2214 ../golden/t2214 >/dev/null 2>&1 ;;
  p2215) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1347 > ../outputs/t2215
    exec diff ../outputs/t2215 ../golden/t2215 >/dev/null 2>&1 ;;
  p2216) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1349 > ../outputs/t2216
    exec diff ../outputs/t2216 ../golden/t2216 >/dev/null 2>&1 ;;
  p2217) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.135 > ../outputs/t2217
    exec diff ../outputs/t2217 ../golden/t2217 >/dev/null 2>&1 ;;
  p2218) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1350 > ../outputs/t2218
    exec diff ../outputs/t2218 ../golden/t2218 >/dev/null 2>&1 ;;
  p2219) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1351 > ../outputs/t2219
    exec diff ../outputs/t2219 ../golden/t2219 >/dev/null 2>&1 ;;
  p2220) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1356 > ../outputs/t2220
    exec diff ../outputs/t2220 ../golden/t2220 >/dev/null 2>&1 ;;
  p2221) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1357 > ../outputs/t2221
    exec diff ../outputs/t2221 ../golden/t2221 >/dev/null 2>&1 ;;
  p2222) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.136 > ../outputs/t2222
    exec diff ../outputs/t2222 ../golden/t2222 >/dev/null 2>&1 ;;
  p2223) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1360 > ../outputs/t2223
    exec diff ../outputs/t2223 ../golden/t2223 >/dev/null 2>&1 ;;
  p2224) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1361 > ../outputs/t2224
    exec diff ../outputs/t2224 ../golden/t2224 >/dev/null 2>&1 ;;
  p2225) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1362 > ../outputs/t2225
    exec diff ../outputs/t2225 ../golden/t2225 >/dev/null 2>&1 ;;
  p2226) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1363 > ../outputs/t2226
    exec diff ../outputs/t2226 ../golden/t2226 >/dev/null 2>&1 ;;
  p2227) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1366 > ../outputs/t2227
    exec diff ../outputs/t2227 ../golden/t2227 >/dev/null 2>&1 ;;
  p2228) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1367 > ../outputs/t2228
    exec diff ../outputs/t2228 ../golden/t2228 >/dev/null 2>&1 ;;
  p2229) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1369 > ../outputs/t2229
    exec diff ../outputs/t2229 ../golden/t2229 >/dev/null 2>&1 ;;
  p2230) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1372 > ../outputs/t2230
    exec diff ../outputs/t2230 ../golden/t2230 >/dev/null 2>&1 ;;
  p2231) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1377 > ../outputs/t2231
    exec diff ../outputs/t2231 ../golden/t2231 >/dev/null 2>&1 ;;
  p2232) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1381 > ../outputs/t2232
    exec diff ../outputs/t2232 ../golden/t2232 >/dev/null 2>&1 ;;
  p2233) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1382 > ../outputs/t2233
    exec diff ../outputs/t2233 ../golden/t2233 >/dev/null 2>&1 ;;
  p2234) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1383 > ../outputs/t2234
    exec diff ../outputs/t2234 ../golden/t2234 >/dev/null 2>&1 ;;
  p2235) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1387 > ../outputs/t2235
    exec diff ../outputs/t2235 ../golden/t2235 >/dev/null 2>&1 ;;
  p2236) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1388 > ../outputs/t2236
    exec diff ../outputs/t2236 ../golden/t2236 >/dev/null 2>&1 ;;
  p2237) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1392 > ../outputs/t2237
    exec diff ../outputs/t2237 ../golden/t2237 >/dev/null 2>&1 ;;
  p2238) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1393 > ../outputs/t2238
    exec diff ../outputs/t2238 ../golden/t2238 >/dev/null 2>&1 ;;
  p2239) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1396 > ../outputs/t2239
    exec diff ../outputs/t2239 ../golden/t2239 >/dev/null 2>&1 ;;
  p2240) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1397 > ../outputs/t2240
    exec diff ../outputs/t2240 ../golden/t2240 >/dev/null 2>&1 ;;
  p2241) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.140 > ../outputs/t2241
    exec diff ../outputs/t2241 ../golden/t2241 >/dev/null 2>&1 ;;
  p2242) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1404 > ../outputs/t2242
    exec diff ../outputs/t2242 ../golden/t2242 >/dev/null 2>&1 ;;
  p2243) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1405 > ../outputs/t2243
    exec diff ../outputs/t2243 ../golden/t2243 >/dev/null 2>&1 ;;
  p2244) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1408 > ../outputs/t2244
    exec diff ../outputs/t2244 ../golden/t2244 >/dev/null 2>&1 ;;
  p2245) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1409 > ../outputs/t2245
    exec diff ../outputs/t2245 ../golden/t2245 >/dev/null 2>&1 ;;
  p2246) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1410 > ../outputs/t2246
    exec diff ../outputs/t2246 ../golden/t2246 >/dev/null 2>&1 ;;
  p2247) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1413 > ../outputs/t2247
    exec diff ../outputs/t2247 ../golden/t2247 >/dev/null 2>&1 ;;
  p2248) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1415 > ../outputs/t2248
    exec diff ../outputs/t2248 ../golden/t2248 >/dev/null 2>&1 ;;
  p2249) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.142 > ../outputs/t2249
    exec diff ../outputs/t2249 ../golden/t2249 >/dev/null 2>&1 ;;
  p2250) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1420 > ../outputs/t2250
    exec diff ../outputs/t2250 ../golden/t2250 >/dev/null 2>&1 ;;
  p2251) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1421 > ../outputs/t2251
    exec diff ../outputs/t2251 ../golden/t2251 >/dev/null 2>&1 ;;
  p2252) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1424 > ../outputs/t2252
    exec diff ../outputs/t2252 ../golden/t2252 >/dev/null 2>&1 ;;
  p2253) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1425 > ../outputs/t2253
    exec diff ../outputs/t2253 ../golden/t2253 >/dev/null 2>&1 ;;
  p2254) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1429 > ../outputs/t2254
    exec diff ../outputs/t2254 ../golden/t2254 >/dev/null 2>&1 ;;
  p2255) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.143 > ../outputs/t2255
    exec diff ../outputs/t2255 ../golden/t2255 >/dev/null 2>&1 ;;
  p2256) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1430 > ../outputs/t2256
    exec diff ../outputs/t2256 ../golden/t2256 >/dev/null 2>&1 ;;
  p2257) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1437 > ../outputs/t2257
    exec diff ../outputs/t2257 ../golden/t2257 >/dev/null 2>&1 ;;
  p2258) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1438 > ../outputs/t2258
    exec diff ../outputs/t2258 ../golden/t2258 >/dev/null 2>&1 ;;
  p2259) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1439 > ../outputs/t2259
    exec diff ../outputs/t2259 ../golden/t2259 >/dev/null 2>&1 ;;
  p2260) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1441 > ../outputs/t2260
    exec diff ../outputs/t2260 ../golden/t2260 >/dev/null 2>&1 ;;
  p2261) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1443 > ../outputs/t2261
    exec diff ../outputs/t2261 ../golden/t2261 >/dev/null 2>&1 ;;
  p2262) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.145 > ../outputs/t2262
    exec diff ../outputs/t2262 ../golden/t2262 >/dev/null 2>&1 ;;
  p2263) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1455 > ../outputs/t2263
    exec diff ../outputs/t2263 ../golden/t2263 >/dev/null 2>&1 ;;
  p2264) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1457 > ../outputs/t2264
    exec diff ../outputs/t2264 ../golden/t2264 >/dev/null 2>&1 ;;
  p2265) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1459 > ../outputs/t2265
    exec diff ../outputs/t2265 ../golden/t2265 >/dev/null 2>&1 ;;
  p2266) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1461 > ../outputs/t2266
    exec diff ../outputs/t2266 ../golden/t2266 >/dev/null 2>&1 ;;
  p2267) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1468 > ../outputs/t2267
    exec diff ../outputs/t2267 ../golden/t2267 >/dev/null 2>&1 ;;
  p2268) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1469 > ../outputs/t2268
    exec diff ../outputs/t2268 ../golden/t2268 >/dev/null 2>&1 ;;
  p2269) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.147 > ../outputs/t2269
    exec diff ../outputs/t2269 ../golden/t2269 >/dev/null 2>&1 ;;
  p2270) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1470 > ../outputs/t2270
    exec diff ../outputs/t2270 ../golden/t2270 >/dev/null 2>&1 ;;
  p2271) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1475 > ../outputs/t2271
    exec diff ../outputs/t2271 ../golden/t2271 >/dev/null 2>&1 ;;
  p2272) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1476 > ../outputs/t2272
    exec diff ../outputs/t2272 ../golden/t2272 >/dev/null 2>&1 ;;
  p2273) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1480 > ../outputs/t2273
    exec diff ../outputs/t2273 ../golden/t2273 >/dev/null 2>&1 ;;
  p2274) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1483 > ../outputs/t2274
    exec diff ../outputs/t2274 ../golden/t2274 >/dev/null 2>&1 ;;
  p2275) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1486 > ../outputs/t2275
    exec diff ../outputs/t2275 ../golden/t2275 >/dev/null 2>&1 ;;
  p2276) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1491 > ../outputs/t2276
    exec diff ../outputs/t2276 ../golden/t2276 >/dev/null 2>&1 ;;
  p2277) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1492 > ../outputs/t2277
    exec diff ../outputs/t2277 ../golden/t2277 >/dev/null 2>&1 ;;
  p2278) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1493 > ../outputs/t2278
    exec diff ../outputs/t2278 ../golden/t2278 >/dev/null 2>&1 ;;
  p2279) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1494 > ../outputs/t2279
    exec diff ../outputs/t2279 ../golden/t2279 >/dev/null 2>&1 ;;
  p2280) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1496 > ../outputs/t2280
    exec diff ../outputs/t2280 ../golden/t2280 >/dev/null 2>&1 ;;
  p2281) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1497 > ../outputs/t2281
    exec diff ../outputs/t2281 ../golden/t2281 >/dev/null 2>&1 ;;
  p2282) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.15 > ../outputs/t2282
    exec diff ../outputs/t2282 ../golden/t2282 >/dev/null 2>&1 ;;
  p2283) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1501 > ../outputs/t2283
    exec diff ../outputs/t2283 ../golden/t2283 >/dev/null 2>&1 ;;
  p2284) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1502 > ../outputs/t2284
    exec diff ../outputs/t2284 ../golden/t2284 >/dev/null 2>&1 ;;
  p2285) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1504 > ../outputs/t2285
    exec diff ../outputs/t2285 ../golden/t2285 >/dev/null 2>&1 ;;
  p2286) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1509 > ../outputs/t2286
    exec diff ../outputs/t2286 ../golden/t2286 >/dev/null 2>&1 ;;
  p2287) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.151 > ../outputs/t2287
    exec diff ../outputs/t2287 ../golden/t2287 >/dev/null 2>&1 ;;
  p2288) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1510 > ../outputs/t2288
    exec diff ../outputs/t2288 ../golden/t2288 >/dev/null 2>&1 ;;
  p2289) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1516 > ../outputs/t2289
    exec diff ../outputs/t2289 ../golden/t2289 >/dev/null 2>&1 ;;
  p2290) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1517 > ../outputs/t2290
    exec diff ../outputs/t2290 ../golden/t2290 >/dev/null 2>&1 ;;
  p2291) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1518 > ../outputs/t2291
    exec diff ../outputs/t2291 ../golden/t2291 >/dev/null 2>&1 ;;
  p2292) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1519 > ../outputs/t2292
    exec diff ../outputs/t2292 ../golden/t2292 >/dev/null 2>&1 ;;
  p2293) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1524 > ../outputs/t2293
    exec diff ../outputs/t2293 ../golden/t2293 >/dev/null 2>&1 ;;
  p2294) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1525 > ../outputs/t2294
    exec diff ../outputs/t2294 ../golden/t2294 >/dev/null 2>&1 ;;
  p2295) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1526 > ../outputs/t2295
    exec diff ../outputs/t2295 ../golden/t2295 >/dev/null 2>&1 ;;
  p2296) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1527 > ../outputs/t2296
    exec diff ../outputs/t2296 ../golden/t2296 >/dev/null 2>&1 ;;
  p2297) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1529 > ../outputs/t2297
    exec diff ../outputs/t2297 ../golden/t2297 >/dev/null 2>&1 ;;
  p2298) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.153 > ../outputs/t2298
    exec diff ../outputs/t2298 ../golden/t2298 >/dev/null 2>&1 ;;
  p2299) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1530 > ../outputs/t2299
    exec diff ../outputs/t2299 ../golden/t2299 >/dev/null 2>&1 ;;
  p2300) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1532 > ../outputs/t2300
    exec diff ../outputs/t2300 ../golden/t2300 >/dev/null 2>&1 ;;
  p2301) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1534 > ../outputs/t2301
    exec diff ../outputs/t2301 ../golden/t2301 >/dev/null 2>&1 ;;
  p2302) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1538 > ../outputs/t2302
    exec diff ../outputs/t2302 ../golden/t2302 >/dev/null 2>&1 ;;
  p2303) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1539 > ../outputs/t2303
    exec diff ../outputs/t2303 ../golden/t2303 >/dev/null 2>&1 ;;
  p2304) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.154 > ../outputs/t2304
    exec diff ../outputs/t2304 ../golden/t2304 >/dev/null 2>&1 ;;
  p2305) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1541 > ../outputs/t2305
    exec diff ../outputs/t2305 ../golden/t2305 >/dev/null 2>&1 ;;
  p2306) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1542 > ../outputs/t2306
    exec diff ../outputs/t2306 ../golden/t2306 >/dev/null 2>&1 ;;
  p2307) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1546 > ../outputs/t2307
    exec diff ../outputs/t2307 ../golden/t2307 >/dev/null 2>&1 ;;
  p2308) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1549 > ../outputs/t2308
    exec diff ../outputs/t2308 ../golden/t2308 >/dev/null 2>&1 ;;
  p2309) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.155 > ../outputs/t2309
    exec diff ../outputs/t2309 ../golden/t2309 >/dev/null 2>&1 ;;
  p2310) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1551 > ../outputs/t2310
    exec diff ../outputs/t2310 ../golden/t2310 >/dev/null 2>&1 ;;
  p2311) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1554 > ../outputs/t2311
    exec diff ../outputs/t2311 ../golden/t2311 >/dev/null 2>&1 ;;
  p2312) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1556 > ../outputs/t2312
    exec diff ../outputs/t2312 ../golden/t2312 >/dev/null 2>&1 ;;
  p2313) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1557 > ../outputs/t2313
    exec diff ../outputs/t2313 ../golden/t2313 >/dev/null 2>&1 ;;
  p2314) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1559 > ../outputs/t2314
    exec diff ../outputs/t2314 ../golden/t2314 >/dev/null 2>&1 ;;
  p2315) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1562 > ../outputs/t2315
    exec diff ../outputs/t2315 ../golden/t2315 >/dev/null 2>&1 ;;
  p2316) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1563 > ../outputs/t2316
    exec diff ../outputs/t2316 ../golden/t2316 >/dev/null 2>&1 ;;
  p2317) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1565 > ../outputs/t2317
    exec diff ../outputs/t2317 ../golden/t2317 >/dev/null 2>&1 ;;
  p2318) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1566 > ../outputs/t2318
    exec diff ../outputs/t2318 ../golden/t2318 >/dev/null 2>&1 ;;
  p2319) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1567 > ../outputs/t2319
    exec diff ../outputs/t2319 ../golden/t2319 >/dev/null 2>&1 ;;
  p2320) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1569 > ../outputs/t2320
    exec diff ../outputs/t2320 ../golden/t2320 >/dev/null 2>&1 ;;
  p2321) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.157 > ../outputs/t2321
    exec diff ../outputs/t2321 ../golden/t2321 >/dev/null 2>&1 ;;
  p2322) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1570 > ../outputs/t2322
    exec diff ../outputs/t2322 ../golden/t2322 >/dev/null 2>&1 ;;
  p2323) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1572 > ../outputs/t2323
    exec diff ../outputs/t2323 ../golden/t2323 >/dev/null 2>&1 ;;
  p2324) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1576 > ../outputs/t2324
    exec diff ../outputs/t2324 ../golden/t2324 >/dev/null 2>&1 ;;
  p2325) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1578 > ../outputs/t2325
    exec diff ../outputs/t2325 ../golden/t2325 >/dev/null 2>&1 ;;
  p2326) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1579 > ../outputs/t2326
    exec diff ../outputs/t2326 ../golden/t2326 >/dev/null 2>&1 ;;
  p2327) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1584 > ../outputs/t2327
    exec diff ../outputs/t2327 ../golden/t2327 >/dev/null 2>&1 ;;
  p2328) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1587 > ../outputs/t2328
    exec diff ../outputs/t2328 ../golden/t2328 >/dev/null 2>&1 ;;
  p2329) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1588 > ../outputs/t2329
    exec diff ../outputs/t2329 ../golden/t2329 >/dev/null 2>&1 ;;
  p2330) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1589 > ../outputs/t2330
    exec diff ../outputs/t2330 ../golden/t2330 >/dev/null 2>&1 ;;
  p2331) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1593 > ../outputs/t2331
    exec diff ../outputs/t2331 ../golden/t2331 >/dev/null 2>&1 ;;
  p2332) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1596 > ../outputs/t2332
    exec diff ../outputs/t2332 ../golden/t2332 >/dev/null 2>&1 ;;
  p2333) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1598 > ../outputs/t2333
    exec diff ../outputs/t2333 ../golden/t2333 >/dev/null 2>&1 ;;
  p2334) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1599 > ../outputs/t2334
    exec diff ../outputs/t2334 ../golden/t2334 >/dev/null 2>&1 ;;
  p2335) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.16 > ../outputs/t2335
    exec diff ../outputs/t2335 ../golden/t2335 >/dev/null 2>&1 ;;
  p2336) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.160 > ../outputs/t2336
    exec diff ../outputs/t2336 ../golden/t2336 >/dev/null 2>&1 ;;
  p2337) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1600 > ../outputs/t2337
    exec diff ../outputs/t2337 ../golden/t2337 >/dev/null 2>&1 ;;
  p2338) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1604 > ../outputs/t2338
    exec diff ../outputs/t2338 ../golden/t2338 >/dev/null 2>&1 ;;
  p2339) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1605 > ../outputs/t2339
    exec diff ../outputs/t2339 ../golden/t2339 >/dev/null 2>&1 ;;
  p2340) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1609 > ../outputs/t2340
    exec diff ../outputs/t2340 ../golden/t2340 >/dev/null 2>&1 ;;
  p2341) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.161 > ../outputs/t2341
    exec diff ../outputs/t2341 ../golden/t2341 >/dev/null 2>&1 ;;
  p2342) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1611 > ../outputs/t2342
    exec diff ../outputs/t2342 ../golden/t2342 >/dev/null 2>&1 ;;
  p2343) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1612 > ../outputs/t2343
    exec diff ../outputs/t2343 ../golden/t2343 >/dev/null 2>&1 ;;
  p2344) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1613 > ../outputs/t2344
    exec diff ../outputs/t2344 ../golden/t2344 >/dev/null 2>&1 ;;
  p2345) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1615 > ../outputs/t2345
    exec diff ../outputs/t2345 ../golden/t2345 >/dev/null 2>&1 ;;
  p2346) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1616 > ../outputs/t2346
    exec diff ../outputs/t2346 ../golden/t2346 >/dev/null 2>&1 ;;
  p2347) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.162 > ../outputs/t2347
    exec diff ../outputs/t2347 ../golden/t2347 >/dev/null 2>&1 ;;
  p2348) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1621 > ../outputs/t2348
    exec diff ../outputs/t2348 ../golden/t2348 >/dev/null 2>&1 ;;
  p2349) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1622 > ../outputs/t2349
    exec diff ../outputs/t2349 ../golden/t2349 >/dev/null 2>&1 ;;
  p2350) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1627 > ../outputs/t2350
    exec diff ../outputs/t2350 ../golden/t2350 >/dev/null 2>&1 ;;
  p2351) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1628 > ../outputs/t2351
    exec diff ../outputs/t2351 ../golden/t2351 >/dev/null 2>&1 ;;
  p2352) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.163 > ../outputs/t2352
    exec diff ../outputs/t2352 ../golden/t2352 >/dev/null 2>&1 ;;
  p2353) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1633 > ../outputs/t2353
    exec diff ../outputs/t2353 ../golden/t2353 >/dev/null 2>&1 ;;
  p2354) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1636 > ../outputs/t2354
    exec diff ../outputs/t2354 ../golden/t2354 >/dev/null 2>&1 ;;
  p2355) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1639 > ../outputs/t2355
    exec diff ../outputs/t2355 ../golden/t2355 >/dev/null 2>&1 ;;
  p2356) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.164 > ../outputs/t2356
    exec diff ../outputs/t2356 ../golden/t2356 >/dev/null 2>&1 ;;
  p2357) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1640 > ../outputs/t2357
    exec diff ../outputs/t2357 ../golden/t2357 >/dev/null 2>&1 ;;
  p2358) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1642 > ../outputs/t2358
    exec diff ../outputs/t2358 ../golden/t2358 >/dev/null 2>&1 ;;
  p2359) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1643 > ../outputs/t2359
    exec diff ../outputs/t2359 ../golden/t2359 >/dev/null 2>&1 ;;
  p2360) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1647 > ../outputs/t2360
    exec diff ../outputs/t2360 ../golden/t2360 >/dev/null 2>&1 ;;
  p2361) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1648 > ../outputs/t2361
    exec diff ../outputs/t2361 ../golden/t2361 >/dev/null 2>&1 ;;
  p2362) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1649 > ../outputs/t2362
    exec diff ../outputs/t2362 ../golden/t2362 >/dev/null 2>&1 ;;
  p2363) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1650 > ../outputs/t2363
    exec diff ../outputs/t2363 ../golden/t2363 >/dev/null 2>&1 ;;
  p2364) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1658 > ../outputs/t2364
    exec diff ../outputs/t2364 ../golden/t2364 >/dev/null 2>&1 ;;
  p2365) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1659 > ../outputs/t2365
    exec diff ../outputs/t2365 ../golden/t2365 >/dev/null 2>&1 ;;
  p2366) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1660 > ../outputs/t2366
    exec diff ../outputs/t2366 ../golden/t2366 >/dev/null 2>&1 ;;
  p2367) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1666 > ../outputs/t2367
    exec diff ../outputs/t2367 ../golden/t2367 >/dev/null 2>&1 ;;
  p2368) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1667 > ../outputs/t2368
    exec diff ../outputs/t2368 ../golden/t2368 >/dev/null 2>&1 ;;
  p2369) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1668 > ../outputs/t2369
    exec diff ../outputs/t2369 ../golden/t2369 >/dev/null 2>&1 ;;
  p2370) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1669 > ../outputs/t2370
    exec diff ../outputs/t2370 ../golden/t2370 >/dev/null 2>&1 ;;
  p2371) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1670 > ../outputs/t2371
    exec diff ../outputs/t2371 ../golden/t2371 >/dev/null 2>&1 ;;
  p2372) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1671 > ../outputs/t2372
    exec diff ../outputs/t2372 ../golden/t2372 >/dev/null 2>&1 ;;
  p2373) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1672 > ../outputs/t2373
    exec diff ../outputs/t2373 ../golden/t2373 >/dev/null 2>&1 ;;
  p2374) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1675 > ../outputs/t2374
    exec diff ../outputs/t2374 ../golden/t2374 >/dev/null 2>&1 ;;
  p2375) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1676 > ../outputs/t2375
    exec diff ../outputs/t2375 ../golden/t2375 >/dev/null 2>&1 ;;
  p2376) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1679 > ../outputs/t2376
    exec diff ../outputs/t2376 ../golden/t2376 >/dev/null 2>&1 ;;
  p2377) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1681 > ../outputs/t2377
    exec diff ../outputs/t2377 ../golden/t2377 >/dev/null 2>&1 ;;
  p2378) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1686 > ../outputs/t2378
    exec diff ../outputs/t2378 ../golden/t2378 >/dev/null 2>&1 ;;
  p2379) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.169 > ../outputs/t2379
    exec diff ../outputs/t2379 ../golden/t2379 >/dev/null 2>&1 ;;
  p2380) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1691 > ../outputs/t2380
    exec diff ../outputs/t2380 ../golden/t2380 >/dev/null 2>&1 ;;
  p2381) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1694 > ../outputs/t2381
    exec diff ../outputs/t2381 ../golden/t2381 >/dev/null 2>&1 ;;
  p2382) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1695 > ../outputs/t2382
    exec diff ../outputs/t2382 ../golden/t2382 >/dev/null 2>&1 ;;
  p2383) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1698 > ../outputs/t2383
    exec diff ../outputs/t2383 ../golden/t2383 >/dev/null 2>&1 ;;
  p2384) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.17 > ../outputs/t2384
    exec diff ../outputs/t2384 ../golden/t2384 >/dev/null 2>&1 ;;
  p2385) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.170 > ../outputs/t2385
    exec diff ../outputs/t2385 ../golden/t2385 >/dev/null 2>&1 ;;
  p2386) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1702 > ../outputs/t2386
    exec diff ../outputs/t2386 ../golden/t2386 >/dev/null 2>&1 ;;
  p2387) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1707 > ../outputs/t2387
    exec diff ../outputs/t2387 ../golden/t2387 >/dev/null 2>&1 ;;
  p2388) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.171 > ../outputs/t2388
    exec diff ../outputs/t2388 ../golden/t2388 >/dev/null 2>&1 ;;
  p2389) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1710 > ../outputs/t2389
    exec diff ../outputs/t2389 ../golden/t2389 >/dev/null 2>&1 ;;
  p2390) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1711 > ../outputs/t2390
    exec diff ../outputs/t2390 ../golden/t2390 >/dev/null 2>&1 ;;
  p2391) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1712 > ../outputs/t2391
    exec diff ../outputs/t2391 ../golden/t2391 >/dev/null 2>&1 ;;
  p2392) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1716 > ../outputs/t2392
    exec diff ../outputs/t2392 ../golden/t2392 >/dev/null 2>&1 ;;
  p2393) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1724 > ../outputs/t2393
    exec diff ../outputs/t2393 ../golden/t2393 >/dev/null 2>&1 ;;
  p2394) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1730 > ../outputs/t2394
    exec diff ../outputs/t2394 ../golden/t2394 >/dev/null 2>&1 ;;
  p2395) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1735 > ../outputs/t2395
    exec diff ../outputs/t2395 ../golden/t2395 >/dev/null 2>&1 ;;
  p2396) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1737 > ../outputs/t2396
    exec diff ../outputs/t2396 ../golden/t2396 >/dev/null 2>&1 ;;
  p2397) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1738 > ../outputs/t2397
    exec diff ../outputs/t2397 ../golden/t2397 >/dev/null 2>&1 ;;
  p2398) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1740 > ../outputs/t2398
    exec diff ../outputs/t2398 ../golden/t2398 >/dev/null 2>&1 ;;
  p2399) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1742 > ../outputs/t2399
    exec diff ../outputs/t2399 ../golden/t2399 >/dev/null 2>&1 ;;
  p2400) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1744 > ../outputs/t2400
    exec diff ../outputs/t2400 ../golden/t2400 >/dev/null 2>&1 ;;
  p2401) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.175 > ../outputs/t2401
    exec diff ../outputs/t2401 ../golden/t2401 >/dev/null 2>&1 ;;
  p2402) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1753 > ../outputs/t2402
    exec diff ../outputs/t2402 ../golden/t2402 >/dev/null 2>&1 ;;
  p2403) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1754 > ../outputs/t2403
    exec diff ../outputs/t2403 ../golden/t2403 >/dev/null 2>&1 ;;
  p2404) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1755 > ../outputs/t2404
    exec diff ../outputs/t2404 ../golden/t2404 >/dev/null 2>&1 ;;
  p2405) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1756 > ../outputs/t2405
    exec diff ../outputs/t2405 ../golden/t2405 >/dev/null 2>&1 ;;
  p2406) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.176 > ../outputs/t2406
    exec diff ../outputs/t2406 ../golden/t2406 >/dev/null 2>&1 ;;
  p2407) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1760 > ../outputs/t2407
    exec diff ../outputs/t2407 ../golden/t2407 >/dev/null 2>&1 ;;
  p2408) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1762 > ../outputs/t2408
    exec diff ../outputs/t2408 ../golden/t2408 >/dev/null 2>&1 ;;
  p2409) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1764 > ../outputs/t2409
    exec diff ../outputs/t2409 ../golden/t2409 >/dev/null 2>&1 ;;
  p2410) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.177 > ../outputs/t2410
    exec diff ../outputs/t2410 ../golden/t2410 >/dev/null 2>&1 ;;
  p2411) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1771 > ../outputs/t2411
    exec diff ../outputs/t2411 ../golden/t2411 >/dev/null 2>&1 ;;
  p2412) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1773 > ../outputs/t2412
    exec diff ../outputs/t2412 ../golden/t2412 >/dev/null 2>&1 ;;
  p2413) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1774 > ../outputs/t2413
    exec diff ../outputs/t2413 ../golden/t2413 >/dev/null 2>&1 ;;
  p2414) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1776 > ../outputs/t2414
    exec diff ../outputs/t2414 ../golden/t2414 >/dev/null 2>&1 ;;
  p2415) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1778 > ../outputs/t2415
    exec diff ../outputs/t2415 ../golden/t2415 >/dev/null 2>&1 ;;
  p2416) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1782 > ../outputs/t2416
    exec diff ../outputs/t2416 ../golden/t2416 >/dev/null 2>&1 ;;
  p2417) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1783 > ../outputs/t2417
    exec diff ../outputs/t2417 ../golden/t2417 >/dev/null 2>&1 ;;
  p2418) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1785 > ../outputs/t2418
    exec diff ../outputs/t2418 ../golden/t2418 >/dev/null 2>&1 ;;
  p2419) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1787 > ../outputs/t2419
    exec diff ../outputs/t2419 ../golden/t2419 >/dev/null 2>&1 ;;
  p2420) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1789 > ../outputs/t2420
    exec diff ../outputs/t2420 ../golden/t2420 >/dev/null 2>&1 ;;
  p2421) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1792 > ../outputs/t2421
    exec diff ../outputs/t2421 ../golden/t2421 >/dev/null 2>&1 ;;
  p2422) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1793 > ../outputs/t2422
    exec diff ../outputs/t2422 ../golden/t2422 >/dev/null 2>&1 ;;
  p2423) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1794 > ../outputs/t2423
    exec diff ../outputs/t2423 ../golden/t2423 >/dev/null 2>&1 ;;
  p2424) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1798 > ../outputs/t2424
    exec diff ../outputs/t2424 ../golden/t2424 >/dev/null 2>&1 ;;
  p2425) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1800 > ../outputs/t2425
    exec diff ../outputs/t2425 ../golden/t2425 >/dev/null 2>&1 ;;
  p2426) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1802 > ../outputs/t2426
    exec diff ../outputs/t2426 ../golden/t2426 >/dev/null 2>&1 ;;
  p2427) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1806 > ../outputs/t2427
    exec diff ../outputs/t2427 ../golden/t2427 >/dev/null 2>&1 ;;
  p2428) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1809 > ../outputs/t2428
    exec diff ../outputs/t2428 ../golden/t2428 >/dev/null 2>&1 ;;
  p2429) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1812 > ../outputs/t2429
    exec diff ../outputs/t2429 ../golden/t2429 >/dev/null 2>&1 ;;
  p2430) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1814 > ../outputs/t2430
    exec diff ../outputs/t2430 ../golden/t2430 >/dev/null 2>&1 ;;
  p2431) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1816 > ../outputs/t2431
    exec diff ../outputs/t2431 ../golden/t2431 >/dev/null 2>&1 ;;
  p2432) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1818 > ../outputs/t2432
    exec diff ../outputs/t2432 ../golden/t2432 >/dev/null 2>&1 ;;
  p2433) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1819 > ../outputs/t2433
    exec diff ../outputs/t2433 ../golden/t2433 >/dev/null 2>&1 ;;
  p2434) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.182 > ../outputs/t2434
    exec diff ../outputs/t2434 ../golden/t2434 >/dev/null 2>&1 ;;
  p2435) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1821 > ../outputs/t2435
    exec diff ../outputs/t2435 ../golden/t2435 >/dev/null 2>&1 ;;
  p2436) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1823 > ../outputs/t2436
    exec diff ../outputs/t2436 ../golden/t2436 >/dev/null 2>&1 ;;
  p2437) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1827 > ../outputs/t2437
    exec diff ../outputs/t2437 ../golden/t2437 >/dev/null 2>&1 ;;
  p2438) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1829 > ../outputs/t2438
    exec diff ../outputs/t2438 ../golden/t2438 >/dev/null 2>&1 ;;
  p2439) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1830 > ../outputs/t2439
    exec diff ../outputs/t2439 ../golden/t2439 >/dev/null 2>&1 ;;
  p2440) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1832 > ../outputs/t2440
    exec diff ../outputs/t2440 ../golden/t2440 >/dev/null 2>&1 ;;
  p2441) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1835 > ../outputs/t2441
    exec diff ../outputs/t2441 ../golden/t2441 >/dev/null 2>&1 ;;
  p2442) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1836 > ../outputs/t2442
    exec diff ../outputs/t2442 ../golden/t2442 >/dev/null 2>&1 ;;
  p2443) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1837 > ../outputs/t2443
    exec diff ../outputs/t2443 ../golden/t2443 >/dev/null 2>&1 ;;
  p2444) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1838 > ../outputs/t2444
    exec diff ../outputs/t2444 ../golden/t2444 >/dev/null 2>&1 ;;
  p2445) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1839 > ../outputs/t2445
    exec diff ../outputs/t2445 ../golden/t2445 >/dev/null 2>&1 ;;
  p2446) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.184 > ../outputs/t2446
    exec diff ../outputs/t2446 ../golden/t2446 >/dev/null 2>&1 ;;
  p2447) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1845 > ../outputs/t2447
    exec diff ../outputs/t2447 ../golden/t2447 >/dev/null 2>&1 ;;
  p2448) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1847 > ../outputs/t2448
    exec diff ../outputs/t2448 ../golden/t2448 >/dev/null 2>&1 ;;
  p2449) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1848 > ../outputs/t2449
    exec diff ../outputs/t2449 ../golden/t2449 >/dev/null 2>&1 ;;
  p2450) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.185 > ../outputs/t2450
    exec diff ../outputs/t2450 ../golden/t2450 >/dev/null 2>&1 ;;
  p2451) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1850 > ../outputs/t2451
    exec diff ../outputs/t2451 ../golden/t2451 >/dev/null 2>&1 ;;
  p2452) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1855 > ../outputs/t2452
    exec diff ../outputs/t2452 ../golden/t2452 >/dev/null 2>&1 ;;
  p2453) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1856 > ../outputs/t2453
    exec diff ../outputs/t2453 ../golden/t2453 >/dev/null 2>&1 ;;
  p2454) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1858 > ../outputs/t2454
    exec diff ../outputs/t2454 ../golden/t2454 >/dev/null 2>&1 ;;
  p2455) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1862 > ../outputs/t2455
    exec diff ../outputs/t2455 ../golden/t2455 >/dev/null 2>&1 ;;
  p2456) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1863 > ../outputs/t2456
    exec diff ../outputs/t2456 ../golden/t2456 >/dev/null 2>&1 ;;
  p2457) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1865 > ../outputs/t2457
    exec diff ../outputs/t2457 ../golden/t2457 >/dev/null 2>&1 ;;
  p2458) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1871 > ../outputs/t2458
    exec diff ../outputs/t2458 ../golden/t2458 >/dev/null 2>&1 ;;
  p2459) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1872 > ../outputs/t2459
    exec diff ../outputs/t2459 ../golden/t2459 >/dev/null 2>&1 ;;
  p2460) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1873 > ../outputs/t2460
    exec diff ../outputs/t2460 ../golden/t2460 >/dev/null 2>&1 ;;
  p2461) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1874 > ../outputs/t2461
    exec diff ../outputs/t2461 ../golden/t2461 >/dev/null 2>&1 ;;
  p2462) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1876 > ../outputs/t2462
    exec diff ../outputs/t2462 ../golden/t2462 >/dev/null 2>&1 ;;
  p2463) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1877 > ../outputs/t2463
    exec diff ../outputs/t2463 ../golden/t2463 >/dev/null 2>&1 ;;
  p2464) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1878 > ../outputs/t2464
    exec diff ../outputs/t2464 ../golden/t2464 >/dev/null 2>&1 ;;
  p2465) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.188 > ../outputs/t2465
    exec diff ../outputs/t2465 ../golden/t2465 >/dev/null 2>&1 ;;
  p2466) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1880 > ../outputs/t2466
    exec diff ../outputs/t2466 ../golden/t2466 >/dev/null 2>&1 ;;
  p2467) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1881 > ../outputs/t2467
    exec diff ../outputs/t2467 ../golden/t2467 >/dev/null 2>&1 ;;
  p2468) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1882 > ../outputs/t2468
    exec diff ../outputs/t2468 ../golden/t2468 >/dev/null 2>&1 ;;
  p2469) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1885 > ../outputs/t2469
    exec diff ../outputs/t2469 ../golden/t2469 >/dev/null 2>&1 ;;
  p2470) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1886 > ../outputs/t2470
    exec diff ../outputs/t2470 ../golden/t2470 >/dev/null 2>&1 ;;
  p2471) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1887 > ../outputs/t2471
    exec diff ../outputs/t2471 ../golden/t2471 >/dev/null 2>&1 ;;
  p2472) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.189 > ../outputs/t2472
    exec diff ../outputs/t2472 ../golden/t2472 >/dev/null 2>&1 ;;
  p2473) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1891 > ../outputs/t2473
    exec diff ../outputs/t2473 ../golden/t2473 >/dev/null 2>&1 ;;
  p2474) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1892 > ../outputs/t2474
    exec diff ../outputs/t2474 ../golden/t2474 >/dev/null 2>&1 ;;
  p2475) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1893 > ../outputs/t2475
    exec diff ../outputs/t2475 ../golden/t2475 >/dev/null 2>&1 ;;
  p2476) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1895 > ../outputs/t2476
    exec diff ../outputs/t2476 ../golden/t2476 >/dev/null 2>&1 ;;
  p2477) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1896 > ../outputs/t2477
    exec diff ../outputs/t2477 ../golden/t2477 >/dev/null 2>&1 ;;
  p2478) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1897 > ../outputs/t2478
    exec diff ../outputs/t2478 ../golden/t2478 >/dev/null 2>&1 ;;
  p2479) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1898 > ../outputs/t2479
    exec diff ../outputs/t2479 ../golden/t2479 >/dev/null 2>&1 ;;
  p2480) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.190 > ../outputs/t2480
    exec diff ../outputs/t2480 ../golden/t2480 >/dev/null 2>&1 ;;
  p2481) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1903 > ../outputs/t2481
    exec diff ../outputs/t2481 ../golden/t2481 >/dev/null 2>&1 ;;
  p2482) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1905 > ../outputs/t2482
    exec diff ../outputs/t2482 ../golden/t2482 >/dev/null 2>&1 ;;
  p2483) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1907 > ../outputs/t2483
    exec diff ../outputs/t2483 ../golden/t2483 >/dev/null 2>&1 ;;
  p2484) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1908 > ../outputs/t2484
    exec diff ../outputs/t2484 ../golden/t2484 >/dev/null 2>&1 ;;
  p2485) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.191 > ../outputs/t2485
    exec diff ../outputs/t2485 ../golden/t2485 >/dev/null 2>&1 ;;
  p2486) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1912 > ../outputs/t2486
    exec diff ../outputs/t2486 ../golden/t2486 >/dev/null 2>&1 ;;
  p2487) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1913 > ../outputs/t2487
    exec diff ../outputs/t2487 ../golden/t2487 >/dev/null 2>&1 ;;
  p2488) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1914 > ../outputs/t2488
    exec diff ../outputs/t2488 ../golden/t2488 >/dev/null 2>&1 ;;
  p2489) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1916 > ../outputs/t2489
    exec diff ../outputs/t2489 ../golden/t2489 >/dev/null 2>&1 ;;
  p2490) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1917 > ../outputs/t2490
    exec diff ../outputs/t2490 ../golden/t2490 >/dev/null 2>&1 ;;
  p2491) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1918 > ../outputs/t2491
    exec diff ../outputs/t2491 ../golden/t2491 >/dev/null 2>&1 ;;
  p2492) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1920 > ../outputs/t2492
    exec diff ../outputs/t2492 ../golden/t2492 >/dev/null 2>&1 ;;
  p2493) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1922 > ../outputs/t2493
    exec diff ../outputs/t2493 ../golden/t2493 >/dev/null 2>&1 ;;
  p2494) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1924 > ../outputs/t2494
    exec diff ../outputs/t2494 ../golden/t2494 >/dev/null 2>&1 ;;
  p2495) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1925 > ../outputs/t2495
    exec diff ../outputs/t2495 ../golden/t2495 >/dev/null 2>&1 ;;
  p2496) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1926 > ../outputs/t2496
    exec diff ../outputs/t2496 ../golden/t2496 >/dev/null 2>&1 ;;
  p2497) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1929 > ../outputs/t2497
    exec diff ../outputs/t2497 ../golden/t2497 >/dev/null 2>&1 ;;
  p2498) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.193 > ../outputs/t2498
    exec diff ../outputs/t2498 ../golden/t2498 >/dev/null 2>&1 ;;
  p2499) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1931 > ../outputs/t2499
    exec diff ../outputs/t2499 ../golden/t2499 >/dev/null 2>&1 ;;
  p2500) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1932 > ../outputs/t2500
    exec diff ../outputs/t2500 ../golden/t2500 >/dev/null 2>&1 ;;
  p2501) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1934 > ../outputs/t2501
    exec diff ../outputs/t2501 ../golden/t2501 >/dev/null 2>&1 ;;
  p2502) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1935 > ../outputs/t2502
    exec diff ../outputs/t2502 ../golden/t2502 >/dev/null 2>&1 ;;
  p2503) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1936 > ../outputs/t2503
    exec diff ../outputs/t2503 ../golden/t2503 >/dev/null 2>&1 ;;
  p2504) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1937 > ../outputs/t2504
    exec diff ../outputs/t2504 ../golden/t2504 >/dev/null 2>&1 ;;
  p2505) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1938 > ../outputs/t2505
    exec diff ../outputs/t2505 ../golden/t2505 >/dev/null 2>&1 ;;
  p2506) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1944 > ../outputs/t2506
    exec diff ../outputs/t2506 ../golden/t2506 >/dev/null 2>&1 ;;
  p2507) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1945 > ../outputs/t2507
    exec diff ../outputs/t2507 ../golden/t2507 >/dev/null 2>&1 ;;
  p2508) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1946 > ../outputs/t2508
    exec diff ../outputs/t2508 ../golden/t2508 >/dev/null 2>&1 ;;
  p2509) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1947 > ../outputs/t2509
    exec diff ../outputs/t2509 ../golden/t2509 >/dev/null 2>&1 ;;
  p2510) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1948 > ../outputs/t2510
    exec diff ../outputs/t2510 ../golden/t2510 >/dev/null 2>&1 ;;
  p2511) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.195 > ../outputs/t2511
    exec diff ../outputs/t2511 ../golden/t2511 >/dev/null 2>&1 ;;
  p2512) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1950 > ../outputs/t2512
    exec diff ../outputs/t2512 ../golden/t2512 >/dev/null 2>&1 ;;
  p2513) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1955 > ../outputs/t2513
    exec diff ../outputs/t2513 ../golden/t2513 >/dev/null 2>&1 ;;
  p2514) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1958 > ../outputs/t2514
    exec diff ../outputs/t2514 ../golden/t2514 >/dev/null 2>&1 ;;
  p2515) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1959 > ../outputs/t2515
    exec diff ../outputs/t2515 ../golden/t2515 >/dev/null 2>&1 ;;
  p2516) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1961 > ../outputs/t2516
    exec diff ../outputs/t2516 ../golden/t2516 >/dev/null 2>&1 ;;
  p2517) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1964 > ../outputs/t2517
    exec diff ../outputs/t2517 ../golden/t2517 >/dev/null 2>&1 ;;
  p2518) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1970 > ../outputs/t2518
    exec diff ../outputs/t2518 ../golden/t2518 >/dev/null 2>&1 ;;
  p2519) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1972 > ../outputs/t2519
    exec diff ../outputs/t2519 ../golden/t2519 >/dev/null 2>&1 ;;
  p2520) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1974 > ../outputs/t2520
    exec diff ../outputs/t2520 ../golden/t2520 >/dev/null 2>&1 ;;
  p2521) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1975 > ../outputs/t2521
    exec diff ../outputs/t2521 ../golden/t2521 >/dev/null 2>&1 ;;
  p2522) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1979 > ../outputs/t2522
    exec diff ../outputs/t2522 ../golden/t2522 >/dev/null 2>&1 ;;
  p2523) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1984 > ../outputs/t2523
    exec diff ../outputs/t2523 ../golden/t2523 >/dev/null 2>&1 ;;
  p2524) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1985 > ../outputs/t2524
    exec diff ../outputs/t2524 ../golden/t2524 >/dev/null 2>&1 ;;
  p2525) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1988 > ../outputs/t2525
    exec diff ../outputs/t2525 ../golden/t2525 >/dev/null 2>&1 ;;
  p2526) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1989 > ../outputs/t2526
    exec diff ../outputs/t2526 ../golden/t2526 >/dev/null 2>&1 ;;
  p2527) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1990 > ../outputs/t2527
    exec diff ../outputs/t2527 ../golden/t2527 >/dev/null 2>&1 ;;
  p2528) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1995 > ../outputs/t2528
    exec diff ../outputs/t2528 ../golden/t2528 >/dev/null 2>&1 ;;
  p2529) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1997 > ../outputs/t2529
    exec diff ../outputs/t2529 ../golden/t2529 >/dev/null 2>&1 ;;
  p2530) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.1999 > ../outputs/t2530
    exec diff ../outputs/t2530 ../golden/t2530 >/dev/null 2>&1 ;;
  p2531) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.20 > ../outputs/t2531
    exec diff ../outputs/t2531 ../golden/t2531 >/dev/null 2>&1 ;;
  p2532) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.2000 > ../outputs/t2532
    exec diff ../outputs/t2532 ../golden/t2532 >/dev/null 2>&1 ;;
  p2533) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.201 > ../outputs/t2533
    exec diff ../outputs/t2533 ../golden/t2533 >/dev/null 2>&1 ;;
  p2534) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.204 > ../outputs/t2534
    exec diff ../outputs/t2534 ../golden/t2534 >/dev/null 2>&1 ;;
  p2535) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.206 > ../outputs/t2535
    exec diff ../outputs/t2535 ../golden/t2535 >/dev/null 2>&1 ;;
  p2536) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.207 > ../outputs/t2536
    exec diff ../outputs/t2536 ../golden/t2536 >/dev/null 2>&1 ;;
  p2537) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.208 > ../outputs/t2537
    exec diff ../outputs/t2537 ../golden/t2537 >/dev/null 2>&1 ;;
  p2538) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.209 > ../outputs/t2538
    exec diff ../outputs/t2538 ../golden/t2538 >/dev/null 2>&1 ;;
  p2539) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.21 > ../outputs/t2539
    exec diff ../outputs/t2539 ../golden/t2539 >/dev/null 2>&1 ;;
  p2540) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.210 > ../outputs/t2540
    exec diff ../outputs/t2540 ../golden/t2540 >/dev/null 2>&1 ;;
  p2541) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.213 > ../outputs/t2541
    exec diff ../outputs/t2541 ../golden/t2541 >/dev/null 2>&1 ;;
  p2542) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.214 > ../outputs/t2542
    exec diff ../outputs/t2542 ../golden/t2542 >/dev/null 2>&1 ;;
  p2543) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.215 > ../outputs/t2543
    exec diff ../outputs/t2543 ../golden/t2543 >/dev/null 2>&1 ;;
  p2544) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.22 > ../outputs/t2544
    exec diff ../outputs/t2544 ../golden/t2544 >/dev/null 2>&1 ;;
  p2545) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.225 > ../outputs/t2545
    exec diff ../outputs/t2545 ../golden/t2545 >/dev/null 2>&1 ;;
  p2546) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.226 > ../outputs/t2546
    exec diff ../outputs/t2546 ../golden/t2546 >/dev/null 2>&1 ;;
  p2547) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.230 > ../outputs/t2547
    exec diff ../outputs/t2547 ../golden/t2547 >/dev/null 2>&1 ;;
  p2548) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.233 > ../outputs/t2548
    exec diff ../outputs/t2548 ../golden/t2548 >/dev/null 2>&1 ;;
  p2549) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.234 > ../outputs/t2549
    exec diff ../outputs/t2549 ../golden/t2549 >/dev/null 2>&1 ;;
  p2550) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.237 > ../outputs/t2550
    exec diff ../outputs/t2550 ../golden/t2550 >/dev/null 2>&1 ;;
  p2551) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.238 > ../outputs/t2551
    exec diff ../outputs/t2551 ../golden/t2551 >/dev/null 2>&1 ;;
  p2552) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.239 > ../outputs/t2552
    exec diff ../outputs/t2552 ../golden/t2552 >/dev/null 2>&1 ;;
  p2553) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.243 > ../outputs/t2553
    exec diff ../outputs/t2553 ../golden/t2553 >/dev/null 2>&1 ;;
  p2554) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.244 > ../outputs/t2554
    exec diff ../outputs/t2554 ../golden/t2554 >/dev/null 2>&1 ;;
  p2555) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.245 > ../outputs/t2555
    exec diff ../outputs/t2555 ../golden/t2555 >/dev/null 2>&1 ;;
  p2556) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.246 > ../outputs/t2556
    exec diff ../outputs/t2556 ../golden/t2556 >/dev/null 2>&1 ;;
  p2557) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.247 > ../outputs/t2557
    exec diff ../outputs/t2557 ../golden/t2557 >/dev/null 2>&1 ;;
  p2558) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.248 > ../outputs/t2558
    exec diff ../outputs/t2558 ../golden/t2558 >/dev/null 2>&1 ;;
  p2559) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.249 > ../outputs/t2559
    exec diff ../outputs/t2559 ../golden/t2559 >/dev/null 2>&1 ;;
  p2560) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.25 > ../outputs/t2560
    exec diff ../outputs/t2560 ../golden/t2560 >/dev/null 2>&1 ;;
  p2561) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.251 > ../outputs/t2561
    exec diff ../outputs/t2561 ../golden/t2561 >/dev/null 2>&1 ;;
  p2562) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.252 > ../outputs/t2562
    exec diff ../outputs/t2562 ../golden/t2562 >/dev/null 2>&1 ;;
  p2563) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.254 > ../outputs/t2563
    exec diff ../outputs/t2563 ../golden/t2563 >/dev/null 2>&1 ;;
  p2564) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.256 > ../outputs/t2564
    exec diff ../outputs/t2564 ../golden/t2564 >/dev/null 2>&1 ;;
  p2565) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.257 > ../outputs/t2565
    exec diff ../outputs/t2565 ../golden/t2565 >/dev/null 2>&1 ;;
  p2566) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.258 > ../outputs/t2566
    exec diff ../outputs/t2566 ../golden/t2566 >/dev/null 2>&1 ;;
  p2567) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.260 > ../outputs/t2567
    exec diff ../outputs/t2567 ../golden/t2567 >/dev/null 2>&1 ;;
  p2568) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.266 > ../outputs/t2568
    exec diff ../outputs/t2568 ../golden/t2568 >/dev/null 2>&1 ;;
  p2569) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.267 > ../outputs/t2569
    exec diff ../outputs/t2569 ../golden/t2569 >/dev/null 2>&1 ;;
  p2570) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.268 > ../outputs/t2570
    exec diff ../outputs/t2570 ../golden/t2570 >/dev/null 2>&1 ;;
  p2571) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.27 > ../outputs/t2571
    exec diff ../outputs/t2571 ../golden/t2571 >/dev/null 2>&1 ;;
  p2572) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.270 > ../outputs/t2572
    exec diff ../outputs/t2572 ../golden/t2572 >/dev/null 2>&1 ;;
  p2573) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.271 > ../outputs/t2573
    exec diff ../outputs/t2573 ../golden/t2573 >/dev/null 2>&1 ;;
  p2574) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.272 > ../outputs/t2574
    exec diff ../outputs/t2574 ../golden/t2574 >/dev/null 2>&1 ;;
  p2575) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.275 > ../outputs/t2575
    exec diff ../outputs/t2575 ../golden/t2575 >/dev/null 2>&1 ;;
  p2576) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.276 > ../outputs/t2576
    exec diff ../outputs/t2576 ../golden/t2576 >/dev/null 2>&1 ;;
  p2577) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.277 > ../outputs/t2577
    exec diff ../outputs/t2577 ../golden/t2577 >/dev/null 2>&1 ;;
  p2578) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.28 > ../outputs/t2578
    exec diff ../outputs/t2578 ../golden/t2578 >/dev/null 2>&1 ;;
  p2579) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.280 > ../outputs/t2579
    exec diff ../outputs/t2579 ../golden/t2579 >/dev/null 2>&1 ;;
  p2580) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.281 > ../outputs/t2580
    exec diff ../outputs/t2580 ../golden/t2580 >/dev/null 2>&1 ;;
  p2581) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.282 > ../outputs/t2581
    exec diff ../outputs/t2581 ../golden/t2581 >/dev/null 2>&1 ;;
  p2582) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.283 > ../outputs/t2582
    exec diff ../outputs/t2582 ../golden/t2582 >/dev/null 2>&1 ;;
  p2583) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.286 > ../outputs/t2583
    exec diff ../outputs/t2583 ../golden/t2583 >/dev/null 2>&1 ;;
  p2584) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.289 > ../outputs/t2584
    exec diff ../outputs/t2584 ../golden/t2584 >/dev/null 2>&1 ;;
  p2585) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.294 > ../outputs/t2585
    exec diff ../outputs/t2585 ../golden/t2585 >/dev/null 2>&1 ;;
  p2586) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.295 > ../outputs/t2586
    exec diff ../outputs/t2586 ../golden/t2586 >/dev/null 2>&1 ;;
  p2587) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.296 > ../outputs/t2587
    exec diff ../outputs/t2587 ../golden/t2587 >/dev/null 2>&1 ;;
  p2588) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.297 > ../outputs/t2588
    exec diff ../outputs/t2588 ../golden/t2588 >/dev/null 2>&1 ;;
  p2589) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.298 > ../outputs/t2589
    exec diff ../outputs/t2589 ../golden/t2589 >/dev/null 2>&1 ;;
  p2590) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.299 > ../outputs/t2590
    exec diff ../outputs/t2590 ../golden/t2590 >/dev/null 2>&1 ;;
  p2591) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.30 > ../outputs/t2591
    exec diff ../outputs/t2591 ../golden/t2591 >/dev/null 2>&1 ;;
  p2592) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.302 > ../outputs/t2592
    exec diff ../outputs/t2592 ../golden/t2592 >/dev/null 2>&1 ;;
  p2593) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.305 > ../outputs/t2593
    exec diff ../outputs/t2593 ../golden/t2593 >/dev/null 2>&1 ;;
  p2594) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.306 > ../outputs/t2594
    exec diff ../outputs/t2594 ../golden/t2594 >/dev/null 2>&1 ;;
  p2595) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.307 > ../outputs/t2595
    exec diff ../outputs/t2595 ../golden/t2595 >/dev/null 2>&1 ;;
  p2596) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.31 > ../outputs/t2596
    exec diff ../outputs/t2596 ../golden/t2596 >/dev/null 2>&1 ;;
  p2597) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.311 > ../outputs/t2597
    exec diff ../outputs/t2597 ../golden/t2597 >/dev/null 2>&1 ;;
  p2598) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.318 > ../outputs/t2598
    exec diff ../outputs/t2598 ../golden/t2598 >/dev/null 2>&1 ;;
  p2599) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.319 > ../outputs/t2599
    exec diff ../outputs/t2599 ../golden/t2599 >/dev/null 2>&1 ;;
  p2600) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.320 > ../outputs/t2600
    exec diff ../outputs/t2600 ../golden/t2600 >/dev/null 2>&1 ;;
  p2601) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.321 > ../outputs/t2601
    exec diff ../outputs/t2601 ../golden/t2601 >/dev/null 2>&1 ;;
  p2602) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.322 > ../outputs/t2602
    exec diff ../outputs/t2602 ../golden/t2602 >/dev/null 2>&1 ;;
  p2603) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.323 > ../outputs/t2603
    exec diff ../outputs/t2603 ../golden/t2603 >/dev/null 2>&1 ;;
  p2604) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.325 > ../outputs/t2604
    exec diff ../outputs/t2604 ../golden/t2604 >/dev/null 2>&1 ;;
  p2605) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.327 > ../outputs/t2605
    exec diff ../outputs/t2605 ../golden/t2605 >/dev/null 2>&1 ;;
  p2606) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.329 > ../outputs/t2606
    exec diff ../outputs/t2606 ../golden/t2606 >/dev/null 2>&1 ;;
  p2607) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.33 > ../outputs/t2607
    exec diff ../outputs/t2607 ../golden/t2607 >/dev/null 2>&1 ;;
  p2608) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.330 > ../outputs/t2608
    exec diff ../outputs/t2608 ../golden/t2608 >/dev/null 2>&1 ;;
  p2609) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.333 > ../outputs/t2609
    exec diff ../outputs/t2609 ../golden/t2609 >/dev/null 2>&1 ;;
  p2610) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.335 > ../outputs/t2610
    exec diff ../outputs/t2610 ../golden/t2610 >/dev/null 2>&1 ;;
  p2611) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.337 > ../outputs/t2611
    exec diff ../outputs/t2611 ../golden/t2611 >/dev/null 2>&1 ;;
  p2612) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.339 > ../outputs/t2612
    exec diff ../outputs/t2612 ../golden/t2612 >/dev/null 2>&1 ;;
  p2613) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.34 > ../outputs/t2613
    exec diff ../outputs/t2613 ../golden/t2613 >/dev/null 2>&1 ;;
  p2614) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.340 > ../outputs/t2614
    exec diff ../outputs/t2614 ../golden/t2614 >/dev/null 2>&1 ;;
  p2615) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.343 > ../outputs/t2615
    exec diff ../outputs/t2615 ../golden/t2615 >/dev/null 2>&1 ;;
  p2616) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.344 > ../outputs/t2616
    exec diff ../outputs/t2616 ../golden/t2616 >/dev/null 2>&1 ;;
  p2617) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.345 > ../outputs/t2617
    exec diff ../outputs/t2617 ../golden/t2617 >/dev/null 2>&1 ;;
  p2618) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.348 > ../outputs/t2618
    exec diff ../outputs/t2618 ../golden/t2618 >/dev/null 2>&1 ;;
  p2619) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.349 > ../outputs/t2619
    exec diff ../outputs/t2619 ../golden/t2619 >/dev/null 2>&1 ;;
  p2620) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.350 > ../outputs/t2620
    exec diff ../outputs/t2620 ../golden/t2620 >/dev/null 2>&1 ;;
  p2621) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.352 > ../outputs/t2621
    exec diff ../outputs/t2621 ../golden/t2621 >/dev/null 2>&1 ;;
  p2622) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.353 > ../outputs/t2622
    exec diff ../outputs/t2622 ../golden/t2622 >/dev/null 2>&1 ;;
  p2623) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.355 > ../outputs/t2623
    exec diff ../outputs/t2623 ../golden/t2623 >/dev/null 2>&1 ;;
  p2624) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.36 > ../outputs/t2624
    exec diff ../outputs/t2624 ../golden/t2624 >/dev/null 2>&1 ;;
  p2625) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.360 > ../outputs/t2625
    exec diff ../outputs/t2625 ../golden/t2625 >/dev/null 2>&1 ;;
  p2626) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.362 > ../outputs/t2626
    exec diff ../outputs/t2626 ../golden/t2626 >/dev/null 2>&1 ;;
  p2627) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.363 > ../outputs/t2627
    exec diff ../outputs/t2627 ../golden/t2627 >/dev/null 2>&1 ;;
  p2628) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.367 > ../outputs/t2628
    exec diff ../outputs/t2628 ../golden/t2628 >/dev/null 2>&1 ;;
  p2629) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.369 > ../outputs/t2629
    exec diff ../outputs/t2629 ../golden/t2629 >/dev/null 2>&1 ;;
  p2630) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.37 > ../outputs/t2630
    exec diff ../outputs/t2630 ../golden/t2630 >/dev/null 2>&1 ;;
  p2631) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.377 > ../outputs/t2631
    exec diff ../outputs/t2631 ../golden/t2631 >/dev/null 2>&1 ;;
  p2632) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.378 > ../outputs/t2632
    exec diff ../outputs/t2632 ../golden/t2632 >/dev/null 2>&1 ;;
  p2633) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.379 > ../outputs/t2633
    exec diff ../outputs/t2633 ../golden/t2633 >/dev/null 2>&1 ;;
  p2634) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.380 > ../outputs/t2634
    exec diff ../outputs/t2634 ../golden/t2634 >/dev/null 2>&1 ;;
  p2635) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.383 > ../outputs/t2635
    exec diff ../outputs/t2635 ../golden/t2635 >/dev/null 2>&1 ;;
  p2636) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.386 > ../outputs/t2636
    exec diff ../outputs/t2636 ../golden/t2636 >/dev/null 2>&1 ;;
  p2637) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.387 > ../outputs/t2637
    exec diff ../outputs/t2637 ../golden/t2637 >/dev/null 2>&1 ;;
  p2638) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.388 > ../outputs/t2638
    exec diff ../outputs/t2638 ../golden/t2638 >/dev/null 2>&1 ;;
  p2639) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.392 > ../outputs/t2639
    exec diff ../outputs/t2639 ../golden/t2639 >/dev/null 2>&1 ;;
  p2640) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.395 > ../outputs/t2640
    exec diff ../outputs/t2640 ../golden/t2640 >/dev/null 2>&1 ;;
  p2641) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.396 > ../outputs/t2641
    exec diff ../outputs/t2641 ../golden/t2641 >/dev/null 2>&1 ;;
  p2642) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.398 > ../outputs/t2642
    exec diff ../outputs/t2642 ../golden/t2642 >/dev/null 2>&1 ;;
  p2643) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.4 > ../outputs/t2643
    exec diff ../outputs/t2643 ../golden/t2643 >/dev/null 2>&1 ;;
  p2644) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.40 > ../outputs/t2644
    exec diff ../outputs/t2644 ../golden/t2644 >/dev/null 2>&1 ;;
  p2645) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.402 > ../outputs/t2645
    exec diff ../outputs/t2645 ../golden/t2645 >/dev/null 2>&1 ;;
  p2646) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.407 > ../outputs/t2646
    exec diff ../outputs/t2646 ../golden/t2646 >/dev/null 2>&1 ;;
  p2647) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.41 > ../outputs/t2647
    exec diff ../outputs/t2647 ../golden/t2647 >/dev/null 2>&1 ;;
  p2648) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.412 > ../outputs/t2648
    exec diff ../outputs/t2648 ../golden/t2648 >/dev/null 2>&1 ;;
  p2649) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.413 > ../outputs/t2649
    exec diff ../outputs/t2649 ../golden/t2649 >/dev/null 2>&1 ;;
  p2650) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.415 > ../outputs/t2650
    exec diff ../outputs/t2650 ../golden/t2650 >/dev/null 2>&1 ;;
  p2651) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.418 > ../outputs/t2651
    exec diff ../outputs/t2651 ../golden/t2651 >/dev/null 2>&1 ;;
  p2652) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.419 > ../outputs/t2652
    exec diff ../outputs/t2652 ../golden/t2652 >/dev/null 2>&1 ;;
  p2653) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.42 > ../outputs/t2653
    exec diff ../outputs/t2653 ../golden/t2653 >/dev/null 2>&1 ;;
  p2654) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.421 > ../outputs/t2654
    exec diff ../outputs/t2654 ../golden/t2654 >/dev/null 2>&1 ;;
  p2655) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.423 > ../outputs/t2655
    exec diff ../outputs/t2655 ../golden/t2655 >/dev/null 2>&1 ;;
  p2656) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.424 > ../outputs/t2656
    exec diff ../outputs/t2656 ../golden/t2656 >/dev/null 2>&1 ;;
  p2657) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.425 > ../outputs/t2657
    exec diff ../outputs/t2657 ../golden/t2657 >/dev/null 2>&1 ;;
  p2658) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.428 > ../outputs/t2658
    exec diff ../outputs/t2658 ../golden/t2658 >/dev/null 2>&1 ;;
  p2659) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.430 > ../outputs/t2659
    exec diff ../outputs/t2659 ../golden/t2659 >/dev/null 2>&1 ;;
  p2660) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.432 > ../outputs/t2660
    exec diff ../outputs/t2660 ../golden/t2660 >/dev/null 2>&1 ;;
  p2661) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.433 > ../outputs/t2661
    exec diff ../outputs/t2661 ../golden/t2661 >/dev/null 2>&1 ;;
  p2662) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.434 > ../outputs/t2662
    exec diff ../outputs/t2662 ../golden/t2662 >/dev/null 2>&1 ;;
  p2663) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.435 > ../outputs/t2663
    exec diff ../outputs/t2663 ../golden/t2663 >/dev/null 2>&1 ;;
  p2664) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.436 > ../outputs/t2664
    exec diff ../outputs/t2664 ../golden/t2664 >/dev/null 2>&1 ;;
  p2665) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.438 > ../outputs/t2665
    exec diff ../outputs/t2665 ../golden/t2665 >/dev/null 2>&1 ;;
  p2666) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.441 > ../outputs/t2666
    exec diff ../outputs/t2666 ../golden/t2666 >/dev/null 2>&1 ;;
  p2667) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.442 > ../outputs/t2667
    exec diff ../outputs/t2667 ../golden/t2667 >/dev/null 2>&1 ;;
  p2668) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.447 > ../outputs/t2668
    exec diff ../outputs/t2668 ../golden/t2668 >/dev/null 2>&1 ;;
  p2669) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.448 > ../outputs/t2669
    exec diff ../outputs/t2669 ../golden/t2669 >/dev/null 2>&1 ;;
  p2670) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.449 > ../outputs/t2670
    exec diff ../outputs/t2670 ../golden/t2670 >/dev/null 2>&1 ;;
  p2671) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.450 > ../outputs/t2671
    exec diff ../outputs/t2671 ../golden/t2671 >/dev/null 2>&1 ;;
  p2672) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.451 > ../outputs/t2672
    exec diff ../outputs/t2672 ../golden/t2672 >/dev/null 2>&1 ;;
  p2673) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.455 > ../outputs/t2673
    exec diff ../outputs/t2673 ../golden/t2673 >/dev/null 2>&1 ;;
  p2674) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.456 > ../outputs/t2674
    exec diff ../outputs/t2674 ../golden/t2674 >/dev/null 2>&1 ;;
  p2675) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.457 > ../outputs/t2675
    exec diff ../outputs/t2675 ../golden/t2675 >/dev/null 2>&1 ;;
  p2676) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.459 > ../outputs/t2676
    exec diff ../outputs/t2676 ../golden/t2676 >/dev/null 2>&1 ;;
  p2677) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.462 > ../outputs/t2677
    exec diff ../outputs/t2677 ../golden/t2677 >/dev/null 2>&1 ;;
  p2678) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.463 > ../outputs/t2678
    exec diff ../outputs/t2678 ../golden/t2678 >/dev/null 2>&1 ;;
  p2679) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.467 > ../outputs/t2679
    exec diff ../outputs/t2679 ../golden/t2679 >/dev/null 2>&1 ;;
  p2680) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.468 > ../outputs/t2680
    exec diff ../outputs/t2680 ../golden/t2680 >/dev/null 2>&1 ;;
  p2681) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.469 > ../outputs/t2681
    exec diff ../outputs/t2681 ../golden/t2681 >/dev/null 2>&1 ;;
  p2682) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.47 > ../outputs/t2682
    exec diff ../outputs/t2682 ../golden/t2682 >/dev/null 2>&1 ;;
  p2683) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.475 > ../outputs/t2683
    exec diff ../outputs/t2683 ../golden/t2683 >/dev/null 2>&1 ;;
  p2684) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.476 > ../outputs/t2684
    exec diff ../outputs/t2684 ../golden/t2684 >/dev/null 2>&1 ;;
  p2685) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.477 > ../outputs/t2685
    exec diff ../outputs/t2685 ../golden/t2685 >/dev/null 2>&1 ;;
  p2686) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.479 > ../outputs/t2686
    exec diff ../outputs/t2686 ../golden/t2686 >/dev/null 2>&1 ;;
  p2687) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.48 > ../outputs/t2687
    exec diff ../outputs/t2687 ../golden/t2687 >/dev/null 2>&1 ;;
  p2688) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.480 > ../outputs/t2688
    exec diff ../outputs/t2688 ../golden/t2688 >/dev/null 2>&1 ;;
  p2689) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.483 > ../outputs/t2689
    exec diff ../outputs/t2689 ../golden/t2689 >/dev/null 2>&1 ;;
  p2690) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.487 > ../outputs/t2690
    exec diff ../outputs/t2690 ../golden/t2690 >/dev/null 2>&1 ;;
  p2691) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.489 > ../outputs/t2691
    exec diff ../outputs/t2691 ../golden/t2691 >/dev/null 2>&1 ;;
  p2692) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.493 > ../outputs/t2692
    exec diff ../outputs/t2692 ../golden/t2692 >/dev/null 2>&1 ;;
  p2693) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.494 > ../outputs/t2693
    exec diff ../outputs/t2693 ../golden/t2693 >/dev/null 2>&1 ;;
  p2694) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.496 > ../outputs/t2694
    exec diff ../outputs/t2694 ../golden/t2694 >/dev/null 2>&1 ;;
  p2695) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.50 > ../outputs/t2695
    exec diff ../outputs/t2695 ../golden/t2695 >/dev/null 2>&1 ;;
  p2696) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.502 > ../outputs/t2696
    exec diff ../outputs/t2696 ../golden/t2696 >/dev/null 2>&1 ;;
  p2697) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.504 > ../outputs/t2697
    exec diff ../outputs/t2697 ../golden/t2697 >/dev/null 2>&1 ;;
  p2698) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.506 > ../outputs/t2698
    exec diff ../outputs/t2698 ../golden/t2698 >/dev/null 2>&1 ;;
  p2699) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.507 > ../outputs/t2699
    exec diff ../outputs/t2699 ../golden/t2699 >/dev/null 2>&1 ;;
  p2700) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.510 > ../outputs/t2700
    exec diff ../outputs/t2700 ../golden/t2700 >/dev/null 2>&1 ;;
  p2701) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.511 > ../outputs/t2701
    exec diff ../outputs/t2701 ../golden/t2701 >/dev/null 2>&1 ;;
  p2702) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.512 > ../outputs/t2702
    exec diff ../outputs/t2702 ../golden/t2702 >/dev/null 2>&1 ;;
  p2703) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.513 > ../outputs/t2703
    exec diff ../outputs/t2703 ../golden/t2703 >/dev/null 2>&1 ;;
  p2704) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.514 > ../outputs/t2704
    exec diff ../outputs/t2704 ../golden/t2704 >/dev/null 2>&1 ;;
  p2705) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.515 > ../outputs/t2705
    exec diff ../outputs/t2705 ../golden/t2705 >/dev/null 2>&1 ;;
  p2706) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.518 > ../outputs/t2706
    exec diff ../outputs/t2706 ../golden/t2706 >/dev/null 2>&1 ;;
  p2707) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.519 > ../outputs/t2707
    exec diff ../outputs/t2707 ../golden/t2707 >/dev/null 2>&1 ;;
  p2708) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.52 > ../outputs/t2708
    exec diff ../outputs/t2708 ../golden/t2708 >/dev/null 2>&1 ;;
  p2709) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.520 > ../outputs/t2709
    exec diff ../outputs/t2709 ../golden/t2709 >/dev/null 2>&1 ;;
  p2710) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.522 > ../outputs/t2710
    exec diff ../outputs/t2710 ../golden/t2710 >/dev/null 2>&1 ;;
  p2711) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.525 > ../outputs/t2711
    exec diff ../outputs/t2711 ../golden/t2711 >/dev/null 2>&1 ;;
  p2712) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.526 > ../outputs/t2712
    exec diff ../outputs/t2712 ../golden/t2712 >/dev/null 2>&1 ;;
  p2713) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.527 > ../outputs/t2713
    exec diff ../outputs/t2713 ../golden/t2713 >/dev/null 2>&1 ;;
  p2714) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.528 > ../outputs/t2714
    exec diff ../outputs/t2714 ../golden/t2714 >/dev/null 2>&1 ;;
  p2715) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.533 > ../outputs/t2715
    exec diff ../outputs/t2715 ../golden/t2715 >/dev/null 2>&1 ;;
  p2716) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.534 > ../outputs/t2716
    exec diff ../outputs/t2716 ../golden/t2716 >/dev/null 2>&1 ;;
  p2717) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.537 > ../outputs/t2717
    exec diff ../outputs/t2717 ../golden/t2717 >/dev/null 2>&1 ;;
  p2718) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.538 > ../outputs/t2718
    exec diff ../outputs/t2718 ../golden/t2718 >/dev/null 2>&1 ;;
  p2719) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.539 > ../outputs/t2719
    exec diff ../outputs/t2719 ../golden/t2719 >/dev/null 2>&1 ;;
  p2720) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.54 > ../outputs/t2720
    exec diff ../outputs/t2720 ../golden/t2720 >/dev/null 2>&1 ;;
  p2721) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.540 > ../outputs/t2721
    exec diff ../outputs/t2721 ../golden/t2721 >/dev/null 2>&1 ;;
  p2722) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.543 > ../outputs/t2722
    exec diff ../outputs/t2722 ../golden/t2722 >/dev/null 2>&1 ;;
  p2723) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.544 > ../outputs/t2723
    exec diff ../outputs/t2723 ../golden/t2723 >/dev/null 2>&1 ;;
  p2724) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.552 > ../outputs/t2724
    exec diff ../outputs/t2724 ../golden/t2724 >/dev/null 2>&1 ;;
  p2725) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.553 > ../outputs/t2725
    exec diff ../outputs/t2725 ../golden/t2725 >/dev/null 2>&1 ;;
  p2726) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.558 > ../outputs/t2726
    exec diff ../outputs/t2726 ../golden/t2726 >/dev/null 2>&1 ;;
  p2727) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.562 > ../outputs/t2727
    exec diff ../outputs/t2727 ../golden/t2727 >/dev/null 2>&1 ;;
  p2728) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.566 > ../outputs/t2728
    exec diff ../outputs/t2728 ../golden/t2728 >/dev/null 2>&1 ;;
  p2729) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.568 > ../outputs/t2729
    exec diff ../outputs/t2729 ../golden/t2729 >/dev/null 2>&1 ;;
  p2730) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.569 > ../outputs/t2730
    exec diff ../outputs/t2730 ../golden/t2730 >/dev/null 2>&1 ;;
  p2731) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.570 > ../outputs/t2731
    exec diff ../outputs/t2731 ../golden/t2731 >/dev/null 2>&1 ;;
  p2732) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.571 > ../outputs/t2732
    exec diff ../outputs/t2732 ../golden/t2732 >/dev/null 2>&1 ;;
  p2733) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.572 > ../outputs/t2733
    exec diff ../outputs/t2733 ../golden/t2733 >/dev/null 2>&1 ;;
  p2734) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.573 > ../outputs/t2734
    exec diff ../outputs/t2734 ../golden/t2734 >/dev/null 2>&1 ;;
  p2735) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.574 > ../outputs/t2735
    exec diff ../outputs/t2735 ../golden/t2735 >/dev/null 2>&1 ;;
  p2736) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.576 > ../outputs/t2736
    exec diff ../outputs/t2736 ../golden/t2736 >/dev/null 2>&1 ;;
  p2737) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.577 > ../outputs/t2737
    exec diff ../outputs/t2737 ../golden/t2737 >/dev/null 2>&1 ;;
  p2738) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.579 > ../outputs/t2738
    exec diff ../outputs/t2738 ../golden/t2738 >/dev/null 2>&1 ;;
  p2739) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.58 > ../outputs/t2739
    exec diff ../outputs/t2739 ../golden/t2739 >/dev/null 2>&1 ;;
  p2740) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.580 > ../outputs/t2740
    exec diff ../outputs/t2740 ../golden/t2740 >/dev/null 2>&1 ;;
  p2741) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.581 > ../outputs/t2741
    exec diff ../outputs/t2741 ../golden/t2741 >/dev/null 2>&1 ;;
  p2742) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.582 > ../outputs/t2742
    exec diff ../outputs/t2742 ../golden/t2742 >/dev/null 2>&1 ;;
  p2743) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.583 > ../outputs/t2743
    exec diff ../outputs/t2743 ../golden/t2743 >/dev/null 2>&1 ;;
  p2744) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.584 > ../outputs/t2744
    exec diff ../outputs/t2744 ../golden/t2744 >/dev/null 2>&1 ;;
  p2745) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.585 > ../outputs/t2745
    exec diff ../outputs/t2745 ../golden/t2745 >/dev/null 2>&1 ;;
  p2746) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.586 > ../outputs/t2746
    exec diff ../outputs/t2746 ../golden/t2746 >/dev/null 2>&1 ;;
  p2747) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.592 > ../outputs/t2747
    exec diff ../outputs/t2747 ../golden/t2747 >/dev/null 2>&1 ;;
  p2748) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.593 > ../outputs/t2748
    exec diff ../outputs/t2748 ../golden/t2748 >/dev/null 2>&1 ;;
  p2749) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.594 > ../outputs/t2749
    exec diff ../outputs/t2749 ../golden/t2749 >/dev/null 2>&1 ;;
  p2750) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.596 > ../outputs/t2750
    exec diff ../outputs/t2750 ../golden/t2750 >/dev/null 2>&1 ;;
  p2751) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.597 > ../outputs/t2751
    exec diff ../outputs/t2751 ../golden/t2751 >/dev/null 2>&1 ;;
  p2752) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.598 > ../outputs/t2752
    exec diff ../outputs/t2752 ../golden/t2752 >/dev/null 2>&1 ;;
  p2753) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.60 > ../outputs/t2753
    exec diff ../outputs/t2753 ../golden/t2753 >/dev/null 2>&1 ;;
  p2754) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.602 > ../outputs/t2754
    exec diff ../outputs/t2754 ../golden/t2754 >/dev/null 2>&1 ;;
  p2755) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.605 > ../outputs/t2755
    exec diff ../outputs/t2755 ../golden/t2755 >/dev/null 2>&1 ;;
  p2756) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.607 > ../outputs/t2756
    exec diff ../outputs/t2756 ../golden/t2756 >/dev/null 2>&1 ;;
  p2757) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.611 > ../outputs/t2757
    exec diff ../outputs/t2757 ../golden/t2757 >/dev/null 2>&1 ;;
  p2758) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.614 > ../outputs/t2758
    exec diff ../outputs/t2758 ../golden/t2758 >/dev/null 2>&1 ;;
  p2759) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.615 > ../outputs/t2759
    exec diff ../outputs/t2759 ../golden/t2759 >/dev/null 2>&1 ;;
  p2760) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.616 > ../outputs/t2760
    exec diff ../outputs/t2760 ../golden/t2760 >/dev/null 2>&1 ;;
  p2761) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.617 > ../outputs/t2761
    exec diff ../outputs/t2761 ../golden/t2761 >/dev/null 2>&1 ;;
  p2762) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.619 > ../outputs/t2762
    exec diff ../outputs/t2762 ../golden/t2762 >/dev/null 2>&1 ;;
  p2763) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.62 > ../outputs/t2763
    exec diff ../outputs/t2763 ../golden/t2763 >/dev/null 2>&1 ;;
  p2764) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.621 > ../outputs/t2764
    exec diff ../outputs/t2764 ../golden/t2764 >/dev/null 2>&1 ;;
  p2765) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.623 > ../outputs/t2765
    exec diff ../outputs/t2765 ../golden/t2765 >/dev/null 2>&1 ;;
  p2766) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.624 > ../outputs/t2766
    exec diff ../outputs/t2766 ../golden/t2766 >/dev/null 2>&1 ;;
  p2767) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.625 > ../outputs/t2767
    exec diff ../outputs/t2767 ../golden/t2767 >/dev/null 2>&1 ;;
  p2768) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.626 > ../outputs/t2768
    exec diff ../outputs/t2768 ../golden/t2768 >/dev/null 2>&1 ;;
  p2769) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.627 > ../outputs/t2769
    exec diff ../outputs/t2769 ../golden/t2769 >/dev/null 2>&1 ;;
  p2770) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.63 > ../outputs/t2770
    exec diff ../outputs/t2770 ../golden/t2770 >/dev/null 2>&1 ;;
  p2771) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.630 > ../outputs/t2771
    exec diff ../outputs/t2771 ../golden/t2771 >/dev/null 2>&1 ;;
  p2772) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.633 > ../outputs/t2772
    exec diff ../outputs/t2772 ../golden/t2772 >/dev/null 2>&1 ;;
  p2773) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.636 > ../outputs/t2773
    exec diff ../outputs/t2773 ../golden/t2773 >/dev/null 2>&1 ;;
  p2774) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.64 > ../outputs/t2774
    exec diff ../outputs/t2774 ../golden/t2774 >/dev/null 2>&1 ;;
  p2775) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.640 > ../outputs/t2775
    exec diff ../outputs/t2775 ../golden/t2775 >/dev/null 2>&1 ;;
  p2776) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.642 > ../outputs/t2776
    exec diff ../outputs/t2776 ../golden/t2776 >/dev/null 2>&1 ;;
  p2777) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.647 > ../outputs/t2777
    exec diff ../outputs/t2777 ../golden/t2777 >/dev/null 2>&1 ;;
  p2778) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.648 > ../outputs/t2778
    exec diff ../outputs/t2778 ../golden/t2778 >/dev/null 2>&1 ;;
  p2779) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.655 > ../outputs/t2779
    exec diff ../outputs/t2779 ../golden/t2779 >/dev/null 2>&1 ;;
  p2780) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.656 > ../outputs/t2780
    exec diff ../outputs/t2780 ../golden/t2780 >/dev/null 2>&1 ;;
  p2781) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.659 > ../outputs/t2781
    exec diff ../outputs/t2781 ../golden/t2781 >/dev/null 2>&1 ;;
  p2782) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.662 > ../outputs/t2782
    exec diff ../outputs/t2782 ../golden/t2782 >/dev/null 2>&1 ;;
  p2783) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.663 > ../outputs/t2783
    exec diff ../outputs/t2783 ../golden/t2783 >/dev/null 2>&1 ;;
  p2784) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.665 > ../outputs/t2784
    exec diff ../outputs/t2784 ../golden/t2784 >/dev/null 2>&1 ;;
  p2785) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.668 > ../outputs/t2785
    exec diff ../outputs/t2785 ../golden/t2785 >/dev/null 2>&1 ;;
  p2786) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.669 > ../outputs/t2786
    exec diff ../outputs/t2786 ../golden/t2786 >/dev/null 2>&1 ;;
  p2787) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.67 > ../outputs/t2787
    exec diff ../outputs/t2787 ../golden/t2787 >/dev/null 2>&1 ;;
  p2788) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.670 > ../outputs/t2788
    exec diff ../outputs/t2788 ../golden/t2788 >/dev/null 2>&1 ;;
  p2789) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.673 > ../outputs/t2789
    exec diff ../outputs/t2789 ../golden/t2789 >/dev/null 2>&1 ;;
  p2790) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.674 > ../outputs/t2790
    exec diff ../outputs/t2790 ../golden/t2790 >/dev/null 2>&1 ;;
  p2791) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.676 > ../outputs/t2791
    exec diff ../outputs/t2791 ../golden/t2791 >/dev/null 2>&1 ;;
  p2792) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.677 > ../outputs/t2792
    exec diff ../outputs/t2792 ../golden/t2792 >/dev/null 2>&1 ;;
  p2793) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.679 > ../outputs/t2793
    exec diff ../outputs/t2793 ../golden/t2793 >/dev/null 2>&1 ;;
  p2794) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.68 > ../outputs/t2794
    exec diff ../outputs/t2794 ../golden/t2794 >/dev/null 2>&1 ;;
  p2795) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.680 > ../outputs/t2795
    exec diff ../outputs/t2795 ../golden/t2795 >/dev/null 2>&1 ;;
  p2796) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.682 > ../outputs/t2796
    exec diff ../outputs/t2796 ../golden/t2796 >/dev/null 2>&1 ;;
  p2797) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.686 > ../outputs/t2797
    exec diff ../outputs/t2797 ../golden/t2797 >/dev/null 2>&1 ;;
  p2798) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.691 > ../outputs/t2798
    exec diff ../outputs/t2798 ../golden/t2798 >/dev/null 2>&1 ;;
  p2799) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.695 > ../outputs/t2799
    exec diff ../outputs/t2799 ../golden/t2799 >/dev/null 2>&1 ;;
  p2800) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.70 > ../outputs/t2800
    exec diff ../outputs/t2800 ../golden/t2800 >/dev/null 2>&1 ;;
  p2801) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.701 > ../outputs/t2801
    exec diff ../outputs/t2801 ../golden/t2801 >/dev/null 2>&1 ;;
  p2802) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.704 > ../outputs/t2802
    exec diff ../outputs/t2802 ../golden/t2802 >/dev/null 2>&1 ;;
  p2803) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.706 > ../outputs/t2803
    exec diff ../outputs/t2803 ../golden/t2803 >/dev/null 2>&1 ;;
  p2804) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.708 > ../outputs/t2804
    exec diff ../outputs/t2804 ../golden/t2804 >/dev/null 2>&1 ;;
  p2805) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.709 > ../outputs/t2805
    exec diff ../outputs/t2805 ../golden/t2805 >/dev/null 2>&1 ;;
  p2806) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.71 > ../outputs/t2806
    exec diff ../outputs/t2806 ../golden/t2806 >/dev/null 2>&1 ;;
  p2807) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.712 > ../outputs/t2807
    exec diff ../outputs/t2807 ../golden/t2807 >/dev/null 2>&1 ;;
  p2808) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.713 > ../outputs/t2808
    exec diff ../outputs/t2808 ../golden/t2808 >/dev/null 2>&1 ;;
  p2809) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.716 > ../outputs/t2809
    exec diff ../outputs/t2809 ../golden/t2809 >/dev/null 2>&1 ;;
  p2810) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.717 > ../outputs/t2810
    exec diff ../outputs/t2810 ../golden/t2810 >/dev/null 2>&1 ;;
  p2811) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.719 > ../outputs/t2811
    exec diff ../outputs/t2811 ../golden/t2811 >/dev/null 2>&1 ;;
  p2812) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.72 > ../outputs/t2812
    exec diff ../outputs/t2812 ../golden/t2812 >/dev/null 2>&1 ;;
  p2813) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.721 > ../outputs/t2813
    exec diff ../outputs/t2813 ../golden/t2813 >/dev/null 2>&1 ;;
  p2814) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.723 > ../outputs/t2814
    exec diff ../outputs/t2814 ../golden/t2814 >/dev/null 2>&1 ;;
  p2815) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.727 > ../outputs/t2815
    exec diff ../outputs/t2815 ../golden/t2815 >/dev/null 2>&1 ;;
  p2816) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.728 > ../outputs/t2816
    exec diff ../outputs/t2816 ../golden/t2816 >/dev/null 2>&1 ;;
  p2817) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.734 > ../outputs/t2817
    exec diff ../outputs/t2817 ../golden/t2817 >/dev/null 2>&1 ;;
  p2818) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.736 > ../outputs/t2818
    exec diff ../outputs/t2818 ../golden/t2818 >/dev/null 2>&1 ;;
  p2819) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.738 > ../outputs/t2819
    exec diff ../outputs/t2819 ../golden/t2819 >/dev/null 2>&1 ;;
  p2820) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.74 > ../outputs/t2820
    exec diff ../outputs/t2820 ../golden/t2820 >/dev/null 2>&1 ;;
  p2821) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.742 > ../outputs/t2821
    exec diff ../outputs/t2821 ../golden/t2821 >/dev/null 2>&1 ;;
  p2822) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.744 > ../outputs/t2822
    exec diff ../outputs/t2822 ../golden/t2822 >/dev/null 2>&1 ;;
  p2823) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.746 > ../outputs/t2823
    exec diff ../outputs/t2823 ../golden/t2823 >/dev/null 2>&1 ;;
  p2824) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.747 > ../outputs/t2824
    exec diff ../outputs/t2824 ../golden/t2824 >/dev/null 2>&1 ;;
  p2825) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.748 > ../outputs/t2825
    exec diff ../outputs/t2825 ../golden/t2825 >/dev/null 2>&1 ;;
  p2826) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.75 > ../outputs/t2826
    exec diff ../outputs/t2826 ../golden/t2826 >/dev/null 2>&1 ;;
  p2827) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.751 > ../outputs/t2827
    exec diff ../outputs/t2827 ../golden/t2827 >/dev/null 2>&1 ;;
  p2828) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.752 > ../outputs/t2828
    exec diff ../outputs/t2828 ../golden/t2828 >/dev/null 2>&1 ;;
  p2829) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.753 > ../outputs/t2829
    exec diff ../outputs/t2829 ../golden/t2829 >/dev/null 2>&1 ;;
  p2830) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.756 > ../outputs/t2830
    exec diff ../outputs/t2830 ../golden/t2830 >/dev/null 2>&1 ;;
  p2831) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.758 > ../outputs/t2831
    exec diff ../outputs/t2831 ../golden/t2831 >/dev/null 2>&1 ;;
  p2832) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.76 > ../outputs/t2832
    exec diff ../outputs/t2832 ../golden/t2832 >/dev/null 2>&1 ;;
  p2833) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.760 > ../outputs/t2833
    exec diff ../outputs/t2833 ../golden/t2833 >/dev/null 2>&1 ;;
  p2834) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.761 > ../outputs/t2834
    exec diff ../outputs/t2834 ../golden/t2834 >/dev/null 2>&1 ;;
  p2835) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.765 > ../outputs/t2835
    exec diff ../outputs/t2835 ../golden/t2835 >/dev/null 2>&1 ;;
  p2836) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.766 > ../outputs/t2836
    exec diff ../outputs/t2836 ../golden/t2836 >/dev/null 2>&1 ;;
  p2837) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.767 > ../outputs/t2837
    exec diff ../outputs/t2837 ../golden/t2837 >/dev/null 2>&1 ;;
  p2838) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.768 > ../outputs/t2838
    exec diff ../outputs/t2838 ../golden/t2838 >/dev/null 2>&1 ;;
  p2839) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.769 > ../outputs/t2839
    exec diff ../outputs/t2839 ../golden/t2839 >/dev/null 2>&1 ;;
  p2840) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.77 > ../outputs/t2840
    exec diff ../outputs/t2840 ../golden/t2840 >/dev/null 2>&1 ;;
  p2841) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.772 > ../outputs/t2841
    exec diff ../outputs/t2841 ../golden/t2841 >/dev/null 2>&1 ;;
  p2842) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.773 > ../outputs/t2842
    exec diff ../outputs/t2842 ../golden/t2842 >/dev/null 2>&1 ;;
  p2843) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.775 > ../outputs/t2843
    exec diff ../outputs/t2843 ../golden/t2843 >/dev/null 2>&1 ;;
  p2844) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.776 > ../outputs/t2844
    exec diff ../outputs/t2844 ../golden/t2844 >/dev/null 2>&1 ;;
  p2845) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.777 > ../outputs/t2845
    exec diff ../outputs/t2845 ../golden/t2845 >/dev/null 2>&1 ;;
  p2846) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.778 > ../outputs/t2846
    exec diff ../outputs/t2846 ../golden/t2846 >/dev/null 2>&1 ;;
  p2847) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.779 > ../outputs/t2847
    exec diff ../outputs/t2847 ../golden/t2847 >/dev/null 2>&1 ;;
  p2848) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.78 > ../outputs/t2848
    exec diff ../outputs/t2848 ../golden/t2848 >/dev/null 2>&1 ;;
  p2849) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.781 > ../outputs/t2849
    exec diff ../outputs/t2849 ../golden/t2849 >/dev/null 2>&1 ;;
  p2850) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.784 > ../outputs/t2850
    exec diff ../outputs/t2850 ../golden/t2850 >/dev/null 2>&1 ;;
  p2851) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.786 > ../outputs/t2851
    exec diff ../outputs/t2851 ../golden/t2851 >/dev/null 2>&1 ;;
  p2852) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.787 > ../outputs/t2852
    exec diff ../outputs/t2852 ../golden/t2852 >/dev/null 2>&1 ;;
  p2853) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.788 > ../outputs/t2853
    exec diff ../outputs/t2853 ../golden/t2853 >/dev/null 2>&1 ;;
  p2854) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.789 > ../outputs/t2854
    exec diff ../outputs/t2854 ../golden/t2854 >/dev/null 2>&1 ;;
  p2855) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.79 > ../outputs/t2855
    exec diff ../outputs/t2855 ../golden/t2855 >/dev/null 2>&1 ;;
  p2856) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.790 > ../outputs/t2856
    exec diff ../outputs/t2856 ../golden/t2856 >/dev/null 2>&1 ;;
  p2857) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.791 > ../outputs/t2857
    exec diff ../outputs/t2857 ../golden/t2857 >/dev/null 2>&1 ;;
  p2858) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.793 > ../outputs/t2858
    exec diff ../outputs/t2858 ../golden/t2858 >/dev/null 2>&1 ;;
  p2859) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.798 > ../outputs/t2859
    exec diff ../outputs/t2859 ../golden/t2859 >/dev/null 2>&1 ;;
  p2860) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.80 > ../outputs/t2860
    exec diff ../outputs/t2860 ../golden/t2860 >/dev/null 2>&1 ;;
  p2861) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.803 > ../outputs/t2861
    exec diff ../outputs/t2861 ../golden/t2861 >/dev/null 2>&1 ;;
  p2862) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.807 > ../outputs/t2862
    exec diff ../outputs/t2862 ../golden/t2862 >/dev/null 2>&1 ;;
  p2863) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.808 > ../outputs/t2863
    exec diff ../outputs/t2863 ../golden/t2863 >/dev/null 2>&1 ;;
  p2864) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.811 > ../outputs/t2864
    exec diff ../outputs/t2864 ../golden/t2864 >/dev/null 2>&1 ;;
  p2865) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.814 > ../outputs/t2865
    exec diff ../outputs/t2865 ../golden/t2865 >/dev/null 2>&1 ;;
  p2866) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.816 > ../outputs/t2866
    exec diff ../outputs/t2866 ../golden/t2866 >/dev/null 2>&1 ;;
  p2867) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.818 > ../outputs/t2867
    exec diff ../outputs/t2867 ../golden/t2867 >/dev/null 2>&1 ;;
  p2868) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.82 > ../outputs/t2868
    exec diff ../outputs/t2868 ../golden/t2868 >/dev/null 2>&1 ;;
  p2869) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.821 > ../outputs/t2869
    exec diff ../outputs/t2869 ../golden/t2869 >/dev/null 2>&1 ;;
  p2870) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.823 > ../outputs/t2870
    exec diff ../outputs/t2870 ../golden/t2870 >/dev/null 2>&1 ;;
  p2871) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.825 > ../outputs/t2871
    exec diff ../outputs/t2871 ../golden/t2871 >/dev/null 2>&1 ;;
  p2872) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.828 > ../outputs/t2872
    exec diff ../outputs/t2872 ../golden/t2872 >/dev/null 2>&1 ;;
  p2873) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.829 > ../outputs/t2873
    exec diff ../outputs/t2873 ../golden/t2873 >/dev/null 2>&1 ;;
  p2874) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.83 > ../outputs/t2874
    exec diff ../outputs/t2874 ../golden/t2874 >/dev/null 2>&1 ;;
  p2875) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.831 > ../outputs/t2875
    exec diff ../outputs/t2875 ../golden/t2875 >/dev/null 2>&1 ;;
  p2876) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.832 > ../outputs/t2876
    exec diff ../outputs/t2876 ../golden/t2876 >/dev/null 2>&1 ;;
  p2877) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.834 > ../outputs/t2877
    exec diff ../outputs/t2877 ../golden/t2877 >/dev/null 2>&1 ;;
  p2878) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.836 > ../outputs/t2878
    exec diff ../outputs/t2878 ../golden/t2878 >/dev/null 2>&1 ;;
  p2879) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.837 > ../outputs/t2879
    exec diff ../outputs/t2879 ../golden/t2879 >/dev/null 2>&1 ;;
  p2880) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.840 > ../outputs/t2880
    exec diff ../outputs/t2880 ../golden/t2880 >/dev/null 2>&1 ;;
  p2881) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.843 > ../outputs/t2881
    exec diff ../outputs/t2881 ../golden/t2881 >/dev/null 2>&1 ;;
  p2882) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.85 > ../outputs/t2882
    exec diff ../outputs/t2882 ../golden/t2882 >/dev/null 2>&1 ;;
  p2883) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.851 > ../outputs/t2883
    exec diff ../outputs/t2883 ../golden/t2883 >/dev/null 2>&1 ;;
  p2884) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.855 > ../outputs/t2884
    exec diff ../outputs/t2884 ../golden/t2884 >/dev/null 2>&1 ;;
  p2885) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.858 > ../outputs/t2885
    exec diff ../outputs/t2885 ../golden/t2885 >/dev/null 2>&1 ;;
  p2886) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.860 > ../outputs/t2886
    exec diff ../outputs/t2886 ../golden/t2886 >/dev/null 2>&1 ;;
  p2887) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.862 > ../outputs/t2887
    exec diff ../outputs/t2887 ../golden/t2887 >/dev/null 2>&1 ;;
  p2888) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.864 > ../outputs/t2888
    exec diff ../outputs/t2888 ../golden/t2888 >/dev/null 2>&1 ;;
  p2889) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.865 > ../outputs/t2889
    exec diff ../outputs/t2889 ../golden/t2889 >/dev/null 2>&1 ;;
  p2890) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.866 > ../outputs/t2890
    exec diff ../outputs/t2890 ../golden/t2890 >/dev/null 2>&1 ;;
  p2891) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.87 > ../outputs/t2891
    exec diff ../outputs/t2891 ../golden/t2891 >/dev/null 2>&1 ;;
  p2892) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.871 > ../outputs/t2892
    exec diff ../outputs/t2892 ../golden/t2892 >/dev/null 2>&1 ;;
  p2893) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.88 > ../outputs/t2893
    exec diff ../outputs/t2893 ../golden/t2893 >/dev/null 2>&1 ;;
  p2894) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.880 > ../outputs/t2894
    exec diff ../outputs/t2894 ../golden/t2894 >/dev/null 2>&1 ;;
  p2895) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.888 > ../outputs/t2895
    exec diff ../outputs/t2895 ../golden/t2895 >/dev/null 2>&1 ;;
  p2896) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.89 > ../outputs/t2896
    exec diff ../outputs/t2896 ../golden/t2896 >/dev/null 2>&1 ;;
  p2897) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.892 > ../outputs/t2897
    exec diff ../outputs/t2897 ../golden/t2897 >/dev/null 2>&1 ;;
  p2898) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.895 > ../outputs/t2898
    exec diff ../outputs/t2898 ../golden/t2898 >/dev/null 2>&1 ;;
  p2899) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.896 > ../outputs/t2899
    exec diff ../outputs/t2899 ../golden/t2899 >/dev/null 2>&1 ;;
  p2900) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.898 > ../outputs/t2900
    exec diff ../outputs/t2900 ../golden/t2900 >/dev/null 2>&1 ;;
  p2901) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.9 > ../outputs/t2901
    exec diff ../outputs/t2901 ../golden/t2901 >/dev/null 2>&1 ;;
  p2902) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.903 > ../outputs/t2902
    exec diff ../outputs/t2902 ../golden/t2902 >/dev/null 2>&1 ;;
  p2903) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.904 > ../outputs/t2903
    exec diff ../outputs/t2903 ../golden/t2903 >/dev/null 2>&1 ;;
  p2904) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.905 > ../outputs/t2904
    exec diff ../outputs/t2904 ../golden/t2904 >/dev/null 2>&1 ;;
  p2905) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.906 > ../outputs/t2905
    exec diff ../outputs/t2905 ../golden/t2905 >/dev/null 2>&1 ;;
  p2906) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.910 > ../outputs/t2906
    exec diff ../outputs/t2906 ../golden/t2906 >/dev/null 2>&1 ;;
  p2907) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.913 > ../outputs/t2907
    exec diff ../outputs/t2907 ../golden/t2907 >/dev/null 2>&1 ;;
  p2908) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.914 > ../outputs/t2908
    exec diff ../outputs/t2908 ../golden/t2908 >/dev/null 2>&1 ;;
  p2909) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.92 > ../outputs/t2909
    exec diff ../outputs/t2909 ../golden/t2909 >/dev/null 2>&1 ;;
  p2910) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.920 > ../outputs/t2910
    exec diff ../outputs/t2910 ../golden/t2910 >/dev/null 2>&1 ;;
  p2911) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.922 > ../outputs/t2911
    exec diff ../outputs/t2911 ../golden/t2911 >/dev/null 2>&1 ;;
  p2912) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.923 > ../outputs/t2912
    exec diff ../outputs/t2912 ../golden/t2912 >/dev/null 2>&1 ;;
  p2913) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.924 > ../outputs/t2913
    exec diff ../outputs/t2913 ../golden/t2913 >/dev/null 2>&1 ;;
  p2914) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.926 > ../outputs/t2914
    exec diff ../outputs/t2914 ../golden/t2914 >/dev/null 2>&1 ;;
  p2915) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.927 > ../outputs/t2915
    exec diff ../outputs/t2915 ../golden/t2915 >/dev/null 2>&1 ;;
  p2916) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.93 > ../outputs/t2916
    exec diff ../outputs/t2916 ../golden/t2916 >/dev/null 2>&1 ;;
  p2917) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.930 > ../outputs/t2917
    exec diff ../outputs/t2917 ../golden/t2917 >/dev/null 2>&1 ;;
  p2918) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.933 > ../outputs/t2918
    exec diff ../outputs/t2918 ../golden/t2918 >/dev/null 2>&1 ;;
  p2919) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.937 > ../outputs/t2919
    exec diff ../outputs/t2919 ../golden/t2919 >/dev/null 2>&1 ;;
  p2920) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.94 > ../outputs/t2920
    exec diff ../outputs/t2920 ../golden/t2920 >/dev/null 2>&1 ;;
  p2921) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.942 > ../outputs/t2921
    exec diff ../outputs/t2921 ../golden/t2921 >/dev/null 2>&1 ;;
  p2922) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.944 > ../outputs/t2922
    exec diff ../outputs/t2922 ../golden/t2922 >/dev/null 2>&1 ;;
  p2923) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.945 > ../outputs/t2923
    exec diff ../outputs/t2923 ../golden/t2923 >/dev/null 2>&1 ;;
  p2924) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.949 > ../outputs/t2924
    exec diff ../outputs/t2924 ../golden/t2924 >/dev/null 2>&1 ;;
  p2925) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.954 > ../outputs/t2925
    exec diff ../outputs/t2925 ../golden/t2925 >/dev/null 2>&1 ;;
  p2926) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.955 > ../outputs/t2926
    exec diff ../outputs/t2926 ../golden/t2926 >/dev/null 2>&1 ;;
  p2927) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.957 > ../outputs/t2927
    exec diff ../outputs/t2927 ../golden/t2927 >/dev/null 2>&1 ;;
  p2928) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.958 > ../outputs/t2928
    exec diff ../outputs/t2928 ../golden/t2928 >/dev/null 2>&1 ;;
  p2929) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.96 > ../outputs/t2929
    exec diff ../outputs/t2929 ../golden/t2929 >/dev/null 2>&1 ;;
  p2930) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.960 > ../outputs/t2930
    exec diff ../outputs/t2930 ../golden/t2930 >/dev/null 2>&1 ;;
  p2931) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.961 > ../outputs/t2931
    exec diff ../outputs/t2931 ../golden/t2931 >/dev/null 2>&1 ;;
  p2932) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.962 > ../outputs/t2932
    exec diff ../outputs/t2932 ../golden/t2932 >/dev/null 2>&1 ;;
  p2933) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.964 > ../outputs/t2933
    exec diff ../outputs/t2933 ../golden/t2933 >/dev/null 2>&1 ;;
  p2934) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.966 > ../outputs/t2934
    exec diff ../outputs/t2934 ../golden/t2934 >/dev/null 2>&1 ;;
  p2935) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.968 > ../outputs/t2935
    exec diff ../outputs/t2935 ../golden/t2935 >/dev/null 2>&1 ;;
  p2936) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.969 > ../outputs/t2936
    exec diff ../outputs/t2936 ../golden/t2936 >/dev/null 2>&1 ;;
  p2937) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.97 > ../outputs/t2937
    exec diff ../outputs/t2937 ../golden/t2937 >/dev/null 2>&1 ;;
  p2938) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.971 > ../outputs/t2938
    exec diff ../outputs/t2938 ../golden/t2938 >/dev/null 2>&1 ;;
  p2939) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.973 > ../outputs/t2939
    exec diff ../outputs/t2939 ../golden/t2939 >/dev/null 2>&1 ;;
  p2940) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.974 > ../outputs/t2940
    exec diff ../outputs/t2940 ../golden/t2940 >/dev/null 2>&1 ;;
  p2941) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.978 > ../outputs/t2941
    exec diff ../outputs/t2941 ../golden/t2941 >/dev/null 2>&1 ;;
  p2942) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.98 > ../outputs/t2942
    exec diff ../outputs/t2942 ../golden/t2942 >/dev/null 2>&1 ;;
  p2943) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.981 > ../outputs/t2943
    exec diff ../outputs/t2943 ../golden/t2943 >/dev/null 2>&1 ;;
  p2944) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.982 > ../outputs/t2944
    exec diff ../outputs/t2944 ../golden/t2944 >/dev/null 2>&1 ;;
  p2945) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.984 > ../outputs/t2945
    exec diff ../outputs/t2945 ../golden/t2945 >/dev/null 2>&1 ;;
  p2946) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.987 > ../outputs/t2946
    exec diff ../outputs/t2946 ../golden/t2946 >/dev/null 2>&1 ;;
  p2947) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.989 > ../outputs/t2947
    exec diff ../outputs/t2947 ../golden/t2947 >/dev/null 2>&1 ;;
  p2948) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.99 > ../outputs/t2948
    exec diff ../outputs/t2948 ../golden/t2948 >/dev/null 2>&1 ;;
  p2949) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.991 > ../outputs/t2949
    exec diff ../outputs/t2949 ../golden/t2949 >/dev/null 2>&1 ;;
  p2950) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.992 > ../outputs/t2950
    exec diff ../outputs/t2950 ../golden/t2950 >/dev/null 2>&1 ;;
  p2951) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.993 > ../outputs/t2951
    exec diff ../outputs/t2951 ../golden/t2951 >/dev/null 2>&1 ;;
  p2952) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.994 > ../outputs/t2952
    exec diff ../outputs/t2952 ../golden/t2952 >/dev/null 2>&1 ;;
  p2953) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.995 > ../outputs/t2953
    exec diff ../outputs/t2953 ../golden/t2953 >/dev/null 2>&1 ;;
  p2954) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.996 > ../outputs/t2954
    exec diff ../outputs/t2954 ../golden/t2954 >/dev/null 2>&1 ;;
  p2955) timeout -s 9 2 ../source/print_tokens2.exe  < ../inputs/uslin.999 > ../outputs/t2955
    exec diff ../outputs/t2955 ../golden/t2955 >/dev/null 2>&1 ;;
  p2956) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t2956
    exec diff ../outputs/t2956 ../golden/t2956 >/dev/null 2>&1 ;;
  p2957) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk1     > ../outputs/t2957
    exec diff ../outputs/t2957 ../golden/t2957 >/dev/null 2>&1 ;;
  p2958) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk10     > ../outputs/t2958
    exec diff ../outputs/t2958 ../golden/t2958 >/dev/null 2>&1 ;;
  p2959) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk11     > ../outputs/t2959
    exec diff ../outputs/t2959 ../golden/t2959 >/dev/null 2>&1 ;;
  p2960) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk12     > ../outputs/t2960
    exec diff ../outputs/t2960 ../golden/t2960 >/dev/null 2>&1 ;;
  p2961) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk13     > ../outputs/t2961
    exec diff ../outputs/t2961 ../golden/t2961 >/dev/null 2>&1 ;;
  p2962) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk14     > ../outputs/t2962
    exec diff ../outputs/t2962 ../golden/t2962 >/dev/null 2>&1 ;;
  p2963) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk15     > ../outputs/t2963
    exec diff ../outputs/t2963 ../golden/t2963 >/dev/null 2>&1 ;;
  p2964) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk16     > ../outputs/t2964
    exec diff ../outputs/t2964 ../golden/t2964 >/dev/null 2>&1 ;;
  p2965) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk17     > ../outputs/t2965
    exec diff ../outputs/t2965 ../golden/t2965 >/dev/null 2>&1 ;;
  p2966) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk18     > ../outputs/t2966
    exec diff ../outputs/t2966 ../golden/t2966 >/dev/null 2>&1 ;;
  p2967) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk19     > ../outputs/t2967
    exec diff ../outputs/t2967 ../golden/t2967 >/dev/null 2>&1 ;;
  p2968) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk2     > ../outputs/t2968
    exec diff ../outputs/t2968 ../golden/t2968 >/dev/null 2>&1 ;;
  p2969) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk20     > ../outputs/t2969
    exec diff ../outputs/t2969 ../golden/t2969 >/dev/null 2>&1 ;;
  p2970) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk21     > ../outputs/t2970
    exec diff ../outputs/t2970 ../golden/t2970 >/dev/null 2>&1 ;;
  p2971) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk22     > ../outputs/t2971
    exec diff ../outputs/t2971 ../golden/t2971 >/dev/null 2>&1 ;;
  p2972) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk23     > ../outputs/t2972
    exec diff ../outputs/t2972 ../golden/t2972 >/dev/null 2>&1 ;;
  p2973) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk24     > ../outputs/t2973
    exec diff ../outputs/t2973 ../golden/t2973 >/dev/null 2>&1 ;;
  p2974) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk25     > ../outputs/t2974
    exec diff ../outputs/t2974 ../golden/t2974 >/dev/null 2>&1 ;;
  p2975) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk26     > ../outputs/t2975
    exec diff ../outputs/t2975 ../golden/t2975 >/dev/null 2>&1 ;;
  p2976) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk27     > ../outputs/t2976
    exec diff ../outputs/t2976 ../golden/t2976 >/dev/null 2>&1 ;;
  p2977) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk28     > ../outputs/t2977
    exec diff ../outputs/t2977 ../golden/t2977 >/dev/null 2>&1 ;;
  p2978) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk29     > ../outputs/t2978
    exec diff ../outputs/t2978 ../golden/t2978 >/dev/null 2>&1 ;;
  p2979) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk3     > ../outputs/t2979
    exec diff ../outputs/t2979 ../golden/t2979 >/dev/null 2>&1 ;;
  p2980) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk30     > ../outputs/t2980
    exec diff ../outputs/t2980 ../golden/t2980 >/dev/null 2>&1 ;;
  p2981) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk31     > ../outputs/t2981
    exec diff ../outputs/t2981 ../golden/t2981 >/dev/null 2>&1 ;;
  p2982) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk32     > ../outputs/t2982
    exec diff ../outputs/t2982 ../golden/t2982 >/dev/null 2>&1 ;;
  p2983) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk33     > ../outputs/t2983
    exec diff ../outputs/t2983 ../golden/t2983 >/dev/null 2>&1 ;;
  p2984) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk34     > ../outputs/t2984
    exec diff ../outputs/t2984 ../golden/t2984 >/dev/null 2>&1 ;;
  p2985) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk35     > ../outputs/t2985
    exec diff ../outputs/t2985 ../golden/t2985 >/dev/null 2>&1 ;;
  p2986) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk36     > ../outputs/t2986
    exec diff ../outputs/t2986 ../golden/t2986 >/dev/null 2>&1 ;;
  p2987) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk37     > ../outputs/t2987
    exec diff ../outputs/t2987 ../golden/t2987 >/dev/null 2>&1 ;;
  p2988) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk38     > ../outputs/t2988
    exec diff ../outputs/t2988 ../golden/t2988 >/dev/null 2>&1 ;;
  p2989) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk39     > ../outputs/t2989
    exec diff ../outputs/t2989 ../golden/t2989 >/dev/null 2>&1 ;;
  p2990) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk4     > ../outputs/t2990
    exec diff ../outputs/t2990 ../golden/t2990 >/dev/null 2>&1 ;;
  p2991) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk40     > ../outputs/t2991
    exec diff ../outputs/t2991 ../golden/t2991 >/dev/null 2>&1 ;;
  p2992) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk41     > ../outputs/t2992
    exec diff ../outputs/t2992 ../golden/t2992 >/dev/null 2>&1 ;;
  p2993) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk42     > ../outputs/t2993
    exec diff ../outputs/t2993 ../golden/t2993 >/dev/null 2>&1 ;;
  p2994) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk43     > ../outputs/t2994
    exec diff ../outputs/t2994 ../golden/t2994 >/dev/null 2>&1 ;;
  p2995) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk44     > ../outputs/t2995
    exec diff ../outputs/t2995 ../golden/t2995 >/dev/null 2>&1 ;;
  p2996) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk45     > ../outputs/t2996
    exec diff ../outputs/t2996 ../golden/t2996 >/dev/null 2>&1 ;;
  p2997) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk46     > ../outputs/t2997
    exec diff ../outputs/t2997 ../golden/t2997 >/dev/null 2>&1 ;;
  p2998) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk47     > ../outputs/t2998
    exec diff ../outputs/t2998 ../golden/t2998 >/dev/null 2>&1 ;;
  p2999) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk48     > ../outputs/t2999
    exec diff ../outputs/t2999 ../golden/t2999 >/dev/null 2>&1 ;;
  p3000) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk49     > ../outputs/t3000
    exec diff ../outputs/t3000 ../golden/t3000 >/dev/null 2>&1 ;;
  p3001) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk5     > ../outputs/t3001
    exec diff ../outputs/t3001 ../golden/t3001 >/dev/null 2>&1 ;;
  p3002) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk50     > ../outputs/t3002
    exec diff ../outputs/t3002 ../golden/t3002 >/dev/null 2>&1 ;;
  p3003) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk6     > ../outputs/t3003
    exec diff ../outputs/t3003 ../golden/t3003 >/dev/null 2>&1 ;;
  p3004) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk7     > ../outputs/t3004
    exec diff ../outputs/t3004 ../golden/t3004 >/dev/null 2>&1 ;;
  p3005) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk8     > ../outputs/t3005
    exec diff ../outputs/t3005 ../golden/t3005 >/dev/null 2>&1 ;;
  p3006) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/jk9     > ../outputs/t3006
    exec diff ../outputs/t3006 ../golden/t3006 >/dev/null 2>&1 ;;
  p3007) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/newtst522.tst.noeof     > ../outputs/t3007
    exec diff ../outputs/t3007 ../golden/t3007 >/dev/null 2>&1 ;;
  p3008) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/tc240.noeof     > ../outputs/t3008
    exec diff ../outputs/t3008 ../golden/t3008 >/dev/null 2>&1 ;;
  p3009) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/test287.noeof     > ../outputs/t3009
    exec diff ../outputs/t3009 ../golden/t3009 >/dev/null 2>&1 ;;
  p3010) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/test330.noeof     > ../outputs/t3010
    exec diff ../outputs/t3010 ../golden/t3010 >/dev/null 2>&1 ;;
  p3011) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/test373.noeof     > ../outputs/t3011
    exec diff ../outputs/t3011 ../golden/t3011 >/dev/null 2>&1 ;;
  p3012) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/ts516.noeof     > ../outputs/t3012
    exec diff ../outputs/t3012 ../golden/t3012 >/dev/null 2>&1 ;;
  p3013) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/ts583.noeof     > ../outputs/t3013
    exec diff ../outputs/t3013 ../golden/t3013 >/dev/null 2>&1 ;;
  p3014) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/ts609.noeof     > ../outputs/t3014
    exec diff ../outputs/t3014 ../golden/t3014 >/dev/null 2>&1 ;;
  p3015) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/ts789.noeof     > ../outputs/t3015
    exec diff ../outputs/t3015 ../golden/t3015 >/dev/null 2>&1 ;;
  p3016) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/tst110.noeof     > ../outputs/t3016
    exec diff ../outputs/t3016 ../golden/t3016 >/dev/null 2>&1 ;;
  p3017) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/tst52.noeof     > ../outputs/t3017
    exec diff ../outputs/t3017 ../golden/t3017 >/dev/null 2>&1 ;;
  p3018) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1     > ../outputs/t3018
    exec diff ../outputs/t3018 ../golden/t3018 >/dev/null 2>&1 ;;
  p3019) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.10     > ../outputs/t3019
    exec diff ../outputs/t3019 ../golden/t3019 >/dev/null 2>&1 ;;
  p3020) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1000     > ../outputs/t3020
    exec diff ../outputs/t3020 ../golden/t3020 >/dev/null 2>&1 ;;
  p3021) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1001     > ../outputs/t3021
    exec diff ../outputs/t3021 ../golden/t3021 >/dev/null 2>&1 ;;
  p3022) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1003     > ../outputs/t3022
    exec diff ../outputs/t3022 ../golden/t3022 >/dev/null 2>&1 ;;
  p3023) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1004     > ../outputs/t3023
    exec diff ../outputs/t3023 ../golden/t3023 >/dev/null 2>&1 ;;
  p3024) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1005     > ../outputs/t3024
    exec diff ../outputs/t3024 ../golden/t3024 >/dev/null 2>&1 ;;
  p3025) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1008     > ../outputs/t3025
    exec diff ../outputs/t3025 ../golden/t3025 >/dev/null 2>&1 ;;
  p3026) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1009     > ../outputs/t3026
    exec diff ../outputs/t3026 ../golden/t3026 >/dev/null 2>&1 ;;
  p3027) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1010     > ../outputs/t3027
    exec diff ../outputs/t3027 ../golden/t3027 >/dev/null 2>&1 ;;
  p3028) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1014     > ../outputs/t3028
    exec diff ../outputs/t3028 ../golden/t3028 >/dev/null 2>&1 ;;
  p3029) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1014.noeof     > ../outputs/t3029
    exec diff ../outputs/t3029 ../golden/t3029 >/dev/null 2>&1 ;;
  p3030) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1015     > ../outputs/t3030
    exec diff ../outputs/t3030 ../golden/t3030 >/dev/null 2>&1 ;;
  p3031) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1018     > ../outputs/t3031
    exec diff ../outputs/t3031 ../golden/t3031 >/dev/null 2>&1 ;;
  p3032) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1020     > ../outputs/t3032
    exec diff ../outputs/t3032 ../golden/t3032 >/dev/null 2>&1 ;;
  p3033) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1024     > ../outputs/t3033
    exec diff ../outputs/t3033 ../golden/t3033 >/dev/null 2>&1 ;;
  p3034) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1025     > ../outputs/t3034
    exec diff ../outputs/t3034 ../golden/t3034 >/dev/null 2>&1 ;;
  p3035) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1030     > ../outputs/t3035
    exec diff ../outputs/t3035 ../golden/t3035 >/dev/null 2>&1 ;;
  p3036) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1031     > ../outputs/t3036
    exec diff ../outputs/t3036 ../golden/t3036 >/dev/null 2>&1 ;;
  p3037) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1032     > ../outputs/t3037
    exec diff ../outputs/t3037 ../golden/t3037 >/dev/null 2>&1 ;;
  p3038) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1034     > ../outputs/t3038
    exec diff ../outputs/t3038 ../golden/t3038 >/dev/null 2>&1 ;;
  p3039) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1035     > ../outputs/t3039
    exec diff ../outputs/t3039 ../golden/t3039 >/dev/null 2>&1 ;;
  p3040) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1036     > ../outputs/t3040
    exec diff ../outputs/t3040 ../golden/t3040 >/dev/null 2>&1 ;;
  p3041) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1038     > ../outputs/t3041
    exec diff ../outputs/t3041 ../golden/t3041 >/dev/null 2>&1 ;;
  p3042) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1038.noeof     > ../outputs/t3042
    exec diff ../outputs/t3042 ../golden/t3042 >/dev/null 2>&1 ;;
  p3043) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1039     > ../outputs/t3043
    exec diff ../outputs/t3043 ../golden/t3043 >/dev/null 2>&1 ;;
  p3044) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1040     > ../outputs/t3044
    exec diff ../outputs/t3044 ../golden/t3044 >/dev/null 2>&1 ;;
  p3045) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1042     > ../outputs/t3045
    exec diff ../outputs/t3045 ../golden/t3045 >/dev/null 2>&1 ;;
  p3046) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1043     > ../outputs/t3046
    exec diff ../outputs/t3046 ../golden/t3046 >/dev/null 2>&1 ;;
  p3047) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1045     > ../outputs/t3047
    exec diff ../outputs/t3047 ../golden/t3047 >/dev/null 2>&1 ;;
  p3048) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1046     > ../outputs/t3048
    exec diff ../outputs/t3048 ../golden/t3048 >/dev/null 2>&1 ;;
  p3049) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1047     > ../outputs/t3049
    exec diff ../outputs/t3049 ../golden/t3049 >/dev/null 2>&1 ;;
  p3050) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1048     > ../outputs/t3050
    exec diff ../outputs/t3050 ../golden/t3050 >/dev/null 2>&1 ;;
  p3051) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1049     > ../outputs/t3051
    exec diff ../outputs/t3051 ../golden/t3051 >/dev/null 2>&1 ;;
  p3052) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.105     > ../outputs/t3052
    exec diff ../outputs/t3052 ../golden/t3052 >/dev/null 2>&1 ;;
  p3053) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1050     > ../outputs/t3053
    exec diff ../outputs/t3053 ../golden/t3053 >/dev/null 2>&1 ;;
  p3054) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1054     > ../outputs/t3054
    exec diff ../outputs/t3054 ../golden/t3054 >/dev/null 2>&1 ;;
  p3055) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1057     > ../outputs/t3055
    exec diff ../outputs/t3055 ../golden/t3055 >/dev/null 2>&1 ;;
  p3056) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1059     > ../outputs/t3056
    exec diff ../outputs/t3056 ../golden/t3056 >/dev/null 2>&1 ;;
  p3057) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.106     > ../outputs/t3057
    exec diff ../outputs/t3057 ../golden/t3057 >/dev/null 2>&1 ;;
  p3058) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1061     > ../outputs/t3058
    exec diff ../outputs/t3058 ../golden/t3058 >/dev/null 2>&1 ;;
  p3059) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1065     > ../outputs/t3059
    exec diff ../outputs/t3059 ../golden/t3059 >/dev/null 2>&1 ;;
  p3060) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1067     > ../outputs/t3060
    exec diff ../outputs/t3060 ../golden/t3060 >/dev/null 2>&1 ;;
  p3061) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1068     > ../outputs/t3061
    exec diff ../outputs/t3061 ../golden/t3061 >/dev/null 2>&1 ;;
  p3062) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1069     > ../outputs/t3062
    exec diff ../outputs/t3062 ../golden/t3062 >/dev/null 2>&1 ;;
  p3063) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.107     > ../outputs/t3063
    exec diff ../outputs/t3063 ../golden/t3063 >/dev/null 2>&1 ;;
  p3064) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1071     > ../outputs/t3064
    exec diff ../outputs/t3064 ../golden/t3064 >/dev/null 2>&1 ;;
  p3065) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1074     > ../outputs/t3065
    exec diff ../outputs/t3065 ../golden/t3065 >/dev/null 2>&1 ;;
  p3066) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1075     > ../outputs/t3066
    exec diff ../outputs/t3066 ../golden/t3066 >/dev/null 2>&1 ;;
  p3067) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1076     > ../outputs/t3067
    exec diff ../outputs/t3067 ../golden/t3067 >/dev/null 2>&1 ;;
  p3068) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1077     > ../outputs/t3068
    exec diff ../outputs/t3068 ../golden/t3068 >/dev/null 2>&1 ;;
  p3069) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1078     > ../outputs/t3069
    exec diff ../outputs/t3069 ../golden/t3069 >/dev/null 2>&1 ;;
  p3070) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1080     > ../outputs/t3070
    exec diff ../outputs/t3070 ../golden/t3070 >/dev/null 2>&1 ;;
  p3071) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1082     > ../outputs/t3071
    exec diff ../outputs/t3071 ../golden/t3071 >/dev/null 2>&1 ;;
  p3072) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1084     > ../outputs/t3072
    exec diff ../outputs/t3072 ../golden/t3072 >/dev/null 2>&1 ;;
  p3073) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1085     > ../outputs/t3073
    exec diff ../outputs/t3073 ../golden/t3073 >/dev/null 2>&1 ;;
  p3074) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.109     > ../outputs/t3074
    exec diff ../outputs/t3074 ../golden/t3074 >/dev/null 2>&1 ;;
  p3075) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1091     > ../outputs/t3075
    exec diff ../outputs/t3075 ../golden/t3075 >/dev/null 2>&1 ;;
  p3076) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1092     > ../outputs/t3076
    exec diff ../outputs/t3076 ../golden/t3076 >/dev/null 2>&1 ;;
  p3077) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1093     > ../outputs/t3077
    exec diff ../outputs/t3077 ../golden/t3077 >/dev/null 2>&1 ;;
  p3078) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1094     > ../outputs/t3078
    exec diff ../outputs/t3078 ../golden/t3078 >/dev/null 2>&1 ;;
  p3079) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1095     > ../outputs/t3079
    exec diff ../outputs/t3079 ../golden/t3079 >/dev/null 2>&1 ;;
  p3080) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1096     > ../outputs/t3080
    exec diff ../outputs/t3080 ../golden/t3080 >/dev/null 2>&1 ;;
  p3081) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1101     > ../outputs/t3081
    exec diff ../outputs/t3081 ../golden/t3081 >/dev/null 2>&1 ;;
  p3082) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1103     > ../outputs/t3082
    exec diff ../outputs/t3082 ../golden/t3082 >/dev/null 2>&1 ;;
  p3083) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1105     > ../outputs/t3083
    exec diff ../outputs/t3083 ../golden/t3083 >/dev/null 2>&1 ;;
  p3084) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1109      > ../outputs/t3084
    exec diff ../outputs/t3084 ../golden/t3084 >/dev/null 2>&1 ;;
  p3085) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.111     > ../outputs/t3085
    exec diff ../outputs/t3085 ../golden/t3085 >/dev/null 2>&1 ;;
  p3086) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1112     > ../outputs/t3086
    exec diff ../outputs/t3086 ../golden/t3086 >/dev/null 2>&1 ;;
  p3087) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1113     > ../outputs/t3087
    exec diff ../outputs/t3087 ../golden/t3087 >/dev/null 2>&1 ;;
  p3088) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1114     > ../outputs/t3088
    exec diff ../outputs/t3088 ../golden/t3088 >/dev/null 2>&1 ;;
  p3089) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1115     > ../outputs/t3089
    exec diff ../outputs/t3089 ../golden/t3089 >/dev/null 2>&1 ;;
  p3090) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1119     > ../outputs/t3090
    exec diff ../outputs/t3090 ../golden/t3090 >/dev/null 2>&1 ;;
  p3091) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1120     > ../outputs/t3091
    exec diff ../outputs/t3091 ../golden/t3091 >/dev/null 2>&1 ;;
  p3092) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1121     > ../outputs/t3092
    exec diff ../outputs/t3092 ../golden/t3092 >/dev/null 2>&1 ;;
  p3093) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1124      > ../outputs/t3093
    exec diff ../outputs/t3093 ../golden/t3093 >/dev/null 2>&1 ;;
  p3094) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1125     > ../outputs/t3094
    exec diff ../outputs/t3094 ../golden/t3094 >/dev/null 2>&1 ;;
  p3095) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1126     > ../outputs/t3095
    exec diff ../outputs/t3095 ../golden/t3095 >/dev/null 2>&1 ;;
  p3096) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1127     > ../outputs/t3096
    exec diff ../outputs/t3096 ../golden/t3096 >/dev/null 2>&1 ;;
  p3097) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1130     > ../outputs/t3097
    exec diff ../outputs/t3097 ../golden/t3097 >/dev/null 2>&1 ;;
  p3098) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1139     > ../outputs/t3098
    exec diff ../outputs/t3098 ../golden/t3098 >/dev/null 2>&1 ;;
  p3099) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.114     > ../outputs/t3099
    exec diff ../outputs/t3099 ../golden/t3099 >/dev/null 2>&1 ;;
  p3100) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1140     > ../outputs/t3100
    exec diff ../outputs/t3100 ../golden/t3100 >/dev/null 2>&1 ;;
  p3101) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1141     > ../outputs/t3101
    exec diff ../outputs/t3101 ../golden/t3101 >/dev/null 2>&1 ;;
  p3102) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1142     > ../outputs/t3102
    exec diff ../outputs/t3102 ../golden/t3102 >/dev/null 2>&1 ;;
  p3103) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1144     > ../outputs/t3103
    exec diff ../outputs/t3103 ../golden/t3103 >/dev/null 2>&1 ;;
  p3104) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.115     > ../outputs/t3104
    exec diff ../outputs/t3104 ../golden/t3104 >/dev/null 2>&1 ;;
  p3105) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1155     > ../outputs/t3105
    exec diff ../outputs/t3105 ../golden/t3105 >/dev/null 2>&1 ;;
  p3106) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1156      > ../outputs/t3106
    exec diff ../outputs/t3106 ../golden/t3106 >/dev/null 2>&1 ;;
  p3107) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1159     > ../outputs/t3107
    exec diff ../outputs/t3107 ../golden/t3107 >/dev/null 2>&1 ;;
  p3108) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1160     > ../outputs/t3108
    exec diff ../outputs/t3108 ../golden/t3108 >/dev/null 2>&1 ;;
  p3109) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1162     > ../outputs/t3109
    exec diff ../outputs/t3109 ../golden/t3109 >/dev/null 2>&1 ;;
  p3110) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1163     > ../outputs/t3110
    exec diff ../outputs/t3110 ../golden/t3110 >/dev/null 2>&1 ;;
  p3111) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1165     > ../outputs/t3111
    exec diff ../outputs/t3111 ../golden/t3111 >/dev/null 2>&1 ;;
  p3112) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1166     > ../outputs/t3112
    exec diff ../outputs/t3112 ../golden/t3112 >/dev/null 2>&1 ;;
  p3113) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1167     > ../outputs/t3113
    exec diff ../outputs/t3113 ../golden/t3113 >/dev/null 2>&1 ;;
  p3114) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.117     > ../outputs/t3114
    exec diff ../outputs/t3114 ../golden/t3114 >/dev/null 2>&1 ;;
  p3115) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1173     > ../outputs/t3115
    exec diff ../outputs/t3115 ../golden/t3115 >/dev/null 2>&1 ;;
  p3116) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1174     > ../outputs/t3116
    exec diff ../outputs/t3116 ../golden/t3116 >/dev/null 2>&1 ;;
  p3117) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1179     > ../outputs/t3117
    exec diff ../outputs/t3117 ../golden/t3117 >/dev/null 2>&1 ;;
  p3118) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1180     > ../outputs/t3118
    exec diff ../outputs/t3118 ../golden/t3118 >/dev/null 2>&1 ;;
  p3119) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1182     > ../outputs/t3119
    exec diff ../outputs/t3119 ../golden/t3119 >/dev/null 2>&1 ;;
  p3120) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1184     > ../outputs/t3120
    exec diff ../outputs/t3120 ../golden/t3120 >/dev/null 2>&1 ;;
  p3121) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1185     > ../outputs/t3121
    exec diff ../outputs/t3121 ../golden/t3121 >/dev/null 2>&1 ;;
  p3122) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1186     > ../outputs/t3122
    exec diff ../outputs/t3122 ../golden/t3122 >/dev/null 2>&1 ;;
  p3123) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1187     > ../outputs/t3123
    exec diff ../outputs/t3123 ../golden/t3123 >/dev/null 2>&1 ;;
  p3124) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1189     > ../outputs/t3124
    exec diff ../outputs/t3124 ../golden/t3124 >/dev/null 2>&1 ;;
  p3125) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.119     > ../outputs/t3125
    exec diff ../outputs/t3125 ../golden/t3125 >/dev/null 2>&1 ;;
  p3126) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1191     > ../outputs/t3126
    exec diff ../outputs/t3126 ../golden/t3126 >/dev/null 2>&1 ;;
  p3127) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1192     > ../outputs/t3127
    exec diff ../outputs/t3127 ../golden/t3127 >/dev/null 2>&1 ;;
  p3128) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1193     > ../outputs/t3128
    exec diff ../outputs/t3128 ../golden/t3128 >/dev/null 2>&1 ;;
  p3129) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1196     > ../outputs/t3129
    exec diff ../outputs/t3129 ../golden/t3129 >/dev/null 2>&1 ;;
  p3130) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1198     > ../outputs/t3130
    exec diff ../outputs/t3130 ../golden/t3130 >/dev/null 2>&1 ;;
  p3131) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1200     > ../outputs/t3131
    exec diff ../outputs/t3131 ../golden/t3131 >/dev/null 2>&1 ;;
  p3132) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1202     > ../outputs/t3132
    exec diff ../outputs/t3132 ../golden/t3132 >/dev/null 2>&1 ;;
  p3133) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1206     > ../outputs/t3133
    exec diff ../outputs/t3133 ../golden/t3133 >/dev/null 2>&1 ;;
  p3134) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1207     > ../outputs/t3134
    exec diff ../outputs/t3134 ../golden/t3134 >/dev/null 2>&1 ;;
  p3135) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1209     > ../outputs/t3135
    exec diff ../outputs/t3135 ../golden/t3135 >/dev/null 2>&1 ;;
  p3136) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.121     > ../outputs/t3136
    exec diff ../outputs/t3136 ../golden/t3136 >/dev/null 2>&1 ;;
  p3137) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1212     > ../outputs/t3137
    exec diff ../outputs/t3137 ../golden/t3137 >/dev/null 2>&1 ;;
  p3138) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1217     > ../outputs/t3138
    exec diff ../outputs/t3138 ../golden/t3138 >/dev/null 2>&1 ;;
  p3139) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1219     > ../outputs/t3139
    exec diff ../outputs/t3139 ../golden/t3139 >/dev/null 2>&1 ;;
  p3140) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1224     > ../outputs/t3140
    exec diff ../outputs/t3140 ../golden/t3140 >/dev/null 2>&1 ;;
  p3141) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1226     > ../outputs/t3141
    exec diff ../outputs/t3141 ../golden/t3141 >/dev/null 2>&1 ;;
  p3142) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1233     > ../outputs/t3142
    exec diff ../outputs/t3142 ../golden/t3142 >/dev/null 2>&1 ;;
  p3143) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1234     > ../outputs/t3143
    exec diff ../outputs/t3143 ../golden/t3143 >/dev/null 2>&1 ;;
  p3144) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1235     > ../outputs/t3144
    exec diff ../outputs/t3144 ../golden/t3144 >/dev/null 2>&1 ;;
  p3145) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1237     > ../outputs/t3145
    exec diff ../outputs/t3145 ../golden/t3145 >/dev/null 2>&1 ;;
  p3146) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1239     > ../outputs/t3146
    exec diff ../outputs/t3146 ../golden/t3146 >/dev/null 2>&1 ;;
  p3147) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1241     > ../outputs/t3147
    exec diff ../outputs/t3147 ../golden/t3147 >/dev/null 2>&1 ;;
  p3148) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1243     > ../outputs/t3148
    exec diff ../outputs/t3148 ../golden/t3148 >/dev/null 2>&1 ;;
  p3149) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1245     > ../outputs/t3149
    exec diff ../outputs/t3149 ../golden/t3149 >/dev/null 2>&1 ;;
  p3150) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1246     > ../outputs/t3150
    exec diff ../outputs/t3150 ../golden/t3150 >/dev/null 2>&1 ;;
  p3151) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.125     > ../outputs/t3151
    exec diff ../outputs/t3151 ../golden/t3151 >/dev/null 2>&1 ;;
  p3152) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1250     > ../outputs/t3152
    exec diff ../outputs/t3152 ../golden/t3152 >/dev/null 2>&1 ;;
  p3153) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1252     > ../outputs/t3153
    exec diff ../outputs/t3153 ../golden/t3153 >/dev/null 2>&1 ;;
  p3154) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1253     > ../outputs/t3154
    exec diff ../outputs/t3154 ../golden/t3154 >/dev/null 2>&1 ;;
  p3155) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1255      > ../outputs/t3155
    exec diff ../outputs/t3155 ../golden/t3155 >/dev/null 2>&1 ;;
  p3156) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1256     > ../outputs/t3156
    exec diff ../outputs/t3156 ../golden/t3156 >/dev/null 2>&1 ;;
  p3157) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1258     > ../outputs/t3157
    exec diff ../outputs/t3157 ../golden/t3157 >/dev/null 2>&1 ;;
  p3158) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.126     > ../outputs/t3158
    exec diff ../outputs/t3158 ../golden/t3158 >/dev/null 2>&1 ;;
  p3159) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1260      > ../outputs/t3159
    exec diff ../outputs/t3159 ../golden/t3159 >/dev/null 2>&1 ;;
  p3160) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1264     > ../outputs/t3160
    exec diff ../outputs/t3160 ../golden/t3160 >/dev/null 2>&1 ;;
  p3161) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1265     > ../outputs/t3161
    exec diff ../outputs/t3161 ../golden/t3161 >/dev/null 2>&1 ;;
  p3162) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1266     > ../outputs/t3162
    exec diff ../outputs/t3162 ../golden/t3162 >/dev/null 2>&1 ;;
  p3163) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1267     > ../outputs/t3163
    exec diff ../outputs/t3163 ../golden/t3163 >/dev/null 2>&1 ;;
  p3164) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1268     > ../outputs/t3164
    exec diff ../outputs/t3164 ../golden/t3164 >/dev/null 2>&1 ;;
  p3165) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.127     > ../outputs/t3165
    exec diff ../outputs/t3165 ../golden/t3165 >/dev/null 2>&1 ;;
  p3166) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1270     > ../outputs/t3166
    exec diff ../outputs/t3166 ../golden/t3166 >/dev/null 2>&1 ;;
  p3167) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1272     > ../outputs/t3167
    exec diff ../outputs/t3167 ../golden/t3167 >/dev/null 2>&1 ;;
  p3168) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1276     > ../outputs/t3168
    exec diff ../outputs/t3168 ../golden/t3168 >/dev/null 2>&1 ;;
  p3169) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1278     > ../outputs/t3169
    exec diff ../outputs/t3169 ../golden/t3169 >/dev/null 2>&1 ;;
  p3170) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.128     > ../outputs/t3170
    exec diff ../outputs/t3170 ../golden/t3170 >/dev/null 2>&1 ;;
  p3171) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1281     > ../outputs/t3171
    exec diff ../outputs/t3171 ../golden/t3171 >/dev/null 2>&1 ;;
  p3172) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1283     > ../outputs/t3172
    exec diff ../outputs/t3172 ../golden/t3172 >/dev/null 2>&1 ;;
  p3173) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1287     > ../outputs/t3173
    exec diff ../outputs/t3173 ../golden/t3173 >/dev/null 2>&1 ;;
  p3174) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1289     > ../outputs/t3174
    exec diff ../outputs/t3174 ../golden/t3174 >/dev/null 2>&1 ;;
  p3175) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.129     > ../outputs/t3175
    exec diff ../outputs/t3175 ../golden/t3175 >/dev/null 2>&1 ;;
  p3176) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1290     > ../outputs/t3176
    exec diff ../outputs/t3176 ../golden/t3176 >/dev/null 2>&1 ;;
  p3177) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1291     > ../outputs/t3177
    exec diff ../outputs/t3177 ../golden/t3177 >/dev/null 2>&1 ;;
  p3178) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1292     > ../outputs/t3178
    exec diff ../outputs/t3178 ../golden/t3178 >/dev/null 2>&1 ;;
  p3179) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1294     > ../outputs/t3179
    exec diff ../outputs/t3179 ../golden/t3179 >/dev/null 2>&1 ;;
  p3180) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1298     > ../outputs/t3180
    exec diff ../outputs/t3180 ../golden/t3180 >/dev/null 2>&1 ;;
  p3181) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1302     > ../outputs/t3181
    exec diff ../outputs/t3181 ../golden/t3181 >/dev/null 2>&1 ;;
  p3182) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1303     > ../outputs/t3182
    exec diff ../outputs/t3182 ../golden/t3182 >/dev/null 2>&1 ;;
  p3183) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1305     > ../outputs/t3183
    exec diff ../outputs/t3183 ../golden/t3183 >/dev/null 2>&1 ;;
  p3184) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1306     > ../outputs/t3184
    exec diff ../outputs/t3184 ../golden/t3184 >/dev/null 2>&1 ;;
  p3185) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.131     > ../outputs/t3185
    exec diff ../outputs/t3185 ../golden/t3185 >/dev/null 2>&1 ;;
  p3186) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1316     > ../outputs/t3186
    exec diff ../outputs/t3186 ../golden/t3186 >/dev/null 2>&1 ;;
  p3187) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1317     > ../outputs/t3187
    exec diff ../outputs/t3187 ../golden/t3187 >/dev/null 2>&1 ;;
  p3188) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.132     > ../outputs/t3188
    exec diff ../outputs/t3188 ../golden/t3188 >/dev/null 2>&1 ;;
  p3189) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1321     > ../outputs/t3189
    exec diff ../outputs/t3189 ../golden/t3189 >/dev/null 2>&1 ;;
  p3190) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1322     > ../outputs/t3190
    exec diff ../outputs/t3190 ../golden/t3190 >/dev/null 2>&1 ;;
  p3191) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1324     > ../outputs/t3191
    exec diff ../outputs/t3191 ../golden/t3191 >/dev/null 2>&1 ;;
  p3192) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1325     > ../outputs/t3192
    exec diff ../outputs/t3192 ../golden/t3192 >/dev/null 2>&1 ;;
  p3193) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1327     > ../outputs/t3193
    exec diff ../outputs/t3193 ../golden/t3193 >/dev/null 2>&1 ;;
  p3194) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1328     > ../outputs/t3194
    exec diff ../outputs/t3194 ../golden/t3194 >/dev/null 2>&1 ;;
  p3195) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1330     > ../outputs/t3195
    exec diff ../outputs/t3195 ../golden/t3195 >/dev/null 2>&1 ;;
  p3196) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1333     > ../outputs/t3196
    exec diff ../outputs/t3196 ../golden/t3196 >/dev/null 2>&1 ;;
  p3197) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1334     > ../outputs/t3197
    exec diff ../outputs/t3197 ../golden/t3197 >/dev/null 2>&1 ;;
  p3198) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1335     > ../outputs/t3198
    exec diff ../outputs/t3198 ../golden/t3198 >/dev/null 2>&1 ;;
  p3199) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1337     > ../outputs/t3199
    exec diff ../outputs/t3199 ../golden/t3199 >/dev/null 2>&1 ;;
  p3200) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1339     > ../outputs/t3200
    exec diff ../outputs/t3200 ../golden/t3200 >/dev/null 2>&1 ;;
  p3201) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.134     > ../outputs/t3201
    exec diff ../outputs/t3201 ../golden/t3201 >/dev/null 2>&1 ;;
  p3202) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1340     > ../outputs/t3202
    exec diff ../outputs/t3202 ../golden/t3202 >/dev/null 2>&1 ;;
  p3203) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1341     > ../outputs/t3203
    exec diff ../outputs/t3203 ../golden/t3203 >/dev/null 2>&1 ;;
  p3204) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1342     > ../outputs/t3204
    exec diff ../outputs/t3204 ../golden/t3204 >/dev/null 2>&1 ;;
  p3205) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1346     > ../outputs/t3205
    exec diff ../outputs/t3205 ../golden/t3205 >/dev/null 2>&1 ;;
  p3206) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1348     > ../outputs/t3206
    exec diff ../outputs/t3206 ../golden/t3206 >/dev/null 2>&1 ;;
  p3207) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1352     > ../outputs/t3207
    exec diff ../outputs/t3207 ../golden/t3207 >/dev/null 2>&1 ;;
  p3208) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1353     > ../outputs/t3208
    exec diff ../outputs/t3208 ../golden/t3208 >/dev/null 2>&1 ;;
  p3209) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1354     > ../outputs/t3209
    exec diff ../outputs/t3209 ../golden/t3209 >/dev/null 2>&1 ;;
  p3210) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1358     > ../outputs/t3210
    exec diff ../outputs/t3210 ../golden/t3210 >/dev/null 2>&1 ;;
  p3211) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1359     > ../outputs/t3211
    exec diff ../outputs/t3211 ../golden/t3211 >/dev/null 2>&1 ;;
  p3212) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1364     > ../outputs/t3212
    exec diff ../outputs/t3212 ../golden/t3212 >/dev/null 2>&1 ;;
  p3213) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1368     > ../outputs/t3213
    exec diff ../outputs/t3213 ../golden/t3213 >/dev/null 2>&1 ;;
  p3214) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.137     > ../outputs/t3214
    exec diff ../outputs/t3214 ../golden/t3214 >/dev/null 2>&1 ;;
  p3215) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1370     > ../outputs/t3215
    exec diff ../outputs/t3215 ../golden/t3215 >/dev/null 2>&1 ;;
  p3216) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1371     > ../outputs/t3216
    exec diff ../outputs/t3216 ../golden/t3216 >/dev/null 2>&1 ;;
  p3217) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1373     > ../outputs/t3217
    exec diff ../outputs/t3217 ../golden/t3217 >/dev/null 2>&1 ;;
  p3218) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1374     > ../outputs/t3218
    exec diff ../outputs/t3218 ../golden/t3218 >/dev/null 2>&1 ;;
  p3219) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1375     > ../outputs/t3219
    exec diff ../outputs/t3219 ../golden/t3219 >/dev/null 2>&1 ;;
  p3220) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1376     > ../outputs/t3220
    exec diff ../outputs/t3220 ../golden/t3220 >/dev/null 2>&1 ;;
  p3221) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1378     > ../outputs/t3221
    exec diff ../outputs/t3221 ../golden/t3221 >/dev/null 2>&1 ;;
  p3222) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1379     > ../outputs/t3222
    exec diff ../outputs/t3222 ../golden/t3222 >/dev/null 2>&1 ;;
  p3223) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.138     > ../outputs/t3223
    exec diff ../outputs/t3223 ../golden/t3223 >/dev/null 2>&1 ;;
  p3224) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1380     > ../outputs/t3224
    exec diff ../outputs/t3224 ../golden/t3224 >/dev/null 2>&1 ;;
  p3225) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1384     > ../outputs/t3225
    exec diff ../outputs/t3225 ../golden/t3225 >/dev/null 2>&1 ;;
  p3226) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1385     > ../outputs/t3226
    exec diff ../outputs/t3226 ../golden/t3226 >/dev/null 2>&1 ;;
  p3227) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1386     > ../outputs/t3227
    exec diff ../outputs/t3227 ../golden/t3227 >/dev/null 2>&1 ;;
  p3228) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1389     > ../outputs/t3228
    exec diff ../outputs/t3228 ../golden/t3228 >/dev/null 2>&1 ;;
  p3229) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.139     > ../outputs/t3229
    exec diff ../outputs/t3229 ../golden/t3229 >/dev/null 2>&1 ;;
  p3230) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1390     > ../outputs/t3230
    exec diff ../outputs/t3230 ../golden/t3230 >/dev/null 2>&1 ;;
  p3231) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1391     > ../outputs/t3231
    exec diff ../outputs/t3231 ../golden/t3231 >/dev/null 2>&1 ;;
  p3232) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1394     > ../outputs/t3232
    exec diff ../outputs/t3232 ../golden/t3232 >/dev/null 2>&1 ;;
  p3233) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1395     > ../outputs/t3233
    exec diff ../outputs/t3233 ../golden/t3233 >/dev/null 2>&1 ;;
  p3234) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1398     > ../outputs/t3234
    exec diff ../outputs/t3234 ../golden/t3234 >/dev/null 2>&1 ;;
  p3235) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1399     > ../outputs/t3235
    exec diff ../outputs/t3235 ../golden/t3235 >/dev/null 2>&1 ;;
  p3236) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.14     > ../outputs/t3236
    exec diff ../outputs/t3236 ../golden/t3236 >/dev/null 2>&1 ;;
  p3237) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1401     > ../outputs/t3237
    exec diff ../outputs/t3237 ../golden/t3237 >/dev/null 2>&1 ;;
  p3238) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1402     > ../outputs/t3238
    exec diff ../outputs/t3238 ../golden/t3238 >/dev/null 2>&1 ;;
  p3239) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1406     > ../outputs/t3239
    exec diff ../outputs/t3239 ../golden/t3239 >/dev/null 2>&1 ;;
  p3240) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1407     > ../outputs/t3240
    exec diff ../outputs/t3240 ../golden/t3240 >/dev/null 2>&1 ;;
  p3241) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.141     > ../outputs/t3241
    exec diff ../outputs/t3241 ../golden/t3241 >/dev/null 2>&1 ;;
  p3242) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1411     > ../outputs/t3242
    exec diff ../outputs/t3242 ../golden/t3242 >/dev/null 2>&1 ;;
  p3243) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1412     > ../outputs/t3243
    exec diff ../outputs/t3243 ../golden/t3243 >/dev/null 2>&1 ;;
  p3244) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1414     > ../outputs/t3244
    exec diff ../outputs/t3244 ../golden/t3244 >/dev/null 2>&1 ;;
  p3245) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1416     > ../outputs/t3245
    exec diff ../outputs/t3245 ../golden/t3245 >/dev/null 2>&1 ;;
  p3246) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1417     > ../outputs/t3246
    exec diff ../outputs/t3246 ../golden/t3246 >/dev/null 2>&1 ;;
  p3247) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1418      > ../outputs/t3247
    exec diff ../outputs/t3247 ../golden/t3247 >/dev/null 2>&1 ;;
  p3248) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1419     > ../outputs/t3248
    exec diff ../outputs/t3248 ../golden/t3248 >/dev/null 2>&1 ;;
  p3249) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1422     > ../outputs/t3249
    exec diff ../outputs/t3249 ../golden/t3249 >/dev/null 2>&1 ;;
  p3250) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1423     > ../outputs/t3250
    exec diff ../outputs/t3250 ../golden/t3250 >/dev/null 2>&1 ;;
  p3251) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1426     > ../outputs/t3251
    exec diff ../outputs/t3251 ../golden/t3251 >/dev/null 2>&1 ;;
  p3252) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1427     > ../outputs/t3252
    exec diff ../outputs/t3252 ../golden/t3252 >/dev/null 2>&1 ;;
  p3253) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1428     > ../outputs/t3253
    exec diff ../outputs/t3253 ../golden/t3253 >/dev/null 2>&1 ;;
  p3254) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1431     > ../outputs/t3254
    exec diff ../outputs/t3254 ../golden/t3254 >/dev/null 2>&1 ;;
  p3255) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1432     > ../outputs/t3255
    exec diff ../outputs/t3255 ../golden/t3255 >/dev/null 2>&1 ;;
  p3256) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1433     > ../outputs/t3256
    exec diff ../outputs/t3256 ../golden/t3256 >/dev/null 2>&1 ;;
  p3257) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1434     > ../outputs/t3257
    exec diff ../outputs/t3257 ../golden/t3257 >/dev/null 2>&1 ;;
  p3258) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1435     > ../outputs/t3258
    exec diff ../outputs/t3258 ../golden/t3258 >/dev/null 2>&1 ;;
  p3259) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1436     > ../outputs/t3259
    exec diff ../outputs/t3259 ../golden/t3259 >/dev/null 2>&1 ;;
  p3260) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.144     > ../outputs/t3260
    exec diff ../outputs/t3260 ../golden/t3260 >/dev/null 2>&1 ;;
  p3261) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1440     > ../outputs/t3261
    exec diff ../outputs/t3261 ../golden/t3261 >/dev/null 2>&1 ;;
  p3262) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1444     > ../outputs/t3262
    exec diff ../outputs/t3262 ../golden/t3262 >/dev/null 2>&1 ;;
  p3263) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1446     > ../outputs/t3263
    exec diff ../outputs/t3263 ../golden/t3263 >/dev/null 2>&1 ;;
  p3264) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1447     > ../outputs/t3264
    exec diff ../outputs/t3264 ../golden/t3264 >/dev/null 2>&1 ;;
  p3265) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1448     > ../outputs/t3265
    exec diff ../outputs/t3265 ../golden/t3265 >/dev/null 2>&1 ;;
  p3266) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1449     > ../outputs/t3266
    exec diff ../outputs/t3266 ../golden/t3266 >/dev/null 2>&1 ;;
  p3267) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1450     > ../outputs/t3267
    exec diff ../outputs/t3267 ../golden/t3267 >/dev/null 2>&1 ;;
  p3268) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1451     > ../outputs/t3268
    exec diff ../outputs/t3268 ../golden/t3268 >/dev/null 2>&1 ;;
  p3269) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1452     > ../outputs/t3269
    exec diff ../outputs/t3269 ../golden/t3269 >/dev/null 2>&1 ;;
  p3270) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1453     > ../outputs/t3270
    exec diff ../outputs/t3270 ../golden/t3270 >/dev/null 2>&1 ;;
  p3271) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1454     > ../outputs/t3271
    exec diff ../outputs/t3271 ../golden/t3271 >/dev/null 2>&1 ;;
  p3272) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1456     > ../outputs/t3272
    exec diff ../outputs/t3272 ../golden/t3272 >/dev/null 2>&1 ;;
  p3273) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1458     > ../outputs/t3273
    exec diff ../outputs/t3273 ../golden/t3273 >/dev/null 2>&1 ;;
  p3274) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.146     > ../outputs/t3274
    exec diff ../outputs/t3274 ../golden/t3274 >/dev/null 2>&1 ;;
  p3275) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1460     > ../outputs/t3275
    exec diff ../outputs/t3275 ../golden/t3275 >/dev/null 2>&1 ;;
  p3276) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1462     > ../outputs/t3276
    exec diff ../outputs/t3276 ../golden/t3276 >/dev/null 2>&1 ;;
  p3277) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1463     > ../outputs/t3277
    exec diff ../outputs/t3277 ../golden/t3277 >/dev/null 2>&1 ;;
  p3278) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1464     > ../outputs/t3278
    exec diff ../outputs/t3278 ../golden/t3278 >/dev/null 2>&1 ;;
  p3279) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1465     > ../outputs/t3279
    exec diff ../outputs/t3279 ../golden/t3279 >/dev/null 2>&1 ;;
  p3280) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1466     > ../outputs/t3280
    exec diff ../outputs/t3280 ../golden/t3280 >/dev/null 2>&1 ;;
  p3281) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1467     > ../outputs/t3281
    exec diff ../outputs/t3281 ../golden/t3281 >/dev/null 2>&1 ;;
  p3282) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1471     > ../outputs/t3282
    exec diff ../outputs/t3282 ../golden/t3282 >/dev/null 2>&1 ;;
  p3283) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1472     > ../outputs/t3283
    exec diff ../outputs/t3283 ../golden/t3283 >/dev/null 2>&1 ;;
  p3284) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1473     > ../outputs/t3284
    exec diff ../outputs/t3284 ../golden/t3284 >/dev/null 2>&1 ;;
  p3285) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1474     > ../outputs/t3285
    exec diff ../outputs/t3285 ../golden/t3285 >/dev/null 2>&1 ;;
  p3286) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1477     > ../outputs/t3286
    exec diff ../outputs/t3286 ../golden/t3286 >/dev/null 2>&1 ;;
  p3287) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1478     > ../outputs/t3287
    exec diff ../outputs/t3287 ../golden/t3287 >/dev/null 2>&1 ;;
  p3288) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1479     > ../outputs/t3288
    exec diff ../outputs/t3288 ../golden/t3288 >/dev/null 2>&1 ;;
  p3289) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.148     > ../outputs/t3289
    exec diff ../outputs/t3289 ../golden/t3289 >/dev/null 2>&1 ;;
  p3290) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1481     > ../outputs/t3290
    exec diff ../outputs/t3290 ../golden/t3290 >/dev/null 2>&1 ;;
  p3291) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1482     > ../outputs/t3291
    exec diff ../outputs/t3291 ../golden/t3291 >/dev/null 2>&1 ;;
  p3292) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1484     > ../outputs/t3292
    exec diff ../outputs/t3292 ../golden/t3292 >/dev/null 2>&1 ;;
  p3293) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1485     > ../outputs/t3293
    exec diff ../outputs/t3293 ../golden/t3293 >/dev/null 2>&1 ;;
  p3294) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1487     > ../outputs/t3294
    exec diff ../outputs/t3294 ../golden/t3294 >/dev/null 2>&1 ;;
  p3295) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1488     > ../outputs/t3295
    exec diff ../outputs/t3295 ../golden/t3295 >/dev/null 2>&1 ;;
  p3296) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1489     > ../outputs/t3296
    exec diff ../outputs/t3296 ../golden/t3296 >/dev/null 2>&1 ;;
  p3297) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.149     > ../outputs/t3297
    exec diff ../outputs/t3297 ../golden/t3297 >/dev/null 2>&1 ;;
  p3298) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1495     > ../outputs/t3298
    exec diff ../outputs/t3298 ../golden/t3298 >/dev/null 2>&1 ;;
  p3299) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1498     > ../outputs/t3299
    exec diff ../outputs/t3299 ../golden/t3299 >/dev/null 2>&1 ;;
  p3300) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1499     > ../outputs/t3300
    exec diff ../outputs/t3300 ../golden/t3300 >/dev/null 2>&1 ;;
  p3301) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.150     > ../outputs/t3301
    exec diff ../outputs/t3301 ../golden/t3301 >/dev/null 2>&1 ;;
  p3302) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1500     > ../outputs/t3302
    exec diff ../outputs/t3302 ../golden/t3302 >/dev/null 2>&1 ;;
  p3303) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1503     > ../outputs/t3303
    exec diff ../outputs/t3303 ../golden/t3303 >/dev/null 2>&1 ;;
  p3304) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1505     > ../outputs/t3304
    exec diff ../outputs/t3304 ../golden/t3304 >/dev/null 2>&1 ;;
  p3305) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1506     > ../outputs/t3305
    exec diff ../outputs/t3305 ../golden/t3305 >/dev/null 2>&1 ;;
  p3306) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1507     > ../outputs/t3306
    exec diff ../outputs/t3306 ../golden/t3306 >/dev/null 2>&1 ;;
  p3307) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1508     > ../outputs/t3307
    exec diff ../outputs/t3307 ../golden/t3307 >/dev/null 2>&1 ;;
  p3308) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1511     > ../outputs/t3308
    exec diff ../outputs/t3308 ../golden/t3308 >/dev/null 2>&1 ;;
  p3309) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1512     > ../outputs/t3309
    exec diff ../outputs/t3309 ../golden/t3309 >/dev/null 2>&1 ;;
  p3310) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1513     > ../outputs/t3310
    exec diff ../outputs/t3310 ../golden/t3310 >/dev/null 2>&1 ;;
  p3311) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1514     > ../outputs/t3311
    exec diff ../outputs/t3311 ../golden/t3311 >/dev/null 2>&1 ;;
  p3312) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1515     > ../outputs/t3312
    exec diff ../outputs/t3312 ../golden/t3312 >/dev/null 2>&1 ;;
  p3313) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.152      > ../outputs/t3313
    exec diff ../outputs/t3313 ../golden/t3313 >/dev/null 2>&1 ;;
  p3314) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1520     > ../outputs/t3314
    exec diff ../outputs/t3314 ../golden/t3314 >/dev/null 2>&1 ;;
  p3315) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1521     > ../outputs/t3315
    exec diff ../outputs/t3315 ../golden/t3315 >/dev/null 2>&1 ;;
  p3316) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1522      > ../outputs/t3316
    exec diff ../outputs/t3316 ../golden/t3316 >/dev/null 2>&1 ;;
  p3317) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1523     > ../outputs/t3317
    exec diff ../outputs/t3317 ../golden/t3317 >/dev/null 2>&1 ;;
  p3318) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1528     > ../outputs/t3318
    exec diff ../outputs/t3318 ../golden/t3318 >/dev/null 2>&1 ;;
  p3319) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1531     > ../outputs/t3319
    exec diff ../outputs/t3319 ../golden/t3319 >/dev/null 2>&1 ;;
  p3320) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1533     > ../outputs/t3320
    exec diff ../outputs/t3320 ../golden/t3320 >/dev/null 2>&1 ;;
  p3321) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1535     > ../outputs/t3321
    exec diff ../outputs/t3321 ../golden/t3321 >/dev/null 2>&1 ;;
  p3322) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1536     > ../outputs/t3322
    exec diff ../outputs/t3322 ../golden/t3322 >/dev/null 2>&1 ;;
  p3323) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1537     > ../outputs/t3323
    exec diff ../outputs/t3323 ../golden/t3323 >/dev/null 2>&1 ;;
  p3324) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1540     > ../outputs/t3324
    exec diff ../outputs/t3324 ../golden/t3324 >/dev/null 2>&1 ;;
  p3325) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1543     > ../outputs/t3325
    exec diff ../outputs/t3325 ../golden/t3325 >/dev/null 2>&1 ;;
  p3326) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1544     > ../outputs/t3326
    exec diff ../outputs/t3326 ../golden/t3326 >/dev/null 2>&1 ;;
  p3327) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1545     > ../outputs/t3327
    exec diff ../outputs/t3327 ../golden/t3327 >/dev/null 2>&1 ;;
  p3328) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1547      > ../outputs/t3328
    exec diff ../outputs/t3328 ../golden/t3328 >/dev/null 2>&1 ;;
  p3329) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1548     > ../outputs/t3329
    exec diff ../outputs/t3329 ../golden/t3329 >/dev/null 2>&1 ;;
  p3330) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1550     > ../outputs/t3330
    exec diff ../outputs/t3330 ../golden/t3330 >/dev/null 2>&1 ;;
  p3331) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1552     > ../outputs/t3331
    exec diff ../outputs/t3331 ../golden/t3331 >/dev/null 2>&1 ;;
  p3332) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1553     > ../outputs/t3332
    exec diff ../outputs/t3332 ../golden/t3332 >/dev/null 2>&1 ;;
  p3333) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1555     > ../outputs/t3333
    exec diff ../outputs/t3333 ../golden/t3333 >/dev/null 2>&1 ;;
  p3334) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1558     > ../outputs/t3334
    exec diff ../outputs/t3334 ../golden/t3334 >/dev/null 2>&1 ;;
  p3335) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.156     > ../outputs/t3335
    exec diff ../outputs/t3335 ../golden/t3335 >/dev/null 2>&1 ;;
  p3336) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1560     > ../outputs/t3336
    exec diff ../outputs/t3336 ../golden/t3336 >/dev/null 2>&1 ;;
  p3337) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1561     > ../outputs/t3337
    exec diff ../outputs/t3337 ../golden/t3337 >/dev/null 2>&1 ;;
  p3338) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1564     > ../outputs/t3338
    exec diff ../outputs/t3338 ../golden/t3338 >/dev/null 2>&1 ;;
  p3339) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1568     > ../outputs/t3339
    exec diff ../outputs/t3339 ../golden/t3339 >/dev/null 2>&1 ;;
  p3340) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1571     > ../outputs/t3340
    exec diff ../outputs/t3340 ../golden/t3340 >/dev/null 2>&1 ;;
  p3341) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1573     > ../outputs/t3341
    exec diff ../outputs/t3341 ../golden/t3341 >/dev/null 2>&1 ;;
  p3342) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1574     > ../outputs/t3342
    exec diff ../outputs/t3342 ../golden/t3342 >/dev/null 2>&1 ;;
  p3343) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1575      > ../outputs/t3343
    exec diff ../outputs/t3343 ../golden/t3343 >/dev/null 2>&1 ;;
  p3344) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1577     > ../outputs/t3344
    exec diff ../outputs/t3344 ../golden/t3344 >/dev/null 2>&1 ;;
  p3345) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.158     > ../outputs/t3345
    exec diff ../outputs/t3345 ../golden/t3345 >/dev/null 2>&1 ;;
  p3346) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1580     > ../outputs/t3346
    exec diff ../outputs/t3346 ../golden/t3346 >/dev/null 2>&1 ;;
  p3347) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1581     > ../outputs/t3347
    exec diff ../outputs/t3347 ../golden/t3347 >/dev/null 2>&1 ;;
  p3348) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1582     > ../outputs/t3348
    exec diff ../outputs/t3348 ../golden/t3348 >/dev/null 2>&1 ;;
  p3349) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1583      > ../outputs/t3349
    exec diff ../outputs/t3349 ../golden/t3349 >/dev/null 2>&1 ;;
  p3350) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1585     > ../outputs/t3350
    exec diff ../outputs/t3350 ../golden/t3350 >/dev/null 2>&1 ;;
  p3351) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1586      > ../outputs/t3351
    exec diff ../outputs/t3351 ../golden/t3351 >/dev/null 2>&1 ;;
  p3352) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.159     > ../outputs/t3352
    exec diff ../outputs/t3352 ../golden/t3352 >/dev/null 2>&1 ;;
  p3353) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1590     > ../outputs/t3353
    exec diff ../outputs/t3353 ../golden/t3353 >/dev/null 2>&1 ;;
  p3354) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1591     > ../outputs/t3354
    exec diff ../outputs/t3354 ../golden/t3354 >/dev/null 2>&1 ;;
  p3355) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1592     > ../outputs/t3355
    exec diff ../outputs/t3355 ../golden/t3355 >/dev/null 2>&1 ;;
  p3356) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1594     > ../outputs/t3356
    exec diff ../outputs/t3356 ../golden/t3356 >/dev/null 2>&1 ;;
  p3357) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1595      > ../outputs/t3357
    exec diff ../outputs/t3357 ../golden/t3357 >/dev/null 2>&1 ;;
  p3358) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1597     > ../outputs/t3358
    exec diff ../outputs/t3358 ../golden/t3358 >/dev/null 2>&1 ;;
  p3359) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1601     > ../outputs/t3359
    exec diff ../outputs/t3359 ../golden/t3359 >/dev/null 2>&1 ;;
  p3360) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1602     > ../outputs/t3360
    exec diff ../outputs/t3360 ../golden/t3360 >/dev/null 2>&1 ;;
  p3361) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1603     > ../outputs/t3361
    exec diff ../outputs/t3361 ../golden/t3361 >/dev/null 2>&1 ;;
  p3362) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1606     > ../outputs/t3362
    exec diff ../outputs/t3362 ../golden/t3362 >/dev/null 2>&1 ;;
  p3363) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1607     > ../outputs/t3363
    exec diff ../outputs/t3363 ../golden/t3363 >/dev/null 2>&1 ;;
  p3364) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1608     > ../outputs/t3364
    exec diff ../outputs/t3364 ../golden/t3364 >/dev/null 2>&1 ;;
  p3365) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1610      > ../outputs/t3365
    exec diff ../outputs/t3365 ../golden/t3365 >/dev/null 2>&1 ;;
  p3366) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1614     > ../outputs/t3366
    exec diff ../outputs/t3366 ../golden/t3366 >/dev/null 2>&1 ;;
  p3367) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1617     > ../outputs/t3367
    exec diff ../outputs/t3367 ../golden/t3367 >/dev/null 2>&1 ;;
  p3368) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1618     > ../outputs/t3368
    exec diff ../outputs/t3368 ../golden/t3368 >/dev/null 2>&1 ;;
  p3369) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1619     > ../outputs/t3369
    exec diff ../outputs/t3369 ../golden/t3369 >/dev/null 2>&1 ;;
  p3370) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1620     > ../outputs/t3370
    exec diff ../outputs/t3370 ../golden/t3370 >/dev/null 2>&1 ;;
  p3371) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1623     > ../outputs/t3371
    exec diff ../outputs/t3371 ../golden/t3371 >/dev/null 2>&1 ;;
  p3372) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1624     > ../outputs/t3372
    exec diff ../outputs/t3372 ../golden/t3372 >/dev/null 2>&1 ;;
  p3373) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1625     > ../outputs/t3373
    exec diff ../outputs/t3373 ../golden/t3373 >/dev/null 2>&1 ;;
  p3374) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1626      > ../outputs/t3374
    exec diff ../outputs/t3374 ../golden/t3374 >/dev/null 2>&1 ;;
  p3375) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1629     > ../outputs/t3375
    exec diff ../outputs/t3375 ../golden/t3375 >/dev/null 2>&1 ;;
  p3376) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1630     > ../outputs/t3376
    exec diff ../outputs/t3376 ../golden/t3376 >/dev/null 2>&1 ;;
  p3377) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1631     > ../outputs/t3377
    exec diff ../outputs/t3377 ../golden/t3377 >/dev/null 2>&1 ;;
  p3378) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1632     > ../outputs/t3378
    exec diff ../outputs/t3378 ../golden/t3378 >/dev/null 2>&1 ;;
  p3379) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1634     > ../outputs/t3379
    exec diff ../outputs/t3379 ../golden/t3379 >/dev/null 2>&1 ;;
  p3380) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1635     > ../outputs/t3380
    exec diff ../outputs/t3380 ../golden/t3380 >/dev/null 2>&1 ;;
  p3381) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1637     > ../outputs/t3381
    exec diff ../outputs/t3381 ../golden/t3381 >/dev/null 2>&1 ;;
  p3382) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1638     > ../outputs/t3382
    exec diff ../outputs/t3382 ../golden/t3382 >/dev/null 2>&1 ;;
  p3383) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1641     > ../outputs/t3383
    exec diff ../outputs/t3383 ../golden/t3383 >/dev/null 2>&1 ;;
  p3384) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1644     > ../outputs/t3384
    exec diff ../outputs/t3384 ../golden/t3384 >/dev/null 2>&1 ;;
  p3385) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1645     > ../outputs/t3385
    exec diff ../outputs/t3385 ../golden/t3385 >/dev/null 2>&1 ;;
  p3386) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1646     > ../outputs/t3386
    exec diff ../outputs/t3386 ../golden/t3386 >/dev/null 2>&1 ;;
  p3387) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.165     > ../outputs/t3387
    exec diff ../outputs/t3387 ../golden/t3387 >/dev/null 2>&1 ;;
  p3388) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1651     > ../outputs/t3388
    exec diff ../outputs/t3388 ../golden/t3388 >/dev/null 2>&1 ;;
  p3389) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1652     > ../outputs/t3389
    exec diff ../outputs/t3389 ../golden/t3389 >/dev/null 2>&1 ;;
  p3390) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1653     > ../outputs/t3390
    exec diff ../outputs/t3390 ../golden/t3390 >/dev/null 2>&1 ;;
  p3391) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1654     > ../outputs/t3391
    exec diff ../outputs/t3391 ../golden/t3391 >/dev/null 2>&1 ;;
  p3392) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1655     > ../outputs/t3392
    exec diff ../outputs/t3392 ../golden/t3392 >/dev/null 2>&1 ;;
  p3393) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1656     > ../outputs/t3393
    exec diff ../outputs/t3393 ../golden/t3393 >/dev/null 2>&1 ;;
  p3394) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1657     > ../outputs/t3394
    exec diff ../outputs/t3394 ../golden/t3394 >/dev/null 2>&1 ;;
  p3395) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.166     > ../outputs/t3395
    exec diff ../outputs/t3395 ../golden/t3395 >/dev/null 2>&1 ;;
  p3396) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1661     > ../outputs/t3396
    exec diff ../outputs/t3396 ../golden/t3396 >/dev/null 2>&1 ;;
  p3397) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1662     > ../outputs/t3397
    exec diff ../outputs/t3397 ../golden/t3397 >/dev/null 2>&1 ;;
  p3398) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1663     > ../outputs/t3398
    exec diff ../outputs/t3398 ../golden/t3398 >/dev/null 2>&1 ;;
  p3399) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1664     > ../outputs/t3399
    exec diff ../outputs/t3399 ../golden/t3399 >/dev/null 2>&1 ;;
  p3400) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1665     > ../outputs/t3400
    exec diff ../outputs/t3400 ../golden/t3400 >/dev/null 2>&1 ;;
  p3401) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.167     > ../outputs/t3401
    exec diff ../outputs/t3401 ../golden/t3401 >/dev/null 2>&1 ;;
  p3402) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1673     > ../outputs/t3402
    exec diff ../outputs/t3402 ../golden/t3402 >/dev/null 2>&1 ;;
  p3403) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1674     > ../outputs/t3403
    exec diff ../outputs/t3403 ../golden/t3403 >/dev/null 2>&1 ;;
  p3404) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1677      > ../outputs/t3404
    exec diff ../outputs/t3404 ../golden/t3404 >/dev/null 2>&1 ;;
  p3405) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1678     > ../outputs/t3405
    exec diff ../outputs/t3405 ../golden/t3405 >/dev/null 2>&1 ;;
  p3406) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.168     > ../outputs/t3406
    exec diff ../outputs/t3406 ../golden/t3406 >/dev/null 2>&1 ;;
  p3407) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1680     > ../outputs/t3407
    exec diff ../outputs/t3407 ../golden/t3407 >/dev/null 2>&1 ;;
  p3408) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1682     > ../outputs/t3408
    exec diff ../outputs/t3408 ../golden/t3408 >/dev/null 2>&1 ;;
  p3409) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1683     > ../outputs/t3409
    exec diff ../outputs/t3409 ../golden/t3409 >/dev/null 2>&1 ;;
  p3410) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1684     > ../outputs/t3410
    exec diff ../outputs/t3410 ../golden/t3410 >/dev/null 2>&1 ;;
  p3411) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1685     > ../outputs/t3411
    exec diff ../outputs/t3411 ../golden/t3411 >/dev/null 2>&1 ;;
  p3412) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1687     > ../outputs/t3412
    exec diff ../outputs/t3412 ../golden/t3412 >/dev/null 2>&1 ;;
  p3413) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1688     > ../outputs/t3413
    exec diff ../outputs/t3413 ../golden/t3413 >/dev/null 2>&1 ;;
  p3414) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1689     > ../outputs/t3414
    exec diff ../outputs/t3414 ../golden/t3414 >/dev/null 2>&1 ;;
  p3415) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1690     > ../outputs/t3415
    exec diff ../outputs/t3415 ../golden/t3415 >/dev/null 2>&1 ;;
  p3416) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1692     > ../outputs/t3416
    exec diff ../outputs/t3416 ../golden/t3416 >/dev/null 2>&1 ;;
  p3417) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1693     > ../outputs/t3417
    exec diff ../outputs/t3417 ../golden/t3417 >/dev/null 2>&1 ;;
  p3418) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1696     > ../outputs/t3418
    exec diff ../outputs/t3418 ../golden/t3418 >/dev/null 2>&1 ;;
  p3419) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1697     > ../outputs/t3419
    exec diff ../outputs/t3419 ../golden/t3419 >/dev/null 2>&1 ;;
  p3420) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1699     > ../outputs/t3420
    exec diff ../outputs/t3420 ../golden/t3420 >/dev/null 2>&1 ;;
  p3421) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1700     > ../outputs/t3421
    exec diff ../outputs/t3421 ../golden/t3421 >/dev/null 2>&1 ;;
  p3422) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1701     > ../outputs/t3422
    exec diff ../outputs/t3422 ../golden/t3422 >/dev/null 2>&1 ;;
  p3423) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1703     > ../outputs/t3423
    exec diff ../outputs/t3423 ../golden/t3423 >/dev/null 2>&1 ;;
  p3424) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1704     > ../outputs/t3424
    exec diff ../outputs/t3424 ../golden/t3424 >/dev/null 2>&1 ;;
  p3425) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1705     > ../outputs/t3425
    exec diff ../outputs/t3425 ../golden/t3425 >/dev/null 2>&1 ;;
  p3426) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1706     > ../outputs/t3426
    exec diff ../outputs/t3426 ../golden/t3426 >/dev/null 2>&1 ;;
  p3427) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1708     > ../outputs/t3427
    exec diff ../outputs/t3427 ../golden/t3427 >/dev/null 2>&1 ;;
  p3428) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1709     > ../outputs/t3428
    exec diff ../outputs/t3428 ../golden/t3428 >/dev/null 2>&1 ;;
  p3429) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1713     > ../outputs/t3429
    exec diff ../outputs/t3429 ../golden/t3429 >/dev/null 2>&1 ;;
  p3430) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1714     > ../outputs/t3430
    exec diff ../outputs/t3430 ../golden/t3430 >/dev/null 2>&1 ;;
  p3431) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1715     > ../outputs/t3431
    exec diff ../outputs/t3431 ../golden/t3431 >/dev/null 2>&1 ;;
  p3432) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1717     > ../outputs/t3432
    exec diff ../outputs/t3432 ../golden/t3432 >/dev/null 2>&1 ;;
  p3433) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1718     > ../outputs/t3433
    exec diff ../outputs/t3433 ../golden/t3433 >/dev/null 2>&1 ;;
  p3434) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1719     > ../outputs/t3434
    exec diff ../outputs/t3434 ../golden/t3434 >/dev/null 2>&1 ;;
  p3435) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.172     > ../outputs/t3435
    exec diff ../outputs/t3435 ../golden/t3435 >/dev/null 2>&1 ;;
  p3436) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1720     > ../outputs/t3436
    exec diff ../outputs/t3436 ../golden/t3436 >/dev/null 2>&1 ;;
  p3437) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1721     > ../outputs/t3437
    exec diff ../outputs/t3437 ../golden/t3437 >/dev/null 2>&1 ;;
  p3438) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1722     > ../outputs/t3438
    exec diff ../outputs/t3438 ../golden/t3438 >/dev/null 2>&1 ;;
  p3439) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1723     > ../outputs/t3439
    exec diff ../outputs/t3439 ../golden/t3439 >/dev/null 2>&1 ;;
  p3440) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1725     > ../outputs/t3440
    exec diff ../outputs/t3440 ../golden/t3440 >/dev/null 2>&1 ;;
  p3441) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1726     > ../outputs/t3441
    exec diff ../outputs/t3441 ../golden/t3441 >/dev/null 2>&1 ;;
  p3442) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1727     > ../outputs/t3442
    exec diff ../outputs/t3442 ../golden/t3442 >/dev/null 2>&1 ;;
  p3443) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1729     > ../outputs/t3443
    exec diff ../outputs/t3443 ../golden/t3443 >/dev/null 2>&1 ;;
  p3444) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.173     > ../outputs/t3444
    exec diff ../outputs/t3444 ../golden/t3444 >/dev/null 2>&1 ;;
  p3445) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1731     > ../outputs/t3445
    exec diff ../outputs/t3445 ../golden/t3445 >/dev/null 2>&1 ;;
  p3446) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1732     > ../outputs/t3446
    exec diff ../outputs/t3446 ../golden/t3446 >/dev/null 2>&1 ;;
  p3447) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1733     > ../outputs/t3447
    exec diff ../outputs/t3447 ../golden/t3447 >/dev/null 2>&1 ;;
  p3448) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1734     > ../outputs/t3448
    exec diff ../outputs/t3448 ../golden/t3448 >/dev/null 2>&1 ;;
  p3449) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1736     > ../outputs/t3449
    exec diff ../outputs/t3449 ../golden/t3449 >/dev/null 2>&1 ;;
  p3450) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1739     > ../outputs/t3450
    exec diff ../outputs/t3450 ../golden/t3450 >/dev/null 2>&1 ;;
  p3451) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.174     > ../outputs/t3451
    exec diff ../outputs/t3451 ../golden/t3451 >/dev/null 2>&1 ;;
  p3452) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1741     > ../outputs/t3452
    exec diff ../outputs/t3452 ../golden/t3452 >/dev/null 2>&1 ;;
  p3453) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1743     > ../outputs/t3453
    exec diff ../outputs/t3453 ../golden/t3453 >/dev/null 2>&1 ;;
  p3454) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1745     > ../outputs/t3454
    exec diff ../outputs/t3454 ../golden/t3454 >/dev/null 2>&1 ;;
  p3455) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1746     > ../outputs/t3455
    exec diff ../outputs/t3455 ../golden/t3455 >/dev/null 2>&1 ;;
  p3456) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1747     > ../outputs/t3456
    exec diff ../outputs/t3456 ../golden/t3456 >/dev/null 2>&1 ;;
  p3457) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1748     > ../outputs/t3457
    exec diff ../outputs/t3457 ../golden/t3457 >/dev/null 2>&1 ;;
  p3458) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1749     > ../outputs/t3458
    exec diff ../outputs/t3458 ../golden/t3458 >/dev/null 2>&1 ;;
  p3459) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1750     > ../outputs/t3459
    exec diff ../outputs/t3459 ../golden/t3459 >/dev/null 2>&1 ;;
  p3460) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1751     > ../outputs/t3460
    exec diff ../outputs/t3460 ../golden/t3460 >/dev/null 2>&1 ;;
  p3461) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1757     > ../outputs/t3461
    exec diff ../outputs/t3461 ../golden/t3461 >/dev/null 2>&1 ;;
  p3462) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1758     > ../outputs/t3462
    exec diff ../outputs/t3462 ../golden/t3462 >/dev/null 2>&1 ;;
  p3463) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1759     > ../outputs/t3463
    exec diff ../outputs/t3463 ../golden/t3463 >/dev/null 2>&1 ;;
  p3464) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1761     > ../outputs/t3464
    exec diff ../outputs/t3464 ../golden/t3464 >/dev/null 2>&1 ;;
  p3465) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1763     > ../outputs/t3465
    exec diff ../outputs/t3465 ../golden/t3465 >/dev/null 2>&1 ;;
  p3466) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1765     > ../outputs/t3466
    exec diff ../outputs/t3466 ../golden/t3466 >/dev/null 2>&1 ;;
  p3467) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1766     > ../outputs/t3467
    exec diff ../outputs/t3467 ../golden/t3467 >/dev/null 2>&1 ;;
  p3468) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1767     > ../outputs/t3468
    exec diff ../outputs/t3468 ../golden/t3468 >/dev/null 2>&1 ;;
  p3469) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1768     > ../outputs/t3469
    exec diff ../outputs/t3469 ../golden/t3469 >/dev/null 2>&1 ;;
  p3470) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1769     > ../outputs/t3470
    exec diff ../outputs/t3470 ../golden/t3470 >/dev/null 2>&1 ;;
  p3471) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1770     > ../outputs/t3471
    exec diff ../outputs/t3471 ../golden/t3471 >/dev/null 2>&1 ;;
  p3472) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1772     > ../outputs/t3472
    exec diff ../outputs/t3472 ../golden/t3472 >/dev/null 2>&1 ;;
  p3473) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1775     > ../outputs/t3473
    exec diff ../outputs/t3473 ../golden/t3473 >/dev/null 2>&1 ;;
  p3474) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1777     > ../outputs/t3474
    exec diff ../outputs/t3474 ../golden/t3474 >/dev/null 2>&1 ;;
  p3475) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1779     > ../outputs/t3475
    exec diff ../outputs/t3475 ../golden/t3475 >/dev/null 2>&1 ;;
  p3476) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.178     > ../outputs/t3476
    exec diff ../outputs/t3476 ../golden/t3476 >/dev/null 2>&1 ;;
  p3477) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1780     > ../outputs/t3477
    exec diff ../outputs/t3477 ../golden/t3477 >/dev/null 2>&1 ;;
  p3478) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1781     > ../outputs/t3478
    exec diff ../outputs/t3478 ../golden/t3478 >/dev/null 2>&1 ;;
  p3479) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1784     > ../outputs/t3479
    exec diff ../outputs/t3479 ../golden/t3479 >/dev/null 2>&1 ;;
  p3480) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1786     > ../outputs/t3480
    exec diff ../outputs/t3480 ../golden/t3480 >/dev/null 2>&1 ;;
  p3481) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1788      > ../outputs/t3481
    exec diff ../outputs/t3481 ../golden/t3481 >/dev/null 2>&1 ;;
  p3482) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.179     > ../outputs/t3482
    exec diff ../outputs/t3482 ../golden/t3482 >/dev/null 2>&1 ;;
  p3483) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1790     > ../outputs/t3483
    exec diff ../outputs/t3483 ../golden/t3483 >/dev/null 2>&1 ;;
  p3484) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1791     > ../outputs/t3484
    exec diff ../outputs/t3484 ../golden/t3484 >/dev/null 2>&1 ;;
  p3485) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1795      > ../outputs/t3485
    exec diff ../outputs/t3485 ../golden/t3485 >/dev/null 2>&1 ;;
  p3486) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1796     > ../outputs/t3486
    exec diff ../outputs/t3486 ../golden/t3486 >/dev/null 2>&1 ;;
  p3487) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1797     > ../outputs/t3487
    exec diff ../outputs/t3487 ../golden/t3487 >/dev/null 2>&1 ;;
  p3488) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1799     > ../outputs/t3488
    exec diff ../outputs/t3488 ../golden/t3488 >/dev/null 2>&1 ;;
  p3489) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.18     > ../outputs/t3489
    exec diff ../outputs/t3489 ../golden/t3489 >/dev/null 2>&1 ;;
  p3490) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.180     > ../outputs/t3490
    exec diff ../outputs/t3490 ../golden/t3490 >/dev/null 2>&1 ;;
  p3491) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1801     > ../outputs/t3491
    exec diff ../outputs/t3491 ../golden/t3491 >/dev/null 2>&1 ;;
  p3492) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1803     > ../outputs/t3492
    exec diff ../outputs/t3492 ../golden/t3492 >/dev/null 2>&1 ;;
  p3493) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1804     > ../outputs/t3493
    exec diff ../outputs/t3493 ../golden/t3493 >/dev/null 2>&1 ;;
  p3494) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1805     > ../outputs/t3494
    exec diff ../outputs/t3494 ../golden/t3494 >/dev/null 2>&1 ;;
  p3495) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1807     > ../outputs/t3495
    exec diff ../outputs/t3495 ../golden/t3495 >/dev/null 2>&1 ;;
  p3496) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1808     > ../outputs/t3496
    exec diff ../outputs/t3496 ../golden/t3496 >/dev/null 2>&1 ;;
  p3497) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1810     > ../outputs/t3497
    exec diff ../outputs/t3497 ../golden/t3497 >/dev/null 2>&1 ;;
  p3498) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1811     > ../outputs/t3498
    exec diff ../outputs/t3498 ../golden/t3498 >/dev/null 2>&1 ;;
  p3499) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1813     > ../outputs/t3499
    exec diff ../outputs/t3499 ../golden/t3499 >/dev/null 2>&1 ;;
  p3500) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1815     > ../outputs/t3500
    exec diff ../outputs/t3500 ../golden/t3500 >/dev/null 2>&1 ;;
  p3501) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1817     > ../outputs/t3501
    exec diff ../outputs/t3501 ../golden/t3501 >/dev/null 2>&1 ;;
  p3502) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1820     > ../outputs/t3502
    exec diff ../outputs/t3502 ../golden/t3502 >/dev/null 2>&1 ;;
  p3503) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1822     > ../outputs/t3503
    exec diff ../outputs/t3503 ../golden/t3503 >/dev/null 2>&1 ;;
  p3504) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1824     > ../outputs/t3504
    exec diff ../outputs/t3504 ../golden/t3504 >/dev/null 2>&1 ;;
  p3505) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1825     > ../outputs/t3505
    exec diff ../outputs/t3505 ../golden/t3505 >/dev/null 2>&1 ;;
  p3506) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1826     > ../outputs/t3506
    exec diff ../outputs/t3506 ../golden/t3506 >/dev/null 2>&1 ;;
  p3507) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1828     > ../outputs/t3507
    exec diff ../outputs/t3507 ../golden/t3507 >/dev/null 2>&1 ;;
  p3508) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.183     > ../outputs/t3508
    exec diff ../outputs/t3508 ../golden/t3508 >/dev/null 2>&1 ;;
  p3509) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1831     > ../outputs/t3509
    exec diff ../outputs/t3509 ../golden/t3509 >/dev/null 2>&1 ;;
  p3510) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1833     > ../outputs/t3510
    exec diff ../outputs/t3510 ../golden/t3510 >/dev/null 2>&1 ;;
  p3511) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1834     > ../outputs/t3511
    exec diff ../outputs/t3511 ../golden/t3511 >/dev/null 2>&1 ;;
  p3512) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1840     > ../outputs/t3512
    exec diff ../outputs/t3512 ../golden/t3512 >/dev/null 2>&1 ;;
  p3513) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1841     > ../outputs/t3513
    exec diff ../outputs/t3513 ../golden/t3513 >/dev/null 2>&1 ;;
  p3514) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1842     > ../outputs/t3514
    exec diff ../outputs/t3514 ../golden/t3514 >/dev/null 2>&1 ;;
  p3515) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1843     > ../outputs/t3515
    exec diff ../outputs/t3515 ../golden/t3515 >/dev/null 2>&1 ;;
  p3516) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1844     > ../outputs/t3516
    exec diff ../outputs/t3516 ../golden/t3516 >/dev/null 2>&1 ;;
  p3517) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1846     > ../outputs/t3517
    exec diff ../outputs/t3517 ../golden/t3517 >/dev/null 2>&1 ;;
  p3518) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1849     > ../outputs/t3518
    exec diff ../outputs/t3518 ../golden/t3518 >/dev/null 2>&1 ;;
  p3519) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1851     > ../outputs/t3519
    exec diff ../outputs/t3519 ../golden/t3519 >/dev/null 2>&1 ;;
  p3520) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1852     > ../outputs/t3520
    exec diff ../outputs/t3520 ../golden/t3520 >/dev/null 2>&1 ;;
  p3521) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1853      > ../outputs/t3521
    exec diff ../outputs/t3521 ../golden/t3521 >/dev/null 2>&1 ;;
  p3522) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1854      > ../outputs/t3522
    exec diff ../outputs/t3522 ../golden/t3522 >/dev/null 2>&1 ;;
  p3523) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1857     > ../outputs/t3523
    exec diff ../outputs/t3523 ../golden/t3523 >/dev/null 2>&1 ;;
  p3524) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1857.noeof     > ../outputs/t3524
    exec diff ../outputs/t3524 ../golden/t3524 >/dev/null 2>&1 ;;
  p3525) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1859     > ../outputs/t3525
    exec diff ../outputs/t3525 ../golden/t3525 >/dev/null 2>&1 ;;
  p3526) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.186     > ../outputs/t3526
    exec diff ../outputs/t3526 ../golden/t3526 >/dev/null 2>&1 ;;
  p3527) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1860     > ../outputs/t3527
    exec diff ../outputs/t3527 ../golden/t3527 >/dev/null 2>&1 ;;
  p3528) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1861     > ../outputs/t3528
    exec diff ../outputs/t3528 ../golden/t3528 >/dev/null 2>&1 ;;
  p3529) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1864     > ../outputs/t3529
    exec diff ../outputs/t3529 ../golden/t3529 >/dev/null 2>&1 ;;
  p3530) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1866     > ../outputs/t3530
    exec diff ../outputs/t3530 ../golden/t3530 >/dev/null 2>&1 ;;
  p3531) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1867     > ../outputs/t3531
    exec diff ../outputs/t3531 ../golden/t3531 >/dev/null 2>&1 ;;
  p3532) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1868     > ../outputs/t3532
    exec diff ../outputs/t3532 ../golden/t3532 >/dev/null 2>&1 ;;
  p3533) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1869     > ../outputs/t3533
    exec diff ../outputs/t3533 ../golden/t3533 >/dev/null 2>&1 ;;
  p3534) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.187     > ../outputs/t3534
    exec diff ../outputs/t3534 ../golden/t3534 >/dev/null 2>&1 ;;
  p3535) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1870     > ../outputs/t3535
    exec diff ../outputs/t3535 ../golden/t3535 >/dev/null 2>&1 ;;
  p3536) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1875     > ../outputs/t3536
    exec diff ../outputs/t3536 ../golden/t3536 >/dev/null 2>&1 ;;
  p3537) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1879     > ../outputs/t3537
    exec diff ../outputs/t3537 ../golden/t3537 >/dev/null 2>&1 ;;
  p3538) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1883     > ../outputs/t3538
    exec diff ../outputs/t3538 ../golden/t3538 >/dev/null 2>&1 ;;
  p3539) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1884     > ../outputs/t3539
    exec diff ../outputs/t3539 ../golden/t3539 >/dev/null 2>&1 ;;
  p3540) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1888     > ../outputs/t3540
    exec diff ../outputs/t3540 ../golden/t3540 >/dev/null 2>&1 ;;
  p3541) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1889     > ../outputs/t3541
    exec diff ../outputs/t3541 ../golden/t3541 >/dev/null 2>&1 ;;
  p3542) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1890     > ../outputs/t3542
    exec diff ../outputs/t3542 ../golden/t3542 >/dev/null 2>&1 ;;
  p3543) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1894     > ../outputs/t3543
    exec diff ../outputs/t3543 ../golden/t3543 >/dev/null 2>&1 ;;
  p3544) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1899     > ../outputs/t3544
    exec diff ../outputs/t3544 ../golden/t3544 >/dev/null 2>&1 ;;
  p3545) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.19     > ../outputs/t3545
    exec diff ../outputs/t3545 ../golden/t3545 >/dev/null 2>&1 ;;
  p3546) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1900     > ../outputs/t3546
    exec diff ../outputs/t3546 ../golden/t3546 >/dev/null 2>&1 ;;
  p3547) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1901     > ../outputs/t3547
    exec diff ../outputs/t3547 ../golden/t3547 >/dev/null 2>&1 ;;
  p3548) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1902     > ../outputs/t3548
    exec diff ../outputs/t3548 ../golden/t3548 >/dev/null 2>&1 ;;
  p3549) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1904     > ../outputs/t3549
    exec diff ../outputs/t3549 ../golden/t3549 >/dev/null 2>&1 ;;
  p3550) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1906     > ../outputs/t3550
    exec diff ../outputs/t3550 ../golden/t3550 >/dev/null 2>&1 ;;
  p3551) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1909     > ../outputs/t3551
    exec diff ../outputs/t3551 ../golden/t3551 >/dev/null 2>&1 ;;
  p3552) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1910     > ../outputs/t3552
    exec diff ../outputs/t3552 ../golden/t3552 >/dev/null 2>&1 ;;
  p3553) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1911     > ../outputs/t3553
    exec diff ../outputs/t3553 ../golden/t3553 >/dev/null 2>&1 ;;
  p3554) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1915     > ../outputs/t3554
    exec diff ../outputs/t3554 ../golden/t3554 >/dev/null 2>&1 ;;
  p3555) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1919     > ../outputs/t3555
    exec diff ../outputs/t3555 ../golden/t3555 >/dev/null 2>&1 ;;
  p3556) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.192     > ../outputs/t3556
    exec diff ../outputs/t3556 ../golden/t3556 >/dev/null 2>&1 ;;
  p3557) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1921     > ../outputs/t3557
    exec diff ../outputs/t3557 ../golden/t3557 >/dev/null 2>&1 ;;
  p3558) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1923     > ../outputs/t3558
    exec diff ../outputs/t3558 ../golden/t3558 >/dev/null 2>&1 ;;
  p3559) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1927     > ../outputs/t3559
    exec diff ../outputs/t3559 ../golden/t3559 >/dev/null 2>&1 ;;
  p3560) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1928      > ../outputs/t3560
    exec diff ../outputs/t3560 ../golden/t3560 >/dev/null 2>&1 ;;
  p3561) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1930     > ../outputs/t3561
    exec diff ../outputs/t3561 ../golden/t3561 >/dev/null 2>&1 ;;
  p3562) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1939     > ../outputs/t3562
    exec diff ../outputs/t3562 ../golden/t3562 >/dev/null 2>&1 ;;
  p3563) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.194     > ../outputs/t3563
    exec diff ../outputs/t3563 ../golden/t3563 >/dev/null 2>&1 ;;
  p3564) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1940     > ../outputs/t3564
    exec diff ../outputs/t3564 ../golden/t3564 >/dev/null 2>&1 ;;
  p3565) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1941     > ../outputs/t3565
    exec diff ../outputs/t3565 ../golden/t3565 >/dev/null 2>&1 ;;
  p3566) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1942     > ../outputs/t3566
    exec diff ../outputs/t3566 ../golden/t3566 >/dev/null 2>&1 ;;
  p3567) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1943     > ../outputs/t3567
    exec diff ../outputs/t3567 ../golden/t3567 >/dev/null 2>&1 ;;
  p3568) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1949     > ../outputs/t3568
    exec diff ../outputs/t3568 ../golden/t3568 >/dev/null 2>&1 ;;
  p3569) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1951     > ../outputs/t3569
    exec diff ../outputs/t3569 ../golden/t3569 >/dev/null 2>&1 ;;
  p3570) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1952     > ../outputs/t3570
    exec diff ../outputs/t3570 ../golden/t3570 >/dev/null 2>&1 ;;
  p3571) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1953     > ../outputs/t3571
    exec diff ../outputs/t3571 ../golden/t3571 >/dev/null 2>&1 ;;
  p3572) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1954     > ../outputs/t3572
    exec diff ../outputs/t3572 ../golden/t3572 >/dev/null 2>&1 ;;
  p3573) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1956     > ../outputs/t3573
    exec diff ../outputs/t3573 ../golden/t3573 >/dev/null 2>&1 ;;
  p3574) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1957     > ../outputs/t3574
    exec diff ../outputs/t3574 ../golden/t3574 >/dev/null 2>&1 ;;
  p3575) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.196     > ../outputs/t3575
    exec diff ../outputs/t3575 ../golden/t3575 >/dev/null 2>&1 ;;
  p3576) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1960     > ../outputs/t3576
    exec diff ../outputs/t3576 ../golden/t3576 >/dev/null 2>&1 ;;
  p3577) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1962     > ../outputs/t3577
    exec diff ../outputs/t3577 ../golden/t3577 >/dev/null 2>&1 ;;
  p3578) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1963     > ../outputs/t3578
    exec diff ../outputs/t3578 ../golden/t3578 >/dev/null 2>&1 ;;
  p3579) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1965     > ../outputs/t3579
    exec diff ../outputs/t3579 ../golden/t3579 >/dev/null 2>&1 ;;
  p3580) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1966     > ../outputs/t3580
    exec diff ../outputs/t3580 ../golden/t3580 >/dev/null 2>&1 ;;
  p3581) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1967     > ../outputs/t3581
    exec diff ../outputs/t3581 ../golden/t3581 >/dev/null 2>&1 ;;
  p3582) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1968     > ../outputs/t3582
    exec diff ../outputs/t3582 ../golden/t3582 >/dev/null 2>&1 ;;
  p3583) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1969     > ../outputs/t3583
    exec diff ../outputs/t3583 ../golden/t3583 >/dev/null 2>&1 ;;
  p3584) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.197      > ../outputs/t3584
    exec diff ../outputs/t3584 ../golden/t3584 >/dev/null 2>&1 ;;
  p3585) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1973     > ../outputs/t3585
    exec diff ../outputs/t3585 ../golden/t3585 >/dev/null 2>&1 ;;
  p3586) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1976     > ../outputs/t3586
    exec diff ../outputs/t3586 ../golden/t3586 >/dev/null 2>&1 ;;
  p3587) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1977     > ../outputs/t3587
    exec diff ../outputs/t3587 ../golden/t3587 >/dev/null 2>&1 ;;
  p3588) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1978     > ../outputs/t3588
    exec diff ../outputs/t3588 ../golden/t3588 >/dev/null 2>&1 ;;
  p3589) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.198     > ../outputs/t3589
    exec diff ../outputs/t3589 ../golden/t3589 >/dev/null 2>&1 ;;
  p3590) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1980     > ../outputs/t3590
    exec diff ../outputs/t3590 ../golden/t3590 >/dev/null 2>&1 ;;
  p3591) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1981     > ../outputs/t3591
    exec diff ../outputs/t3591 ../golden/t3591 >/dev/null 2>&1 ;;
  p3592) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1982     > ../outputs/t3592
    exec diff ../outputs/t3592 ../golden/t3592 >/dev/null 2>&1 ;;
  p3593) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1983     > ../outputs/t3593
    exec diff ../outputs/t3593 ../golden/t3593 >/dev/null 2>&1 ;;
  p3594) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1984.noeof     > ../outputs/t3594
    exec diff ../outputs/t3594 ../golden/t3594 >/dev/null 2>&1 ;;
  p3595) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1986     > ../outputs/t3595
    exec diff ../outputs/t3595 ../golden/t3595 >/dev/null 2>&1 ;;
  p3596) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1987     > ../outputs/t3596
    exec diff ../outputs/t3596 ../golden/t3596 >/dev/null 2>&1 ;;
  p3597) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.199     > ../outputs/t3597
    exec diff ../outputs/t3597 ../golden/t3597 >/dev/null 2>&1 ;;
  p3598) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1991     > ../outputs/t3598
    exec diff ../outputs/t3598 ../golden/t3598 >/dev/null 2>&1 ;;
  p3599) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1992      > ../outputs/t3599
    exec diff ../outputs/t3599 ../golden/t3599 >/dev/null 2>&1 ;;
  p3600) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1993     > ../outputs/t3600
    exec diff ../outputs/t3600 ../golden/t3600 >/dev/null 2>&1 ;;
  p3601) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1994     > ../outputs/t3601
    exec diff ../outputs/t3601 ../golden/t3601 >/dev/null 2>&1 ;;
  p3602) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.1996     > ../outputs/t3602
    exec diff ../outputs/t3602 ../golden/t3602 >/dev/null 2>&1 ;;
  p3603) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.200     > ../outputs/t3603
    exec diff ../outputs/t3603 ../golden/t3603 >/dev/null 2>&1 ;;
  p3604) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.202     > ../outputs/t3604
    exec diff ../outputs/t3604 ../golden/t3604 >/dev/null 2>&1 ;;
  p3605) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.203     > ../outputs/t3605
    exec diff ../outputs/t3605 ../golden/t3605 >/dev/null 2>&1 ;;
  p3606) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.205     > ../outputs/t3606
    exec diff ../outputs/t3606 ../golden/t3606 >/dev/null 2>&1 ;;
  p3607) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.211     > ../outputs/t3607
    exec diff ../outputs/t3607 ../golden/t3607 >/dev/null 2>&1 ;;
  p3608) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.212     > ../outputs/t3608
    exec diff ../outputs/t3608 ../golden/t3608 >/dev/null 2>&1 ;;
  p3609) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.216     > ../outputs/t3609
    exec diff ../outputs/t3609 ../golden/t3609 >/dev/null 2>&1 ;;
  p3610) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.217     > ../outputs/t3610
    exec diff ../outputs/t3610 ../golden/t3610 >/dev/null 2>&1 ;;
  p3611) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.218     > ../outputs/t3611
    exec diff ../outputs/t3611 ../golden/t3611 >/dev/null 2>&1 ;;
  p3612) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.219     > ../outputs/t3612
    exec diff ../outputs/t3612 ../golden/t3612 >/dev/null 2>&1 ;;
  p3613) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.220     > ../outputs/t3613
    exec diff ../outputs/t3613 ../golden/t3613 >/dev/null 2>&1 ;;
  p3614) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.221     > ../outputs/t3614
    exec diff ../outputs/t3614 ../golden/t3614 >/dev/null 2>&1 ;;
  p3615) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.222     > ../outputs/t3615
    exec diff ../outputs/t3615 ../golden/t3615 >/dev/null 2>&1 ;;
  p3616) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.223     > ../outputs/t3616
    exec diff ../outputs/t3616 ../golden/t3616 >/dev/null 2>&1 ;;
  p3617) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.224     > ../outputs/t3617
    exec diff ../outputs/t3617 ../golden/t3617 >/dev/null 2>&1 ;;
  p3618) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.227     > ../outputs/t3618
    exec diff ../outputs/t3618 ../golden/t3618 >/dev/null 2>&1 ;;
  p3619) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.228     > ../outputs/t3619
    exec diff ../outputs/t3619 ../golden/t3619 >/dev/null 2>&1 ;;
  p3620) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.229     > ../outputs/t3620
    exec diff ../outputs/t3620 ../golden/t3620 >/dev/null 2>&1 ;;
  p3621) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.23     > ../outputs/t3621
    exec diff ../outputs/t3621 ../golden/t3621 >/dev/null 2>&1 ;;
  p3622) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.231     > ../outputs/t3622
    exec diff ../outputs/t3622 ../golden/t3622 >/dev/null 2>&1 ;;
  p3623) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.232     > ../outputs/t3623
    exec diff ../outputs/t3623 ../golden/t3623 >/dev/null 2>&1 ;;
  p3624) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.235     > ../outputs/t3624
    exec diff ../outputs/t3624 ../golden/t3624 >/dev/null 2>&1 ;;
  p3625) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.236     > ../outputs/t3625
    exec diff ../outputs/t3625 ../golden/t3625 >/dev/null 2>&1 ;;
  p3626) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.24     > ../outputs/t3626
    exec diff ../outputs/t3626 ../golden/t3626 >/dev/null 2>&1 ;;
  p3627) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.240     > ../outputs/t3627
    exec diff ../outputs/t3627 ../golden/t3627 >/dev/null 2>&1 ;;
  p3628) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.241     > ../outputs/t3628
    exec diff ../outputs/t3628 ../golden/t3628 >/dev/null 2>&1 ;;
  p3629) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.242     > ../outputs/t3629
    exec diff ../outputs/t3629 ../golden/t3629 >/dev/null 2>&1 ;;
  p3630) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.250     > ../outputs/t3630
    exec diff ../outputs/t3630 ../golden/t3630 >/dev/null 2>&1 ;;
  p3631) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.253     > ../outputs/t3631
    exec diff ../outputs/t3631 ../golden/t3631 >/dev/null 2>&1 ;;
  p3632) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.255     > ../outputs/t3632
    exec diff ../outputs/t3632 ../golden/t3632 >/dev/null 2>&1 ;;
  p3633) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.259     > ../outputs/t3633
    exec diff ../outputs/t3633 ../golden/t3633 >/dev/null 2>&1 ;;
  p3634) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.26     > ../outputs/t3634
    exec diff ../outputs/t3634 ../golden/t3634 >/dev/null 2>&1 ;;
  p3635) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.261     > ../outputs/t3635
    exec diff ../outputs/t3635 ../golden/t3635 >/dev/null 2>&1 ;;
  p3636) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.262     > ../outputs/t3636
    exec diff ../outputs/t3636 ../golden/t3636 >/dev/null 2>&1 ;;
  p3637) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.263     > ../outputs/t3637
    exec diff ../outputs/t3637 ../golden/t3637 >/dev/null 2>&1 ;;
  p3638) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.265      > ../outputs/t3638
    exec diff ../outputs/t3638 ../golden/t3638 >/dev/null 2>&1 ;;
  p3639) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.269     > ../outputs/t3639
    exec diff ../outputs/t3639 ../golden/t3639 >/dev/null 2>&1 ;;
  p3640) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.273     > ../outputs/t3640
    exec diff ../outputs/t3640 ../golden/t3640 >/dev/null 2>&1 ;;
  p3641) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.274     > ../outputs/t3641
    exec diff ../outputs/t3641 ../golden/t3641 >/dev/null 2>&1 ;;
  p3642) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.278     > ../outputs/t3642
    exec diff ../outputs/t3642 ../golden/t3642 >/dev/null 2>&1 ;;
  p3643) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.279     > ../outputs/t3643
    exec diff ../outputs/t3643 ../golden/t3643 >/dev/null 2>&1 ;;
  p3644) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.285     > ../outputs/t3644
    exec diff ../outputs/t3644 ../golden/t3644 >/dev/null 2>&1 ;;
  p3645) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.288     > ../outputs/t3645
    exec diff ../outputs/t3645 ../golden/t3645 >/dev/null 2>&1 ;;
  p3646) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.29     > ../outputs/t3646
    exec diff ../outputs/t3646 ../golden/t3646 >/dev/null 2>&1 ;;
  p3647) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.290     > ../outputs/t3647
    exec diff ../outputs/t3647 ../golden/t3647 >/dev/null 2>&1 ;;
  p3648) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.291     > ../outputs/t3648
    exec diff ../outputs/t3648 ../golden/t3648 >/dev/null 2>&1 ;;
  p3649) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.292     > ../outputs/t3649
    exec diff ../outputs/t3649 ../golden/t3649 >/dev/null 2>&1 ;;
  p3650) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.293     > ../outputs/t3650
    exec diff ../outputs/t3650 ../golden/t3650 >/dev/null 2>&1 ;;
  p3651) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.3      > ../outputs/t3651
    exec diff ../outputs/t3651 ../golden/t3651 >/dev/null 2>&1 ;;
  p3652) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.300     > ../outputs/t3652
    exec diff ../outputs/t3652 ../golden/t3652 >/dev/null 2>&1 ;;
  p3653) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.303      > ../outputs/t3653
    exec diff ../outputs/t3653 ../golden/t3653 >/dev/null 2>&1 ;;
  p3654) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.304     > ../outputs/t3654
    exec diff ../outputs/t3654 ../golden/t3654 >/dev/null 2>&1 ;;
  p3655) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.308      > ../outputs/t3655
    exec diff ../outputs/t3655 ../golden/t3655 >/dev/null 2>&1 ;;
  p3656) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.309     > ../outputs/t3656
    exec diff ../outputs/t3656 ../golden/t3656 >/dev/null 2>&1 ;;
  p3657) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.310     > ../outputs/t3657
    exec diff ../outputs/t3657 ../golden/t3657 >/dev/null 2>&1 ;;
  p3658) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.312     > ../outputs/t3658
    exec diff ../outputs/t3658 ../golden/t3658 >/dev/null 2>&1 ;;
  p3659) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.313     > ../outputs/t3659
    exec diff ../outputs/t3659 ../golden/t3659 >/dev/null 2>&1 ;;
  p3660) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.314     > ../outputs/t3660
    exec diff ../outputs/t3660 ../golden/t3660 >/dev/null 2>&1 ;;
  p3661) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.315     > ../outputs/t3661
    exec diff ../outputs/t3661 ../golden/t3661 >/dev/null 2>&1 ;;
  p3662) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.316     > ../outputs/t3662
    exec diff ../outputs/t3662 ../golden/t3662 >/dev/null 2>&1 ;;
  p3663) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.317     > ../outputs/t3663
    exec diff ../outputs/t3663 ../golden/t3663 >/dev/null 2>&1 ;;
  p3664) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.32     > ../outputs/t3664
    exec diff ../outputs/t3664 ../golden/t3664 >/dev/null 2>&1 ;;
  p3665) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.324     > ../outputs/t3665
    exec diff ../outputs/t3665 ../golden/t3665 >/dev/null 2>&1 ;;
  p3666) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.328     > ../outputs/t3666
    exec diff ../outputs/t3666 ../golden/t3666 >/dev/null 2>&1 ;;
  p3667) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.331     > ../outputs/t3667
    exec diff ../outputs/t3667 ../golden/t3667 >/dev/null 2>&1 ;;
  p3668) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.332     > ../outputs/t3668
    exec diff ../outputs/t3668 ../golden/t3668 >/dev/null 2>&1 ;;
  p3669) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.336     > ../outputs/t3669
    exec diff ../outputs/t3669 ../golden/t3669 >/dev/null 2>&1 ;;
  p3670) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.341     > ../outputs/t3670
    exec diff ../outputs/t3670 ../golden/t3670 >/dev/null 2>&1 ;;
  p3671) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.342     > ../outputs/t3671
    exec diff ../outputs/t3671 ../golden/t3671 >/dev/null 2>&1 ;;
  p3672) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.346     > ../outputs/t3672
    exec diff ../outputs/t3672 ../golden/t3672 >/dev/null 2>&1 ;;
  p3673) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.347     > ../outputs/t3673
    exec diff ../outputs/t3673 ../golden/t3673 >/dev/null 2>&1 ;;
  p3674) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.35     > ../outputs/t3674
    exec diff ../outputs/t3674 ../golden/t3674 >/dev/null 2>&1 ;;
  p3675) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.351     > ../outputs/t3675
    exec diff ../outputs/t3675 ../golden/t3675 >/dev/null 2>&1 ;;
  p3676) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.354     > ../outputs/t3676
    exec diff ../outputs/t3676 ../golden/t3676 >/dev/null 2>&1 ;;
  p3677) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.356     > ../outputs/t3677
    exec diff ../outputs/t3677 ../golden/t3677 >/dev/null 2>&1 ;;
  p3678) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.357     > ../outputs/t3678
    exec diff ../outputs/t3678 ../golden/t3678 >/dev/null 2>&1 ;;
  p3679) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.358     > ../outputs/t3679
    exec diff ../outputs/t3679 ../golden/t3679 >/dev/null 2>&1 ;;
  p3680) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.359     > ../outputs/t3680
    exec diff ../outputs/t3680 ../golden/t3680 >/dev/null 2>&1 ;;
  p3681) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.361     > ../outputs/t3681
    exec diff ../outputs/t3681 ../golden/t3681 >/dev/null 2>&1 ;;
  p3682) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.364     > ../outputs/t3682
    exec diff ../outputs/t3682 ../golden/t3682 >/dev/null 2>&1 ;;
  p3683) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.365     > ../outputs/t3683
    exec diff ../outputs/t3683 ../golden/t3683 >/dev/null 2>&1 ;;
  p3684) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.366     > ../outputs/t3684
    exec diff ../outputs/t3684 ../golden/t3684 >/dev/null 2>&1 ;;
  p3685) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.368     > ../outputs/t3685
    exec diff ../outputs/t3685 ../golden/t3685 >/dev/null 2>&1 ;;
  p3686) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.370     > ../outputs/t3686
    exec diff ../outputs/t3686 ../golden/t3686 >/dev/null 2>&1 ;;
  p3687) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.371     > ../outputs/t3687
    exec diff ../outputs/t3687 ../golden/t3687 >/dev/null 2>&1 ;;
  p3688) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.373     > ../outputs/t3688
    exec diff ../outputs/t3688 ../golden/t3688 >/dev/null 2>&1 ;;
  p3689) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.374     > ../outputs/t3689
    exec diff ../outputs/t3689 ../golden/t3689 >/dev/null 2>&1 ;;
  p3690) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.375     > ../outputs/t3690
    exec diff ../outputs/t3690 ../golden/t3690 >/dev/null 2>&1 ;;
  p3691) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.376     > ../outputs/t3691
    exec diff ../outputs/t3691 ../golden/t3691 >/dev/null 2>&1 ;;
  p3692) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.38     > ../outputs/t3692
    exec diff ../outputs/t3692 ../golden/t3692 >/dev/null 2>&1 ;;
  p3693) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.381     > ../outputs/t3693
    exec diff ../outputs/t3693 ../golden/t3693 >/dev/null 2>&1 ;;
  p3694) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.382     > ../outputs/t3694
    exec diff ../outputs/t3694 ../golden/t3694 >/dev/null 2>&1 ;;
  p3695) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.384     > ../outputs/t3695
    exec diff ../outputs/t3695 ../golden/t3695 >/dev/null 2>&1 ;;
  p3696) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.385     > ../outputs/t3696
    exec diff ../outputs/t3696 ../golden/t3696 >/dev/null 2>&1 ;;
  p3697) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.389     > ../outputs/t3697
    exec diff ../outputs/t3697 ../golden/t3697 >/dev/null 2>&1 ;;
  p3698) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.39     > ../outputs/t3698
    exec diff ../outputs/t3698 ../golden/t3698 >/dev/null 2>&1 ;;
  p3699) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.390     > ../outputs/t3699
    exec diff ../outputs/t3699 ../golden/t3699 >/dev/null 2>&1 ;;
  p3700) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.391     > ../outputs/t3700
    exec diff ../outputs/t3700 ../golden/t3700 >/dev/null 2>&1 ;;
  p3701) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.393     > ../outputs/t3701
    exec diff ../outputs/t3701 ../golden/t3701 >/dev/null 2>&1 ;;
  p3702) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.394     > ../outputs/t3702
    exec diff ../outputs/t3702 ../golden/t3702 >/dev/null 2>&1 ;;
  p3703) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.396.noeof     > ../outputs/t3703
    exec diff ../outputs/t3703 ../golden/t3703 >/dev/null 2>&1 ;;
  p3704) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.397     > ../outputs/t3704
    exec diff ../outputs/t3704 ../golden/t3704 >/dev/null 2>&1 ;;
  p3705) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.400     > ../outputs/t3705
    exec diff ../outputs/t3705 ../golden/t3705 >/dev/null 2>&1 ;;
  p3706) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.401     > ../outputs/t3706
    exec diff ../outputs/t3706 ../golden/t3706 >/dev/null 2>&1 ;;
  p3707) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.403     > ../outputs/t3707
    exec diff ../outputs/t3707 ../golden/t3707 >/dev/null 2>&1 ;;
  p3708) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.404     > ../outputs/t3708
    exec diff ../outputs/t3708 ../golden/t3708 >/dev/null 2>&1 ;;
  p3709) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.405     > ../outputs/t3709
    exec diff ../outputs/t3709 ../golden/t3709 >/dev/null 2>&1 ;;
  p3710) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.406     > ../outputs/t3710
    exec diff ../outputs/t3710 ../golden/t3710 >/dev/null 2>&1 ;;
  p3711) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.408     > ../outputs/t3711
    exec diff ../outputs/t3711 ../golden/t3711 >/dev/null 2>&1 ;;
  p3712) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.409     > ../outputs/t3712
    exec diff ../outputs/t3712 ../golden/t3712 >/dev/null 2>&1 ;;
  p3713) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.410     > ../outputs/t3713
    exec diff ../outputs/t3713 ../golden/t3713 >/dev/null 2>&1 ;;
  p3714) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.411      > ../outputs/t3714
    exec diff ../outputs/t3714 ../golden/t3714 >/dev/null 2>&1 ;;
  p3715) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.414     > ../outputs/t3715
    exec diff ../outputs/t3715 ../golden/t3715 >/dev/null 2>&1 ;;
  p3716) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.416     > ../outputs/t3716
    exec diff ../outputs/t3716 ../golden/t3716 >/dev/null 2>&1 ;;
  p3717) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.416.noeof     > ../outputs/t3717
    exec diff ../outputs/t3717 ../golden/t3717 >/dev/null 2>&1 ;;
  p3718) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.417     > ../outputs/t3718
    exec diff ../outputs/t3718 ../golden/t3718 >/dev/null 2>&1 ;;
  p3719) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.420     > ../outputs/t3719
    exec diff ../outputs/t3719 ../golden/t3719 >/dev/null 2>&1 ;;
  p3720) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.422     > ../outputs/t3720
    exec diff ../outputs/t3720 ../golden/t3720 >/dev/null 2>&1 ;;
  p3721) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.426     > ../outputs/t3721
    exec diff ../outputs/t3721 ../golden/t3721 >/dev/null 2>&1 ;;
  p3722) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.427     > ../outputs/t3722
    exec diff ../outputs/t3722 ../golden/t3722 >/dev/null 2>&1 ;;
  p3723) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.429     > ../outputs/t3723
    exec diff ../outputs/t3723 ../golden/t3723 >/dev/null 2>&1 ;;
  p3724) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.43     > ../outputs/t3724
    exec diff ../outputs/t3724 ../golden/t3724 >/dev/null 2>&1 ;;
  p3725) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.431     > ../outputs/t3725
    exec diff ../outputs/t3725 ../golden/t3725 >/dev/null 2>&1 ;;
  p3726) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.437     > ../outputs/t3726
    exec diff ../outputs/t3726 ../golden/t3726 >/dev/null 2>&1 ;;
  p3727) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.439     > ../outputs/t3727
    exec diff ../outputs/t3727 ../golden/t3727 >/dev/null 2>&1 ;;
  p3728) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.44     > ../outputs/t3728
    exec diff ../outputs/t3728 ../golden/t3728 >/dev/null 2>&1 ;;
  p3729) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.440     > ../outputs/t3729
    exec diff ../outputs/t3729 ../golden/t3729 >/dev/null 2>&1 ;;
  p3730) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.441.noeof     > ../outputs/t3730
    exec diff ../outputs/t3730 ../golden/t3730 >/dev/null 2>&1 ;;
  p3731) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.443     > ../outputs/t3731
    exec diff ../outputs/t3731 ../golden/t3731 >/dev/null 2>&1 ;;
  p3732) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.444     > ../outputs/t3732
    exec diff ../outputs/t3732 ../golden/t3732 >/dev/null 2>&1 ;;
  p3733) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.445     > ../outputs/t3733
    exec diff ../outputs/t3733 ../golden/t3733 >/dev/null 2>&1 ;;
  p3734) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.446     > ../outputs/t3734
    exec diff ../outputs/t3734 ../golden/t3734 >/dev/null 2>&1 ;;
  p3735) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.45     > ../outputs/t3735
    exec diff ../outputs/t3735 ../golden/t3735 >/dev/null 2>&1 ;;
  p3736) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.452     > ../outputs/t3736
    exec diff ../outputs/t3736 ../golden/t3736 >/dev/null 2>&1 ;;
  p3737) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.453     > ../outputs/t3737
    exec diff ../outputs/t3737 ../golden/t3737 >/dev/null 2>&1 ;;
  p3738) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.454     > ../outputs/t3738
    exec diff ../outputs/t3738 ../golden/t3738 >/dev/null 2>&1 ;;
  p3739) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.458     > ../outputs/t3739
    exec diff ../outputs/t3739 ../golden/t3739 >/dev/null 2>&1 ;;
  p3740) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.46     > ../outputs/t3740
    exec diff ../outputs/t3740 ../golden/t3740 >/dev/null 2>&1 ;;
  p3741) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.460     > ../outputs/t3741
    exec diff ../outputs/t3741 ../golden/t3741 >/dev/null 2>&1 ;;
  p3742) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.461     > ../outputs/t3742
    exec diff ../outputs/t3742 ../golden/t3742 >/dev/null 2>&1 ;;
  p3743) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.464     > ../outputs/t3743
    exec diff ../outputs/t3743 ../golden/t3743 >/dev/null 2>&1 ;;
  p3744) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.465     > ../outputs/t3744
    exec diff ../outputs/t3744 ../golden/t3744 >/dev/null 2>&1 ;;
  p3745) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.466     > ../outputs/t3745
    exec diff ../outputs/t3745 ../golden/t3745 >/dev/null 2>&1 ;;
  p3746) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.470     > ../outputs/t3746
    exec diff ../outputs/t3746 ../golden/t3746 >/dev/null 2>&1 ;;
  p3747) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.471     > ../outputs/t3747
    exec diff ../outputs/t3747 ../golden/t3747 >/dev/null 2>&1 ;;
  p3748) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.472     > ../outputs/t3748
    exec diff ../outputs/t3748 ../golden/t3748 >/dev/null 2>&1 ;;
  p3749) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.473     > ../outputs/t3749
    exec diff ../outputs/t3749 ../golden/t3749 >/dev/null 2>&1 ;;
  p3750) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.474     > ../outputs/t3750
    exec diff ../outputs/t3750 ../golden/t3750 >/dev/null 2>&1 ;;
  p3751) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.478     > ../outputs/t3751
    exec diff ../outputs/t3751 ../golden/t3751 >/dev/null 2>&1 ;;
  p3752) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.481     > ../outputs/t3752
    exec diff ../outputs/t3752 ../golden/t3752 >/dev/null 2>&1 ;;
  p3753) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.482     > ../outputs/t3753
    exec diff ../outputs/t3753 ../golden/t3753 >/dev/null 2>&1 ;;
  p3754) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.484     > ../outputs/t3754
    exec diff ../outputs/t3754 ../golden/t3754 >/dev/null 2>&1 ;;
  p3755) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.485     > ../outputs/t3755
    exec diff ../outputs/t3755 ../golden/t3755 >/dev/null 2>&1 ;;
  p3756) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.486     > ../outputs/t3756
    exec diff ../outputs/t3756 ../golden/t3756 >/dev/null 2>&1 ;;
  p3757) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.488     > ../outputs/t3757
    exec diff ../outputs/t3757 ../golden/t3757 >/dev/null 2>&1 ;;
  p3758) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.49     > ../outputs/t3758
    exec diff ../outputs/t3758 ../golden/t3758 >/dev/null 2>&1 ;;
  p3759) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.490     > ../outputs/t3759
    exec diff ../outputs/t3759 ../golden/t3759 >/dev/null 2>&1 ;;
  p3760) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.491     > ../outputs/t3760
    exec diff ../outputs/t3760 ../golden/t3760 >/dev/null 2>&1 ;;
  p3761) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.492     > ../outputs/t3761
    exec diff ../outputs/t3761 ../golden/t3761 >/dev/null 2>&1 ;;
  p3762) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.495     > ../outputs/t3762
    exec diff ../outputs/t3762 ../golden/t3762 >/dev/null 2>&1 ;;
  p3763) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.497     > ../outputs/t3763
    exec diff ../outputs/t3763 ../golden/t3763 >/dev/null 2>&1 ;;
  p3764) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.498     > ../outputs/t3764
    exec diff ../outputs/t3764 ../golden/t3764 >/dev/null 2>&1 ;;
  p3765) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.499     > ../outputs/t3765
    exec diff ../outputs/t3765 ../golden/t3765 >/dev/null 2>&1 ;;
  p3766) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.5      > ../outputs/t3766
    exec diff ../outputs/t3766 ../golden/t3766 >/dev/null 2>&1 ;;
  p3767) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.5.noeof     > ../outputs/t3767
    exec diff ../outputs/t3767 ../golden/t3767 >/dev/null 2>&1 ;;
  p3768) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.500     > ../outputs/t3768
    exec diff ../outputs/t3768 ../golden/t3768 >/dev/null 2>&1 ;;
  p3769) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.501     > ../outputs/t3769
    exec diff ../outputs/t3769 ../golden/t3769 >/dev/null 2>&1 ;;
  p3770) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.503     > ../outputs/t3770
    exec diff ../outputs/t3770 ../golden/t3770 >/dev/null 2>&1 ;;
  p3771) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.505     > ../outputs/t3771
    exec diff ../outputs/t3771 ../golden/t3771 >/dev/null 2>&1 ;;
  p3772) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.508     > ../outputs/t3772
    exec diff ../outputs/t3772 ../golden/t3772 >/dev/null 2>&1 ;;
  p3773) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.509     > ../outputs/t3773
    exec diff ../outputs/t3773 ../golden/t3773 >/dev/null 2>&1 ;;
  p3774) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.51     > ../outputs/t3774
    exec diff ../outputs/t3774 ../golden/t3774 >/dev/null 2>&1 ;;
  p3775) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.516     > ../outputs/t3775
    exec diff ../outputs/t3775 ../golden/t3775 >/dev/null 2>&1 ;;
  p3776) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.517     > ../outputs/t3776
    exec diff ../outputs/t3776 ../golden/t3776 >/dev/null 2>&1 ;;
  p3777) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.521     > ../outputs/t3777
    exec diff ../outputs/t3777 ../golden/t3777 >/dev/null 2>&1 ;;
  p3778) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.523     > ../outputs/t3778
    exec diff ../outputs/t3778 ../golden/t3778 >/dev/null 2>&1 ;;
  p3779) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.524     > ../outputs/t3779
    exec diff ../outputs/t3779 ../golden/t3779 >/dev/null 2>&1 ;;
  p3780) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.529     > ../outputs/t3780
    exec diff ../outputs/t3780 ../golden/t3780 >/dev/null 2>&1 ;;
  p3781) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.53     > ../outputs/t3781
    exec diff ../outputs/t3781 ../golden/t3781 >/dev/null 2>&1 ;;
  p3782) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.530     > ../outputs/t3782
    exec diff ../outputs/t3782 ../golden/t3782 >/dev/null 2>&1 ;;
  p3783) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.531     > ../outputs/t3783
    exec diff ../outputs/t3783 ../golden/t3783 >/dev/null 2>&1 ;;
  p3784) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.532     > ../outputs/t3784
    exec diff ../outputs/t3784 ../golden/t3784 >/dev/null 2>&1 ;;
  p3785) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.535     > ../outputs/t3785
    exec diff ../outputs/t3785 ../golden/t3785 >/dev/null 2>&1 ;;
  p3786) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.536     > ../outputs/t3786
    exec diff ../outputs/t3786 ../golden/t3786 >/dev/null 2>&1 ;;
  p3787) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.541     > ../outputs/t3787
    exec diff ../outputs/t3787 ../golden/t3787 >/dev/null 2>&1 ;;
  p3788) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.542     > ../outputs/t3788
    exec diff ../outputs/t3788 ../golden/t3788 >/dev/null 2>&1 ;;
  p3789) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.545     > ../outputs/t3789
    exec diff ../outputs/t3789 ../golden/t3789 >/dev/null 2>&1 ;;
  p3790) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.546     > ../outputs/t3790
    exec diff ../outputs/t3790 ../golden/t3790 >/dev/null 2>&1 ;;
  p3791) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.547     > ../outputs/t3791
    exec diff ../outputs/t3791 ../golden/t3791 >/dev/null 2>&1 ;;
  p3792) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.548     > ../outputs/t3792
    exec diff ../outputs/t3792 ../golden/t3792 >/dev/null 2>&1 ;;
  p3793) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.549     > ../outputs/t3793
    exec diff ../outputs/t3793 ../golden/t3793 >/dev/null 2>&1 ;;
  p3794) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.55     > ../outputs/t3794
    exec diff ../outputs/t3794 ../golden/t3794 >/dev/null 2>&1 ;;
  p3795) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.550      > ../outputs/t3795
    exec diff ../outputs/t3795 ../golden/t3795 >/dev/null 2>&1 ;;
  p3796) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.551     > ../outputs/t3796
    exec diff ../outputs/t3796 ../golden/t3796 >/dev/null 2>&1 ;;
  p3797) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.554     > ../outputs/t3797
    exec diff ../outputs/t3797 ../golden/t3797 >/dev/null 2>&1 ;;
  p3798) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.555     > ../outputs/t3798
    exec diff ../outputs/t3798 ../golden/t3798 >/dev/null 2>&1 ;;
  p3799) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.556     > ../outputs/t3799
    exec diff ../outputs/t3799 ../golden/t3799 >/dev/null 2>&1 ;;
  p3800) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.559     > ../outputs/t3800
    exec diff ../outputs/t3800 ../golden/t3800 >/dev/null 2>&1 ;;
  p3801) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.56     > ../outputs/t3801
    exec diff ../outputs/t3801 ../golden/t3801 >/dev/null 2>&1 ;;
  p3802) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.560     > ../outputs/t3802
    exec diff ../outputs/t3802 ../golden/t3802 >/dev/null 2>&1 ;;
  p3803) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.561     > ../outputs/t3803
    exec diff ../outputs/t3803 ../golden/t3803 >/dev/null 2>&1 ;;
  p3804) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.563     > ../outputs/t3804
    exec diff ../outputs/t3804 ../golden/t3804 >/dev/null 2>&1 ;;
  p3805) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.564     > ../outputs/t3805
    exec diff ../outputs/t3805 ../golden/t3805 >/dev/null 2>&1 ;;
  p3806) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.565     > ../outputs/t3806
    exec diff ../outputs/t3806 ../golden/t3806 >/dev/null 2>&1 ;;
  p3807) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.567     > ../outputs/t3807
    exec diff ../outputs/t3807 ../golden/t3807 >/dev/null 2>&1 ;;
  p3808) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.57     > ../outputs/t3808
    exec diff ../outputs/t3808 ../golden/t3808 >/dev/null 2>&1 ;;
  p3809) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.575     > ../outputs/t3809
    exec diff ../outputs/t3809 ../golden/t3809 >/dev/null 2>&1 ;;
  p3810) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.578     > ../outputs/t3810
    exec diff ../outputs/t3810 ../golden/t3810 >/dev/null 2>&1 ;;
  p3811) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.587     > ../outputs/t3811
    exec diff ../outputs/t3811 ../golden/t3811 >/dev/null 2>&1 ;;
  p3812) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.588     > ../outputs/t3812
    exec diff ../outputs/t3812 ../golden/t3812 >/dev/null 2>&1 ;;
  p3813) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.589     > ../outputs/t3813
    exec diff ../outputs/t3813 ../golden/t3813 >/dev/null 2>&1 ;;
  p3814) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.59     > ../outputs/t3814
    exec diff ../outputs/t3814 ../golden/t3814 >/dev/null 2>&1 ;;
  p3815) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.590     > ../outputs/t3815
    exec diff ../outputs/t3815 ../golden/t3815 >/dev/null 2>&1 ;;
  p3816) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.591     > ../outputs/t3816
    exec diff ../outputs/t3816 ../golden/t3816 >/dev/null 2>&1 ;;
  p3817) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.595     > ../outputs/t3817
    exec diff ../outputs/t3817 ../golden/t3817 >/dev/null 2>&1 ;;
  p3818) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.599     > ../outputs/t3818
    exec diff ../outputs/t3818 ../golden/t3818 >/dev/null 2>&1 ;;
  p3819) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.6     > ../outputs/t3819
    exec diff ../outputs/t3819 ../golden/t3819 >/dev/null 2>&1 ;;
  p3820) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.600     > ../outputs/t3820
    exec diff ../outputs/t3820 ../golden/t3820 >/dev/null 2>&1 ;;
  p3821) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.601     > ../outputs/t3821
    exec diff ../outputs/t3821 ../golden/t3821 >/dev/null 2>&1 ;;
  p3822) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.603     > ../outputs/t3822
    exec diff ../outputs/t3822 ../golden/t3822 >/dev/null 2>&1 ;;
  p3823) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.604     > ../outputs/t3823
    exec diff ../outputs/t3823 ../golden/t3823 >/dev/null 2>&1 ;;
  p3824) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.606     > ../outputs/t3824
    exec diff ../outputs/t3824 ../golden/t3824 >/dev/null 2>&1 ;;
  p3825) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.608     > ../outputs/t3825
    exec diff ../outputs/t3825 ../golden/t3825 >/dev/null 2>&1 ;;
  p3826) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.609      > ../outputs/t3826
    exec diff ../outputs/t3826 ../golden/t3826 >/dev/null 2>&1 ;;
  p3827) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.61     > ../outputs/t3827
    exec diff ../outputs/t3827 ../golden/t3827 >/dev/null 2>&1 ;;
  p3828) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.610     > ../outputs/t3828
    exec diff ../outputs/t3828 ../golden/t3828 >/dev/null 2>&1 ;;
  p3829) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.612     > ../outputs/t3829
    exec diff ../outputs/t3829 ../golden/t3829 >/dev/null 2>&1 ;;
  p3830) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.613     > ../outputs/t3830
    exec diff ../outputs/t3830 ../golden/t3830 >/dev/null 2>&1 ;;
  p3831) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.618     > ../outputs/t3831
    exec diff ../outputs/t3831 ../golden/t3831 >/dev/null 2>&1 ;;
  p3832) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.620     > ../outputs/t3832
    exec diff ../outputs/t3832 ../golden/t3832 >/dev/null 2>&1 ;;
  p3833) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.622     > ../outputs/t3833
    exec diff ../outputs/t3833 ../golden/t3833 >/dev/null 2>&1 ;;
  p3834) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.628     > ../outputs/t3834
    exec diff ../outputs/t3834 ../golden/t3834 >/dev/null 2>&1 ;;
  p3835) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.629      > ../outputs/t3835
    exec diff ../outputs/t3835 ../golden/t3835 >/dev/null 2>&1 ;;
  p3836) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.631     > ../outputs/t3836
    exec diff ../outputs/t3836 ../golden/t3836 >/dev/null 2>&1 ;;
  p3837) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.632     > ../outputs/t3837
    exec diff ../outputs/t3837 ../golden/t3837 >/dev/null 2>&1 ;;
  p3838) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.634     > ../outputs/t3838
    exec diff ../outputs/t3838 ../golden/t3838 >/dev/null 2>&1 ;;
  p3839) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.635     > ../outputs/t3839
    exec diff ../outputs/t3839 ../golden/t3839 >/dev/null 2>&1 ;;
  p3840) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.637     > ../outputs/t3840
    exec diff ../outputs/t3840 ../golden/t3840 >/dev/null 2>&1 ;;
  p3841) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.637.noeof     > ../outputs/t3841
    exec diff ../outputs/t3841 ../golden/t3841 >/dev/null 2>&1 ;;
  p3842) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.638     > ../outputs/t3842
    exec diff ../outputs/t3842 ../golden/t3842 >/dev/null 2>&1 ;;
  p3843) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.639     > ../outputs/t3843
    exec diff ../outputs/t3843 ../golden/t3843 >/dev/null 2>&1 ;;
  p3844) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.639.noeof     > ../outputs/t3844
    exec diff ../outputs/t3844 ../golden/t3844 >/dev/null 2>&1 ;;
  p3845) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.641     > ../outputs/t3845
    exec diff ../outputs/t3845 ../golden/t3845 >/dev/null 2>&1 ;;
  p3846) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.643     > ../outputs/t3846
    exec diff ../outputs/t3846 ../golden/t3846 >/dev/null 2>&1 ;;
  p3847) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.644     > ../outputs/t3847
    exec diff ../outputs/t3847 ../golden/t3847 >/dev/null 2>&1 ;;
  p3848) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.645     > ../outputs/t3848
    exec diff ../outputs/t3848 ../golden/t3848 >/dev/null 2>&1 ;;
  p3849) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.646     > ../outputs/t3849
    exec diff ../outputs/t3849 ../golden/t3849 >/dev/null 2>&1 ;;
  p3850) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.649     > ../outputs/t3850
    exec diff ../outputs/t3850 ../golden/t3850 >/dev/null 2>&1 ;;
  p3851) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.65     > ../outputs/t3851
    exec diff ../outputs/t3851 ../golden/t3851 >/dev/null 2>&1 ;;
  p3852) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.651     > ../outputs/t3852
    exec diff ../outputs/t3852 ../golden/t3852 >/dev/null 2>&1 ;;
  p3853) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.652     > ../outputs/t3853
    exec diff ../outputs/t3853 ../golden/t3853 >/dev/null 2>&1 ;;
  p3854) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.653     > ../outputs/t3854
    exec diff ../outputs/t3854 ../golden/t3854 >/dev/null 2>&1 ;;
  p3855) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.654     > ../outputs/t3855
    exec diff ../outputs/t3855 ../golden/t3855 >/dev/null 2>&1 ;;
  p3856) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.657     > ../outputs/t3856
    exec diff ../outputs/t3856 ../golden/t3856 >/dev/null 2>&1 ;;
  p3857) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.658     > ../outputs/t3857
    exec diff ../outputs/t3857 ../golden/t3857 >/dev/null 2>&1 ;;
  p3858) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.66      > ../outputs/t3858
    exec diff ../outputs/t3858 ../golden/t3858 >/dev/null 2>&1 ;;
  p3859) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.660     > ../outputs/t3859
    exec diff ../outputs/t3859 ../golden/t3859 >/dev/null 2>&1 ;;
  p3860) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.661     > ../outputs/t3860
    exec diff ../outputs/t3860 ../golden/t3860 >/dev/null 2>&1 ;;
  p3861) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.664     > ../outputs/t3861
    exec diff ../outputs/t3861 ../golden/t3861 >/dev/null 2>&1 ;;
  p3862) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.666     > ../outputs/t3862
    exec diff ../outputs/t3862 ../golden/t3862 >/dev/null 2>&1 ;;
  p3863) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.667     > ../outputs/t3863
    exec diff ../outputs/t3863 ../golden/t3863 >/dev/null 2>&1 ;;
  p3864) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.671     > ../outputs/t3864
    exec diff ../outputs/t3864 ../golden/t3864 >/dev/null 2>&1 ;;
  p3865) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.672     > ../outputs/t3865
    exec diff ../outputs/t3865 ../golden/t3865 >/dev/null 2>&1 ;;
  p3866) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.675     > ../outputs/t3866
    exec diff ../outputs/t3866 ../golden/t3866 >/dev/null 2>&1 ;;
  p3867) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.678     > ../outputs/t3867
    exec diff ../outputs/t3867 ../golden/t3867 >/dev/null 2>&1 ;;
  p3868) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.681     > ../outputs/t3868
    exec diff ../outputs/t3868 ../golden/t3868 >/dev/null 2>&1 ;;
  p3869) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.683     > ../outputs/t3869
    exec diff ../outputs/t3869 ../golden/t3869 >/dev/null 2>&1 ;;
  p3870) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.684     > ../outputs/t3870
    exec diff ../outputs/t3870 ../golden/t3870 >/dev/null 2>&1 ;;
  p3871) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.685     > ../outputs/t3871
    exec diff ../outputs/t3871 ../golden/t3871 >/dev/null 2>&1 ;;
  p3872) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.687     > ../outputs/t3872
    exec diff ../outputs/t3872 ../golden/t3872 >/dev/null 2>&1 ;;
  p3873) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.688     > ../outputs/t3873
    exec diff ../outputs/t3873 ../golden/t3873 >/dev/null 2>&1 ;;
  p3874) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.689     > ../outputs/t3874
    exec diff ../outputs/t3874 ../golden/t3874 >/dev/null 2>&1 ;;
  p3875) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.69     > ../outputs/t3875
    exec diff ../outputs/t3875 ../golden/t3875 >/dev/null 2>&1 ;;
  p3876) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.690     > ../outputs/t3876
    exec diff ../outputs/t3876 ../golden/t3876 >/dev/null 2>&1 ;;
  p3877) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.692     > ../outputs/t3877
    exec diff ../outputs/t3877 ../golden/t3877 >/dev/null 2>&1 ;;
  p3878) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.693     > ../outputs/t3878
    exec diff ../outputs/t3878 ../golden/t3878 >/dev/null 2>&1 ;;
  p3879) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.694     > ../outputs/t3879
    exec diff ../outputs/t3879 ../golden/t3879 >/dev/null 2>&1 ;;
  p3880) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.696     > ../outputs/t3880
    exec diff ../outputs/t3880 ../golden/t3880 >/dev/null 2>&1 ;;
  p3881) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.697     > ../outputs/t3881
    exec diff ../outputs/t3881 ../golden/t3881 >/dev/null 2>&1 ;;
  p3882) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.698     > ../outputs/t3882
    exec diff ../outputs/t3882 ../golden/t3882 >/dev/null 2>&1 ;;
  p3883) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.699     > ../outputs/t3883
    exec diff ../outputs/t3883 ../golden/t3883 >/dev/null 2>&1 ;;
  p3884) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.700     > ../outputs/t3884
    exec diff ../outputs/t3884 ../golden/t3884 >/dev/null 2>&1 ;;
  p3885) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.702     > ../outputs/t3885
    exec diff ../outputs/t3885 ../golden/t3885 >/dev/null 2>&1 ;;
  p3886) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.703     > ../outputs/t3886
    exec diff ../outputs/t3886 ../golden/t3886 >/dev/null 2>&1 ;;
  p3887) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.705     > ../outputs/t3887
    exec diff ../outputs/t3887 ../golden/t3887 >/dev/null 2>&1 ;;
  p3888) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.707     > ../outputs/t3888
    exec diff ../outputs/t3888 ../golden/t3888 >/dev/null 2>&1 ;;
  p3889) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.710     > ../outputs/t3889
    exec diff ../outputs/t3889 ../golden/t3889 >/dev/null 2>&1 ;;
  p3890) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.714     > ../outputs/t3890
    exec diff ../outputs/t3890 ../golden/t3890 >/dev/null 2>&1 ;;
  p3891) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.715     > ../outputs/t3891
    exec diff ../outputs/t3891 ../golden/t3891 >/dev/null 2>&1 ;;
  p3892) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.718     > ../outputs/t3892
    exec diff ../outputs/t3892 ../golden/t3892 >/dev/null 2>&1 ;;
  p3893) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.720     > ../outputs/t3893
    exec diff ../outputs/t3893 ../golden/t3893 >/dev/null 2>&1 ;;
  p3894) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.722     > ../outputs/t3894
    exec diff ../outputs/t3894 ../golden/t3894 >/dev/null 2>&1 ;;
  p3895) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.724     > ../outputs/t3895
    exec diff ../outputs/t3895 ../golden/t3895 >/dev/null 2>&1 ;;
  p3896) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.724.noeof     > ../outputs/t3896
    exec diff ../outputs/t3896 ../golden/t3896 >/dev/null 2>&1 ;;
  p3897) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.725     > ../outputs/t3897
    exec diff ../outputs/t3897 ../golden/t3897 >/dev/null 2>&1 ;;
  p3898) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.726     > ../outputs/t3898
    exec diff ../outputs/t3898 ../golden/t3898 >/dev/null 2>&1 ;;
  p3899) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.729     > ../outputs/t3899
    exec diff ../outputs/t3899 ../golden/t3899 >/dev/null 2>&1 ;;
  p3900) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.73     > ../outputs/t3900
    exec diff ../outputs/t3900 ../golden/t3900 >/dev/null 2>&1 ;;
  p3901) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.730     > ../outputs/t3901
    exec diff ../outputs/t3901 ../golden/t3901 >/dev/null 2>&1 ;;
  p3902) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.731     > ../outputs/t3902
    exec diff ../outputs/t3902 ../golden/t3902 >/dev/null 2>&1 ;;
  p3903) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.732     > ../outputs/t3903
    exec diff ../outputs/t3903 ../golden/t3903 >/dev/null 2>&1 ;;
  p3904) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.733     > ../outputs/t3904
    exec diff ../outputs/t3904 ../golden/t3904 >/dev/null 2>&1 ;;
  p3905) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.735     > ../outputs/t3905
    exec diff ../outputs/t3905 ../golden/t3905 >/dev/null 2>&1 ;;
  p3906) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.737     > ../outputs/t3906
    exec diff ../outputs/t3906 ../golden/t3906 >/dev/null 2>&1 ;;
  p3907) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.739     > ../outputs/t3907
    exec diff ../outputs/t3907 ../golden/t3907 >/dev/null 2>&1 ;;
  p3908) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.740     > ../outputs/t3908
    exec diff ../outputs/t3908 ../golden/t3908 >/dev/null 2>&1 ;;
  p3909) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.741     > ../outputs/t3909
    exec diff ../outputs/t3909 ../golden/t3909 >/dev/null 2>&1 ;;
  p3910) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.743     > ../outputs/t3910
    exec diff ../outputs/t3910 ../golden/t3910 >/dev/null 2>&1 ;;
  p3911) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.745      > ../outputs/t3911
    exec diff ../outputs/t3911 ../golden/t3911 >/dev/null 2>&1 ;;
  p3912) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.749     > ../outputs/t3912
    exec diff ../outputs/t3912 ../golden/t3912 >/dev/null 2>&1 ;;
  p3913) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.750     > ../outputs/t3913
    exec diff ../outputs/t3913 ../golden/t3913 >/dev/null 2>&1 ;;
  p3914) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.754     > ../outputs/t3914
    exec diff ../outputs/t3914 ../golden/t3914 >/dev/null 2>&1 ;;
  p3915) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.755     > ../outputs/t3915
    exec diff ../outputs/t3915 ../golden/t3915 >/dev/null 2>&1 ;;
  p3916) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.757     > ../outputs/t3916
    exec diff ../outputs/t3916 ../golden/t3916 >/dev/null 2>&1 ;;
  p3917) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.759     > ../outputs/t3917
    exec diff ../outputs/t3917 ../golden/t3917 >/dev/null 2>&1 ;;
  p3918) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.762     > ../outputs/t3918
    exec diff ../outputs/t3918 ../golden/t3918 >/dev/null 2>&1 ;;
  p3919) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.763     > ../outputs/t3919
    exec diff ../outputs/t3919 ../golden/t3919 >/dev/null 2>&1 ;;
  p3920) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.764     > ../outputs/t3920
    exec diff ../outputs/t3920 ../golden/t3920 >/dev/null 2>&1 ;;
  p3921) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.77.noeof     > ../outputs/t3921
    exec diff ../outputs/t3921 ../golden/t3921 >/dev/null 2>&1 ;;
  p3922) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.770     > ../outputs/t3922
    exec diff ../outputs/t3922 ../golden/t3922 >/dev/null 2>&1 ;;
  p3923) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.771     > ../outputs/t3923
    exec diff ../outputs/t3923 ../golden/t3923 >/dev/null 2>&1 ;;
  p3924) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.774     > ../outputs/t3924
    exec diff ../outputs/t3924 ../golden/t3924 >/dev/null 2>&1 ;;
  p3925) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.780     > ../outputs/t3925
    exec diff ../outputs/t3925 ../golden/t3925 >/dev/null 2>&1 ;;
  p3926) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.782     > ../outputs/t3926
    exec diff ../outputs/t3926 ../golden/t3926 >/dev/null 2>&1 ;;
  p3927) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.783     > ../outputs/t3927
    exec diff ../outputs/t3927 ../golden/t3927 >/dev/null 2>&1 ;;
  p3928) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.785     > ../outputs/t3928
    exec diff ../outputs/t3928 ../golden/t3928 >/dev/null 2>&1 ;;
  p3929) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.792     > ../outputs/t3929
    exec diff ../outputs/t3929 ../golden/t3929 >/dev/null 2>&1 ;;
  p3930) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.794     > ../outputs/t3930
    exec diff ../outputs/t3930 ../golden/t3930 >/dev/null 2>&1 ;;
  p3931) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.795     > ../outputs/t3931
    exec diff ../outputs/t3931 ../golden/t3931 >/dev/null 2>&1 ;;
  p3932) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.796     > ../outputs/t3932
    exec diff ../outputs/t3932 ../golden/t3932 >/dev/null 2>&1 ;;
  p3933) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.797      > ../outputs/t3933
    exec diff ../outputs/t3933 ../golden/t3933 >/dev/null 2>&1 ;;
  p3934) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.799     > ../outputs/t3934
    exec diff ../outputs/t3934 ../golden/t3934 >/dev/null 2>&1 ;;
  p3935) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.800     > ../outputs/t3935
    exec diff ../outputs/t3935 ../golden/t3935 >/dev/null 2>&1 ;;
  p3936) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.801     > ../outputs/t3936
    exec diff ../outputs/t3936 ../golden/t3936 >/dev/null 2>&1 ;;
  p3937) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.802     > ../outputs/t3937
    exec diff ../outputs/t3937 ../golden/t3937 >/dev/null 2>&1 ;;
  p3938) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.804     > ../outputs/t3938
    exec diff ../outputs/t3938 ../golden/t3938 >/dev/null 2>&1 ;;
  p3939) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.805     > ../outputs/t3939
    exec diff ../outputs/t3939 ../golden/t3939 >/dev/null 2>&1 ;;
  p3940) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.806     > ../outputs/t3940
    exec diff ../outputs/t3940 ../golden/t3940 >/dev/null 2>&1 ;;
  p3941) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.809     > ../outputs/t3941
    exec diff ../outputs/t3941 ../golden/t3941 >/dev/null 2>&1 ;;
  p3942) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.81     > ../outputs/t3942
    exec diff ../outputs/t3942 ../golden/t3942 >/dev/null 2>&1 ;;
  p3943) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.810     > ../outputs/t3943
    exec diff ../outputs/t3943 ../golden/t3943 >/dev/null 2>&1 ;;
  p3944) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.812     > ../outputs/t3944
    exec diff ../outputs/t3944 ../golden/t3944 >/dev/null 2>&1 ;;
  p3945) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.813     > ../outputs/t3945
    exec diff ../outputs/t3945 ../golden/t3945 >/dev/null 2>&1 ;;
  p3946) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.815      > ../outputs/t3946
    exec diff ../outputs/t3946 ../golden/t3946 >/dev/null 2>&1 ;;
  p3947) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.817     > ../outputs/t3947
    exec diff ../outputs/t3947 ../golden/t3947 >/dev/null 2>&1 ;;
  p3948) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.819     > ../outputs/t3948
    exec diff ../outputs/t3948 ../golden/t3948 >/dev/null 2>&1 ;;
  p3949) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.820     > ../outputs/t3949
    exec diff ../outputs/t3949 ../golden/t3949 >/dev/null 2>&1 ;;
  p3950) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.822     > ../outputs/t3950
    exec diff ../outputs/t3950 ../golden/t3950 >/dev/null 2>&1 ;;
  p3951) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.824     > ../outputs/t3951
    exec diff ../outputs/t3951 ../golden/t3951 >/dev/null 2>&1 ;;
  p3952) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.826     > ../outputs/t3952
    exec diff ../outputs/t3952 ../golden/t3952 >/dev/null 2>&1 ;;
  p3953) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.827      > ../outputs/t3953
    exec diff ../outputs/t3953 ../golden/t3953 >/dev/null 2>&1 ;;
  p3954) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.830     > ../outputs/t3954
    exec diff ../outputs/t3954 ../golden/t3954 >/dev/null 2>&1 ;;
  p3955) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.833     > ../outputs/t3955
    exec diff ../outputs/t3955 ../golden/t3955 >/dev/null 2>&1 ;;
  p3956) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.835     > ../outputs/t3956
    exec diff ../outputs/t3956 ../golden/t3956 >/dev/null 2>&1 ;;
  p3957) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.838     > ../outputs/t3957
    exec diff ../outputs/t3957 ../golden/t3957 >/dev/null 2>&1 ;;
  p3958) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.839     > ../outputs/t3958
    exec diff ../outputs/t3958 ../golden/t3958 >/dev/null 2>&1 ;;
  p3959) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.84     > ../outputs/t3959
    exec diff ../outputs/t3959 ../golden/t3959 >/dev/null 2>&1 ;;
  p3960) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.841     > ../outputs/t3960
    exec diff ../outputs/t3960 ../golden/t3960 >/dev/null 2>&1 ;;
  p3961) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.842     > ../outputs/t3961
    exec diff ../outputs/t3961 ../golden/t3961 >/dev/null 2>&1 ;;
  p3962) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.844     > ../outputs/t3962
    exec diff ../outputs/t3962 ../golden/t3962 >/dev/null 2>&1 ;;
  p3963) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.845     > ../outputs/t3963
    exec diff ../outputs/t3963 ../golden/t3963 >/dev/null 2>&1 ;;
  p3964) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.846     > ../outputs/t3964
    exec diff ../outputs/t3964 ../golden/t3964 >/dev/null 2>&1 ;;
  p3965) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.847     > ../outputs/t3965
    exec diff ../outputs/t3965 ../golden/t3965 >/dev/null 2>&1 ;;
  p3966) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.848     > ../outputs/t3966
    exec diff ../outputs/t3966 ../golden/t3966 >/dev/null 2>&1 ;;
  p3967) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.849      > ../outputs/t3967
    exec diff ../outputs/t3967 ../golden/t3967 >/dev/null 2>&1 ;;
  p3968) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.850     > ../outputs/t3968
    exec diff ../outputs/t3968 ../golden/t3968 >/dev/null 2>&1 ;;
  p3969) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.852     > ../outputs/t3969
    exec diff ../outputs/t3969 ../golden/t3969 >/dev/null 2>&1 ;;
  p3970) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.853     > ../outputs/t3970
    exec diff ../outputs/t3970 ../golden/t3970 >/dev/null 2>&1 ;;
  p3971) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.854     > ../outputs/t3971
    exec diff ../outputs/t3971 ../golden/t3971 >/dev/null 2>&1 ;;
  p3972) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.856     > ../outputs/t3972
    exec diff ../outputs/t3972 ../golden/t3972 >/dev/null 2>&1 ;;
  p3973) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.857     > ../outputs/t3973
    exec diff ../outputs/t3973 ../golden/t3973 >/dev/null 2>&1 ;;
  p3974) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.859     > ../outputs/t3974
    exec diff ../outputs/t3974 ../golden/t3974 >/dev/null 2>&1 ;;
  p3975) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.86     > ../outputs/t3975
    exec diff ../outputs/t3975 ../golden/t3975 >/dev/null 2>&1 ;;
  p3976) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.861     > ../outputs/t3976
    exec diff ../outputs/t3976 ../golden/t3976 >/dev/null 2>&1 ;;
  p3977) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.863     > ../outputs/t3977
    exec diff ../outputs/t3977 ../golden/t3977 >/dev/null 2>&1 ;;
  p3978) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.867     > ../outputs/t3978
    exec diff ../outputs/t3978 ../golden/t3978 >/dev/null 2>&1 ;;
  p3979) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.868     > ../outputs/t3979
    exec diff ../outputs/t3979 ../golden/t3979 >/dev/null 2>&1 ;;
  p3980) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.869     > ../outputs/t3980
    exec diff ../outputs/t3980 ../golden/t3980 >/dev/null 2>&1 ;;
  p3981) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.870     > ../outputs/t3981
    exec diff ../outputs/t3981 ../golden/t3981 >/dev/null 2>&1 ;;
  p3982) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.870.noeof     > ../outputs/t3982
    exec diff ../outputs/t3982 ../golden/t3982 >/dev/null 2>&1 ;;
  p3983) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.873     > ../outputs/t3983
    exec diff ../outputs/t3983 ../golden/t3983 >/dev/null 2>&1 ;;
  p3984) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.874     > ../outputs/t3984
    exec diff ../outputs/t3984 ../golden/t3984 >/dev/null 2>&1 ;;
  p3985) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.877      > ../outputs/t3985
    exec diff ../outputs/t3985 ../golden/t3985 >/dev/null 2>&1 ;;
  p3986) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.878     > ../outputs/t3986
    exec diff ../outputs/t3986 ../golden/t3986 >/dev/null 2>&1 ;;
  p3987) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.879     > ../outputs/t3987
    exec diff ../outputs/t3987 ../golden/t3987 >/dev/null 2>&1 ;;
  p3988) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.881     > ../outputs/t3988
    exec diff ../outputs/t3988 ../golden/t3988 >/dev/null 2>&1 ;;
  p3989) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.882     > ../outputs/t3989
    exec diff ../outputs/t3989 ../golden/t3989 >/dev/null 2>&1 ;;
  p3990) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.883     > ../outputs/t3990
    exec diff ../outputs/t3990 ../golden/t3990 >/dev/null 2>&1 ;;
  p3991) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.884     > ../outputs/t3991
    exec diff ../outputs/t3991 ../golden/t3991 >/dev/null 2>&1 ;;
  p3992) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.885     > ../outputs/t3992
    exec diff ../outputs/t3992 ../golden/t3992 >/dev/null 2>&1 ;;
  p3993) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.885.noeof     > ../outputs/t3993
    exec diff ../outputs/t3993 ../golden/t3993 >/dev/null 2>&1 ;;
  p3994) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.886     > ../outputs/t3994
    exec diff ../outputs/t3994 ../golden/t3994 >/dev/null 2>&1 ;;
  p3995) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.887     > ../outputs/t3995
    exec diff ../outputs/t3995 ../golden/t3995 >/dev/null 2>&1 ;;
  p3996) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.889     > ../outputs/t3996
    exec diff ../outputs/t3996 ../golden/t3996 >/dev/null 2>&1 ;;
  p3997) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.890     > ../outputs/t3997
    exec diff ../outputs/t3997 ../golden/t3997 >/dev/null 2>&1 ;;
  p3998) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.891     > ../outputs/t3998
    exec diff ../outputs/t3998 ../golden/t3998 >/dev/null 2>&1 ;;
  p3999) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.893     > ../outputs/t3999
    exec diff ../outputs/t3999 ../golden/t3999 >/dev/null 2>&1 ;;
  p4000) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.894     > ../outputs/t4000
    exec diff ../outputs/t4000 ../golden/t4000 >/dev/null 2>&1 ;;
  p4001) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.897     > ../outputs/t4001
    exec diff ../outputs/t4001 ../golden/t4001 >/dev/null 2>&1 ;;
  p4002) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.899     > ../outputs/t4002
    exec diff ../outputs/t4002 ../golden/t4002 >/dev/null 2>&1 ;;
  p4003) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.90     > ../outputs/t4003
    exec diff ../outputs/t4003 ../golden/t4003 >/dev/null 2>&1 ;;
  p4004) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.900     > ../outputs/t4004
    exec diff ../outputs/t4004 ../golden/t4004 >/dev/null 2>&1 ;;
  p4005) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.901     > ../outputs/t4005
    exec diff ../outputs/t4005 ../golden/t4005 >/dev/null 2>&1 ;;
  p4006) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.902     > ../outputs/t4006
    exec diff ../outputs/t4006 ../golden/t4006 >/dev/null 2>&1 ;;
  p4007) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.907     > ../outputs/t4007
    exec diff ../outputs/t4007 ../golden/t4007 >/dev/null 2>&1 ;;
  p4008) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.908     > ../outputs/t4008
    exec diff ../outputs/t4008 ../golden/t4008 >/dev/null 2>&1 ;;
  p4009) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.909     > ../outputs/t4009
    exec diff ../outputs/t4009 ../golden/t4009 >/dev/null 2>&1 ;;
  p4010) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.91     > ../outputs/t4010
    exec diff ../outputs/t4010 ../golden/t4010 >/dev/null 2>&1 ;;
  p4011) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.911     > ../outputs/t4011
    exec diff ../outputs/t4011 ../golden/t4011 >/dev/null 2>&1 ;;
  p4012) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.912     > ../outputs/t4012
    exec diff ../outputs/t4012 ../golden/t4012 >/dev/null 2>&1 ;;
  p4013) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.916     > ../outputs/t4013
    exec diff ../outputs/t4013 ../golden/t4013 >/dev/null 2>&1 ;;
  p4014) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.917     > ../outputs/t4014
    exec diff ../outputs/t4014 ../golden/t4014 >/dev/null 2>&1 ;;
  p4015) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.918     > ../outputs/t4015
    exec diff ../outputs/t4015 ../golden/t4015 >/dev/null 2>&1 ;;
  p4016) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.919     > ../outputs/t4016
    exec diff ../outputs/t4016 ../golden/t4016 >/dev/null 2>&1 ;;
  p4017) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.921     > ../outputs/t4017
    exec diff ../outputs/t4017 ../golden/t4017 >/dev/null 2>&1 ;;
  p4018) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.925      > ../outputs/t4018
    exec diff ../outputs/t4018 ../golden/t4018 >/dev/null 2>&1 ;;
  p4019) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.928     > ../outputs/t4019
    exec diff ../outputs/t4019 ../golden/t4019 >/dev/null 2>&1 ;;
  p4020) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.929     > ../outputs/t4020
    exec diff ../outputs/t4020 ../golden/t4020 >/dev/null 2>&1 ;;
  p4021) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.931     > ../outputs/t4021
    exec diff ../outputs/t4021 ../golden/t4021 >/dev/null 2>&1 ;;
  p4022) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.932     > ../outputs/t4022
    exec diff ../outputs/t4022 ../golden/t4022 >/dev/null 2>&1 ;;
  p4023) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.934     > ../outputs/t4023
    exec diff ../outputs/t4023 ../golden/t4023 >/dev/null 2>&1 ;;
  p4024) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.935     > ../outputs/t4024
    exec diff ../outputs/t4024 ../golden/t4024 >/dev/null 2>&1 ;;
  p4025) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.936     > ../outputs/t4025
    exec diff ../outputs/t4025 ../golden/t4025 >/dev/null 2>&1 ;;
  p4026) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.938     > ../outputs/t4026
    exec diff ../outputs/t4026 ../golden/t4026 >/dev/null 2>&1 ;;
  p4027) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.939     > ../outputs/t4027
    exec diff ../outputs/t4027 ../golden/t4027 >/dev/null 2>&1 ;;
  p4028) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.940     > ../outputs/t4028
    exec diff ../outputs/t4028 ../golden/t4028 >/dev/null 2>&1 ;;
  p4029) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.941     > ../outputs/t4029
    exec diff ../outputs/t4029 ../golden/t4029 >/dev/null 2>&1 ;;
  p4030) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.943     > ../outputs/t4030
    exec diff ../outputs/t4030 ../golden/t4030 >/dev/null 2>&1 ;;
  p4031) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.946     > ../outputs/t4031
    exec diff ../outputs/t4031 ../golden/t4031 >/dev/null 2>&1 ;;
  p4032) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.947     > ../outputs/t4032
    exec diff ../outputs/t4032 ../golden/t4032 >/dev/null 2>&1 ;;
  p4033) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.948     > ../outputs/t4033
    exec diff ../outputs/t4033 ../golden/t4033 >/dev/null 2>&1 ;;
  p4034) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.95     > ../outputs/t4034
    exec diff ../outputs/t4034 ../golden/t4034 >/dev/null 2>&1 ;;
  p4035) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.950     > ../outputs/t4035
    exec diff ../outputs/t4035 ../golden/t4035 >/dev/null 2>&1 ;;
  p4036) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.951     > ../outputs/t4036
    exec diff ../outputs/t4036 ../golden/t4036 >/dev/null 2>&1 ;;
  p4037) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.952     > ../outputs/t4037
    exec diff ../outputs/t4037 ../golden/t4037 >/dev/null 2>&1 ;;
  p4038) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.956     > ../outputs/t4038
    exec diff ../outputs/t4038 ../golden/t4038 >/dev/null 2>&1 ;;
  p4039) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.959     > ../outputs/t4039
    exec diff ../outputs/t4039 ../golden/t4039 >/dev/null 2>&1 ;;
  p4040) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.963     > ../outputs/t4040
    exec diff ../outputs/t4040 ../golden/t4040 >/dev/null 2>&1 ;;
  p4041) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.965     > ../outputs/t4041
    exec diff ../outputs/t4041 ../golden/t4041 >/dev/null 2>&1 ;;
  p4042) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.967     > ../outputs/t4042
    exec diff ../outputs/t4042 ../golden/t4042 >/dev/null 2>&1 ;;
  p4043) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.970     > ../outputs/t4043
    exec diff ../outputs/t4043 ../golden/t4043 >/dev/null 2>&1 ;;
  p4044) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.972     > ../outputs/t4044
    exec diff ../outputs/t4044 ../golden/t4044 >/dev/null 2>&1 ;;
  p4045) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.975     > ../outputs/t4045
    exec diff ../outputs/t4045 ../golden/t4045 >/dev/null 2>&1 ;;
  p4046) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.976     > ../outputs/t4046
    exec diff ../outputs/t4046 ../golden/t4046 >/dev/null 2>&1 ;;
  p4047) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.977     > ../outputs/t4047
    exec diff ../outputs/t4047 ../golden/t4047 >/dev/null 2>&1 ;;
  p4048) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.979     > ../outputs/t4048
    exec diff ../outputs/t4048 ../golden/t4048 >/dev/null 2>&1 ;;
  p4049) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.980     > ../outputs/t4049
    exec diff ../outputs/t4049 ../golden/t4049 >/dev/null 2>&1 ;;
  p4050) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.983     > ../outputs/t4050
    exec diff ../outputs/t4050 ../golden/t4050 >/dev/null 2>&1 ;;
  p4051) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.985     > ../outputs/t4051
    exec diff ../outputs/t4051 ../golden/t4051 >/dev/null 2>&1 ;;
  p4052) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.986     > ../outputs/t4052
    exec diff ../outputs/t4052 ../golden/t4052 >/dev/null 2>&1 ;;
  p4053) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.988     > ../outputs/t4053
    exec diff ../outputs/t4053 ../golden/t4053 >/dev/null 2>&1 ;;
  p4054) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.990     > ../outputs/t4054
    exec diff ../outputs/t4054 ../golden/t4054 >/dev/null 2>&1 ;;
  p4055) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.997     > ../outputs/t4055
    exec diff ../outputs/t4055 ../golden/t4055 >/dev/null 2>&1 ;;
  p4056) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/uslin.998     > ../outputs/t4056
    exec diff ../outputs/t4056 ../golden/t4056 >/dev/null 2>&1 ;;
  p4057) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4057
    exec diff ../outputs/t4057 ../golden/t4057 >/dev/null 2>&1 ;;
  p4058) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4058
    exec diff ../outputs/t4058 ../golden/t4058 >/dev/null 2>&1 ;;
  p4059) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4059
    exec diff ../outputs/t4059 ../golden/t4059 >/dev/null 2>&1 ;;
  p4060) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4060
    exec diff ../outputs/t4060 ../golden/t4060 >/dev/null 2>&1 ;;
  p4061) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4061
    exec diff ../outputs/t4061 ../golden/t4061 >/dev/null 2>&1 ;;
  p4062) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4062
    exec diff ../outputs/t4062 ../golden/t4062 >/dev/null 2>&1 ;;
  p4063) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4063
    exec diff ../outputs/t4063 ../golden/t4063 >/dev/null 2>&1 ;;
  p4064) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4064
    exec diff ../outputs/t4064 ../golden/t4064 >/dev/null 2>&1 ;;
  p4065) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4065
    exec diff ../outputs/t4065 ../golden/t4065 >/dev/null 2>&1 ;;
  p4066) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4066
    exec diff ../outputs/t4066 ../golden/t4066 >/dev/null 2>&1 ;;
  p4067) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4067
    exec diff ../outputs/t4067 ../golden/t4067 >/dev/null 2>&1 ;;
  p4068) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4068
    exec diff ../outputs/t4068 ../golden/t4068 >/dev/null 2>&1 ;;
  p4069) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4069
    exec diff ../outputs/t4069 ../golden/t4069 >/dev/null 2>&1 ;;
  p4070) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4070
    exec diff ../outputs/t4070 ../golden/t4070 >/dev/null 2>&1 ;;
  p4071) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4071
    exec diff ../outputs/t4071 ../golden/t4071 >/dev/null 2>&1 ;;
  p4072) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4072
    exec diff ../outputs/t4072 ../golden/t4072 >/dev/null 2>&1 ;;
  p4073) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4073
    exec diff ../outputs/t4073 ../golden/t4073 >/dev/null 2>&1 ;;
  p4074) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4074
    exec diff ../outputs/t4074 ../golden/t4074 >/dev/null 2>&1 ;;
  p4075) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4075
    exec diff ../outputs/t4075 ../golden/t4075 >/dev/null 2>&1 ;;
  p4076) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4076
    exec diff ../outputs/t4076 ../golden/t4076 >/dev/null 2>&1 ;;
  p4077) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4077
    exec diff ../outputs/t4077 ../golden/t4077 >/dev/null 2>&1 ;;
  p4078) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4078
    exec diff ../outputs/t4078 ../golden/t4078 >/dev/null 2>&1 ;;
  p4079) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4079
    exec diff ../outputs/t4079 ../golden/t4079 >/dev/null 2>&1 ;;
  p4080) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4080
    exec diff ../outputs/t4080 ../golden/t4080 >/dev/null 2>&1 ;;
  p4081) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4081
    exec diff ../outputs/t4081 ../golden/t4081 >/dev/null 2>&1 ;;
  p4082) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4082
    exec diff ../outputs/t4082 ../golden/t4082 >/dev/null 2>&1 ;;
  p4083) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4083
    exec diff ../outputs/t4083 ../golden/t4083 >/dev/null 2>&1 ;;
  p4084) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4084
    exec diff ../outputs/t4084 ../golden/t4084 >/dev/null 2>&1 ;;
  p4085) timeout -s 9 2 ../source/print_tokens2.exe ../inputs/garbage/nothing     > ../outputs/t4085
    exec diff ../outputs/t4085 ../golden/t4085 >/dev/null 2>&1 ;;
  p4086) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4086
    exec diff ../outputs/t4086 ../golden/t4086 >/dev/null 2>&1 ;;
  p4087) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4087
    exec diff ../outputs/t4087 ../golden/t4087 >/dev/null 2>&1 ;;
  p4088) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4088
    exec diff ../outputs/t4088 ../golden/t4088 >/dev/null 2>&1 ;;
  p4089) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4089
    exec diff ../outputs/t4089 ../golden/t4089 >/dev/null 2>&1 ;;
  p4090) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4090
    exec diff ../outputs/t4090 ../golden/t4090 >/dev/null 2>&1 ;;
  p4091) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4091
    exec diff ../outputs/t4091 ../golden/t4091 >/dev/null 2>&1 ;;
  p4092) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4092
    exec diff ../outputs/t4092 ../golden/t4092 >/dev/null 2>&1 ;;
  p4093) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4093
    exec diff ../outputs/t4093 ../golden/t4093 >/dev/null 2>&1 ;;
  p4094) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4094
    exec diff ../outputs/t4094 ../golden/t4094 >/dev/null 2>&1 ;;
  p4095) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4095
    exec diff ../outputs/t4095 ../golden/t4095 >/dev/null 2>&1 ;;
  p4096) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4096
    exec diff ../outputs/t4096 ../golden/t4096 >/dev/null 2>&1 ;;
  p4097) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4097
    exec diff ../outputs/t4097 ../golden/t4097 >/dev/null 2>&1 ;;
  p4098) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4098
    exec diff ../outputs/t4098 ../golden/t4098 >/dev/null 2>&1 ;;
  p4099) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4099
    exec diff ../outputs/t4099 ../golden/t4099 >/dev/null 2>&1 ;;
  p4100) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4100
    exec diff ../outputs/t4100 ../golden/t4100 >/dev/null 2>&1 ;;
  p4101) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4101
    exec diff ../outputs/t4101 ../golden/t4101 >/dev/null 2>&1 ;;
  p4102) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4102
    exec diff ../outputs/t4102 ../golden/t4102 >/dev/null 2>&1 ;;
  p4103) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4103
    exec diff ../outputs/t4103 ../golden/t4103 >/dev/null 2>&1 ;;
  p4104) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4104
    exec diff ../outputs/t4104 ../golden/t4104 >/dev/null 2>&1 ;;
  p4105) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4105
    exec diff ../outputs/t4105 ../golden/t4105 >/dev/null 2>&1 ;;
  p4106) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4106
    exec diff ../outputs/t4106 ../golden/t4106 >/dev/null 2>&1 ;;
  p4107) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4107
    exec diff ../outputs/t4107 ../golden/t4107 >/dev/null 2>&1 ;;
  p4108) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4108
    exec diff ../outputs/t4108 ../golden/t4108 >/dev/null 2>&1 ;;
  p4109) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4109
    exec diff ../outputs/t4109 ../golden/t4109 >/dev/null 2>&1 ;;
  p4110) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4110
    exec diff ../outputs/t4110 ../golden/t4110 >/dev/null 2>&1 ;;
  p4111) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4111
    exec diff ../outputs/t4111 ../golden/t4111 >/dev/null 2>&1 ;;
  p4112) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4112
    exec diff ../outputs/t4112 ../golden/t4112 >/dev/null 2>&1 ;;
  p4113) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4113
    exec diff ../outputs/t4113 ../golden/t4113 >/dev/null 2>&1 ;;
  p4114) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4114
    exec diff ../outputs/t4114 ../golden/t4114 >/dev/null 2>&1 ;;
  p4115) timeout -s 9 2 ../source/print_tokens2.exe one doesntliketwo     > ../outputs/t4115
    exec diff ../outputs/t4115 ../golden/t4115 >/dev/null 2>&1 ;;
  *) exit 2 ;;
esac
